(* Content-type: application/mathematica *)

(*** Wolfram Notebook File ***)
(* http://www.wolfram.com/nb *)

(* CreatedBy='Mathematica 7.0' *)

(*CacheID: 234*)
(* Internal cache information:
NotebookFileLineBreakTest
NotebookFileLineBreakTest
NotebookDataPosition[       145,          7]
NotebookDataLength[     12550,        263]
NotebookOptionsPosition[     11585,        229]
NotebookOutlinePosition[     12367,        258]
CellTagsIndexPosition[     12324,        255]
WindowFrame->Normal*)

(* Beginning of Notebook Content *)
Notebook[{
Cell[TextData[StyleBox["\nINTRODUCTION TO THE NOTEBOOKS\n",
 FontVariations->{"Underline"->False}]], "Text",
 CellChangeTimes->{{3.5746766040814667`*^9, 3.574676774728005*^9}, {
  3.5756107800094137`*^9, 3.575610859334268*^9}, {3.57572698351598*^9, 
  3.5757270134368324`*^9}, {3.5757274460567923`*^9, 3.575727469020033*^9}, {
  3.5765051771240854`*^9, 3.576505182225294*^9}},
 FontSize->36,
 FontWeight->"Bold",
 FontVariations->{"Underline"->True},
 FontColor->RGBColor[0, 0, 1],
 Background->RGBColor[1, 0.9, 0.8]],

Cell[TextData[{
 "This introduction concerns some simple general remarks on the notebooks  \n\
contained in the  List of Notebooks:\n\na) The Goal\nb) The tools and the \
style\nc) Reliability\nd) Evaluation time and warnings (clock time referred)\n\
e) Recommended readings and tutorial sites\nf) Link to Mathgroup\n\n",
 StyleBox["a) The Goal",
  Background->RGBColor[0.88, 1, 0.88]],
 "\n\nThe reader is invited to take advantage of the capabilities offered by\n\
this Computer Aided System, that is, ",
 StyleBox["Mathematica,",
  FontSlant->"Italic"],
 "\n~to solve the equations governing the systems under examination~.\n",
 StyleBox["\n",
  Background->RGBColor[0.88, 1, 0.88]],
 "It is used today in all of the world\[CloseCurlyQuote]s 50 largest \
universities. ",
 StyleBox["\n",
  Background->RGBColor[0.88, 1, 0.88]],
 "\n\n",
 StyleBox["b) The tools and  the style",
  Background->RGBColor[0.88, 1, 0.88]],
 "\n\nProbably, the command NDSolve has been used most frequently\nand some \
examples show how to sail into its various options.\nReaders having little \
experience with the ODE or PDE, should\nconsult the relevant tutorials in the \
Help.\n\nWe have avoided to force the reader to decrypt one-line commands \
which,\nalthough very elegant, are sometimes counter-intuitive.\nAll comments \
are intended to help the reader.\n\nThe style (combination of backgrounds and \
textcolors) is planned to\nunderline the most important information and at \
the same time to\ncreate a mental order for the reader.\n\n",
 StyleBox["c) Reliability",
  Background->RGBColor[0.88, 1, 0.88]],
 "\n\nEach notebook has been tested with:\n\n     -Version Number: 9.0.1.0\n  \
   -Platform: Linux x86 (64-bit)\n     \n      -Version Number: 8.0\n     \
-Platform: Microsoft Windows-x86 - Windows 7 (64 bit)\n     \n     If you don\
\[CloseCurlyQuote]t own a ",
 StyleBox["Mathematica",
  FontSlant->"Italic"],
 " license you can however interact with the \n     notebooks using the CDF \
player  (The download and information for the use can be found at the link \
http://www.wolfram.com/cdf-player/.)\n \n ",
 StyleBox["d) Evaluation time and warnings",
  Background->RGBColor[0.88, 1, 0.88]],
 "\n\n  1) most of the notebook can be evaluated istantaneously or in a \
couple of minutes. \n  For helping the reader we reported the ",
 StyleBox["evaluation time",
  FontWeight->"Bold"],
 " at the beginning\n  of each notebook; this way it is possible to avoid a \
long waiting if you are\n  not specifically interested on the exact question.\
\n  1.1) Some of them may require many hours but a clear warning is reported \
in the\n         Head of the nb\n  \n 2) certain ",
 StyleBox["Plot3D",
  FontWeight->"Bold"],
 " may not appear after the evaluation for several reason, e.g. due to their \
big size.\n In this case, the problem can be overtaken, clicking on them. In \
very few cases when in the notebook\n several plots are generated with the \
same command you should be careful, because the quality of the \n output \
depends upon you computer setup.\n\n3) The files with extension  ",
 StyleBox[".mx",
  FontWeight->"Bold"],
 " are useful but machine-dependent. The reader is invited to\n     insert  \
the name  Mydir when appropriate, e.g. \n ",
 StyleBox["   << \[OpenCurlyDoubleQuote]Mydir/Ch6-1-Sphere... .mx\
\[CloseCurlyDoubleQuote]",
  Background->RGBColor[0.88, 1, 0.88]],
 "       or\n   ",
 StyleBox[" ",
  Background->RGBColor[1, 0.925, 0.925]],
 StyleBox["DumpSave[\[OpenCurlyDoubleQuote]Mydir/Ch6-1-Sphere... .mx\
\[CloseCurlyDoubleQuote]",
  Background->RGBColor[0.88, 1, 0.88]],
 ", {\[OpenCurlyDoubleQuote]Global`\[CloseCurlyDoubleQuote], Subscript}]\n\n  \
\n",
 StyleBox["e) Recommended readings and tutorial sites",
  Background->RGBColor[0.88, 1, 0.88]],
 "\n  \nIf the reader is interested in finding further informations dealing \
with this software, we suggest:\n\n1)  Mathematica for Scientists and \
Engineers by Thomas B. Bahder\n\n2)  Mathematica Navigator: Mathematics, \
Statistics and Graphics by Heikki Ruskeepaa \n\nOr, for various applications \
related to Physics:\n\n3) Mathematica for Physics,  by Robert L. Zimmerman & \
Fredrick I. Olness (Author) \n\n4) A Physicist\[CloseCurlyQuote]s Guide to \
Mathematica,  by Patrick T. Tam\n     ",
 StyleBox["\n     ",
  FontColor->RGBColor[1, 0, 0]],
 " An extended bibliography can be found at http://www.wolfram.com/books/\n \n\
  ",
 StyleBox["f) Link to Mathgroup",
  Background->RGBColor[0.88, 1, 0.88]],
 "\n  \nWe suggest the reader to click on \
http://www.xmarks.com/site/math.fullerton.edu/mathews/N250L/\
MathematicaTutorials.html. \nThis TUTORIAL may help you in getting along with \
the ",
 StyleBox["Mathematica",
  FontSlant->"Italic"],
 StyleBox[" software.\n\n",
  FontColor->RGBColor[1, 0, 0]],
 "A MathGroup exists where it is possible to get useful information from \
scholars of ",
 StyleBox["Mathematica:",
  FontSlant->"Italic"],
 StyleBox[" ",
  FontColor->RGBColor[1, 0, 0]],
 StyleBox["http://forums.wolfram.com/mathgroup/",
  Background->RGBColor[0.94, 0.91, 0.88]],
 StyleBox["\n\n",
  FontColor->RGBColor[1, 0, 0]],
 StyleBox["The archive of files is available with many helpful examples in \
comp.soft-sys.math.mathematica.*",
  Background->RGBColor[0.94, 0.91, 0.88]],
 StyleBox["\n\n",
  FontColor->RGBColor[1, 0, 0]],
 StyleBox["MathGroup",
  FontSlant->"Italic",
  Background->RGBColor[0.94, 0.91, 0.88]],
 " has also a forum. If you want to get subscribed send an e-mail to \
mathgroup@smc.vnet.net \nand ask to be added to the mailing list. ",
 StyleBox["Make sure to send a valid email address.",
  FontColor->RGBColor[1, 0, 0],
  Background->RGBColor[0.94, 0.91, 0.88]]
}], "Text",
 CellChangeTimes->{{3.4916488885*^9, 3.4916489540625*^9}, {
   3.491649038890625*^9, 3.491649040640625*^9}, {3.4916491686875*^9, 
   3.49164917021875*^9}, {3.4916507385*^9, 3.491650741234375*^9}, 
   3.491652965125*^9, {3.491738708671875*^9, 3.491738729828125*^9}, {
   3.4917387999375*^9, 3.491738802390625*^9}, {3.4917388381875*^9, 
   3.491738955265625*^9}, {3.491739059078125*^9, 3.491739198890625*^9}, {
   3.49173927225*^9, 3.491739287234375*^9}, {3.49173932959375*^9, 
   3.4917393638125*^9}, {3.491739417734375*^9, 3.491739425625*^9}, {
   3.4917409141875*^9, 3.491740937015625*^9}, {3.4938751373125*^9, 
   3.4938751373125*^9}, 3.493875177640625*^9, {3.493875210140625*^9, 
   3.493875233625*^9}, {3.5064243503349543`*^9, 3.506424454695549*^9}, {
   3.5064244950067596`*^9, 3.506424538844447*^9}, {3.506424577820396*^9, 
   3.506424578232539*^9}, {3.506424609193211*^9, 3.506424670927354*^9}, {
   3.5064247364157677`*^9, 3.50642473699634*^9}, {3.5064247841367607`*^9, 
   3.506424900679058*^9}, {3.506424931558351*^9, 3.506424958458496*^9}, {
   3.506424993353549*^9, 3.506425055317256*^9}, {3.506425118539771*^9, 
   3.5064253154970217`*^9}, {3.5064253514649487`*^9, 3.506425495323896*^9}, {
   3.506432219496532*^9, 3.5064322911925383`*^9}, {3.506432352002954*^9, 
   3.506432354919997*^9}, {3.5064324499350967`*^9, 3.506432451629615*^9}, {
   3.506432523231414*^9, 3.506432526264495*^9}, {3.5064330900439157`*^9, 
   3.506433094857142*^9}, {3.506434229445178*^9, 3.506434247908168*^9}, {
   3.506575065226345*^9, 3.506575069532022*^9}, {3.506602793432601*^9, 
   3.506602980904729*^9}, 3.50660303534589*^9, {3.50744693578125*^9, 
   3.5074469613125*^9}, {3.529303419625*^9, 3.529303461234375*^9}, {
   3.575609832884816*^9, 3.5756099434804153`*^9}, {3.575610000780587*^9, 
   3.575610187011908*^9}, {3.575610220791617*^9, 3.57561026246139*^9}, {
   3.575610562030785*^9, 3.575610757361416*^9}, 3.575610803337769*^9, {
   3.575610872711893*^9, 3.5756108744399014`*^9}, {3.575687526740204*^9, 
   3.5756876330430117`*^9}, {3.575726975981167*^9, 3.5757269769639683`*^9}, {
   3.5757270581777115`*^9, 3.5757274306595654`*^9}, {3.5757274726548395`*^9, 
   3.575727508644102*^9}, {3.575951058576762*^9, 3.5759510761443977`*^9}, {
   3.575951130725546*^9, 3.575951268981447*^9}, {3.575951364545027*^9, 
   3.5759514437288513`*^9}, {3.575951490621222*^9, 3.575951520210684*^9}, {
   3.575951562123517*^9, 3.5759516117845383`*^9}, {3.575951697682302*^9, 
   3.575951770862379*^9}, {3.575951806794828*^9, 3.575951813884076*^9}, {
   3.5762164495934887`*^9, 3.576216475737913*^9}, {3.576504423740673*^9, 
   3.5765044456587114`*^9}, {3.5765045046892157`*^9, 3.576504708222554*^9}, {
   3.5765047436935835`*^9, 3.576504786110009*^9}, {3.5765048217570477`*^9, 
   3.5765050331181374`*^9}, {3.576505115285577*^9, 3.5765051612432575`*^9}, {
   3.57666042024914*^9, 3.576660458199232*^9}, {3.5766604954204073`*^9, 
   3.576660646705608*^9}, {3.576660678298177*^9, 3.576660859571439*^9}, {
   3.57666093392456*^9, 3.576660937086733*^9}, {3.576661004104444*^9, 
   3.5766610500364723`*^9}, {3.57691527307656*^9, 3.576915283238463*^9}, {
   3.576915742996558*^9, 3.576915766417707*^9}, {3.576915922236342*^9, 
   3.5769159386035213`*^9}, {3.57711509612217*^9, 3.5771151088428974`*^9}, {
   3.5777028274243193`*^9, 3.577703100088872*^9}, {3.5777031509735203`*^9, 
   3.57770321526226*^9}, {3.5777032479473953`*^9, 3.577703289085408*^9}, 
   3.577703358796833*^9, {3.577703399463121*^9, 3.577703400720042*^9}, {
   3.577703538697524*^9, 3.5777035665738363`*^9}, {3.577703615120491*^9, 
   3.5777036174108143`*^9}, {3.5777036768582077`*^9, 3.5777036771919317`*^9}, 
   3.577703715606742*^9, {3.577703801497036*^9, 3.577703817784256*^9}, {
   3.577703852445216*^9, 3.5777038804094553`*^9}, {3.577870970377749*^9, 
   3.5778710046847887`*^9}, {3.577871057629637*^9, 3.577871232368279*^9}, {
   3.577871264988029*^9, 3.577871288840908*^9}, {3.5786530530490017`*^9, 
   3.578653054970014*^9}, {3.578653121957972*^9, 3.5786531228314342`*^9}, {
   3.578653173779529*^9, 3.578653178079657*^9}},
 FontSize->24,
 FontColor->RGBColor[0, 0, 1],
 Background->RGBColor[1, 1, 0.85]],

Cell[BoxData["$System"], "Input",
 CellChangeTimes->{{3.575610339224946*^9, 3.575610341926128*^9}}],

Cell[BoxData["$SystemID"], "Input",
 CellChangeTimes->{{3.5756104695875053`*^9, 3.5756104732693567`*^9}}],

Cell[BoxData["$Version"], "Input",
 CellChangeTimes->{{3.575610346377122*^9, 3.575610348476598*^9}}],

Cell[BoxData["$MachineType"], "Input",
 CellChangeTimes->{{3.575610361726802*^9, 3.575610369794757*^9}}],

Cell[BoxData["$OperatingSystem"], "Input",
 CellChangeTimes->{{3.575610380416401*^9, 3.575610385590098*^9}}],

Cell[BoxData["SystemInformation"], "Input",
 CellChangeTimes->{{3.5756103960649548`*^9, 3.575610404964237*^9}}]
},
ScreenStyleEnvironment->"Working",
PrintingStyleEnvironment->"Printout",
CellGrouping->Manual,
WindowSize->{1438, 813},
WindowMargins->{{0, Automatic}, {Automatic, 0}},
PrintingPageRange->{Automatic, Automatic},
PrintingOptions->{"Magnification"->1,
"PaperOrientation"->"Portrait",
"PaperSize"->{612, 792},
"PostScriptOutputFile":>"",
"PrintCellBrackets"->False,
"PrintMultipleHorizontalPages"->False,
"PrintRegistrationMarks"->True,
"PrintingMargins"->{{54, 54}, {72, 72}}},
CellLabelAutoDelete->True,
Magnification->1,
FrontEndVersion->"9.0 for Linux x86 (64-bit) (January 25, 2013)",
StyleDefinitions->"Default.nb"
]
(* End of Notebook Content *)

(* Internal cache information *)
(*CellTagsOutline
CellTagsIndex->{}
*)
(*CellTagsIndex
CellTagsIndex->{}
*)
(*NotebookFileOutline
Notebook[{
Cell[545, 20, 517, 10, 159, "Text"],
Cell[1065, 32, 9871, 177, 3034, "Text"],
Cell[10939, 211, 99, 1, 32, "Input"],
Cell[11041, 214, 105, 1, 32, "Input"],
Cell[11149, 217, 100, 1, 32, "Input"],
Cell[11252, 220, 104, 1, 32, "Input"],
Cell[11359, 223, 108, 1, 32, "Input"],
Cell[11470, 226, 111, 1, 32, "Input"]
}
]
*)

(* End of internal cache information *)
