(* Content-type: application/vnd.wolfram.mathematica *)

(*** Wolfram Notebook File ***)
(* http://www.wolfram.com/nb *)

(* CreatedBy='Mathematica 8.0' *)

(*CacheID: 234*)
(* Internal cache information:
NotebookFileLineBreakTest
NotebookFileLineBreakTest
NotebookDataPosition[       157,          7]
NotebookDataLength[    486592,      10234]
NotebookOptionsPosition[    472618,       9821]
NotebookOutlinePosition[    473011,       9838]
CellTagsIndexPosition[    472968,       9835]
WindowFrame->Normal*)

(* Beginning of Notebook Content *)
Notebook[{
Cell[TextData[StyleBox["Evaluation time\n\[CapitalDelta]t < 2 min",
 FontColor->RGBColor[0, 0, 1]]], "Text",
 CellChangeTimes->{{3.5749416987827597`*^9, 3.57494176969971*^9}, {
  3.574941802165905*^9, 3.574941866327519*^9}, {3.574943490448987*^9, 
  3.574943500939139*^9}, {3.575255844265176*^9, 3.575255848239403*^9}},
 FontSize->36,
 Background->RGBColor[1, 0.9, 0.8]],

Cell[TextData[{
 StyleBox["In the 3D case, the diamond cell of silicon is characterized by 3 \
basis of two atoms each.\n\nAccording to what we wrote in Section 2.2.1.5 to \
evaluate the susceptivity ",
  FontColor->RGBColor[0, 0, 1]],
 Cell[BoxData[
  FormBox[
   SubscriptBox["\[Chi]", "g"], TraditionalForm]],
  FontColor->RGBColor[0, 0, 1]],
 StyleBox[", we have to\ncalculate the unit cell scattering factor F(",
  FontColor->RGBColor[0, 0, 1]],
 StyleBox["g",
  FontWeight->"Bold",
  FontColor->RGBColor[0, 0, 1]],
 StyleBox["), based on the FourierTransform of the\nelectronic density \
\[Rho](",
  FontColor->RGBColor[0, 0, 1]],
 StyleBox["r",
  FontWeight->"Bold",
  FontColor->RGBColor[0, 0, 1]],
 StyleBox[") of the single silicon atom.\n\nFor representing in a clearer way \
the physics behind this calculations,\nwe begin considering simply a 1D cell \
with just two atoms of silicon.\n\nClearly we can consider different \
positions for the two atoms and compare the results we get. \nIn this case ",
  FontColor->RGBColor[0, 0, 1]],
 StyleBox["g ",
  FontWeight->"Bold",
  FontColor->RGBColor[0, 0, 1]],
 StyleBox[" is a scalar. Then in the next notebook \
(Chap2-1-2D-Polar-Rho-Susce-check.nb)\nwe will consider a more advanced \
situation in two dimensions.\n\nThe structure of the notebook is as follows:\n\
\n- Preliminary Definitions: we introduce useful quantities and constants;\n\n\
- Part I: we evaluate the above cited quantities considering the two atoms in \
the cell or around one node (@ -1/8",
  FontColor->RGBColor[0, 0, 1]],
 StyleBox["a",
  FontSlant->"Italic",
  FontColor->RGBColor[0, 0, 1]],
 StyleBox[" and +1/8",
  FontColor->RGBColor[0, 0, 1]],
 StyleBox["a",
  FontSlant->"Italic",
  FontColor->RGBColor[0, 0, 1]],
 StyleBox[" position) or inside the cell (@ +1/8",
  FontColor->RGBColor[0, 0, 1]],
 StyleBox["a",
  FontSlant->"Italic",
  FontColor->RGBColor[0, 0, 1]],
 StyleBox[" and +7/8",
  FontColor->RGBColor[0, 0, 1]],
 StyleBox["a",
  FontSlant->"Italic",
  FontColor->RGBColor[0, 0, 1]],
 StyleBox[" position),\nreminding that the coordinate of the j-th cell are 0 \
and ",
  FontColor->RGBColor[0, 0, 1]],
 StyleBox["a",
  FontSlant->"Italic",
  FontColor->RGBColor[0, 0, 1]],
 StyleBox[" for the considered cell;\n\n- Part II: we evaluate the above \
cited quantities considering the two atoms as a unique U-shaped electronic \
density;\n\n- Part III: we check the previous results calculating the Fourier \
coefficients of expansion by mean of the equation:\n\n",
  FontColor->RGBColor[0, 0, 1]],
 Cell[BoxData[
  FormBox[
   RowBox[{
    SubscriptBox["c", "n"], 
    StyleBox["  ",
     FontColor->RGBColor[1, 0, 0]], 
    StyleBox["=",
     FontColor->RGBColor[1, 0, 0]], 
    StyleBox[" ",
     FontColor->RGBColor[1, 0, 0]], 
    RowBox[{
     FractionBox["1", "L"], 
     StyleBox[" ",
      FontColor->RGBColor[1, 0, 0]], 
     RowBox[{
      SubscriptBox["F", "0"], 
      StyleBox["[",
       FontColor->RGBColor[1, 0, 0]], 
      RowBox[{
       StyleBox["n",
        FontColor->RGBColor[1, 0, 0]], 
       StyleBox[" ",
        FontColor->RGBColor[1, 0, 0]], 
       FractionBox[
        RowBox[{"2", " ", "\[Pi]"}], "L"]}], 
      StyleBox["]",
       FontColor->RGBColor[1, 0, 0]]}]}]}], TraditionalForm]],
  FontColor->RGBColor[0, 0, 1]]
}], "Text",
 CellChangeTimes->{{3.49778539303125*^9, 3.497785455890625*^9}, {
   3.49778633871875*^9, 3.497786388953125*^9}, {3.497786527234375*^9, 
   3.49778661515625*^9}, {3.49785659690625*^9, 3.49785661915625*^9}, {
   3.497877632046875*^9, 3.49787765253125*^9}, {3.49795909240625*^9, 
   3.497959230109375*^9}, {3.49795926353125*^9, 3.497959309984375*^9}, {
   3.497959346203125*^9, 3.497959376125*^9}, 3.49796052334375*^9, 
   3.497960754703125*^9, {3.4979610276875*^9, 3.49796110215625*^9}, {
   3.498106285*^9, 3.498106289875*^9}, {3.49810640334375*^9, 
   3.498106411421875*^9}, {3.4981151435*^9, 3.498115157859375*^9}, {
   3.49882848628125*^9, 3.498828487*^9}, {3.498828539921875*^9, 
   3.498828598578125*^9}, {3.498828658234375*^9, 3.49882867534375*^9}, {
   3.498831697578125*^9, 3.498831706359375*^9}, {3.498912272328125*^9, 
   3.498912312546875*^9}, {3.49891364478125*^9, 3.49891370509375*^9}, {
   3.553259738203125*^9, 3.553259926421875*^9}, {3.553259962046875*^9, 
   3.55325997528125*^9}, {3.553260014421875*^9, 3.55326001809375*^9}, {
   3.55326027565625*^9, 3.553260324890625*^9}, {3.553260362625*^9, 
   3.553260445953125*^9}, {3.55326047903125*^9, 3.55326065671875*^9}, {
   3.553261039640625*^9, 3.55326107021875*^9}, {3.553774510391384*^9, 
   3.55377462397139*^9}, {3.55377465931855*^9, 3.553774844985372*^9}, {
   3.553774891356955*^9, 3.553775190164221*^9}, 3.553783907589079*^9, {
   3.553784275529397*^9, 3.5537842894851007`*^9}, {3.553827985700789*^9, 
   3.553828009040845*^9}, {3.553828129654746*^9, 3.553828157169492*^9}, {
   3.574941962425593*^9, 3.574941962729019*^9}, {3.574945714109519*^9, 
   3.574945746304599*^9}, {3.574945811677092*^9, 3.574945971211494*^9}, {
   3.574946028016472*^9, 3.5749461021582003`*^9}, {3.5752558622982073`*^9, 
   3.5752558678305235`*^9}, {3.5752561659635754`*^9, 
   3.5752561715528955`*^9}, {3.575256785563015*^9, 3.5752573200785875`*^9}, {
   3.5752574036383667`*^9, 3.575257433751089*^9}},
 FontSize->24,
 Background->RGBColor[1, 1, 0.85]],

Cell[BoxData[
 RowBox[{
  RowBox[{"SetOptions", "[", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{
     "Plot", ",", "ListPlot", ",", "DiscretePlot", ",", "ContourPlot", ",", 
      "Plot3D"}], "}"}], ",", 
    RowBox[{"ImageSize", "\[Rule]", "700"}], ",", 
    RowBox[{"LabelStyle", "\[Rule]", 
     RowBox[{"(", 
      RowBox[{"FontFamily", "\[Rule]", "\"\<Helvetica\>\""}], ")"}]}], ",", 
    RowBox[{"AxesStyle", "\[Rule]", 
     RowBox[{"Directive", "[", 
      RowBox[{"20", ",", 
       RowBox[{"Thickness", "[", "0.005", "]"}], ",", "Blue"}], "]"}]}]}], 
   "]"}], ";"}]], "Input",
 CellChangeTimes->{{3.431404133265625*^9, 3.431404152625*^9}, {
   3.431404184828125*^9, 3.43140419784375*^9}, {3.431404229828125*^9, 
   3.431404286*^9}, {3.431404358734375*^9, 3.431404362015625*^9}, 
   3.43140449659375*^9, {3.431404585328125*^9, 3.431404586390625*^9}, {
   3.431404647765625*^9, 3.431404694953125*^9}, {3.43140617875*^9, 
   3.4314062495625*^9}, {3.431406282875*^9, 3.4314063513125*^9}, {
   3.43140679328125*^9, 3.43140680225*^9}, {3.4314068341875*^9, 
   3.431406876078125*^9}, {3.48396135521875*^9, 3.483961362359375*^9}, {
   3.48396582775*^9, 3.48396583034375*^9}, {3.4840494269375*^9, 
   3.48404942946875*^9}, {3.484104769703125*^9, 3.484104774828125*^9}, {
   3.484122942015625*^9, 3.48412294471875*^9}, {3.489318163125*^9, 
   3.48931816853125*^9}, {3.497696376359375*^9, 3.497696384640625*^9}, {
   3.497696431390625*^9, 3.497696435203125*^9}, {3.497789769765625*^9, 
   3.49778977328125*^9}, {3.498828771625*^9, 3.498828772171875*^9}, {
   3.498830949421875*^9, 3.498830953265625*^9}, 3.5750892780656548`*^9},
 FontSize->24,
 Background->GrayLevel[0.85]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Preliminary", " ", "Definitions"}]], "Text",
 CellChangeTimes->{{3.553775858737446*^9, 3.5537758682010927`*^9}, 
   3.553775900523551*^9, {3.55377598764578*^9, 3.553776019276904*^9}, 
   3.5750892780781717`*^9, {3.5751076077872753`*^9, 3.5751076981413517`*^9}, {
   3.5752560447476425`*^9, 3.5752560470887766`*^9}, {3.575256377680685*^9, 
   3.575256380479845*^9}},
 FontFamily->"Times New Roman",
 FontSize->36,
 FontColor->RGBColor[0, 0, 1],
 Background->RGBColor[1, 0.9, 0.8]],

Cell[BoxData[
 RowBox[{
  RowBox[{"Needs", "[", "\"\<Notation`\>\"", "]"}], "  "}]], "Input",
 CellChangeTimes->{
  3.3935991603113327`*^9, {3.499857585765625*^9, 3.4998575875*^9}, {
   3.499945519546875*^9, 3.499945521*^9}, 3.55210564625*^9, 
   3.5750892780658627`*^9},
 FontSize->24],

Cell[BoxData[
 RowBox[{
  RowBox[{"DynamicSymbolize", "[", 
   RowBox[{"f_", ",", "k_"}], "]"}], ":=", 
  RowBox[{"Symbolize", "[", 
   RowBox[{
    StyleBox["ParsedBoxWrapper",
     FontColor->RGBColor[1, 0, 0]], "[", 
    RowBox[{"SubscriptBox", "[", 
     RowBox[{"f", ",", "k"}], "]"}], "]"}], "]"}]}]], "Input",
 CellChangeTimes->{{3.55210539890625*^9, 3.552105403*^9}, {
   3.552105527421875*^9, 3.5521055556875*^9}, {3.552105629890625*^9, 
   3.552105639921875*^9}, 3.55247335309375*^9, 3.5750892780661716`*^9},
 FontSize->24],

Cell[BoxData[
 RowBox[{"DynamicSymbolize", "[", 
  RowBox[{"\"\<a\>\"", ",", "\"\<0\>\""}], "]"}]], "Input",
 CellChangeTimes->{{3.409561442890625*^9, 3.40956144328125*^9}, {
   3.433757607109375*^9, 3.433757629078125*^9}, {3.433836019828125*^9, 
   3.433836021421875*^9}, {3.433836066546875*^9, 3.43383607190625*^9}, {
   3.49759654940625*^9, 3.497596552953125*^9}, {3.49759662575*^9, 
   3.49759662609375*^9}, 3.575089278066414*^9},
 FontSize->24],

Cell[BoxData[
 RowBox[{"DynamicSymbolize", "[", 
  RowBox[{"\"\<width\>\"", ",", "\"\<at\>\""}], "]"}]], "Input",
 CellChangeTimes->{{3.409561442890625*^9, 3.40956144328125*^9}, {
   3.433757607109375*^9, 3.433757629078125*^9}, {3.433836019828125*^9, 
   3.433836021421875*^9}, {3.433836066546875*^9, 3.43383607190625*^9}, {
   3.49759654940625*^9, 3.497596552953125*^9}, {3.553248923953125*^9, 
   3.55324892759375*^9}, {3.553249008921875*^9, 3.5532490105625*^9}, 
   3.575089278066654*^9},
 FontSize->24],

Cell[BoxData[
 RowBox[{"DynamicSymbolize", "[", 
  RowBox[{"\"\<CG\>\"", ",", "\"\<1\>\""}], "]"}]], "Input",
 CellChangeTimes->{{3.409561442890625*^9, 3.40956144328125*^9}, {
   3.433757607109375*^9, 3.433757629078125*^9}, {3.433836019828125*^9, 
   3.433836021421875*^9}, {3.433836066546875*^9, 3.43383607190625*^9}, {
   3.49759654940625*^9, 3.497596552953125*^9}, {3.553248923953125*^9, 
   3.55324892759375*^9}, {3.553249008921875*^9, 3.5532490105625*^9}, {
   3.55325904046875*^9, 3.553259042859375*^9}, 3.55339862647843*^9, 
   3.553398759815813*^9, 3.553398801621751*^9, 3.575089278066834*^9},
 FontSize->24],

Cell[BoxData[
 RowBox[{"DynamicSymbolize", "[", 
  RowBox[{"\"\<CG\>\"", ",", "\"\<2\>\""}], "]"}]], "Input",
 CellChangeTimes->{{3.409561442890625*^9, 3.40956144328125*^9}, {
   3.433757607109375*^9, 3.433757629078125*^9}, {3.433836019828125*^9, 
   3.433836021421875*^9}, {3.433836066546875*^9, 3.43383607190625*^9}, {
   3.49759654940625*^9, 3.497596552953125*^9}, {3.553248923953125*^9, 
   3.55324892759375*^9}, {3.553249008921875*^9, 3.5532490105625*^9}, {
   3.55325904046875*^9, 3.553259042859375*^9}, {3.55339862647843*^9, 
   3.553398635398357*^9}, 3.553398762879931*^9, 3.5533988306189003`*^9, 
   3.575089278067068*^9},
 FontSize->24],

Cell[BoxData[
 RowBox[{"DynamicSymbolize", "[", 
  RowBox[{"\"\<CG\>\"", ",", "\"\<3\>\""}], "]"}]], "Input",
 CellChangeTimes->{{3.409561442890625*^9, 3.40956144328125*^9}, {
   3.433757607109375*^9, 3.433757629078125*^9}, {3.433836019828125*^9, 
   3.433836021421875*^9}, {3.433836066546875*^9, 3.43383607190625*^9}, {
   3.49759654940625*^9, 3.497596552953125*^9}, {3.553248923953125*^9, 
   3.55324892759375*^9}, {3.553249008921875*^9, 3.5532490105625*^9}, {
   3.55325904046875*^9, 3.553259042859375*^9}, {3.55339862647843*^9, 
   3.5533986546778593`*^9}, {3.5533988325395193`*^9, 3.553398834497785*^9}, 
   3.575089278067244*^9},
 FontSize->24],

Cell[BoxData[
 RowBox[{"DynamicSymbolize", "[", 
  RowBox[{"\"\<r\>\"", ",", "\"\<e\>\""}], "]"}]], "Input",
 CellChangeTimes->{{3.409561442890625*^9, 3.40956144328125*^9}, {
   3.433757607109375*^9, 3.433757629078125*^9}, {3.433836019828125*^9, 
   3.433836021421875*^9}, {3.433836066546875*^9, 3.43383607190625*^9}, {
   3.49759654940625*^9, 3.497596552953125*^9}, {3.55325156884375*^9, 
   3.553251569421875*^9}, 3.575089278067485*^9},
 FontSize->24],

Cell[BoxData[
 RowBox[{"DynamicSymbolize", "[", 
  RowBox[{"\"\<k\>\"", ",", "\"\<x\>\""}], "]"}]], "Input",
 CellChangeTimes->{{3.409561442890625*^9, 3.40956144328125*^9}, {
   3.433757607109375*^9, 3.433757629078125*^9}, {3.433836019828125*^9, 
   3.433836021421875*^9}, {3.433836066546875*^9, 3.433836093015625*^9}, {
   3.4975965945625*^9, 3.497596608140625*^9}, {3.49759664871875*^9, 
   3.497596655125*^9}, {3.497597152046875*^9, 3.49759716015625*^9}, 
   3.57508927806768*^9},
 FontSize->24],

Cell[BoxData[
 RowBox[{"DynamicSymbolize", "[", 
  RowBox[{"\"\<g\>\"", ",", "\"\<x\>\""}], "]"}]], "Input",
 CellChangeTimes->{{3.409561442890625*^9, 3.40956144328125*^9}, {
   3.433757607109375*^9, 3.433757629078125*^9}, {3.433836019828125*^9, 
   3.433836021421875*^9}, {3.433836066546875*^9, 3.433836093015625*^9}, {
   3.4975965945625*^9, 3.497596608140625*^9}, {3.49759664871875*^9, 
   3.497596655125*^9}, {3.497597152046875*^9, 3.49759716015625*^9}, {
   3.553398035133032*^9, 3.5533980356325912`*^9}, 3.575089278067902*^9},
 FontSize->24],

Cell[BoxData[
 RowBox[{"DynamicSymbolize", "[", 
  RowBox[{"\"\<FT\>\"", ",", "\"\<at\>\""}], "]"}]], "Input",
 CellChangeTimes->{{3.409561442890625*^9, 3.40956144328125*^9}, {
   3.433757607109375*^9, 3.433757629078125*^9}, {3.433836019828125*^9, 
   3.433836021421875*^9}, {3.433836066546875*^9, 3.433836093015625*^9}, {
   3.4975965945625*^9, 3.497596608140625*^9}, {3.49759664871875*^9, 
   3.497596655125*^9}, {3.497597163359375*^9, 3.497597170765625*^9}, {
   3.4975972363125*^9, 3.497597239953125*^9}, 3.4975973785*^9, {
   3.55325116075*^9, 3.553251168125*^9}, 3.5750892780681353`*^9},
 FontSize->24],

Cell[BoxData[
 RowBox[{"DynamicSymbolize", "[", 
  RowBox[{"\"\<dueFT\>\"", ",", "\"\<at\>\""}], "]"}]], "Input",
 CellChangeTimes->{{3.409561442890625*^9, 3.40956144328125*^9}, {
   3.433757607109375*^9, 3.433757629078125*^9}, {3.433836019828125*^9, 
   3.433836021421875*^9}, {3.433836066546875*^9, 3.433836093015625*^9}, {
   3.4975965945625*^9, 3.497596608140625*^9}, {3.49759664871875*^9, 
   3.497596655125*^9}, {3.497597163359375*^9, 3.497597170765625*^9}, {
   3.4975972363125*^9, 3.497597239953125*^9}, 3.4975973785*^9, {
   3.55325116075*^9, 3.553251168125*^9}, {3.553764889584547*^9, 
   3.5537648903989677`*^9}, 3.575089278068342*^9},
 FontSize->24],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"FullForm", "[", 
   SubscriptBox["a", "0"], "]"}], "        ", 
  RowBox[{"(*", " ", 
   RowBox[{"just", " ", "for", " ", "checking"}], " ", "*)"}]}]], "Input",
 CellChangeTimes->{{3.552473381453125*^9, 3.55247346678125*^9}, {
   3.553251670625*^9, 3.55325167375*^9}, 3.575089278068636*^9, {
   3.575256213881316*^9, 3.575256229840229*^9}, {3.575347348458397*^9, 
   3.5753473567589483`*^9}, {3.575347440675716*^9, 3.575347441579814*^9}},
 FontSize->24],

Cell[BoxData[
 TagBox[
  StyleBox["a\\[UnderBracket]Subscript\\[UnderBracket]0",
   ShowSpecialCharacters->False,
   ShowStringCharacters->True,
   NumberMarks->True],
  FullForm]], "Output",
 CellChangeTimes->{3.5776832816809673`*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"FullForm", "[", 
   SubscriptBox["k", "x"], "]"}], "        ", 
  RowBox[{"(*", " ", 
   RowBox[{"just", " ", "for", " ", "checking"}], " ", "*)"}]}]], "Input",
 CellChangeTimes->{{3.552473381453125*^9, 3.55247346678125*^9}, 
   3.553258953546875*^9, 3.5750892780691757`*^9, {3.5751077945461473`*^9, 
   3.5751078057297688`*^9}, {3.575256235776569*^9, 3.575256238816743*^9}, {
   3.575347438856586*^9, 3.575347439306465*^9}},
 FontSize->24],

Cell[BoxData[
 TagBox[
  StyleBox["k\\[UnderBracket]Subscript\\[UnderBracket]x",
   ShowSpecialCharacters->False,
   ShowStringCharacters->True,
   NumberMarks->True],
  FullForm]], "Output",
 CellChangeTimes->{3.577683281716279*^9}]
}, Open  ]],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"FullForm", "[", 
    SubscriptBox["g", "x"], "]"}], ";"}], "  "}]], "Input",
 CellChangeTimes->{{3.552473381453125*^9, 3.55247346678125*^9}, 
   3.553258953546875*^9, {3.553398054080247*^9, 3.553398054570187*^9}, 
   3.57508927806961*^9, 3.575107786217371*^9},
 FontSize->24],

Cell[BoxData[
 RowBox[{
  RowBox[{"FullForm", "[", 
   SubscriptBox["r", "e"], "]"}], " ", ";"}]], "Input",
 CellChangeTimes->{{3.552473381453125*^9, 3.55247346678125*^9}, {
   3.5532489511875*^9, 3.553248956921875*^9}, {3.55325163925*^9, 
   3.553251647515625*^9}, 3.5532589575*^9, 3.575089278070013*^9, 
   3.575107787106781*^9},
 FontSize->24],

Cell[BoxData[
 RowBox[{
  RowBox[{"FullForm", "[", 
   SubscriptBox["CG", "1"], "]"}], " ", ";"}]], "Input",
 CellChangeTimes->{{3.552473381453125*^9, 3.55247346678125*^9}, {
   3.5532489511875*^9, 3.553248956921875*^9}, {3.55325163925*^9, 
   3.553251647515625*^9}, 3.5532589575*^9, {3.55339888766541*^9, 
   3.553398909660925*^9}, 3.57508927807041*^9, 3.575107787789613*^9},
 FontSize->24],

Cell[BoxData[
 RowBox[{
  RowBox[{"FullForm", "[", 
   SubscriptBox["CG", "2"], "]"}], " ", ";"}]], "Input",
 CellChangeTimes->{{3.552473381453125*^9, 3.55247346678125*^9}, {
   3.5532489511875*^9, 3.553248956921875*^9}, {3.55325163925*^9, 
   3.553251647515625*^9}, 3.5532589575*^9, {3.55339888766541*^9, 
   3.553398909660925*^9}, {3.553399029063242*^9, 3.553399029565949*^9}, 
   3.5750892780708237`*^9, 3.575107788330275*^9},
 FontSize->24],

Cell[BoxData[
 RowBox[{
  RowBox[{"FullForm", "[", 
   SubscriptBox["CG", "3"], "]"}], ";"}]], "Input",
 CellChangeTimes->{{3.553398954993819*^9, 3.553399002679202*^9}, 
   3.575089278071204*^9, 3.575107788955925*^9},
 FontSize->24],

Cell[BoxData[
 RowBox[{
  RowBox[{"FullForm", "[", 
   SubscriptBox["width", "at"], "]"}], ";"}]], "Input",
 CellChangeTimes->{{3.552473381453125*^9, 3.55247346678125*^9}, {
   3.5532489511875*^9, 3.553248956921875*^9}, {3.553249023671875*^9, 
   3.553249025453125*^9}, 3.5532589613125*^9, 3.575089278071628*^9, 
   3.57510779000064*^9},
 FontSize->24],

Cell[BoxData[
 RowBox[{
  RowBox[{"FullForm", "[", 
   SubscriptBox["dueFT", "at"], "]"}], ";"}]], "Input",
 CellChangeTimes->{{3.552473381453125*^9, 3.55247346678125*^9}, {
   3.5532489511875*^9, 3.553248956921875*^9}, {3.553249023671875*^9, 
   3.553249025453125*^9}, {3.553251189890625*^9, 3.553251192515625*^9}, {
   3.553258966234375*^9, 3.553258968125*^9}, {3.55376491355591*^9, 
   3.55376491422805*^9}, 3.575089278072031*^9, 3.575107790744379*^9},
 FontSize->24],

Cell[BoxData[
 RowBox[{
  RowBox[{"FullForm", "[", 
   SubscriptBox["FT", "at"], "]"}], ";"}]], "Input",
 CellChangeTimes->{{3.552473381453125*^9, 3.55247346678125*^9}, {
   3.5532489511875*^9, 3.553248956921875*^9}, {3.553249023671875*^9, 
   3.553249025453125*^9}, {3.553251189890625*^9, 3.553251192515625*^9}, {
   3.553258966234375*^9, 3.553258968125*^9}, 3.5750892780724287`*^9, 
   3.575107791438198*^9},
 FontSize->24],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"\[Lambda]", "=", " ", 
  RowBox[{"0.709", "*", 
   SuperscriptBox["10", 
    RowBox[{"-", "10"}]], "           ", 
   RowBox[{"(*", " ", 
    RowBox[{
    "useful", " ", "for", " ", "calculating", " ", "V", " ", "in", " ", "2.2",
      ".96"}], " ", "*)"}]}]}]], "Input",
 CellChangeTimes->{{3.553251693359375*^9, 3.553251707828125*^9}, {
   3.5532606916875*^9, 3.553260734890625*^9}, 3.5750892780728893`*^9, {
   3.5752562447130795`*^9, 3.575256248880318*^9}},
 FontSize->18],

Cell[BoxData["7.09`*^-11"], "Output",
 CellChangeTimes->{3.5776832820359287`*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  SubscriptBox["r", "e"], " ", "=", " ", 
  RowBox[{"2.81", "*", 
   SuperscriptBox["10", 
    RowBox[{"-", "15"}]], "          ", 
   RowBox[{"(*", " ", 
    RowBox[{
    "useful", " ", "for", " ", "calculatin", " ", "V", " ", "in", " ", "2.2", 
     ".96"}], " ", "*)"}]}]}]], "Input",
 CellChangeTimes->{{3.553251745171875*^9, 3.553251770484375*^9}, {
   3.553260739625*^9, 3.55326074265625*^9}, 3.5750892780733757`*^9, {
   3.575256251800485*^9, 3.575256255624704*^9}},
 FontSize->18],

Cell[BoxData["2.8100000000000003`*^-15"], "Output",
 CellChangeTimes->{3.577683282150865*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  SubscriptBox["a", "0"], "=", 
  RowBox[{
   FractionBox["54", "10"], " ", "*", 
   SuperscriptBox["10", 
    RowBox[{"-", "10"}]], "   ", 
   RowBox[{"(*", " ", 
    RowBox[{
    "standard", " ", "cell", " ", "length", " ", "in", " ", "Si", " ", 
     "lattice"}], " ", "*)"}]}]}]], "Input",
 CellChangeTimes->{
  3.428806436828125*^9, {3.49779294684375*^9, 3.49779297634375*^9}, {
   3.497869819046875*^9, 3.49786982121875*^9}, 3.49787091496875*^9, 
   3.497871298296875*^9, 3.49787700834375*^9, 3.497878390828125*^9, {
   3.497955756671875*^9, 3.49795577359375*^9}, {3.498912202515625*^9, 
   3.498912211421875*^9}, 3.575089278073929*^9, 3.5750925195363913`*^9, {
   3.5752562644662094`*^9, 3.575256272081645*^9}},
 FontSize->24],

Cell[BoxData[
 FractionBox["27", "50000000000"]], "Output",
 CellChangeTimes->{3.5776832821830273`*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  SubscriptBox["width", "at"], "=", 
  RowBox[{
   FractionBox["1", "4"], "*", 
   SubscriptBox["a", "0"], "          ", 
   StyleBox[
    RowBox[{"(*", " ", 
     RowBox[{
     "the", " ", "diameter", " ", "of", " ", "Si", " ", "atom", " ", "is", 
      " ", 
      RowBox[{"1", "/", "16"}], " ", "of", " ", "the", " ", "cell", " ", 
      "size"}], " ", "*)"}],
    FontSize->18]}]}]], "Input",
 CellChangeTimes->{
  3.428806436828125*^9, {3.49779294684375*^9, 3.49779297634375*^9}, {
   3.497869819046875*^9, 3.49786982121875*^9}, 3.49787091496875*^9, 
   3.497871298296875*^9, 3.49787700834375*^9, 3.497878390828125*^9, {
   3.497953938734375*^9, 3.49795396325*^9}, {3.497954341171875*^9, 
   3.4979543555625*^9}, {3.4979557270625*^9, 3.49795579690625*^9}, {
   3.49891221725*^9, 3.49891222303125*^9}, 3.49891240484375*^9, {
   3.553249039609375*^9, 3.553249041109375*^9}, {3.553249140625*^9, 
   3.553249141453125*^9}, {3.553250452125*^9, 3.55325047184375*^9}, {
   3.553259182640625*^9, 3.553259190546875*^9}, {3.55378431495898*^9, 
   3.553784315762269*^9}, 3.575089278074808*^9, {3.575256309666795*^9, 
   3.575256318642308*^9}},
 FontSize->18],

Cell[BoxData[
 FractionBox["27", "200000000000"]], "Output",
 CellChangeTimes->{3.57768328221434*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"N", "[", "%", "]"}], "/", "2"}]], "Input",
 CellChangeTimes->{{3.553259944484375*^9, 3.55325994828125*^9}, {
   3.574943268157281*^9, 3.574943278675415*^9}, 3.575089278075193*^9}],

Cell[BoxData["6.75`*^-11"], "Output",
 CellChangeTimes->{3.577683282246649*^9}]
}, Open  ]],

Cell[BoxData[
 RowBox[{
  RowBox[{
   SubscriptBox["CG", "1"], " ", "=", " ", 
   RowBox[{
   "position", " ", "of", " ", "the", " ", "center", " ", "of", " ", 
    "gravity", " ", "of", " ", "the", " ", "first", " ", "atom"}]}], ",", " ", 
  RowBox[{"near", " ", "the", " ", "origin"}], ",", " ", 
  RowBox[{"positive", " ", "axis"}]}]], "Text",
 CellChangeTimes->{{3.553775829351016*^9, 3.5537758395558577`*^9}, 
   3.575089278075678*^9},
 FontFamily->"Times New Roman",
 FontSize->24,
 Background->GrayLevel[0.85]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  SubscriptBox["CG", "1"], " ", "=", 
  RowBox[{"N", "[", 
   RowBox[{
    FractionBox["1", "2"], "*", 
    FractionBox["1", "4"], "*", 
    SubscriptBox["a", "0"]}], "]"}], "   "}]], "Input",
 CellChangeTimes->{{3.553399171863435*^9, 3.55339917870542*^9}, {
   3.553399220329187*^9, 3.553399231455578*^9}, 3.55339927878718*^9, {
   3.553775575947589*^9, 3.5537756788945*^9}, {3.553775816643363*^9, 
   3.553775823386682*^9}, 3.5537773469258823`*^9, {3.553784323415254*^9, 
   3.553784327813511*^9}, 3.575089278075964*^9},
 FontSize->24],

Cell[BoxData["6.75`*^-11"], "Output",
 CellChangeTimes->{3.577683282292077*^9}]
}, Open  ]],

Cell[BoxData[
 RowBox[{
  RowBox[{
   SubscriptBox["CG", "2"], " ", "=", " ", 
   RowBox[{
   "position", " ", "of", " ", "the", " ", "center", " ", "of", " ", 
    "gravity", " ", "of", " ", "the", " ", "twin", " ", "atom"}]}], ",", " ", 
  RowBox[{
  "near", " ", "the", " ", "end", " ", "of", " ", "the", " ", "cell"}], ",", 
  " ", 
  RowBox[{"positive", " ", "axis"}]}]], "Text",
 CellChangeTimes->{{3.553775858737446*^9, 3.553775887029492*^9}, 
   3.575089278076418*^9},
 FontFamily->"Times New Roman",
 FontSize->24,
 Background->GrayLevel[0.85]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  SubscriptBox["CG", "2"], "  ", "=", " ", 
  RowBox[{"N", "[", 
   RowBox[{
    SubscriptBox["a", "0"], " ", "-", " ", 
    RowBox[{
     FractionBox["1", "2"], "*", 
     FractionBox["1", "4"], "*", 
     SubscriptBox["a", "0"]}]}], "]"}], "  "}]], "Input",
 CellChangeTimes->{{3.553399171863435*^9, 3.55339917870542*^9}, {
   3.55339921209041*^9, 3.553399270236249*^9}, {3.553775661320633*^9, 
   3.5537757182901907`*^9}, 3.553775864541885*^9, {3.5537773554150667`*^9, 
   3.5537773563875027`*^9}, {3.553777979895907*^9, 3.553777986679528*^9}, {
   3.553778092492845*^9, 3.5537780947709513`*^9}, {3.553784332428948*^9, 
   3.553784333333254*^9}, 3.575089278076706*^9},
 FontSize->24],

Cell[BoxData["4.725`*^-10"], "Output",
 CellChangeTimes->{3.5776832823243017`*^9}]
}, Open  ]],

Cell[BoxData[
 RowBox[{"coord1CG", " ", "and", " ", "coord2CG", "  ", "to", " ", 
  "highlight", " ", "the", " ", "CG"}]], "Text",
 CellChangeTimes->{{3.553775858737446*^9, 3.5537758682010927`*^9}, 
   3.553775900523551*^9, {3.55377598764578*^9, 3.553776019276904*^9}, 
   3.5750892780781717`*^9, {3.5751076077872753`*^9, 3.5751076981413517`*^9}, {
   3.5752564951214027`*^9, 3.5752564958794456`*^9}},
 FontFamily->"Times New Roman",
 FontSize->24,
 Background->GrayLevel[0.85]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"coord1CG", "=", " ", 
  RowBox[{"{", 
   StyleBox[
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"-", 
        SubscriptBox["CG", "1"]}], " ", ",", "0"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       SubscriptBox["CG", "1"], " ", ",", "0"}], "}"}]}],
    FontColor->RGBColor[0, 0, 1]], 
   StyleBox["}",
    FontColor->RGBColor[0, 0, 1]]}]}]], "Input",
 CellChangeTimes->{{3.5532558944375*^9, 3.553255930078125*^9}, {
   3.553256014546875*^9, 3.5532560378125*^9}, {3.55325619003125*^9, 
   3.5532561939375*^9}, {3.553260771296875*^9, 3.55326078178125*^9}, {
   3.553399360326522*^9, 3.553399381742526*^9}, {3.553399655295185*^9, 
   3.553399658339883*^9}, {3.553775920199477*^9, 3.5537759535185328`*^9}, {
   3.5537760240363703`*^9, 3.5537760303828087`*^9}, {3.575088953701936*^9, 
   3.5750889575765467`*^9}, 3.5750892780785503`*^9, {3.575092572317623*^9, 
   3.575092574376072*^9}},
 FontSize->18],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", "6.75`*^-11"}], ",", "0"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"6.75`*^-11", ",", "0"}], "}"}]}], "}"}]], "Output",
 CellChangeTimes->{3.577683282332761*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"coord1CGb", "=", " ", 
  RowBox[{"{", 
   StyleBox[
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        RowBox[{"-", 
         SubscriptBox["CG", "1"]}], " ", "+", 
        SubscriptBox["a", "0"]}], ",", "0"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        SubscriptBox["CG", "1"], " ", "+", 
        SubscriptBox["a", "0"]}], ",", "0"}], "}"}]}],
    FontColor->RGBColor[0, 0, 1]], 
   StyleBox["}",
    FontColor->RGBColor[0, 0, 1]]}]}]], "Input",
 CellChangeTimes->{{3.5532558944375*^9, 3.553255930078125*^9}, {
   3.553256014546875*^9, 3.5532560378125*^9}, {3.55325619003125*^9, 
   3.5532561939375*^9}, {3.553260771296875*^9, 3.55326078178125*^9}, {
   3.553399360326522*^9, 3.553399381742526*^9}, {3.553399655295185*^9, 
   3.553399658339883*^9}, {3.553775920199477*^9, 3.5537759535185328`*^9}, {
   3.5537760240363703`*^9, 3.5537760303828087`*^9}, {3.575088953701936*^9, 
   3.5750889575765467`*^9}, 3.5750892780785503`*^9, {3.575092572317623*^9, 
   3.575092574376072*^9}, {3.575095812667405*^9, 3.575095840817519*^9}},
 FontSize->18],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{"4.725`*^-10", ",", "0"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"6.075`*^-10", ",", "0"}], "}"}]}], "}"}]], "Output",
 CellChangeTimes->{3.577683282380988*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"coord1CGc", "=", " ", 
  RowBox[{"{", 
   StyleBox[
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        RowBox[{"-", 
         SubscriptBox["CG", "1"]}], " ", "+", 
        RowBox[{"2", " ", 
         SubscriptBox["a", "0"]}]}], ",", "0"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        SubscriptBox["CG", "1"], " ", "+", 
        RowBox[{"2", " ", 
         SubscriptBox["a", "0"]}]}], ",", "0"}], "}"}]}],
    FontColor->RGBColor[0, 0, 1]], 
   StyleBox["}",
    FontColor->RGBColor[0, 0, 1]]}]}]], "Input",
 CellChangeTimes->{{3.5532558944375*^9, 3.553255930078125*^9}, {
   3.553256014546875*^9, 3.5532560378125*^9}, {3.55325619003125*^9, 
   3.5532561939375*^9}, {3.553260771296875*^9, 3.55326078178125*^9}, {
   3.553399360326522*^9, 3.553399381742526*^9}, {3.553399655295185*^9, 
   3.553399658339883*^9}, {3.553775920199477*^9, 3.5537759535185328`*^9}, {
   3.5537760240363703`*^9, 3.5537760303828087`*^9}, {3.575088953701936*^9, 
   3.5750889575765467`*^9}, 3.5750892780785503`*^9, {3.575092572317623*^9, 
   3.575092574376072*^9}, {3.575095812667405*^9, 3.575095840817519*^9}, {
   3.575095902194502*^9, 3.575095909358046*^9}},
 FontSize->18],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{"1.0125`*^-9", ",", "0"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"1.1475`*^-9", ",", "0"}], "}"}]}], "}"}]], "Output",
 CellChangeTimes->{3.577683282473443*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"coord2CG", "=", " ", 
  RowBox[{"{", 
   StyleBox[
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       SubscriptBox["CG", "1"], " ", ",", "0"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       SubscriptBox["CG", "2"], " ", ",", "0"}], "}"}]}],
    FontColor->RGBColor[0, 0, 1]], 
   StyleBox["}",
    FontColor->RGBColor[0, 0, 1]]}]}]], "Input",
 CellChangeTimes->{{3.5532558944375*^9, 3.553255930078125*^9}, {
   3.553256014546875*^9, 3.5532560378125*^9}, {3.55325619003125*^9, 
   3.5532561939375*^9}, {3.553256358875*^9, 3.553256411640625*^9}, 
   3.553399414585566*^9, {3.553399600589871*^9, 3.553399629538187*^9}, {
   3.553399665232847*^9, 3.553399673677108*^9}, {3.553399873972548*^9, 
   3.553399878744467*^9}, {3.553775942449402*^9, 3.553775956494639*^9}, 
   3.553776027270911*^9, 3.57508927807897*^9, {3.575092579071204*^9, 
   3.575092580042322*^9}, {3.575092843183379*^9, 3.57509285863472*^9}},
 FontSize->18],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{"6.75`*^-11", ",", "0"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"4.725`*^-10", ",", "0"}], "}"}]}], "}"}]], "Output",
 CellChangeTimes->{3.577683282508027*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"coord2CGb", "=", " ", 
  RowBox[{"{", 
   StyleBox[
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        SubscriptBox["CG", "1"], " ", "+", 
        SubscriptBox["a", "0"]}], ",", "0"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        SubscriptBox["CG", "2"], " ", "+", 
        SubscriptBox["a", "0"]}], ",", "0"}], "}"}]}],
    FontColor->RGBColor[0, 0, 1]], 
   StyleBox["}",
    FontColor->RGBColor[0, 0, 1]]}]}]], "Input",
 CellChangeTimes->{{3.5532558944375*^9, 3.553255930078125*^9}, {
   3.553256014546875*^9, 3.5532560378125*^9}, {3.55325619003125*^9, 
   3.5532561939375*^9}, {3.553256358875*^9, 3.553256411640625*^9}, 
   3.553399414585566*^9, {3.553399600589871*^9, 3.553399629538187*^9}, {
   3.553399665232847*^9, 3.553399673677108*^9}, {3.553399873972548*^9, 
   3.553399878744467*^9}, {3.553775942449402*^9, 3.553775956494639*^9}, 
   3.553776027270911*^9, 3.57508927807897*^9, {3.575092579071204*^9, 
   3.575092580042322*^9}, {3.575092843183379*^9, 3.57509285863472*^9}, {
   3.5750961655329313`*^9, 3.575096192654778*^9}},
 FontSize->18],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{"6.075`*^-10", ",", "0"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"1.0125`*^-9", ",", "0"}], "}"}]}], "}"}]], "Output",
 CellChangeTimes->{3.577683282540311*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"coord2CGc", "=", " ", 
  RowBox[{"{", 
   StyleBox[
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        SubscriptBox["CG", "1"], " ", "+", 
        RowBox[{"2", 
         SubscriptBox["a", "0"]}]}], ",", "0"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        SubscriptBox["CG", "2"], " ", "+", 
        RowBox[{"2", 
         SubscriptBox["a", "0"]}]}], ",", "0"}], "}"}]}],
    FontColor->RGBColor[0, 0, 1]], 
   StyleBox["}",
    FontColor->RGBColor[0, 0, 1]]}]}]], "Input",
 CellChangeTimes->{{3.5532558944375*^9, 3.553255930078125*^9}, {
   3.553256014546875*^9, 3.5532560378125*^9}, {3.55325619003125*^9, 
   3.5532561939375*^9}, {3.553256358875*^9, 3.553256411640625*^9}, 
   3.553399414585566*^9, {3.553399600589871*^9, 3.553399629538187*^9}, {
   3.553399665232847*^9, 3.553399673677108*^9}, {3.553399873972548*^9, 
   3.553399878744467*^9}, {3.553775942449402*^9, 3.553775956494639*^9}, 
   3.553776027270911*^9, 3.57508927807897*^9, {3.575092579071204*^9, 
   3.575092580042322*^9}, {3.575092843183379*^9, 3.57509285863472*^9}, {
   3.5750961655329313`*^9, 3.575096221231661*^9}},
 FontSize->18],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{"1.1475`*^-9", ",", "0"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"1.5525`*^-9", ",", "0"}], "}"}]}], "}"}]], "Output",
 CellChangeTimes->{3.577683282610574*^9}]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Part I", "Text",
 CellChangeTimes->{{3.49795814646875*^9, 3.4979581888125*^9}, {
   3.49795824053125*^9, 3.497958316*^9}, {3.497959406296875*^9, 
   3.497959420546875*^9}, {3.498043168328125*^9, 3.498043187546875*^9}, {
   3.498106516515625*^9, 3.49810655075*^9}, 3.498811881546875*^9, {
   3.498827995140625*^9, 3.49882799565625*^9}, 3.49882868975*^9, 
   3.552473872765625*^9, {3.552473968390625*^9, 3.55247402665625*^9}, {
   3.553260807015625*^9, 3.553260815*^9}, {3.553753211917671*^9, 
   3.5537532471483917`*^9}, {3.5537532772628927`*^9, 3.553753310106073*^9}, {
   3.553775339564728*^9, 3.553775388928371*^9}, {3.5538272658268547`*^9, 
   3.553827271558619*^9}, {3.553827318764749*^9, 3.553827365915971*^9}, {
   3.553827426142563*^9, 3.553827457019126*^9}, 3.553828090670125*^9, {
   3.553828174641241*^9, 3.553828202866152*^9}, {3.574943132840713*^9, 
   3.57494313890244*^9}, {3.574943229021974*^9, 3.57494323680661*^9}, {
   3.574943304707011*^9, 3.5749433047071123`*^9}, {3.5750891979997683`*^9, 
   3.575089219260971*^9}, 3.575096334352598*^9, 3.575096473118904*^9, {
   3.575256082096779*^9, 3.5752560828788233`*^9}},
 FontFamily->"Times New Roman",
 FontSize->36,
 FontColor->RGBColor[0, 0, 1],
 Background->RGBColor[1, 0.9, 0.8]],

Cell[TextData[{
 "I consider one cell containing two silicon atoms.\n\nWe have different \
chances dealing with the electronic density.\n\nTo consider the electronic \
density of a single atom centred in the origin; usually\nin the handlebar, \
the two atoms are symmetrically located with respect to the origin\nwith \
distance 1/8 of the cell size (for the first one).\n\nThe cell has ",
 Cell[BoxData[
  RowBox[{
   SubscriptBox["a", "0"], "=", 
   RowBox[{"5.42883", " ", "*", 
    RowBox[{
     SuperscriptBox["10", 
      RowBox[{"-", "10"}]], "  ", "[", "m", "]"}], " "}]}]],
  CellChangeTimes->{
   3.428806436828125*^9, {3.49779294684375*^9, 3.49779297634375*^9}, {
    3.497869819046875*^9, 3.49786982121875*^9}, 3.49787091496875*^9, 
    3.497871298296875*^9, 3.49787700834375*^9, 3.497878390828125*^9, {
    3.497955756671875*^9, 3.49795577359375*^9}},
  FontSize->24],
 "cell parameter \nThe diameter of the silicon atom (spherical construct) is ",
 Cell[BoxData[
  RowBox[{
   SubscriptBox["width", "at"], "=", 
   RowBox[{
    FractionBox["1", "4"], "*", 
    SubscriptBox["a", "0"], " "}]}]],
  CellChangeTimes->{
   3.428806436828125*^9, {3.49779294684375*^9, 3.49779297634375*^9}, {
    3.497869819046875*^9, 3.49786982121875*^9}, 3.49787091496875*^9, 
    3.497871298296875*^9, 3.49787700834375*^9, 3.497878390828125*^9, {
    3.497953938734375*^9, 3.49795396325*^9}, {3.497954341171875*^9, 
    3.4979543555625*^9}, {3.4979557270625*^9, 3.49795579690625*^9}},
  FontSize->24],
 "=",
 Cell[BoxData[
  RowBox[{" ", "1.35`*^-10"}]], "Output",
  GeneratedCell->False,
  CellAutoOverwrite->False,
  CellChangeTimes->{3.553259953875*^9, 3.55326010959375*^9, 
   3.553343244823125*^9, 3.553399742570649*^9, 3.553753155890566*^9, 
   3.55375468513898*^9, 3.553754848631722*^9, 3.553762521707066*^9, 
   3.553763649549182*^9, 3.553767738278607*^9, 3.553769976959447*^9, 
   3.553775778166173*^9, 3.553777335076611*^9, 3.553784364093465*^9, 
   3.5749416303325367`*^9, 3.574943205652384*^9},
  FontSize->24],
 " [m]  \nThe center of mass of the first atom is therefore @ ",
 Cell[BoxData[
  RowBox[{
   FractionBox["1", "8"], "*", 
   SubscriptBox["a", "0"], " "}]],
  CellChangeTimes->{
   3.428806436828125*^9, {3.49779294684375*^9, 3.49779297634375*^9}, {
    3.497869819046875*^9, 3.49786982121875*^9}, 3.49787091496875*^9, 
    3.497871298296875*^9, 3.49787700834375*^9, 3.497878390828125*^9, {
    3.497953938734375*^9, 3.49795396325*^9}, {3.497954341171875*^9, 
    3.4979543555625*^9}, {3.4979557270625*^9, 3.49795579690625*^9}},
  FontSize->24],
 "= ",
 Cell[BoxData["6.75`*^-11"],
  CellChangeTimes->{3.5532556198125*^9, 3.553257029671875*^9, 
   3.553259242578125*^9, 3.553260109671875*^9}],
 " [m]\n\nI have two options for the second atom of the cell:\n\na. \
symetrically located on the opposite side of the origin, i.e. at1= ",
 Cell[BoxData[
  RowBox[{"+", 
   FractionBox["1", "8"]}]],
  CellChangeTimes->{{3.55323332190625*^9, 3.553233452296875*^9}, {
    3.553233546296875*^9, 3.553233643078125*^9}, {3.553233674296875*^9, 
    3.55323369940625*^9}, {3.553233745359375*^9, 3.5532337625*^9}, 
    3.55323385990625*^9, {3.553233929109375*^9, 3.55323393034375*^9}, {
    3.5532340236875*^9, 3.553234031234375*^9}, {3.55323531940625*^9, 
    3.553235327859375*^9}, {3.553235393484375*^9, 3.55323544403125*^9}, {
    3.553236356890625*^9, 3.5532363763125*^9}, {3.553249517125*^9, 
    3.5532495475*^9}, {3.55324962609375*^9, 3.553249654703125*^9}, {
    3.553251430734375*^9, 3.5532514450625*^9}, {3.553252686609375*^9, 
    3.553252692265625*^9}, {3.55325957378125*^9, 3.5532595796875*^9}, {
    3.55326007428125*^9, 3.553260080015625*^9}, {3.55326017065625*^9, 
    3.553260171640625*^9}, {3.553260240109375*^9, 3.553260240484375*^9}}],
 "*",
 Cell[BoxData[
  SubscriptBox["a", "0"]],
  CellChangeTimes->{
   3.428806436828125*^9, {3.49779294684375*^9, 3.49779297634375*^9}, {
    3.497869819046875*^9, 3.49786982121875*^9}, 3.49787091496875*^9, 
    3.497871298296875*^9, 3.49787700834375*^9, 3.497878390828125*^9, {
    3.497953938734375*^9, 3.49795396325*^9}, {3.497954341171875*^9, 
    3.4979543555625*^9}, {3.4979557270625*^9, 3.49795579690625*^9}},
  FontSize->24],
 " ed at2 = ",
 Cell[BoxData[
  RowBox[{"-", 
   FractionBox["1", "8"]}]],
  CellChangeTimes->{{3.55323332190625*^9, 3.553233452296875*^9}, {
    3.553233546296875*^9, 3.553233643078125*^9}, {3.553233674296875*^9, 
    3.55323369940625*^9}, {3.553233745359375*^9, 3.5532337625*^9}, 
    3.55323385990625*^9, {3.553233929109375*^9, 3.55323393034375*^9}, {
    3.5532340236875*^9, 3.553234031234375*^9}, {3.55323531940625*^9, 
    3.553235327859375*^9}, {3.553235393484375*^9, 3.55323544403125*^9}, {
    3.553236356890625*^9, 3.5532363763125*^9}, {3.553249517125*^9, 
    3.5532495475*^9}, {3.55324962609375*^9, 3.553249654703125*^9}, {
    3.553251430734375*^9, 3.5532514450625*^9}, {3.553252686609375*^9, 
    3.553252692265625*^9}, {3.55325957378125*^9, 3.5532595796875*^9}, {
    3.55326007428125*^9, 3.553260080015625*^9}, {3.55326017065625*^9, 
    3.553260171640625*^9}, {3.553260240109375*^9, 3.553260240484375*^9}}],
 Cell[BoxData[
  RowBox[{"*", 
   SubscriptBox["a", "0"]}]],
  CellChangeTimes->{
   3.428806436828125*^9, {3.49779294684375*^9, 3.49779297634375*^9}, {
    3.497869819046875*^9, 3.49786982121875*^9}, 3.49787091496875*^9, 
    3.497871298296875*^9, 3.49787700834375*^9, 3.497878390828125*^9, {
    3.497953938734375*^9, 3.49795396325*^9}, {3.497954341171875*^9, 
    3.4979543555625*^9}, {3.4979557270625*^9, 3.49795579690625*^9}},
  FontSize->24],
 "\nb. inside the cell on the opposite side, i.e.  at1 = ",
 Cell[BoxData[
  RowBox[{"+", 
   FractionBox["1", "8"]}]],
  CellChangeTimes->{{3.55323332190625*^9, 3.553233452296875*^9}, {
    3.553233546296875*^9, 3.553233643078125*^9}, {3.553233674296875*^9, 
    3.55323369940625*^9}, {3.553233745359375*^9, 3.5532337625*^9}, 
    3.55323385990625*^9, {3.553233929109375*^9, 3.55323393034375*^9}, {
    3.5532340236875*^9, 3.553234031234375*^9}, {3.55323531940625*^9, 
    3.553235327859375*^9}, {3.553235393484375*^9, 3.55323544403125*^9}, {
    3.553236356890625*^9, 3.5532363763125*^9}, {3.553249517125*^9, 
    3.5532495475*^9}, {3.55324962609375*^9, 3.553249654703125*^9}, {
    3.553251430734375*^9, 3.5532514450625*^9}, {3.553252686609375*^9, 
    3.553252692265625*^9}, {3.55325957378125*^9, 3.5532595796875*^9}, {
    3.55326007428125*^9, 3.553260080015625*^9}, {3.55326017065625*^9, 
    3.553260171640625*^9}, {3.553260240109375*^9, 3.553260240484375*^9}}],
 "*",
 Cell[BoxData[
  SubscriptBox["a", "0"]],
  CellChangeTimes->{
   3.428806436828125*^9, {3.49779294684375*^9, 3.49779297634375*^9}, {
    3.497869819046875*^9, 3.49786982121875*^9}, 3.49787091496875*^9, 
    3.497871298296875*^9, 3.49787700834375*^9, 3.497878390828125*^9, {
    3.497953938734375*^9, 3.49795396325*^9}, {3.497954341171875*^9, 
    3.4979543555625*^9}, {3.4979557270625*^9, 3.49795579690625*^9}},
  FontSize->24],
 " ed  at2 = ",
 Cell[BoxData[
  RowBox[{
   RowBox[{"+", 
    FractionBox["7", "8"]}], "*", 
   SubscriptBox["a", "0"]}]],
  CellChangeTimes->{{3.55323332190625*^9, 3.553233452296875*^9}, {
    3.553233546296875*^9, 3.553233643078125*^9}, {3.553233674296875*^9, 
    3.55323369940625*^9}, {3.553233745359375*^9, 3.5532337625*^9}, 
    3.55323385990625*^9, {3.553233929109375*^9, 3.55323393034375*^9}, {
    3.5532340236875*^9, 3.553234031234375*^9}, {3.55323531940625*^9, 
    3.553235327859375*^9}, {3.553235393484375*^9, 3.55323544403125*^9}, {
    3.553236356890625*^9, 3.5532363763125*^9}, {3.553249517125*^9, 
    3.5532495475*^9}, {3.55324962609375*^9, 3.553249654703125*^9}, {
    3.553251430734375*^9, 3.5532514450625*^9}, {3.553252686609375*^9, 
    3.553252692265625*^9}, {3.55325957378125*^9, 3.5532595796875*^9}, {
    3.55326007428125*^9, 3.553260080015625*^9}, {3.55326017065625*^9, 
    3.553260171640625*^9}, {3.553260240109375*^9, 3.553260240484375*^9}}]
}], "Text",
 CellChangeTimes->{{3.49795814646875*^9, 3.4979581888125*^9}, {
   3.49795824053125*^9, 3.497958316*^9}, {3.497959406296875*^9, 
   3.497959420546875*^9}, {3.498043168328125*^9, 3.498043187546875*^9}, {
   3.498106516515625*^9, 3.49810655075*^9}, 3.498811881546875*^9, {
   3.498827995140625*^9, 3.49882799565625*^9}, 3.49882868975*^9, 
   3.552473872765625*^9, {3.552473968390625*^9, 3.55247402665625*^9}, {
   3.553260807015625*^9, 3.553260815*^9}, {3.553753211917671*^9, 
   3.5537532471483917`*^9}, {3.5537532772628927`*^9, 3.553753310106073*^9}, {
   3.553775339564728*^9, 3.553775388928371*^9}, {3.5538272658268547`*^9, 
   3.553827271558619*^9}, {3.553827318764749*^9, 3.553827365915971*^9}, {
   3.553827426142563*^9, 3.553827457019126*^9}, 3.553828090670125*^9, {
   3.553828174641241*^9, 3.553828202866152*^9}, {3.574943132840713*^9, 
   3.57494313890244*^9}, {3.574943229021974*^9, 3.57494323680661*^9}, {
   3.574943304707011*^9, 3.5749433047071123`*^9}, {3.5750891979997683`*^9, 
   3.575089219260971*^9}, 3.575096334352598*^9, 3.575096473118904*^9, {
   3.575256103776019*^9, 3.575256103960029*^9}, {3.5752576646152935`*^9, 
   3.575257709158841*^9}, {3.575257782423032*^9, 3.575257843126504*^9}, {
   3.5752578804546385`*^9, 3.5752581512341266`*^9}, {3.5752581923994813`*^9, 
   3.5752581943095903`*^9}},
 FontFamily->"Times New Roman",
 FontSize->26,
 FontColor->GrayLevel[0],
 Background->GrayLevel[0.85]],

Cell["\<\
First of all we see the case a. and a case b.with a simple scatch...\
\>", "Text",
 CellChangeTimes->{{3.49795814646875*^9, 3.4979581888125*^9}, {
   3.49795824053125*^9, 3.497958316*^9}, {3.497959406296875*^9, 
   3.497959420546875*^9}, {3.498043168328125*^9, 3.498043187546875*^9}, {
   3.498106516515625*^9, 3.49810655075*^9}, 3.498811881546875*^9, {
   3.498827995140625*^9, 3.49882799565625*^9}, 3.49882868975*^9, 
   3.552473872765625*^9, {3.552473968390625*^9, 3.55247402665625*^9}, {
   3.553260807015625*^9, 3.553260815*^9}, {3.553753211917671*^9, 
   3.5537532471483917`*^9}, {3.5537532772628927`*^9, 3.553753310106073*^9}, {
   3.553775339564728*^9, 3.553775388928371*^9}, {3.5538272658268547`*^9, 
   3.553827271558619*^9}, {3.553827318764749*^9, 3.553827365915971*^9}, {
   3.553827426142563*^9, 3.553827457019126*^9}, 3.553828090670125*^9, {
   3.553828174641241*^9, 3.553828202866152*^9}, {3.574943132840713*^9, 
   3.57494313890244*^9}, {3.574943229021974*^9, 3.57494323680661*^9}, {
   3.574943304707011*^9, 3.5749433047071123`*^9}, {3.5750891979997683`*^9, 
   3.575089219260971*^9}, 3.575096334352598*^9, {3.575096473118904*^9, 
   3.575096549237656*^9}, {3.5752581595596027`*^9, 3.575258181038831*^9}},
 FontFamily->"Times New Roman",
 FontSize->26,
 FontColor->GrayLevel[0],
 Background->GrayLevel[0.85]],

Cell["For the case a,", "Text",
 CellChangeTimes->{{3.49795814646875*^9, 3.4979581888125*^9}, {
   3.49795824053125*^9, 3.497958316*^9}, {3.497959406296875*^9, 
   3.497959420546875*^9}, {3.498043168328125*^9, 3.498043187546875*^9}, {
   3.498106516515625*^9, 3.49810655075*^9}, 3.498811881546875*^9, {
   3.498827995140625*^9, 3.49882799565625*^9}, 3.49882868975*^9, 
   3.552473872765625*^9, {3.552473968390625*^9, 3.55247402665625*^9}, {
   3.553260807015625*^9, 3.553260815*^9}, {3.553753211917671*^9, 
   3.5537532471483917`*^9}, {3.5537532772628927`*^9, 3.553753310106073*^9}, {
   3.553775339564728*^9, 3.553775388928371*^9}, {3.5538272658268547`*^9, 
   3.553827271558619*^9}, {3.553827318764749*^9, 3.553827365915971*^9}, {
   3.553827426142563*^9, 3.553827457019126*^9}, 3.553828090670125*^9, {
   3.553828174641241*^9, 3.553828202866152*^9}, {3.574943132840713*^9, 
   3.57494313890244*^9}, {3.574943229021974*^9, 3.57494323680661*^9}, {
   3.574943304707011*^9, 3.5749433047071123`*^9}, {3.5750891979997683`*^9, 
   3.575089219260971*^9}, 3.575096334352598*^9, {3.575096473118904*^9, 
   3.575096549237656*^9}, {3.5752581595596027`*^9, 3.5752581905423746`*^9}, {
   3.575343501811928*^9, 3.5753435022339163`*^9}},
 FontFamily->"Times New Roman",
 FontSize->26,
 FontColor->GrayLevel[0],
 Background->GrayLevel[0.85]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"Graphics", "[", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"Thick", ",", 
       RowBox[{"Line", "[", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"{", 
           RowBox[{"0", ",", 
            RowBox[{
             RowBox[{"-", 
              SubscriptBox["a", "0"]}], "/", "15"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"0", ",", 
            RowBox[{
             SubscriptBox["a", "0"], "/", "15"}]}], "}"}]}], "}"}], "]"}]}], 
      "}"}], ",", "\[IndentingNewLine]", 
     RowBox[{"{", 
      RowBox[{"Thick", ",", 
       RowBox[{"Line", "[", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"{", 
           RowBox[{
            RowBox[{"0", "+", 
             SubscriptBox["a", "0"]}], ",", 
            RowBox[{
             RowBox[{"-", 
              SubscriptBox["a", "0"]}], "/", "15"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"0", " ", "+", 
             SubscriptBox["a", "0"]}], ",", 
            RowBox[{
             SubscriptBox["a", "0"], "/", "15"}]}], "}"}]}], "}"}], "]"}]}], 
      "}"}], ",", "\[IndentingNewLine]", 
     RowBox[{"{", 
      RowBox[{"Thick", ",", 
       RowBox[{"Line", "[", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"{", 
           RowBox[{
            RowBox[{"0", "+", 
             RowBox[{"2", " ", 
              SubscriptBox["a", "0"]}]}], ",", 
            RowBox[{
             RowBox[{"-", 
              SubscriptBox["a", "0"]}], "/", "15"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"0", " ", "+", 
             RowBox[{"2", " ", 
              SubscriptBox["a", "0"]}]}], ",", 
            RowBox[{
             SubscriptBox["a", "0"], "/", "15"}]}], "}"}]}], "}"}], "]"}]}], 
      "}"}], ",", "\[IndentingNewLine]", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"PointSize", "[", "Large", "]"}], ",", "Orange", ",", 
       RowBox[{"Point", "[", "coord1CG", "]"}]}], "}"}], ",", 
     "\[IndentingNewLine]", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"PointSize", "[", "Large", "]"}], ",", "Red", ",", 
       RowBox[{"Point", "[", "coord1CGb", "]"}]}], "}"}], ",", 
     "\[IndentingNewLine]", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"PointSize", "[", "Large", "]"}], ",", "Blue", ",", 
       RowBox[{"Point", "[", "coord1CGc", "]"}]}], "}"}], ",", 
     "\[IndentingNewLine]", 
     RowBox[{"{", 
      RowBox[{"Thick", ",", 
       RowBox[{"Line", "[", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"{", 
           RowBox[{
            RowBox[{"-", 
             SubscriptBox["a", "0"]}], ",", "0"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            SubscriptBox["a", "0"], ",", "0"}], "}"}]}], "}"}], "]"}]}], 
      "}"}], ",", "\[IndentingNewLine]", 
     RowBox[{"{", 
      RowBox[{"Thick", ",", 
       RowBox[{"Line", "[", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"{", 
           RowBox[{
            SubscriptBox["a", "0"], ",", "0"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"2", " ", 
             SubscriptBox["a", "0"]}], ",", "0"}], "}"}]}], "}"}], "]"}]}], 
      "}"}], ",", "\[IndentingNewLine]", 
     RowBox[{"{", 
      RowBox[{"Thick", ",", 
       RowBox[{"Line", "[", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"{", 
           RowBox[{
            RowBox[{"2", 
             SubscriptBox["a", "0"]}], ",", "0"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"3", " ", 
             SubscriptBox["a", "0"]}], ",", "0"}], "}"}]}], "}"}], "]"}]}], 
      "}"}]}], "\[IndentingNewLine]", "}"}], "]"}], " "}]], "Input",
 CellChangeTimes->{
  3.575090500550215*^9, {3.575092454949616*^9, 3.575092477155217*^9}, {
   3.5750926033963947`*^9, 3.575092610045735*^9}, {3.575092642120648*^9, 
   3.575092647372718*^9}, {3.575092692791471*^9, 3.5750927163497066`*^9}, {
   3.575095671108225*^9, 3.575095695249464*^9}, {3.575095735796382*^9, 
   3.575095783115345*^9}, {3.5750958584840603`*^9, 3.575095892380879*^9}, {
   3.575095987443829*^9, 3.575096072853794*^9}, {3.575107833029068*^9, 
   3.575107845815899*^9}}],

Cell[BoxData[
 GraphicsBox[{
   {Thickness[Large], 
    LineBox[NCache[{{0, Rational[-9, 250000000000]}, {
       0, Rational[9, 250000000000]}}, {{0, -3.6*^-11}, {0, 3.6*^-11}}]]}, 
   {Thickness[Large], 
    LineBox[NCache[{{Rational[27, 50000000000], Rational[-9, 250000000000]}, {
       Rational[27, 50000000000], Rational[9, 250000000000]}}, {{
      5.4*^-10, -3.6*^-11}, {5.4*^-10, 3.6*^-11}}]]}, 
   {Thickness[Large], 
    LineBox[NCache[{{Rational[27, 25000000000], Rational[-9, 250000000000]}, {
       Rational[27, 25000000000], Rational[9, 250000000000]}}, {{
      1.08*^-9, -3.6*^-11}, {1.08*^-9, 3.6*^-11}}]]}, 
   {RGBColor[1, 0.5, 0], PointSize[Large], 
    PointBox[{{-6.75*^-11, 0}, {6.75*^-11, 0}}]}, 
   {RGBColor[1, 0, 0], PointSize[Large], 
    PointBox[{{4.725*^-10, 0}, {6.075*^-10, 0}}]}, 
   {RGBColor[0, 0, 1], PointSize[Large], 
    PointBox[{{1.0125*^-9, 0}, {1.1475*^-9, 0}}]}, 
   {Thickness[Large], 
    LineBox[NCache[{{Rational[-27, 50000000000], 0}, {
       Rational[27, 50000000000], 0}}, {{-5.4*^-10, 0}, {5.4*^-10, 0}}]]}, 
   {Thickness[Large], 
    LineBox[NCache[{{Rational[27, 50000000000], 0}, {
       Rational[27, 25000000000], 0}}, {{5.4*^-10, 0}, {1.08*^-9, 0}}]]}, 
   {Thickness[Large], 
    LineBox[NCache[{{Rational[27, 25000000000], 0}, {
       Rational[81, 50000000000], 0}}, {{1.08*^-9, 0}, {
       1.62*^-9, 0}}]]}}]], "Output",
 CellChangeTimes->{
  3.577683282650983*^9},ImageCache->GraphicsData["CompressedBitmap", "\<\
eJzNVUGIElEYftNz5+BFMAIlELvporFStBGibYeiRLwpeBNt2UHD2PYgKOxA
QYciil2Cx3YN2ltEdS48icMcEussWEtB0KVDF//e/8a3zUyzatQhmP+f9773
/d//3s/8b/KVrY3rNypbWrUSvbJZubmhVW9FLzc3OUQVQpQoIeRElOAY+HDq
gD9wCh0ifza+Jl70ZS6XG0UiETG7ZGHvkslkN51O27FvgUDgablcFrOr/5PE
RfHyJeDzYBde1XfgdWMZvgxVD2WfN3VFwgMO1znc4PBQKjj24fOmSoXBAHbr
ddhpNGB5OATVY9c+b+qadZglKyLd7XbXGWNoZFV49Ta71wGWJ9ImLK9ss/v6
klgW2/waDAat2eyQ03K5w5f5ZzG1CVP4si4VUe1TOBx2KnqHSMVOh/FTHNpE
Udi2rrOp4g9VVT/EYjGH4hEhFyzSuV6vJ2oi6uIo0mNN08DWC4QcF0N6t9Vq
HRETGY1GZwzDQCOrwtPnxoMCGOsEjRwTnu4bj4qHPGp5/AgOQqGQHZsbm5C8
AufxbXJDHhG84m858FN9H4/HnTnmxMochYLBTyqM89DT/WLRcOf47vf732Yy
GUeOebHnLd7J8XjsLm3WmpyFj30AnaBxCfQUO81Fd3YkXTA2IXn9vrjIQJQC
PcVedOdw9CxdMFbm+EUDUQqOYbe6czi6mi4Ym3HcWXjsPXhRQ0vBgTnjznJT
VyTc53CthpYC05xxZ7mpUoFvea9WE5YyzVl3lpu69q9/Aw+bzSbK2OnPSqXS
k2q1asfeZLPZO+122y7xN/9CovwEVu+bNA==\
\>"]]
}, Open  ]],

Cell["and, for the case b,", "Text",
 CellChangeTimes->{{3.49795814646875*^9, 3.4979581888125*^9}, {
   3.49795824053125*^9, 3.497958316*^9}, {3.497959406296875*^9, 
   3.497959420546875*^9}, {3.498043168328125*^9, 3.498043187546875*^9}, {
   3.498106516515625*^9, 3.49810655075*^9}, 3.498811881546875*^9, {
   3.498827995140625*^9, 3.49882799565625*^9}, 3.49882868975*^9, 
   3.552473872765625*^9, {3.552473968390625*^9, 3.55247402665625*^9}, {
   3.553260807015625*^9, 3.553260815*^9}, {3.553753211917671*^9, 
   3.5537532471483917`*^9}, {3.5537532772628927`*^9, 3.553753310106073*^9}, {
   3.553775339564728*^9, 3.553775388928371*^9}, {3.5538272658268547`*^9, 
   3.553827271558619*^9}, {3.553827318764749*^9, 3.553827365915971*^9}, {
   3.553827426142563*^9, 3.553827457019126*^9}, 3.553828090670125*^9, {
   3.553828174641241*^9, 3.553828202866152*^9}, {3.574943132840713*^9, 
   3.57494313890244*^9}, {3.574943229021974*^9, 3.57494323680661*^9}, {
   3.574943304707011*^9, 3.5749433047071123`*^9}, {3.5750891979997683`*^9, 
   3.575089219260971*^9}, 3.575096334352598*^9, {3.575096473118904*^9, 
   3.575096549237656*^9}, {3.5752581595596027`*^9, 3.575258202623066*^9}, {
   3.575343491673175*^9, 3.5753435076700783`*^9}},
 FontFamily->"Times New Roman",
 FontSize->26,
 FontColor->GrayLevel[0],
 Background->GrayLevel[0.85]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"Graphics", "[", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"Thick", ",", 
       RowBox[{"Line", "[", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"{", 
           RowBox[{"0", ",", 
            RowBox[{
             RowBox[{"-", 
              SubscriptBox["a", "0"]}], "/", "15"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"0", ",", 
            RowBox[{
             SubscriptBox["a", "0"], "/", "15"}]}], "}"}]}], "}"}], "]"}]}], 
      "}"}], ",", "\[IndentingNewLine]", 
     RowBox[{"{", 
      RowBox[{"Thick", ",", 
       RowBox[{"Line", "[", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"{", 
           RowBox[{
            RowBox[{"0", "+", 
             SubscriptBox["a", "0"]}], ",", 
            RowBox[{
             RowBox[{"-", 
              SubscriptBox["a", "0"]}], "/", "15"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"0", " ", "+", 
             SubscriptBox["a", "0"]}], ",", 
            RowBox[{
             SubscriptBox["a", "0"], "/", "15"}]}], "}"}]}], "}"}], "]"}]}], 
      "}"}], ",", "\[IndentingNewLine]", 
     RowBox[{"{", 
      RowBox[{"Thick", ",", 
       RowBox[{"Line", "[", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"{", 
           RowBox[{
            RowBox[{"0", "+", 
             RowBox[{"2", " ", 
              SubscriptBox["a", "0"]}]}], ",", 
            RowBox[{
             RowBox[{"-", 
              SubscriptBox["a", "0"]}], "/", "15"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"0", " ", "+", 
             RowBox[{"2", " ", 
              SubscriptBox["a", "0"]}]}], ",", 
            RowBox[{
             SubscriptBox["a", "0"], "/", "15"}]}], "}"}]}], "}"}], "]"}]}], 
      "}"}], ",", "\[IndentingNewLine]", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"PointSize", "[", "Large", "]"}], ",", "Orange", ",", 
       RowBox[{"Point", "[", "coord2CG", "]"}]}], "}"}], ",", 
     "\[IndentingNewLine]", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"PointSize", "[", "Large", "]"}], ",", "Red", ",", 
       RowBox[{"Point", "[", "coord2CGb", "]"}]}], "}"}], ",", 
     "\[IndentingNewLine]", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"PointSize", "[", "Large", "]"}], ",", "Blue", ",", 
       RowBox[{"Point", "[", "coord2CGc", "]"}]}], "}"}], ",", 
     "\[IndentingNewLine]", 
     RowBox[{"{", 
      RowBox[{"Thick", ",", 
       RowBox[{"Line", "[", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"{", 
           RowBox[{
            RowBox[{"-", 
             SubscriptBox["a", "0"]}], ",", "0"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            SubscriptBox["a", "0"], ",", "0"}], "}"}]}], "}"}], "]"}]}], 
      "}"}], ",", "\[IndentingNewLine]", 
     RowBox[{"{", 
      RowBox[{"Thick", ",", 
       RowBox[{"Line", "[", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"{", 
           RowBox[{
            SubscriptBox["a", "0"], ",", "0"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"2", " ", 
             SubscriptBox["a", "0"]}], ",", "0"}], "}"}]}], "}"}], "]"}]}], 
      "}"}], ",", "\[IndentingNewLine]", 
     RowBox[{"{", 
      RowBox[{"Thick", ",", 
       RowBox[{"Line", "[", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"{", 
           RowBox[{
            RowBox[{"2", 
             SubscriptBox["a", "0"]}], ",", "0"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"3", " ", 
             SubscriptBox["a", "0"]}], ",", "0"}], "}"}]}], "}"}], "]"}]}], 
      "}"}]}], "\[IndentingNewLine]", "}"}], "]"}], " "}]], "Input",
 CellChangeTimes->{
  3.575090500550215*^9, {3.575092454949616*^9, 3.575092477155217*^9}, {
   3.5750926033963947`*^9, 3.575092610045735*^9}, {3.575092642120648*^9, 
   3.575092647372718*^9}, {3.575092692791471*^9, 3.5750927163497066`*^9}, {
   3.575095671108225*^9, 3.575095695249464*^9}, {3.575095735796382*^9, 
   3.575095783115345*^9}, {3.5750958584840603`*^9, 3.575095892380879*^9}, {
   3.575095987443829*^9, 3.575096072853794*^9}, {3.575096145334983*^9, 
   3.575096145785367*^9}, {3.575096269616613*^9, 3.575096274259282*^9}, {
   3.575107851025537*^9, 3.575107857800099*^9}}],

Cell[BoxData[
 GraphicsBox[{
   {Thickness[Large], 
    LineBox[NCache[{{0, Rational[-9, 250000000000]}, {
       0, Rational[9, 250000000000]}}, {{0, -3.6*^-11}, {0, 3.6*^-11}}]]}, 
   {Thickness[Large], 
    LineBox[NCache[{{Rational[27, 50000000000], Rational[-9, 250000000000]}, {
       Rational[27, 50000000000], Rational[9, 250000000000]}}, {{
      5.4*^-10, -3.6*^-11}, {5.4*^-10, 3.6*^-11}}]]}, 
   {Thickness[Large], 
    LineBox[NCache[{{Rational[27, 25000000000], Rational[-9, 250000000000]}, {
       Rational[27, 25000000000], Rational[9, 250000000000]}}, {{
      1.08*^-9, -3.6*^-11}, {1.08*^-9, 3.6*^-11}}]]}, 
   {RGBColor[1, 0.5, 0], PointSize[Large], 
    PointBox[{{6.75*^-11, 0}, {4.725*^-10, 0}}]}, 
   {RGBColor[1, 0, 0], PointSize[Large], 
    PointBox[{{6.075*^-10, 0}, {1.0125*^-9, 0}}]}, 
   {RGBColor[0, 0, 1], PointSize[Large], 
    PointBox[{{1.1475*^-9, 0}, {1.5525*^-9, 0}}]}, 
   {Thickness[Large], 
    LineBox[NCache[{{Rational[-27, 50000000000], 0}, {
       Rational[27, 50000000000], 0}}, {{-5.4*^-10, 0}, {5.4*^-10, 0}}]]}, 
   {Thickness[Large], 
    LineBox[NCache[{{Rational[27, 50000000000], 0}, {
       Rational[27, 25000000000], 0}}, {{5.4*^-10, 0}, {1.08*^-9, 0}}]]}, 
   {Thickness[Large], 
    LineBox[NCache[{{Rational[27, 25000000000], 0}, {
       Rational[81, 50000000000], 0}}, {{1.08*^-9, 0}, {
       1.62*^-9, 0}}]]}}]], "Output",
 CellChangeTimes->{
  3.5776832828230963`*^9},ImageCache->GraphicsData["CompressedBitmap", "\<\
eJzNVU2IUlEUvq878xbCIBiBEojtdNBBKVqJgouiRNwpuBNfwzw0jGkWgsII
BS2KKGYILrYNml1EtS5ciQ8XibUWrKEgaNOijad77vXvjTffRC0Cv+O93z3n
O+8e3zlmins7N24W98xSMXB1t3hrxyzdDlyp7nKKaoRoAULIuQDBNfDlxAD/
wAU0yPzZ+rr4oq/S6fTQ7/eLXUpy7yORSDsejy9y391u97NCoSB21/53iTVp
w/ClfwivywfwprIJXwdRNa0rEs4U+ty1zF0r3HUwV7DTuuLxpgr9PhyWy3BQ
qcDmYABRNb0hL7MuheLtdnubMYYgKWHF433zeDxyJ6x+h91vAMuQKcYso+2z
B82t1cfrUgPVPvt8Prtig4fwV2WCMdN4SHOuqD6eKP7Udf1jMBi0KTYajN9s
hrGmsf1mk22tPtalxuVOpyNqIupiK9IT0zRhoRcIOSuW9F6tVvtNjH84HF60
LAtBUsJS/M2PvV6v3En7wnqYBWubIMgZYemR9Tg3iw2f0m+ih2/mh1AoZM+R
5bH80TkwlojYnCKHg99E74fL5XqXSCRsObJZi99egMeipUe5nLWUw8lvTfqd
H41GJ0urakB5RC/Bpy5AkyC4LFqK3TeTCJ/SjypadJaj2xXDDUR50FLsz+Uc
Dn5U0cTTHPNQEOXhHHbwUg4nP5fjzMJStOClgYjBcS+qplfMLLxoCwwDEYPe
XMFOr5hZeI2WYQjEer3pzDpJb/zrGf6oWq2izKL783w+/7RUKi1yb5PJ5N16
vb4o8Tf/hUT7BSb5mzQ=\
\>"]]
}, Open  ]]
}, Open  ]],

Cell["\<\
We represent the electronic density function \[Rho][x] of the silicon atom by \
the following function
containing a coefficient coefnorm to be determined,
by imposing the normalization  of the electronic density (in the case of \
silicon Z=14).
Clearly, the period of  Sin[x]^2n is one half of the period of  Sin[x].\
\>", "Text",
 CellChangeTimes->{{3.49795814646875*^9, 3.4979581888125*^9}, {
   3.49795824053125*^9, 3.497958316*^9}, {3.497959406296875*^9, 
   3.497959420546875*^9}, {3.498043168328125*^9, 3.498043187546875*^9}, {
   3.498106516515625*^9, 3.49810655075*^9}, 3.498811881546875*^9, {
   3.498827995140625*^9, 3.49882799565625*^9}, 3.49882868975*^9, 
   3.552473872765625*^9, {3.552473968390625*^9, 3.55247402665625*^9}, {
   3.553260807015625*^9, 3.553260815*^9}, {3.553753211917671*^9, 
   3.5537532471483917`*^9}, {3.5537532772628927`*^9, 3.553753310106073*^9}, {
   3.553775339564728*^9, 3.553775388928371*^9}, {3.5538272658268547`*^9, 
   3.553827271558619*^9}, {3.553827318764749*^9, 3.553827365915971*^9}, {
   3.553827426142563*^9, 3.553827457019126*^9}, 3.553828090670125*^9, {
   3.553828174641241*^9, 3.553828202866152*^9}, {3.574943132840713*^9, 
   3.57494313890244*^9}, {3.574943229021974*^9, 3.57494323680661*^9}, {
   3.574943304707011*^9, 3.5749433047071123`*^9}, {3.5750891979997683`*^9, 
   3.575089219260971*^9}, 3.575096334352598*^9, {3.575096387660264*^9, 
   3.57509638997435*^9}, {3.575096422064083*^9, 3.5750964514221077`*^9}, {
   3.5752582118785954`*^9, 3.5752582306306677`*^9}},
 FontFamily->"Times New Roman",
 FontSize->26,
 FontColor->GrayLevel[0],
 Background->GrayLevel[0.85]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"\[Rho]", "[", "x_", "]"}], "=", 
  RowBox[{"coefnorm", " ", 
   RowBox[{
    RowBox[{"(", 
     RowBox[{"Sin", "[", 
      RowBox[{"2", " ", "\[Pi]", " ", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{"x", "+", 
          RowBox[{
           SubscriptBox["width", "at"], "/", "2"}]}], ")"}], "/", 
        RowBox[{"(", 
         RowBox[{"2", "*", 
          SubscriptBox["width", "at"]}], ")"}]}]}], "]"}], ")"}], "^", 
    "6"}]}]}]], "Input",
 CellChangeTimes->{{3.428806000296875*^9, 3.4288060590625*^9}, 
   3.49779292540625*^9, {3.497849788171875*^9, 3.497849791703125*^9}, {
   3.497849829203125*^9, 3.497849845859375*^9}, {3.49785269434375*^9, 
   3.497852696*^9}, {3.49785405859375*^9, 3.497854061765625*^9}, {
   3.49785507915625*^9, 3.497855079515625*^9}, 3.497856711921875*^9, {
   3.4978570273125*^9, 3.49785702796875*^9}, {3.4978689468125*^9, 
   3.497868950515625*^9}, {3.497868984640625*^9, 3.4978689888125*^9}, {
   3.4978770133125*^9, 3.49787701775*^9}, {3.497944703328125*^9, 
   3.497944735046875*^9}, {3.497944849859375*^9, 3.49794485071875*^9}, {
   3.497953876109375*^9, 3.49795387746875*^9}, 3.49795399771875*^9, 
   3.49795567959375*^9, {3.4979612845*^9, 3.49796133075*^9}, {
   3.49796154209375*^9, 3.4979615465625*^9}, {3.497962578046875*^9, 
   3.497962589390625*^9}, 3.497962635921875*^9, 3.498043147984375*^9, {
   3.498043273671875*^9, 3.498043279375*^9}, {3.49804346625*^9, 
   3.49804347503125*^9}, {3.498043753203125*^9, 3.49804375465625*^9}, {
   3.498043808703125*^9, 3.498043812453125*^9}, 3.498046689875*^9, {
   3.498047494171875*^9, 3.49804751059375*^9}, {3.55149477534375*^9, 
   3.551494781296875*^9}, {3.551494824203125*^9, 3.55149484725*^9}, 
   3.551494880015625*^9, {3.55149728784375*^9, 3.551497289421875*^9}, {
   3.5532316476875*^9, 3.553231647859375*^9}, {3.553231859171875*^9, 
   3.55323187140625*^9}, {3.55324905078125*^9, 3.55324907203125*^9}, {
   3.553250599953125*^9, 3.5532506140625*^9}, {3.5533432490792913`*^9, 
   3.553343251245709*^9}},
 FontSize->24],

Cell[BoxData[
 RowBox[{"coefnorm", " ", 
  SuperscriptBox[
   RowBox[{"Sin", "[", 
    RowBox[{
     FractionBox["200000000000", "27"], " ", "\[Pi]", " ", 
     RowBox[{"(", 
      RowBox[{
       FractionBox["27", "400000000000"], "+", "x"}], ")"}]}], "]"}], 
   "6"]}]], "Output",
 CellChangeTimes->{3.5776832828336*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"coe", "=", " ", 
  RowBox[{"Solve", "[", " ", 
   RowBox[{
    RowBox[{
     RowBox[{"Integrate", "[", 
      RowBox[{
       RowBox[{"\[Rho]", "[", "x", "]"}], ",", 
       RowBox[{"{", 
        RowBox[{"x", ",", 
         RowBox[{"-", 
          FractionBox[
           SubscriptBox["width", "at"], "2"]}], ",", 
         FractionBox[
          SubscriptBox["width", "at"], "2"]}], " ", "}"}]}], "]"}], 
     "\[Equal]", "14"}], ",", "coefnorm"}], "]"}]}]], "Input",
 CellChangeTimes->{{3.428806000296875*^9, 3.4288060590625*^9}, 
   3.49779292540625*^9, {3.497849788171875*^9, 3.497849791703125*^9}, {
   3.497849829203125*^9, 3.497849845859375*^9}, {3.49785269434375*^9, 
   3.497852696*^9}, {3.49785405859375*^9, 3.497854061765625*^9}, {
   3.49785507915625*^9, 3.497855079515625*^9}, 3.497856711921875*^9, {
   3.4978570273125*^9, 3.49785702796875*^9}, {3.4978689468125*^9, 
   3.497868950515625*^9}, {3.497868984640625*^9, 3.4978689888125*^9}, {
   3.4978770133125*^9, 3.49787701775*^9}, {3.497944703328125*^9, 
   3.497944735046875*^9}, {3.497944849859375*^9, 3.49794485071875*^9}, {
   3.497953876109375*^9, 3.49795387746875*^9}, 3.49795399771875*^9, 
   3.49795567959375*^9, {3.497957553046875*^9, 3.497957577671875*^9}, {
   3.497957677421875*^9, 3.497957715078125*^9}, 3.4979579236875*^9, {
   3.497958027453125*^9, 3.497958039140625*^9}, {3.498043420171875*^9, 
   3.498043448296875*^9}, {3.498043784078125*^9, 3.498043818203125*^9}, {
   3.4980474783125*^9, 3.498047485234375*^9}, {3.553247442828125*^9, 
   3.553247488109375*^9}, {3.553247561296875*^9, 3.553247562859375*^9}, {
   3.553248550875*^9, 3.553248554203125*^9}},
 FontSize->24],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"{", 
   RowBox[{"coefnorm", "\[Rule]", 
    FractionBox["8960000000000", "27"]}], "}"}], "}"}]], "Output",
 CellChangeTimes->{3.577683283747015*^9}]
}, Open  ]],

Cell["Simple check.", "Text",
 CellChangeTimes->{{3.553753419543477*^9, 3.553753476721383*^9}, {
  3.553753514339069*^9, 3.553753556975505*^9}, {3.553753594228037*^9, 
  3.553753639319337*^9}, {3.553776476521082*^9, 3.5537766675327187`*^9}, {
  3.553783813271534*^9, 3.5537838254436207`*^9}, {3.574944471895488*^9, 
  3.574944519174021*^9}, {3.574944597242223*^9, 3.574944628498501*^9}, {
  3.574944676006432*^9, 3.5749446837424583`*^9}},
 FontFamily->"Times New Roman",
 FontSize->26,
 FontColor->GrayLevel[0],
 Background->GrayLevel[0.85]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"Integrate", "[", 
   RowBox[{
    RowBox[{
     RowBox[{"\[Rho]", "[", "x", "]"}], " ", "/.", " ", 
     RowBox[{"coefnorm", "\[Rule]", " ", 
      RowBox[{"coe", "[", 
       RowBox[{"[", 
        RowBox[{"1", ",", "1", ",", "2"}], "]"}], "]"}]}]}], ",", 
    "\[IndentingNewLine]", 
    RowBox[{"{", 
     RowBox[{"x", ",", 
      RowBox[{"-", 
       FractionBox[
        SubscriptBox["width", "at"], "2"]}], ",", 
      FractionBox[
       SubscriptBox["width", "at"], "2"]}], " ", "}"}]}], "]"}], "//", " ", 
  "N"}]], "Input",
 CellChangeTimes->{{3.55324753528125*^9, 3.55324754540625*^9}, {
  3.553247619859375*^9, 3.553247641625*^9}, {3.553247699390625*^9, 
  3.553247701078125*^9}, {3.55324773346875*^9, 3.55324777775*^9}, {
  3.55324858065625*^9, 3.5532485835625*^9}},
 FontSize->24],

Cell[BoxData["14.`"], "Output",
 CellChangeTimes->{3.577683283922353*^9}]
}, Open  ]],

Cell[BoxData[
 RowBox[{
  RowBox[{"\[Rho]1", "[", "x_", "]"}], " ", ":=", " ", 
  RowBox[{
   RowBox[{"\[Rho]", "[", "x", "]"}], "/.", " ", 
   RowBox[{"coefnorm", "\[Rule]", " ", 
    RowBox[{"coe", "[", 
     RowBox[{"[", 
      RowBox[{"1", ",", "1", ",", "2"}], "]"}], "]"}]}]}]}]], "Input",
 CellChangeTimes->{{3.553251009671875*^9, 3.553251053140625*^9}},
 FontSize->24],

Cell[TextData[{
 "To evaluate the coefficients ",
 Cell[BoxData[
  FormBox[
   RowBox[{
    SubscriptBox["\[Chi]", "g"], " ", 
    RowBox[{"(", 
     StyleBox[
      RowBox[{"2.2", ".87"}], "Text"], 
     StyleBox[")", "Text"]}], "  ", "it", " ", "is", " ", "convenient", " "}],
    TraditionalForm]]],
 "to consider the electronic density centered at the origin of the cell.\nWe \
will examine later an alternative path."
}], "Text",
 CellChangeTimes->{{3.553753419543477*^9, 3.553753476721383*^9}, {
  3.553753514339069*^9, 3.553753556975505*^9}, {3.553753594228037*^9, 
  3.553753639319337*^9}, {3.553776476521082*^9, 3.5537766675327187`*^9}, {
  3.553783813271534*^9, 3.5537838254436207`*^9}, {3.5749447602150183`*^9, 
  3.574944765764537*^9}, {3.574945033859393*^9, 3.5749450376377974`*^9}, {
  3.575258237068036*^9, 3.575258245198501*^9}},
 FontFamily->"Times New Roman",
 FontSize->26,
 FontColor->GrayLevel[0],
 Background->GrayLevel[0.85]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"\[Rho]1", "[", "x_", "]"}], " ", "=", " ", 
  RowBox[{
   RowBox[{"\[Rho]", "[", "x", "]"}], "/.", " ", 
   RowBox[{"coefnorm", "\[Rule]", " ", 
    RowBox[{"coe", "[", 
     RowBox[{"[", 
      RowBox[{"1", ",", "1", ",", "2"}], "]"}], "]"}]}]}]}]], "Input",
 CellChangeTimes->{{3.553251009671875*^9, 3.553251053140625*^9}, 
   3.5537773096955347`*^9},
 FontSize->24],

Cell[BoxData[
 RowBox[{
  FractionBox["8960000000000", "27"], " ", 
  SuperscriptBox[
   RowBox[{"Sin", "[", 
    RowBox[{
     FractionBox["200000000000", "27"], " ", "\[Pi]", " ", 
     RowBox[{"(", 
      RowBox[{
       FractionBox["27", "400000000000"], "+", "x"}], ")"}]}], "]"}], 
   "6"]}]], "Output",
 CellChangeTimes->{3.5776832841348057`*^9}]
}, Open  ]],

Cell["\<\
The width of the silicon atom is indicated by the following  two red dots\
\>", "Text",
 CellChangeTimes->{{3.553753419543477*^9, 3.553753476721383*^9}, {
  3.553753514339069*^9, 3.553753556975505*^9}, {3.553753594228037*^9, 
  3.553753639319337*^9}, {3.553776476521082*^9, 3.5537766675327187`*^9}, {
  3.553783813271534*^9, 3.5537838254436207`*^9}, {3.5749447602150183`*^9, 
  3.574944765764537*^9}, {3.574944961816679*^9, 3.5749449981278048`*^9}},
 FontFamily->"Times New Roman",
 FontSize->26,
 FontColor->GrayLevel[0],
 Background->GrayLevel[0.85]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"graph\[Rho]1", "=", 
  RowBox[{"Plot", "[", 
   RowBox[{
    RowBox[{"\[Rho]1", "[", "x", "]"}], " ", ",", 
    RowBox[{"{", 
     RowBox[{"x", ",", 
      RowBox[{
       RowBox[{"-", 
        SubscriptBox["width", "at"]}], "/", "2"}], ",", 
      RowBox[{
       SubscriptBox["width", "at"], "/", "2"}]}], "}"}], ",", 
    "\[IndentingNewLine]", 
    RowBox[{"Epilog", "->", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"PointSize", "[", "0.01", "]"}], ",", "Red", ",", 
       RowBox[{"Point", "[", "coord1CG", "]"}]}], "}"}]}], ",", 
    RowBox[{"PlotRange", "\[Rule]", "All"}]}], "]"}]}]], "Input",
 CellChangeTimes->{
  3.4288042703125*^9, {3.49778604878125*^9, 3.49778605965625*^9}, 
   3.4977861058125*^9, {3.49785387028125*^9, 3.497853884921875*^9}, 
   3.49785671559375*^9, {3.497857394734375*^9, 3.497857397078125*^9}, 
   3.49786902040625*^9, 3.4978770305*^9, {3.497944771953125*^9, 
   3.49794477259375*^9}, {3.4979448625625*^9, 3.4979448636875*^9}, {
   3.4979540598125*^9, 3.497954172265625*^9}, {3.497955714734375*^9, 
   3.497955717125*^9}, {3.49795838578125*^9, 3.497958388171875*^9}, 
   3.497961577203125*^9, {3.497961713953125*^9, 3.497961715859375*^9}, {
   3.497961849203125*^9, 3.49796195371875*^9}, {3.497962691828125*^9, 
   3.497962719796875*^9}, {3.4979630325*^9, 3.49796307140625*^9}, {
   3.49796322521875*^9, 3.49796323203125*^9}, {3.497963678203125*^9, 
   3.49796369953125*^9}, {3.497963735796875*^9, 3.497963738140625*^9}, {
   3.497964055828125*^9, 3.497964059265625*^9}, {3.49796409296875*^9, 
   3.497964095546875*^9}, {3.497965051734375*^9, 3.497965055*^9}, {
   3.49804353478125*^9, 3.498043555296875*^9}, {3.498043595328125*^9, 
   3.4980435973125*^9}, {3.49804363465625*^9, 3.49804364075*^9}, 
   3.498043686078125*^9, {3.498043725515625*^9, 3.49804374590625*^9}, {
   3.49804385228125*^9, 3.498043854109375*^9}, 3.498043985703125*^9, 
   3.4980440170625*^9, 3.498046689890625*^9, 3.4980475526875*^9, {
   3.55149489528125*^9, 3.55149489840625*^9}, {3.551495004671875*^9, 
   3.55149501709375*^9}, {3.551497540078125*^9, 3.5514975621875*^9}, {
   3.5514976541875*^9, 3.551497654796875*^9}, 3.5514979865*^9, {
   3.551498275953125*^9, 3.5514982804375*^9}, {3.551498313609375*^9, 
   3.551498354703125*^9}, 3.5514984259375*^9, {3.551498623046875*^9, 
   3.5514986278125*^9}, {3.55149871228125*^9, 3.551498712859375*^9}, {
   3.551498783921875*^9, 3.55149879471875*^9}, 3.551498872234375*^9, {
   3.55158288580766*^9, 3.5515828866717463`*^9}, {3.551767493671875*^9, 
   3.551767503609375*^9}, {3.551767559015625*^9, 3.551767560015625*^9}, {
   3.551767594671875*^9, 3.551767598328125*^9}, 3.551767963671875*^9, {
   3.553231775125*^9, 3.553231781015625*^9}, {3.55323182396875*^9, 
   3.553231833640625*^9}, {3.553231882578125*^9, 3.55323189565625*^9}, {
   3.553249080578125*^9, 3.55324908346875*^9}, 3.55325096315625*^9, 
   3.553251023390625*^9, 3.55325109021875*^9, {3.55325594278125*^9, 
   3.553256004140625*^9}, {3.55325604009375*^9, 3.55325604071875*^9}, 
   3.553256202015625*^9, {3.553776408942176*^9, 3.55377643997792*^9}},
 FontSize->24],

Cell[BoxData[
 GraphicsBox[{{}, {}, 
   {Hue[0.67, 0.6, 0.6], LineBox[CompressedData["
1:eJwtm3c4l9//x5VCGUmyiuxZGUXI4T43KorsFRlZZaQIWSGzEDKiiEIISSjj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     "]]}},
  AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
  Axes->True,
  AxesLabel->{None, None},
  AxesOrigin->{0, 0},
  AxesStyle->Directive[20, 
    Thickness[0.005], 
    RGBColor[0, 0, 1]],
  Epilog->{
    PointSize[0.01], 
    RGBColor[1, 0, 0], 
    PointBox[{{-6.75*^-11, 0}, {6.75*^-11, 0}}]},
  ImageSize->700,
  LabelStyle->(FontFamily -> "Helvetica"),
  Method->{},
  PlotRange->{All, All},
  PlotRangeClipping->True,
  PlotRangePadding->{Automatic, Automatic}]], "Output",
 CellChangeTimes->{
  3.577683284199679*^9},ImageCache->GraphicsData["CompressedBitmap", "\<\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\
\>"]]
}, Open  ]],

Cell["\<\
As the function is intrinsically periodic, we could  take advantage of the \
following command
to restrict the domain of the electronc  density\
\>", "Text",
 CellChangeTimes->{{3.553753419543477*^9, 3.553753476721383*^9}, {
  3.553753514339069*^9, 3.553753556975505*^9}, {3.553753594228037*^9, 
  3.553753639319337*^9}, {3.553776476521082*^9, 3.5537766675327187`*^9}, {
  3.553776782357346*^9, 3.553776823902068*^9}, {3.553776893748953*^9, 
  3.5537768945932207`*^9}, {3.5537770827883577`*^9, 3.553777155219255*^9}},
 FontFamily->"Times New Roman",
 FontSize->26,
 FontColor->GrayLevel[0],
 Background->GrayLevel[0.85]],

Cell[BoxData[
 RowBox[{
  RowBox[{"\[Rho]p", "[", "x_", "]"}], ":=", 
  RowBox[{"Piecewise", "[", 
   RowBox[{"{", "    ", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"\[Rho]1", "[", "x", "]"}], ",", 
       RowBox[{
        RowBox[{
         RowBox[{"-", 
          SubscriptBox["width", "at"]}], "/", "2"}], "\[LessEqual]", "x", 
        "\[LessEqual]", 
        RowBox[{
         SubscriptBox["width", "at"], "/", "2"}]}]}], "}"}], ",", 
     "\[IndentingNewLine]", 
     "                                                       ", 
     RowBox[{"{", 
      RowBox[{"0", ",", 
       RowBox[{
        RowBox[{
         RowBox[{"-", 
          SubscriptBox["width", "at"]}], "/", "2"}], " ", "\[LessEqual]", " ",
         "x", " ", "\[GreaterEqual]", " ", 
        RowBox[{
         SubscriptBox["width", "at"], "/", "2"}]}]}], "}"}]}], 
    "\[IndentingNewLine]", "                                    ", "}"}], 
   "]"}]}]], "Input",
 CellChangeTimes->{{3.551498491640625*^9, 3.5514986003125*^9}, 
   3.55149887221875*^9, {3.551767390609375*^9, 3.5517674035625*^9}, {
   3.55176789890625*^9, 3.55176795065625*^9}, {3.551767999828125*^9, 
   3.551768017375*^9}, 3.5517681059375*^9, {3.553231940296875*^9, 
   3.553231952640625*^9}, {3.553231999359375*^9, 3.553232080390625*^9}, {
   3.553249092765625*^9, 3.553249100859375*^9}, 3.55325110878125*^9, {
   3.553776866432743*^9, 3.553776868500639*^9}},
 FontSize->24],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"graph\[Rho]p", "=", 
  RowBox[{"Plot", "[", 
   RowBox[{
    RowBox[{"\[Rho]p", "[", "x", "]"}], ",", 
    RowBox[{"{", 
     RowBox[{"x", ",", 
      RowBox[{
       RowBox[{"-", "3"}], 
       SubscriptBox["width", "at"]}], ",", 
      RowBox[{"3", 
       SubscriptBox["width", "at"]}]}], " ", "}"}], ",", 
    RowBox[{"Epilog", "->", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"PointSize", "[", "0.01", "]"}], ",", "Red", ",", 
       RowBox[{"Point", "[", "coord1CG", "]"}]}], "}"}]}], ",", 
    RowBox[{"PlotRange", "\[Rule]", "All"}]}], "]"}]}]], "Input",
 CellChangeTimes->{
  3.4288042703125*^9, {3.49778604878125*^9, 3.49778605965625*^9}, 
   3.4977861058125*^9, {3.49785387028125*^9, 3.497853884921875*^9}, 
   3.49785671559375*^9, {3.497857394734375*^9, 3.497857397078125*^9}, 
   3.49786902040625*^9, 3.4978770305*^9, {3.497944771953125*^9, 
   3.49794477259375*^9}, {3.4979448625625*^9, 3.4979448636875*^9}, {
   3.4979540598125*^9, 3.497954172265625*^9}, {3.497955714734375*^9, 
   3.497955717125*^9}, {3.49795838578125*^9, 3.497958388171875*^9}, 
   3.497961577203125*^9, {3.497961713953125*^9, 3.497961715859375*^9}, {
   3.497961849203125*^9, 3.49796195371875*^9}, {3.497962691828125*^9, 
   3.497962719796875*^9}, {3.4979630325*^9, 3.49796307140625*^9}, {
   3.49796322521875*^9, 3.49796323203125*^9}, {3.497963678203125*^9, 
   3.49796369953125*^9}, {3.497963735796875*^9, 3.497963738140625*^9}, {
   3.497964055828125*^9, 3.497964059265625*^9}, {3.49796409296875*^9, 
   3.497964095546875*^9}, {3.497965051734375*^9, 3.497965055*^9}, {
   3.49804353478125*^9, 3.498043555296875*^9}, {3.498043595328125*^9, 
   3.4980435973125*^9}, {3.49804363465625*^9, 3.49804364075*^9}, 
   3.498043686078125*^9, {3.498043725515625*^9, 3.49804374590625*^9}, {
   3.49804385228125*^9, 3.498043854109375*^9}, 3.498043985703125*^9, 
   3.4980440170625*^9, 3.498046689890625*^9, 3.4980475526875*^9, {
   3.55149489528125*^9, 3.55149489840625*^9}, {3.551495004671875*^9, 
   3.55149501709375*^9}, {3.551497540078125*^9, 3.5514975621875*^9}, {
   3.5514976541875*^9, 3.551497654796875*^9}, 3.5514979865*^9, {
   3.551498275953125*^9, 3.5514982804375*^9}, {3.551498313609375*^9, 
   3.551498354703125*^9}, 3.5514984259375*^9, {3.551498623046875*^9, 
   3.5514986278125*^9}, {3.55149871228125*^9, 3.551498712859375*^9}, {
   3.551498783921875*^9, 3.55149879471875*^9}, 3.551498872234375*^9, {
   3.55158288580766*^9, 3.5515828866717463`*^9}, {3.551767493671875*^9, 
   3.551767503609375*^9}, {3.551767559015625*^9, 3.551767560015625*^9}, {
   3.551767594671875*^9, 3.551767598328125*^9}, 3.551767963671875*^9, {
   3.553232093328125*^9, 3.553232114203125*^9}, {3.55324910453125*^9, 
   3.553249107359375*^9}, 3.55325610815625*^9, 3.553256212375*^9, {
   3.553777183128254*^9, 3.553777232802731*^9}},
 FontSize->24],

Cell[BoxData[
 GraphicsBox[{{{}, {}, 
    {Hue[0.67, 0.6, 0.6], LineBox[CompressedData["
1:eJxTTMoPSmViYGAwBWIQ3bfS79jVK7/3MkDBtt1nvpddQPDvnfXSlDiD4Ot9
cuuJOozgn7WyD7q/EcHnOaN/70Ufgt/1TuDbbw8Ev934sqrS3l9w/h2dgjnP
e3/C+YVPnzocLfoB5/+a7rnNIPY7wj07jzqJGnyD85lmS/0VFP8K5ze9bj/X
/uwznP/N9HFB9+5PcP5Ke3HH5Us+wvk7diRr2JR9gPN5HwlWX9r+Ds6f6Gbh
7tH3Bs4/09nvuMH0FcI/3jOme7C+gPN/vr4ofXnpUzg/uOG5Y2XgYzhfZ/K6
w/6qD+H8Kk7f5wZT7sL5s17O/6ekdxPOF9iTFyEkjeC39dluYuRA8IuNb6c+
eHgDzvepFTs7dyqC/0+gd7bE3+twfpJFlQXfmWtw/g0uz0l/dyD4fnfF37xZ
iuBbN22df7oewRc584Gt0xjBPxaffpV59lU4X6s9pOhn5hU438HSaKVjOIIf
+pr/QacLgt/gf9pXSh7BvybupGl95TKc/+akfELzQQSfsebvtNPrEHydBztY
YjoR/KYV+g9q7BD8GVG84ke1Efy1PK99eSUR/BsFy3bP/XwJzn+n1PLp6QME
n/lqoqbeOQRfz1J2+r4VCH7t4+RbAgsQfABDg/c3
      "]], LineBox[CompressedData["
1:eJwtmHk0FG7cxe1LSalERSkhkSVLWR7meWTPNpNClBD5paRkibJEsu9rlpCy
JbKFntJYZswMZiYJbSKRLFGJsry9533/+p7P+Z5z71/3j3v3uHgTz3FxcHCY
c3Jw/O/VXxCfbwhi46Pbdiof4UvSv2TVoJN5mY31n0l39aew9CM40658dGLj
EVq5T5+RKCG71qdMzpyNr37JmSiQNyBUnbMa9j7Cxm9EEl4QJM4R2sUOij2V
YeOZbzKih63DCINd6yw5tvzTW7k1IUXMJMwETUSYcLDxw0lL+2qTCgKPUmdL
0jQL84tWbeZofEbYMVw8PzDEwmf7AgIu9dEJyilh8nuoLJwWE+b4XH+QcPTo
GWfPeha+Or/Zqax2jOCwoJtZU8TCt+KqVpP65giXS3f0LCWy8JZLAhGX1ZYJ
kQ6LPOgGC5eh9U3y6bwwR6hfJ+Y/FmaRnpxf27AJVj+vvcI+ycKu8zs+Hz0m
BjsvJ5ftMGRh3rXwfv9oKfh2r/ewyyEWlglbZ3eTVw5+7zsmVrGbheev/c4W
vKkM+aIOWP4QYuEcqsLxRTUNKKElEKnzh4kZRwZp7jK6UPXbWMutcSa2PSFw
pvYygkZ5bfP0Pib2a9m/UDxsDB2tCuW3kplY86TbesN0S3iFM8TZ8TETz1Hm
sxdcSTCq1jHzfi4TO3hMNUQ62sHcc9o9U9FMXJat02Frdxo+ERPn1fBnYuUs
HsKLFy6Q2vVL54YbE7+ekPulueYO3we9utJhw8SPpj+82sbtBecP1pRt0Gfi
63WzBgd+XIYCwwnDtopMzPVV8qeuqy/cleIllr+diRMa6sDnswFQ7aiZ5Rc+
Jj51kT+uiuMGTJ6yWuc00Yuza2VGj8uHwWfW6wOmyb2YTmXFa2tGwC91nWM3
8nrxu5wdp+WfREGR7eEk4YBefPzCcpNEWSzcl77Yuce2F/um1n9W70+EmiLe
2hqHevH41kMfHFEKNI0fe2SysRefbk65azycBh0FHfc4TvXgc42RAwr0TOgd
yU7z7urBO85tePdM8C4M5zQVuPWgB7eIoHebi/Nh+o0XQRm3erAOt8enE1aF
sHRJY7bMuQdnV/LN6oQXw5ZrlS4Y9ODGhDg9t5kS2DO3t5+5owd/qY7QVssq
hZ8uZpt+/t2Nfy58MDKMqIA/v27Ev/u6MedFOHm5sQryu99WWf+kG8v9bf7p
urMG7hhZLt6V2I2P8W8+wOCuhYShrzGGpt24sHUpRMChEZJOOK/ayXbjRRVG
fUd3E3Rn9/t4cXdj74fD+Zv9nsFAS4uxkGEG/n1hulXtxAsYR2uzS8UM/KEh
bRflyEtYYKTNeJDDwN8zkVDfGBk+IVfrN/szcGUCQ3drXTt805wn+0mVgePK
jSWYLVQ4qbk156cwA3Oe8042WqLB5ScxGwSm6LjigsX02JluuFGZM2xnFx0f
cmaUvp7rhXsr/H8qPaDjTeYXBB/asaCG3IwHukXH9+4nSx9jsqFJsdtbW2c6
3irpspH/bB+8dNeGHLyDjq/pfSm6y34Dw8SoGkm/abgypjNmsX4QpqXqlRX3
0bD5xsR8n8a3sDlWIYmWQMMb473fr98wDLv5i7g/XKDhi45Zojz6n+DwLXH/
ORMaRrGz5d3hI5A3mPe0ODcNB4u4q5DRGBRfDGIpDHfhLOHeD16tX+AB3/mj
+rgLH+1NOjJBnIDWXh8V3P27sIvs00C/pm/QdcK2IPB4F1YrUzLYlzgN/dwY
m+NVu/C6DWz9geBZmOvYtFT7jYqDc0Zf9bHm4OMB5YsUKhVv61Ur152dh+Tj
D4aHSqgY1l5usN/xE04cS6VwOlMxy4tb5urdBfiXKqgjCv79Va4KEOd/Q2HD
0Kr9O6j4W0nYYrndElQHF9Ot+ii4+6tTd7btMjRuGhVwraHgOXeZd+LTK9BB
wyHYL4GCE9JHtn9OX4OhB41d80wouFTuVMzdBE5El9yj+u1ZJ37FzJ/5FMWL
aA+vUzZkdmLtV1xt5o18iKra56Ti04kLvY5GbP7Bj9oNo2KuyXTia1U7ez8l
rUPk3mGprLUOTFv3o/nmj/Xopb12Y/NgB47Tkt1f6LoBPb84PboW34GLHD7J
MzQ3oWe/ja7vPd+Bu70Z8yvcIqgl7N4mQ9SBjZzua4YNiKCn6SQQs9COrZxG
nHmztqAnuClj65l2PPUx4849XzFUbbzl4GGtdszr0j+6EiKOHrO82uy3tOMa
huhAZep2VDm2+3s+pQ0HHNYv9e7biUo23DaVV2nDBuoKV5XPSKH7mR8/mq9r
w7WivBUp/HtQ0R4tv0ufydgzCHuE1u1B+RpTRbVZZOxrZxQlJSGNspyIy4CT
jGttz7AspWVRxnhFivPbl7jvk7Dql++yKN2HV/5W/UvcYmEyp9cmh1Iin9pS
PV/iP0pxXQQ/eRT7aNdjIrsVk6UJb8tED6KYwwGG1ypbscLLAhE/QSV05yXr
bebtVlzZG5TJw6WMIl5HCLzXbsW33V5GVISqoOU/r9t6jF7gbOk8sDH3EFoS
jv6+5e9z3PP5UkDpfjW0sFdX0v7xc6yu1rItolENzZoV+Y2KPcc+G84f+vpW
HY3kXJJfnHiGt4l4v72rdxhRtfkT98Q2Y771p9PcXXVR+k0VitfRZizooOuY
zAOQC9l+rXGlCQu+kO6SfQjQX9NKb8vLTXjTNb2Is9/1kJK9jXWQ7VMMKrT8
BqgElOp/V+T17gZcry68qyrMAJ2uU067U1eDCxT1f9HFTJHCoh3j1cUaTD2Q
+BdeNkWLOuE8u+VqcG6QXfZZqilKbuvzrc+uxtsfGZhf8zdDUSU/yttXqvD3
fk4Ku9ccEUeiDgaklOOpJlR+y9kSffMcyhPmLcc+5gTpvipLFDGnKFziX4Yp
HE2fFJctUSMHe4blWIp59dRVmKlWSGK3RLWC3AM80CDK/dXBGjU8uCRFzi7B
tas3t1TesEZWSi+T7IRKMEstJKq7wBqFA3efyLlifN4rnb19xBqNn6o+9LGl
EG+OJUWeOW2Drg8HxuqqFmJqu0Xt+iAbJHzO4HP2g3vY0enTieUMG3T+XaVC
2d4C7HtRojyXYYMSxvTfu27IxwE7kj0Mv9iguhl2wq7FXDx+PbFx35oN4uRc
mkvtzsEvhyRVrisR0f51ccWWT7Px+bQ2ucmjRGS5ZbetYHEWDj1rYxPhQEQ5
MoZPbwZk4Ivs24sKt4ioVWnAU8s1Hf+tr9+unkFE44cv7PxpkYZ9or7UnSol
InWz5Jue0il4Rkp8YK2LiBxI+1T2CSfjeifyhP8gEXE1XWrDc4m4VLcwkm+C
iKzoabJqlHh8zk7nedkvIsp93xxdmhuLna8Ot57hIqGvs8NTkleiMWma562s
MAlpcvFbpxpH4SrFzMAVcRIK33qwVkAyEruNW8qP7CWhXlnStpvz4Xj18ELG
KwUSktAKDPxBCcXnL1YmMtVIiJ2h18TSvoH5I/dyDmiTkFdLTMizsQC8FbKW
JggkxDvcb/gwyRdf7t5fxmVEQgU80kIpOpexxETTmX1mJORD/HB/ieGBx8Pt
Ei0sSMj08LRLvuFprNx/mH7DioScU3UWU0ZM8df3a5Q6axK6n9hZfjBOFZTq
vDs1/4/DRcJsnBttgcj1iJua/zhBf3/uUKQrYD0GpmGWJOSwkLiRV8ULpIS9
XmCbk1Baf9BLsYtXgFJExqiCCQn9qVH+q0j2A4JcmvFxBv/84kfVkVgQeCrX
kvILkFDn+cxLJ71CgFv+mTqPwyS0rUjmeMNwGJjP8Xw1qkxCtMS174T1ESDz
wtrcf3IkdOPGYDxd4za4mPDz0KokCalcqD1wwvkO2OqUNJi/hYRG7eIpwzEx
oPGUpamlAAllGHm4XaiPA0TtLF7hZSJaTdpgRYhMAqolFhs7holoIOp6XmRO
MrDJcudoZRFRzc3xb7THKcCf8DiC/ZKI3Lxe3rEdSgPMCNH3RgVEpOeq9CZn
Nh3ELpw2ehRHROIOd2WGeTLBZyMzL/VAIqIbXyP/p5wN9jocOv7Yioju641s
qj6aA8yyIxNKtYjopobVmV/2d8GbbWLXuvcS0SFp+eWQiDwg+ibf8cG8DToW
MpNDm7oHBqT3lM/csUHr27IaVG4VAusQDy7l/2wQjc+AnbG9CFRVHFdNN7NB
JgmZgq5GxUALHjD9ImCDDPIIAX8LSsBt8/h2uWBrpN2SYqtIKgek2vAzj29Z
oqVVXZ+Ur+XgCTOmv1fZEj1F43GLIRVA5PyOXZNDFkiTptPeXlkJ+lVPC+sq
WSDVwc+HnPgeg88nRsxLaeYoLWinAOVdDWihCbdYjZkg37zvon/knoD061fr
8G0TRHrRIX3w6hOw2fjdo3E5E7SZ+7J+qmAtmNQc3F7gaYySYtr9zmjWAQ37
G2Mj3wxRbPbFsd+JDcDgWkBM8i+EwhtfkPcbtACHw7l1o53aKKVsV4dtdAuQ
N7AptVfURoV3b1DCe1uAjFYu81yqFmoN0WG8O/UMdJ1+aOnufgStGje+/hcH
MOwzPLgopYmEtbcN4GYMBoye829N00CSiteGJjmeg4JLuyGfoAbS3aT28Wj8
c+B6ob7hzqIaChqomlgseQGa1eMq8mZUUQxtwzeZqRfARGKUQ8hHFVmcbvCT
394KViz2TAT8UkFO1qKBJ860AhNVf7YDjwoKVn91o/pbK3DHf9o5rymi5mXL
KDceMhAP3Gn/32ZZRL52UyBIjgzGa3/7hNjJINrMo+hkMzL48a+nFRXtQ4PD
QnHPk8iAs0JTawVJo8V2WpK4ZBv4kxBY5FErhTj0/ogoE9pAwIFRebPtUkig
UT7V0LUNLDtpvBHi243Eyu6kXylrA+F953RZbRJIM94oh6HRDv7QO1Mjs8SR
Hp/fzlG7dvBxnluZXiCGjEJKcpeC2sH7nTOxUlXbkK0PT4EsuR3sKQ1Ky/m4
FTlOqkmBsXbgMWjxNJ5rK3JzdS0kCXSAS7+WCg4qbkG+tuTiUMsOEM2nmLMu
VQQF98zty/TpAELJiRMizE0ownjPg0dpHaAVKUU4bNmEUrVCS4eGOoBkkotk
iN0G9ERS75G6RyfQEBkL8DIRQD13YtbrxneC7/uR5jI/P5r80e9pUNsJttfn
z4v18SJpmrcsca0TkM8+ek1O4kYEjWcR9jIUQNLwlG0K5UKO9wRGnc0pIFKT
sCgYzInS/AoLvDMpIKzu9YSI3Bqs/jS94ocpoOo64anu6RXIOKbteHOUAvbI
Br5qKvsLeaVficcrU8H72RFty6BFuDdht3+aLRWsn/zuocXxG+otXXh9N4gK
Dv41m96V+Qv69fKklFOoIGzqYmn84jxM0bb5XjNNBVWqSsyfL+dgVUmeZdOW
LhDdl+u7+e53OB6kuZ56pgvUvVY+GfJzCvKMh3v2RnaByJV1iX6rk1CK2Evp
r+gC6QFZ1rHSX6Hd/vMRY7+7gMBbc+2p5jHom1o3MiVJA/OVAtZqCp9h8ioH
/GlAAxMSUbsSnozAKk+Lgr+eNPCjWMSJz/oTpPVlr3Al0YDs3s+T5VzD8Iv+
l1PrGmig68/0+92p7yFXxaFmkXc0IHGl+2ue8VuoE0b3k9pPB3/bS2OaJN9A
uymx13KWdDCGgn/+1HkNfU+6qSn70sGsms9JqeuvYBK5Olkzhw4ePPI6/rCf
BSsPrsyCVjpIWtHS4rRmQmqWqaXhFzoQtDeUdenqhmPcGZXHhBhg9ZN7QKws
He4aUvI8ZccAhuF9kvt9OqG2YRDF5SYDDO1L0bSwb4cnqiky/91ngFBN5F7w
Hxle2bk1wofGABIVP6OeFLXCxNvOIwHfGeBuNaPBdRXDyrlKQui2bnC2Xqbh
xd9mSHVcyo/S7QbmisJbFLWews8Uw5UEl24gCkK9op/UQw61lFMZd7rB5uM0
3zHXWiiR/6Epr6ob+AyeOnXdtAYeEVQQL+nrBsECMlaOL6rgcV9/v8o/3YB/
2HPdPqMK6POxra9WqgdU8mXytUmVwgSzTWotRj2ggrk9jtu0BJbXOyaTvXrA
nJ6SPWdTEeyUKpvtSukBgudc++Uu3IMjsb8sWE97gMULlwvOdblwdQFWDnzo
AaEh5n/1uLLhDpeEdcM8vYDPypknuiEdanYPnR8/0AuCFbWzL1BTIOmIHGXG
uhfU3Lo3ka+cBC8XX5VZ8OsFpYNmD9uosTBOuPXWSm4vkHmm8GbyeRQsDRQa
4WnrBXocQ/Uq6hGw/bMdQehrL2jlWQjgkQiDNlSDeRV+JhCIx1dmp4IhYdep
9rfbmeAkNUejlRQAlX2vZNxWZIJJnf5TOfa+cBct+ryqPhM4v3GRFZ++DDdI
FWq/s2GCnRavnl9fvgCXrz0VinJjAp/5ggT6sjucpPd+UPVngrDlX7s9Wl3g
4J7x6nfRTLAq873tt9NpSPVfDY/KZYIC9fLgNTc72NAtanvoMRP0YHHqzksk
WCJ9UO79y3/6Ma4CWyssYVrg0aWoPiaoEWWJZS0Yw1u9p+iHxpmA/ove0R2J
4BWZq3nvl5igLEhmIOaYLjwbFON9R4gFtu2TOal6UgNaswqh2m4WQMXLV8kt
ylBfrmnLB1UW0E69LqSnLQeVbjDH7hxlgRolY8HAeiko+Wq8Ue0kCyh5h/6Y
SRWDQvJr0R88WeCJx7apr0ab4N+b2xyjg1kgNu9EneY0L5zsO6iknsgCp6ek
2OzGZcLgAUOOj4UswDqSMbymPk+ghjqyo+tYIPJtaCrU+UJo7L96X53CAudW
zJppC4OEB4qxfh8HWeBB25AvdyuDkB5eZBIzxQKKI7p5lq8xIWKgaYfGGgtc
9UeUubhKwlUl1tRHETb4uG6N9LUwi+ASMfE8Zh8bYMNZM43IcIL10FqSxuF/
bP2jU3jNnaCvIuY6bMoGXZqM8s2BhgSl20oasY5s8Oz3VDTatJ0g8c6QX9Ob
DYzX7d8L5d/o//8+CeT2/t8++T8mOjSM
      "]], LineBox[CompressedData["
1:eJxTTMoPSmViYGCwAWIQXfs4+ZbAgku2DFDw8m53rdlyBP+G8WL/hzsR/G33
L342u4/gLzV9efThRwR/SjfDjB6Wy3B+kbm+zSNNBF+vv6eltwTBl326OMyi
HcHnsd6t8Xgmgv/q2cszFvsR/KV27qJPOK/A+TLvGJdZzUfwxXdYf128AcEX
aip14T2E4HOIvXx0/wmC/8X2gnyr1lU4/3TvvJnntyL4VbrWvSlnriHCI6ek
pO/nDThfVa/12d+Nd+F8q8qZAWy8D+H8ynQRnk+mj+F8xvK4ma97n8L5XBzf
T23Z+xzOj94Vd65b5hWcr/tOpMwo+A2cL6H3vnpv3TtEeLif0Vyd8wHO/29x
Iv1+60c4/++u1X2ztn2C89mdFz45/vAznH+Rex/P3R9f4HyH1EOylerf4Pz8
/28Z/jp+h/NXzdcW/hz2A87vvBDAV9D8E87XdJp7+8rsX3D+MXaP+zsWIPgp
Zz89mrMUwV8Q4fEqZT2CL5b/+ceXQwg+0xxPMdFXCP6dr18DQi1+I+Jn94IQ
S1sEX7zRO0LWCcEP4lkY/9QbwT+h5JNXGo/gb/Vf1D21DUm9qG9/ZTeC/+HW
90mxExB8nTTfWaqzEPxFNT9WbF2L4Ds4LV4zcxOCf5fdb0PtdgRfYvLi7a4H
EfxtEX67NY8h+MFyP/fxnkay//HiQx/PI/h9K/2OXb2C4AMAuc0CnA==
      "]]}, {}}, {{}, {}, {}}},
  AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
  Axes->True,
  AxesLabel->{None, None},
  AxesOrigin->{0, 0},
  AxesStyle->Directive[20, 
    Thickness[0.005], 
    RGBColor[0, 0, 1]],
  Epilog->{
    PointSize[0.01], 
    RGBColor[1, 0, 0], 
    PointBox[{{-6.75*^-11, 0}, {6.75*^-11, 0}}]},
  ImageSize->700,
  LabelStyle->(FontFamily -> "Helvetica"),
  Method->{},
  PlotRange->{All, All},
  PlotRangeClipping->True,
  PlotRangePadding->{Automatic, Automatic}]], "Output",
 CellChangeTimes->{
  3.577683284653561*^9},ImageCache->GraphicsData["CompressedBitmap", "\<\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\
\>"]]
}, Open  ]],

Cell[TextData[{
 "Among the various possibilities regarding the definition of the FT we have \
chosen\n\n",
 Cell[BoxData[
  RowBox[{"\t ", 
   RowBox[{
    RowBox[{"F", 
     RowBox[{"(", "\[Omega]", ")"}]}], "=", " ", 
    RowBox[{
     SubsuperscriptBox["\[Integral]", 
      RowBox[{"-", "\[Infinity]"}], "\[Infinity]"], 
     RowBox[{"f", 
      RowBox[{"(", "x", ")"}], 
      SuperscriptBox["e", "i\[Omega]x"], " ", "dx"}]}]}]}]], "Text",
  CellChangeTimes->{{3.553750551441822*^9, 3.5537505594330397`*^9}}],
 "\n\nand\n\n",
 Cell[BoxData[
  RowBox[{"           ", 
   RowBox[{
    RowBox[{"f", 
     RowBox[{"(", "x", ")"}]}], "=", 
    RowBox[{
     RowBox[{"1", "/", 
      RowBox[{"(", 
       RowBox[{"2", " ", "\[Pi]"}], ")"}]}], " ", 
     RowBox[{
      SubsuperscriptBox["\[Integral]", 
       RowBox[{"-", "\[Infinity]"}], "\[Infinity]"], 
      RowBox[{"F", 
       RowBox[{"(", "\[Omega]", ")"}], 
       SuperscriptBox["e", 
        RowBox[{"-", "i\[Omega]x"}]], " ", "d\[Omega]"}]}]}]}]}]], "Text",
  CellChangeTimes->{{3.553750551441822*^9, 3.5537505594330397`*^9}}],
 ",\n\nin our case \[Omega] = ",
 Cell[BoxData[
  SubscriptBox["g", "x"]], "Input",
  CellChangeTimes->{{3.481001763312841*^9, 3.48100179025881*^9}, {
    3.4810018259402733`*^9, 3.4810018281991377`*^9}, 3.481002082124165*^9, {
    3.481002118911682*^9, 3.481002131067219*^9}, {3.481002194106564*^9, 
    3.481002196919539*^9}, {3.481002527406123*^9, 3.481002572078869*^9}, {
    3.481002767103146*^9, 3.48100298801945*^9}, {3.48100945135767*^9, 
    3.481009473760816*^9}, {3.481024658821968*^9, 3.481024659686016*^9}, {
    3.481210836970812*^9, 3.48121086500147*^9}, {3.4812645359106483`*^9, 
    3.4812645431625843`*^9}, {3.481288876335642*^9, 3.481288883106428*^9}, {
    3.481346420242552*^9, 3.4813464414352503`*^9}, 3.4813464915825367`*^9, {
    3.481346539256961*^9, 3.481346592577322*^9}, {3.481346697650846*^9, 
    3.481346737781479*^9}, 3.4972688164375*^9, 3.497269677765625*^9, {
    3.4972700479375*^9, 3.49727006065625*^9}, {3.497349793359375*^9, 
    3.497349866609375*^9}, {3.497350186171875*^9, 3.4973501984375*^9}, 
    3.49735073321875*^9, 3.49752423409375*^9, {3.497524603109375*^9, 
    3.49752461078125*^9}, {3.497524722765625*^9, 3.497524756953125*^9}, {
    3.497524859671875*^9, 3.497524878296875*^9}, {3.497526379953125*^9, 
    3.497526389421875*^9}, {3.497597337203125*^9, 3.49759735246875*^9}, {
    3.49759739434375*^9, 3.497597400515625*^9}, {3.49897815*^9, 
    3.498978157*^9}, {3.4990040203125*^9, 3.49900403603125*^9}, {
    3.499004145109375*^9, 3.4990041596875*^9}, {3.49916645034375*^9, 
    3.499166466*^9}, 3.499324277265625*^9, {3.49932443321875*^9, 
    3.499324434078125*^9}, {3.499325565359375*^9, 3.499325568421875*^9}, 
    3.499430386359375*^9, 3.499435892453125*^9, {3.499524490035037*^9, 
    3.499524501421846*^9}, {3.499524783782597*^9, 3.499524803126767*^9}, {
    3.499524834765884*^9, 3.499524956395052*^9}, {3.499525031168552*^9, 
    3.499525107509087*^9}, {3.499525153602892*^9, 3.4995251561980762`*^9}, {
    3.499582086164734*^9, 3.499582089972714*^9}, {3.499582185932995*^9, 
    3.499582192408908*^9}, {3.4995822822983027`*^9, 3.4995824039406643`*^9}, {
    3.499582494360783*^9, 3.499582550277582*^9}, {3.4995826542132263`*^9, 
    3.4995826763908253`*^9}, 3.499582715102212*^9, {3.499598836671875*^9, 
    3.499598849921875*^9}, {3.499608029140625*^9, 3.4996080315625*^9}, {
    3.499769634953125*^9, 3.49976967396875*^9}, 3.499770699515625*^9, {
    3.49977074928125*^9, 3.499770789953125*^9}, {3.499771024859375*^9, 
    3.499771051828125*^9}, {3.49977189534375*^9, 3.499771898046875*^9}, {
    3.500021736530417*^9, 3.500021744056431*^9}, {3.500099837477235*^9, 
    3.500099868264522*^9}, {3.500105749414968*^9, 3.5001057498622627`*^9}, {
    3.55204614034375*^9, 3.55204617309375*^9}, {3.552046215828125*^9, 
    3.552046227046875*^9}, 3.5520463241875*^9, {3.552046654328125*^9, 
    3.552046656609375*^9}, {3.552046831421875*^9, 3.552046833453125*^9}, {
    3.552047259265625*^9, 3.552047262375*^9}, {3.55210335371875*^9, 
    3.552103367984375*^9}, {3.5524751661875*^9, 3.55247518640625*^9}, 
    3.553251219671875*^9, {3.553398097704089*^9, 3.553398098274935*^9}},
  FontSize->24],
 "\n"
}], "Text",
 CellChangeTimes->{{3.553753419543477*^9, 3.553753476721383*^9}, {
  3.553753514339069*^9, 3.553753556975505*^9}, {3.553753594228037*^9, 
  3.553753639319337*^9}, {3.553753675149734*^9, 3.553753703681539*^9}, {
  3.553753780424994*^9, 3.553753911022949*^9}, {3.553777415704143*^9, 
  3.553777436295158*^9}, {3.553777484398322*^9, 3.553777530946208*^9}, {
  3.5537838447981157`*^9, 3.553783877309123*^9}},
 FontFamily->"Times New Roman",
 FontSize->26,
 FontColor->GrayLevel[0],
 Background->GrayLevel[0.85]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  SubscriptBox["FT", "at"], "=", 
  RowBox[{"(", 
   RowBox[{"Timing", "[", 
    RowBox[{"FourierTransform", "[", 
     RowBox[{
      RowBox[{"\[Rho]p", "[", "x", "]"}], ",", "x", ",", 
      SubscriptBox["g", "x"], 
      StyleBox[",",
       FontColor->RGBColor[0, 0, 1]], 
      RowBox[{"FourierParameters", "->", 
       RowBox[{"{", 
        RowBox[{"1", ",", "1"}], "}"}]}]}], "]"}], "]"}], ")"}]}]], "Input",
 CellChangeTimes->{{3.481001763312841*^9, 3.48100179025881*^9}, {
   3.4810018259402733`*^9, 3.4810018281991377`*^9}, 3.481002082124165*^9, {
   3.481002118911682*^9, 3.481002131067219*^9}, {3.481002194106564*^9, 
   3.481002196919539*^9}, {3.481002527406123*^9, 3.481002572078869*^9}, {
   3.481002767103146*^9, 3.48100298801945*^9}, {3.48100945135767*^9, 
   3.481009473760816*^9}, {3.481024658821968*^9, 3.481024659686016*^9}, {
   3.481210836970812*^9, 3.48121086500147*^9}, {3.4812645359106483`*^9, 
   3.4812645431625843`*^9}, {3.481288876335642*^9, 3.481288883106428*^9}, {
   3.481346420242552*^9, 3.4813464414352503`*^9}, 3.4813464915825367`*^9, {
   3.481346539256961*^9, 3.481346592577322*^9}, {3.481346697650846*^9, 
   3.481346737781479*^9}, 3.4972688164375*^9, 3.497269677765625*^9, {
   3.4972700479375*^9, 3.49727006065625*^9}, {3.497349793359375*^9, 
   3.497349866609375*^9}, {3.497350186171875*^9, 3.4973501984375*^9}, 
   3.49735073321875*^9, 3.49752423409375*^9, {3.497524603109375*^9, 
   3.49752461078125*^9}, {3.497524722765625*^9, 3.497524756953125*^9}, {
   3.497524859671875*^9, 3.497524878296875*^9}, {3.497526379953125*^9, 
   3.497526389421875*^9}, {3.497597337203125*^9, 3.49759735246875*^9}, {
   3.49759739434375*^9, 3.497597400515625*^9}, {3.49897815*^9, 
   3.498978157*^9}, {3.4990040203125*^9, 3.49900403603125*^9}, {
   3.499004145109375*^9, 3.4990041596875*^9}, {3.49916645034375*^9, 
   3.499166466*^9}, 3.499324277265625*^9, {3.49932443321875*^9, 
   3.499324434078125*^9}, {3.499325565359375*^9, 3.499325568421875*^9}, 
   3.499430386359375*^9, 3.499435892453125*^9, {3.499524490035037*^9, 
   3.499524501421846*^9}, {3.499524783782597*^9, 3.499524803126767*^9}, {
   3.499524834765884*^9, 3.499524956395052*^9}, {3.499525031168552*^9, 
   3.499525107509087*^9}, {3.499525153602892*^9, 3.4995251561980762`*^9}, {
   3.499582086164734*^9, 3.499582089972714*^9}, {3.499582185932995*^9, 
   3.499582192408908*^9}, {3.4995822822983027`*^9, 3.4995824039406643`*^9}, {
   3.499582494360783*^9, 3.499582550277582*^9}, {3.4995826542132263`*^9, 
   3.4995826763908253`*^9}, 3.499582715102212*^9, {3.499598836671875*^9, 
   3.499598849921875*^9}, {3.499608029140625*^9, 3.4996080315625*^9}, {
   3.499769634953125*^9, 3.49976967396875*^9}, 3.499770699515625*^9, {
   3.49977074928125*^9, 3.499770789953125*^9}, {3.499771024859375*^9, 
   3.499771051828125*^9}, {3.49977189534375*^9, 3.499771898046875*^9}, {
   3.500021736530417*^9, 3.500021744056431*^9}, {3.500099837477235*^9, 
   3.500099868264522*^9}, {3.500105749414968*^9, 3.5001057498622627`*^9}, {
   3.55204614034375*^9, 3.55204617309375*^9}, {3.552046215828125*^9, 
   3.552046227046875*^9}, 3.5520463241875*^9, {3.552046654328125*^9, 
   3.552046656609375*^9}, {3.552046831421875*^9, 3.552046833453125*^9}, {
   3.552047259265625*^9, 3.552047262375*^9}, {3.55210335371875*^9, 
   3.552103367984375*^9}, {3.5524751661875*^9, 3.55247518640625*^9}, 
   3.553251219671875*^9, {3.553398097704089*^9, 3.553398098274935*^9}, {
   3.5537775458785553`*^9, 3.553777574275655*^9}},
 FontSize->18,
 CellID->53852264],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"5.05999999999999960920149533194489777088`6.724750430119423", ",", 
   RowBox[{
    RowBox[{"(", 
     RowBox[{
     "917504000000000000000000000000000000000000000000000000000000000000000000\
00000000000", " ", 
      SuperscriptBox["\[Pi]", "6"], " ", 
      RowBox[{"Sin", "[", 
       FractionBox[
        RowBox[{"27", " ", 
         SubscriptBox["g", "x"]}], "400000000000"], "]"}]}], ")"}], "/", 
    RowBox[{"(", 
     RowBox[{"27", " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{
         RowBox[{"-", "43046721"}], " ", 
         SubsuperscriptBox["g", "x", "7"]}], "+", 
        RowBox[{"132269760000000000000000000000", " ", 
         SubsuperscriptBox["g", "x", "5"], " ", 
         SuperscriptBox["\[Pi]", "2"]}], "-", 
        RowBox[{"101606400000000000000000000000000000000000000000000", " ", 
         SubsuperscriptBox["g", "x", "3"], " ", 
         SuperscriptBox["\[Pi]", "4"]}], "+", 
        RowBox[{
        "163840000000000000000000000000000000000000000000000000000000000000000\
00", " ", 
         SubscriptBox["g", "x"], " ", 
         SuperscriptBox["\[Pi]", "6"]}]}], ")"}]}], ")"}]}]}], 
  "}"}]], "Output",
 CellChangeTimes->{3.577683290113714*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  SubscriptBox["FT", "at"], "[", 
  RowBox[{"[", "2", "]"}], "]"}]], "Input",
 CellChangeTimes->{{3.553232549046875*^9, 3.553232580203125*^9}, 
   3.553251236234375*^9},
 FontSize->18],

Cell[BoxData[
 RowBox[{
  RowBox[{"(", 
   RowBox[{
   "91750400000000000000000000000000000000000000000000000000000000000000000000\
000000000", " ", 
    SuperscriptBox["\[Pi]", "6"], " ", 
    RowBox[{"Sin", "[", 
     FractionBox[
      RowBox[{"27", " ", 
       SubscriptBox["g", "x"]}], "400000000000"], "]"}]}], ")"}], "/", 
  RowBox[{"(", 
   RowBox[{"27", " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{
       RowBox[{"-", "43046721"}], " ", 
       SubsuperscriptBox["g", "x", "7"]}], "+", 
      RowBox[{"132269760000000000000000000000", " ", 
       SubsuperscriptBox["g", "x", "5"], " ", 
       SuperscriptBox["\[Pi]", "2"]}], "-", 
      RowBox[{"101606400000000000000000000000000000000000000000000", " ", 
       SubsuperscriptBox["g", "x", "3"], " ", 
       SuperscriptBox["\[Pi]", "4"]}], "+", 
      RowBox[{
      "16384000000000000000000000000000000000000000000000000000000000000000000\
", " ", 
       SubscriptBox["g", "x"], " ", 
       SuperscriptBox["\[Pi]", "6"]}]}], ")"}]}], ")"}]}]], "Output",
 CellChangeTimes->{3.577683290273522*^9}]
}, Open  ]],

Cell[BoxData[
 RowBox[{
  RowBox[{
   StyleBox["Let",
    FontWeight->"Plain"], 
   StyleBox[" ",
    FontWeight->"Plain"], 
   StyleBox["us",
    FontWeight->"Plain"], 
   StyleBox[" ",
    FontWeight->"Plain"], 
   StyleBox["calculate",
    FontWeight->"Plain"], 
   StyleBox[" ",
    FontWeight->"Plain"], 
   StyleBox["the",
    FontWeight->"Plain"], 
   StyleBox[" ",
    FontWeight->"Plain"], 
   RowBox[{
    StyleBox[
     SubscriptBox["FT", "at"],
     FontWeight->"Bold"], 
    StyleBox[" ",
     FontWeight->"Bold"], 
    StyleBox["@",
     FontWeight->"Bold"], "certain"}], " ", "values", " ", "of", 
   StyleBox[" ",
    FontWeight->"Bold"], 
   StyleBox["g",
    FontWeight->"Bold"]}], 
  StyleBox[" ",
   FontWeight->"Bold"], "..."}]], "Text",
 CellChangeTimes->{{3.553260861796875*^9, 3.553260880921875*^9}, {
  3.55326095890625*^9, 3.553260971875*^9}, {3.553398246128132*^9, 
  3.553398291961837*^9}, {3.5752582659696894`*^9, 3.5752583088171396`*^9}},
 FontFamily->"Times New Roman",
 FontSize->26,
 FontColor->GrayLevel[0],
 Background->GrayLevel[0.85]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Limit", "[", 
  RowBox[{
   RowBox[{
    SubscriptBox["FT", "at"], "[", 
    RowBox[{"[", "2", "]"}], "]"}], ",", " ", 
   RowBox[{
    SubscriptBox["g", "x"], " ", "\[Rule]", "0"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.5532323323125*^9, 3.553232383328125*^9}, {
   3.553251242421875*^9, 3.553251250046875*^9}, {3.5533981255386744`*^9, 
   3.5533981260102367`*^9}, 3.553398329812833*^9},
 FontSize->24],

Cell[BoxData["14"], "Output",
 CellChangeTimes->{3.577683290414444*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"Limit", "[", 
   RowBox[{
    RowBox[{
     SubscriptBox["FT", "at"], "[", 
     RowBox[{"[", "2", "]"}], "]"}], ",", " ", 
    RowBox[{
     SubscriptBox["g", "x"], " ", "\[Rule]", 
     FractionBox[
      RowBox[{"2", " ", "\[Pi]"}], 
      SubscriptBox["a", "0"]]}]}], "]"}], "//", "N"}]], "Input",
 CellChangeTimes->{{3.5532323323125*^9, 3.553232383328125*^9}, {
   3.553232425828125*^9, 3.553232456546875*^9}, {3.5532512575*^9, 
   3.553251261296875*^9}, 3.553251339828125*^9, {3.5533981296512403`*^9, 
   3.553398129729288*^9}, 3.5533983519414883`*^9},
 FontSize->24],

Cell[BoxData["13.753643378944549`"], "Output",
 CellChangeTimes->{3.577683290628498*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"Limit", "[", 
   RowBox[{
    RowBox[{
     SubscriptBox["FT", "at"], "[", 
     RowBox[{"[", "2", "]"}], "]"}], ",", " ", 
    RowBox[{
     SubscriptBox["g", "x"], " ", "\[Rule]", 
     RowBox[{"2", " ", "*", " ", 
      FractionBox[
       RowBox[{"2", " ", "\[Pi]"}], 
       SubscriptBox["a", "0"]]}]}]}], "]"}], "//", "N", 
  "          "}]], "Input",
 CellChangeTimes->{{3.5532323323125*^9, 3.553232383328125*^9}, {
   3.553232425828125*^9, 3.553232456546875*^9}, {3.5532512575*^9, 
   3.5532513319375*^9}, {3.553398133170833*^9, 3.553398133228321*^9}, 
   3.5533983563555727`*^9, {3.574947418797392*^9, 3.5749474420010223`*^9}, 
   3.5753474642418613`*^9},
 FontSize->24],

Cell[BoxData["13.037972938088068`"], "Output",
 CellChangeTimes->{3.577683290771735*^9}]
}, Open  ]],

Cell[" ...after  some attempts, we find convenient  nterm1=50", "Text",
 CellChangeTimes->{{3.553777643614771*^9, 3.553777661656756*^9}, {
  3.5752583161915617`*^9, 3.5752583223669147`*^9}},
 FontFamily->"Times New Roman",
 FontSize->26,
 FontColor->GrayLevel[0],
 Background->GrayLevel[0.85]],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"nterm1", "=", "50"}], ";"}], "            "}]], "Input",
 CellChangeTimes->{{3.55325954446875*^9, 3.55325955696875*^9}, {
  3.553753924126307*^9, 3.5537539372097483`*^9}, {3.5537548074246197`*^9, 
  3.553754811983869*^9}, {3.5537776027509937`*^9, 3.55377763834305*^9}},
 FontSize->24],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  SubscriptBox["coef$tab$50FT", "at"], "=", " ", 
  RowBox[{
   RowBox[{"Table", "[", 
    RowBox[{
     RowBox[{"Limit", "[", 
      RowBox[{
       RowBox[{
        SubscriptBox["FT", "at"], "[", 
        RowBox[{"[", "2", "]"}], "]"}], ",", " ", 
       RowBox[{
        SubscriptBox["g", "x"], " ", "\[Rule]", 
        RowBox[{"n", "  ", 
         FractionBox[
          RowBox[{"2", " ", "\[Pi]"}], 
          SubscriptBox["a", "0"]]}]}]}], "]"}], ",", 
     RowBox[{"{", 
      RowBox[{"n", ",", 
       RowBox[{"-", "nterm1"}], ",", "nterm1"}], "}"}]}], "]"}], "//", 
   "N"}]}]], "Input",
 CellChangeTimes->{{3.5532323323125*^9, 3.553232383328125*^9}, {
  3.553232425828125*^9, 3.55323251878125*^9}, {3.553232588921875*^9, 
  3.55323259021875*^9}, {3.553233253515625*^9, 3.553233254453125*^9}, {
  3.55323393575*^9, 3.5532339373125*^9}, {3.553236095828125*^9, 
  3.553236099984375*^9}, {3.553236160828125*^9, 3.55323616578125*^9}, {
  3.553249281984375*^9, 3.553249283984375*^9}, {3.55324960325*^9, 
  3.55324960446875*^9}, {3.553251364921875*^9, 3.553251411*^9}, {
  3.553252667828125*^9, 3.5532526681875*^9}, {3.553259518484375*^9, 
  3.553259536875*^9}, {3.553398138359424*^9, 3.553398140819633*^9}, {
  3.553754177079156*^9, 3.5537541787979593`*^9}},
 FontSize->24],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"-", "3.6874525210762096`*^-6"}], ",", 
   RowBox[{"-", "3.015163522286592`*^-6"}], ",", "0.`", ",", 
   "4.071006193377674`*^-6", ",", "6.724178126668382`*^-6", ",", 
   "5.573484086650973`*^-6", ",", "0.`", ",", 
   RowBox[{"-", "7.748044045460736`*^-6"}], ",", 
   RowBox[{"-", "0.000013000077711558874`"}], ",", 
   RowBox[{"-", "0.000010954779066865706`"}], ",", "0.`", ",", 
   "0.000015783052685197792`", ",", "0.000027000161400929967`", ",", 
   "0.000023224131621755297`", ",", "0.`", ",", 
   RowBox[{"-", "0.000034997203780221197`"}], ",", 
   RowBox[{"-", "0.00006136400318393173`"}], ",", 
   RowBox[{"-", "0.000054189640450762355`"}], ",", "0.`", ",", 
   "0.00008657203040370506`", ",", "0.00015681911924782558`", ",", 
   "0.00014344316589907683`", ",", "0.`", ",", 
   RowBox[{"-", "0.0002481731538239545`"}], ",", 
   RowBox[{"-", "0.0004704573577434767`"}], ",", 
   RowBox[{"-", "0.00045239767706631924`"}], ",", "0.`", ",", 
   "0.0008798866362849297`", ",", "0.0017877379594252113`", ",", 
   "0.0018598571168282011`", ",", "0.`", ",", 
   RowBox[{"-", "0.004399433181424648`"}], ",", 
   RowBox[{"-", "0.01013051510340953`"}], ",", 
   RowBox[{"-", "0.012275056971066128`"}], ",", "0.`", ",", 
   "0.045460809541388036`", ",", "0.15195772655114298`", ",", 
   "0.35597665216091773`", ",", "0.7`", ",", "1.2274418576174768`", ",", 
   "1.9754504451648587`", ",", "2.966472101340981`", ",", "4.2`", ",", 
   "5.646232545040394`", ",", "7.243318298937815`", ",", "8.899416304022942`",
    ",", "10.5`", ",", "11.919824261751941`", ",", "13.037972938088068`", ",",
    "13.753643378944549`", ",", "14.`", ",", "13.753643378944549`", ",", 
   "13.037972938088068`", ",", "11.919824261751941`", ",", "10.5`", ",", 
   "8.899416304022942`", ",", "7.243318298937815`", ",", "5.646232545040394`",
    ",", "4.2`", ",", "2.966472101340981`", ",", "1.9754504451648587`", ",", 
   "1.2274418576174768`", ",", "0.7`", ",", "0.35597665216091773`", ",", 
   "0.15195772655114298`", ",", "0.045460809541388036`", ",", "0.`", ",", 
   RowBox[{"-", "0.012275056971066128`"}], ",", 
   RowBox[{"-", "0.01013051510340953`"}], ",", 
   RowBox[{"-", "0.004399433181424648`"}], ",", "0.`", ",", 
   "0.0018598571168282011`", ",", "0.0017877379594252113`", ",", 
   "0.0008798866362849297`", ",", "0.`", ",", 
   RowBox[{"-", "0.00045239767706631924`"}], ",", 
   RowBox[{"-", "0.0004704573577434767`"}], ",", 
   RowBox[{"-", "0.0002481731538239545`"}], ",", "0.`", ",", 
   "0.00014344316589907683`", ",", "0.00015681911924782558`", ",", 
   "0.00008657203040370506`", ",", "0.`", ",", 
   RowBox[{"-", "0.000054189640450762355`"}], ",", 
   RowBox[{"-", "0.00006136400318393173`"}], ",", 
   RowBox[{"-", "0.000034997203780221197`"}], ",", "0.`", ",", 
   "0.000023224131621755297`", ",", "0.000027000161400929967`", ",", 
   "0.000015783052685197792`", ",", "0.`", ",", 
   RowBox[{"-", "0.000010954779066865706`"}], ",", 
   RowBox[{"-", "0.000013000077711558874`"}], ",", 
   RowBox[{"-", "7.748044045460736`*^-6"}], ",", "0.`", ",", 
   "5.573484086650973`*^-6", ",", "6.724178126668382`*^-6", ",", 
   "4.071006193377674`*^-6", ",", "0.`", ",", 
   RowBox[{"-", "3.015163522286592`*^-6"}], ",", 
   RowBox[{"-", "3.6874525210762096`*^-6"}]}], "}"}]], "Output",
 CellChangeTimes->{3.577683295981879*^9}]
}, Open  ]],

Cell[BoxData[
 RowBox[{
  RowBox[{
   SubscriptBox["coef$func$F50FT", "at"], "[", "n_", "]"}], ":=", " ", 
  RowBox[{
   RowBox[{"Limit", "[", 
    RowBox[{
     RowBox[{
      SubscriptBox["FT", "at"], "[", 
      RowBox[{"[", "2", "]"}], "]"}], ",", " ", 
     RowBox[{
      SubscriptBox["g", "x"], " ", "\[Rule]", 
      RowBox[{"n", "  ", 
       FractionBox[
        RowBox[{"2", " ", "\[Pi]"}], 
        SubscriptBox["a", "0"]]}]}]}], "]"}], "//", "N"}]}]], "Input",
 CellChangeTimes->{{3.5532323323125*^9, 3.553232383328125*^9}, {
  3.553232425828125*^9, 3.55323251878125*^9}, {3.553232588921875*^9, 
  3.55323259021875*^9}, {3.553233253515625*^9, 3.553233254453125*^9}, {
  3.55323393575*^9, 3.5532339373125*^9}, {3.553236095828125*^9, 
  3.553236099984375*^9}, {3.553236160828125*^9, 3.55323616578125*^9}, {
  3.553249281984375*^9, 3.553249283984375*^9}, {3.55324960325*^9, 
  3.55324960446875*^9}, {3.553251364921875*^9, 3.553251411*^9}, {
  3.553252667828125*^9, 3.5532526681875*^9}, {3.553259518484375*^9, 
  3.553259536875*^9}, {3.553397723996784*^9, 3.553397796722617*^9}, {
  3.5533981458934393`*^9, 3.553398146333048*^9}, {3.553754197028943*^9, 
  3.553754201863378*^9}},
 FontSize->24],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Vol1D", "=", " ", 
  RowBox[{
   RowBox[{"-", 
    FractionBox["1", 
     SubscriptBox["a", "0"]]}], 
   FractionBox[
    RowBox[{
     SubscriptBox["r", "e"], " ", 
     SuperscriptBox["\[Lambda]", "2"]}], "\[Pi]"]}]}]], "Input",
 CellChangeTimes->{
  3.553235597390625*^9, {3.553251523203125*^9, 3.553251554421875*^9}, {
   3.553251837703125*^9, 3.55325188546875*^9}, {3.553259297875*^9, 
   3.553259303359375*^9}, 3.553260996109375*^9},
 FontSize->24],

Cell[BoxData[
 RowBox[{"-", "8.326359493145908`*^-27"}]], "Output",
 CellChangeTimes->{3.577683296159482*^9}]
}, Open  ]],

Cell[TextData[{
 "We have two options now...\n\ni) we reconstruct the ( 2.2.98) in the case \
that the two silicon atoms\nare  @  ",
 Cell[BoxData[
  RowBox[{
   SubscriptBox["CG", "1"], " "}]], "Input",
  CellChangeTimes->{{3.553399171863435*^9, 3.55339917870542*^9}, {
    3.553399220329187*^9, 3.553399231455578*^9}, 3.55339927878718*^9, {
    3.553775575947589*^9, 3.5537756788945*^9}, {3.553775816643363*^9, 
    3.553775823386682*^9}, 3.5537773469258823`*^9},
  FontSize->24],
 " and ",
 Cell[BoxData[
  SubscriptBox["CG", "2"]], "Input",
  CellChangeTimes->{{3.553399171863435*^9, 3.55339917870542*^9}, {
    3.553399220329187*^9, 3.553399231455578*^9}, 3.55339927878718*^9, {
    3.553775575947589*^9, 3.5537756788945*^9}, {3.553775816643363*^9, 
    3.553775823386682*^9}, 3.5537773469258823`*^9},
  FontSize->24]
}], "Text",
 CellChangeTimes->{{3.553261113984375*^9, 3.553261152046875*^9}, {
   3.5537540034918547`*^9, 3.553754062388558*^9}, {3.5537643309436693`*^9, 
   3.553764348539936*^9}, {3.5537777025606623`*^9, 3.553777783320912*^9}, {
   3.553777822966282*^9, 3.553777871746028*^9}, {3.553777902635889*^9, 
   3.553777949928587*^9}, {3.553778272869059*^9, 3.553778272869199*^9}, 
   3.553826860073675*^9, {3.57494749397497*^9, 3.574947543203638*^9}, 
   3.57509737173516*^9, {3.575097405161908*^9, 3.5750974067037497`*^9}, {
   3.5750975248979187`*^9, 3.575097544770369*^9}, {3.575258333072527*^9, 
   3.575258361343144*^9}},
 FontFamily->"Times New Roman",
 FontSize->26,
 FontColor->GrayLevel[0],
 Background->GrayLevel[0.85]],

Cell[" We can create a function...", "Text",
 CellChangeTimes->{{3.553777643614771*^9, 3.553777661656756*^9}, {
  3.5537781750300694`*^9, 3.553778186471857*^9}, {3.575258372702794*^9, 
  3.5752583829983826`*^9}},
 FontFamily->"Times New Roman",
 FontSize->26,
 FontColor->GrayLevel[0],
 Background->GrayLevel[0.85]],

Cell[" We can creta a function", "Text",
 CellChangeTimes->{{3.553777643614771*^9, 3.553777661656756*^9}, {
  3.5537781750300694`*^9, 3.553778186471857*^9}},
 FontSize->24],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"\[Chi]func50", "[", "x_", "]"}], "=", " ", 
  RowBox[{
   RowBox[{
    RowBox[{"ExpToTrig", "[", 
     RowBox[{"Sum", "[", 
      RowBox[{
       RowBox[{
        RowBox[{"Exp", "[", 
         RowBox[{"I", " ", 
          FractionBox[
           RowBox[{"2", "  ", "\[Pi]", " ", "n", " ", "x"}], 
           SubscriptBox["a", "0"]]}], "]"}], "*", 
        RowBox[{
         SubscriptBox["coef$func$F50FT", "at"], "[", "n", "]"}], "*", " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"Exp", "[", 
           RowBox[{
            RowBox[{"-", "I"}], " ", 
            FractionBox[
             RowBox[{"2", "  ", "\[Pi]", " ", "n"}], "8"]}], "]"}], " ", "+", 
          " ", 
          RowBox[{"Exp", "[", 
           RowBox[{
            RowBox[{"-", "I"}], " ", 
            FractionBox[
             RowBox[{"2", " ", "\[Pi]", " ", "n", " ", "7", " "}], "8"]}], 
           "]"}]}], ")"}]}], ",", 
       RowBox[{"{", 
        RowBox[{"n", ",", 
         RowBox[{"-", "nterm1"}], ",", "nterm1"}], "}"}]}], "]"}], "]"}], "//",
     "N"}], " ", "//", "Chop"}]}]], "Input",
 CellChangeTimes->{{3.55323332190625*^9, 3.553233452296875*^9}, {
   3.553233546296875*^9, 3.553233643078125*^9}, {3.553233674296875*^9, 
   3.55323369940625*^9}, {3.553233745359375*^9, 3.5532337625*^9}, 
   3.55323385990625*^9, {3.553233929109375*^9, 3.55323393034375*^9}, {
   3.5532340236875*^9, 3.553234031234375*^9}, {3.55323531940625*^9, 
   3.553235327859375*^9}, {3.553235393484375*^9, 3.55323544403125*^9}, {
   3.553236356890625*^9, 3.5532363763125*^9}, {3.553249517125*^9, 
   3.5532495475*^9}, {3.55324962609375*^9, 3.553249654703125*^9}, {
   3.553251430734375*^9, 3.5532514450625*^9}, {3.553252686609375*^9, 
   3.553252692265625*^9}, {3.55325957378125*^9, 3.5532595796875*^9}, {
   3.55326007428125*^9, 3.553260080015625*^9}, {3.55326017065625*^9, 
   3.553260171640625*^9}, {3.553260240109375*^9, 3.553260240484375*^9}, {
   3.5533441132964077`*^9, 3.553344122765182*^9}, {3.553397813566637*^9, 
   3.553397841979066*^9}, {3.5537542298623123`*^9, 3.5537542330103817`*^9}, {
   3.553754445962132*^9, 3.5537544473885517`*^9}, {3.5537844991241293`*^9, 
   3.5537845374771957`*^9}},
 FontSize->18],

Cell[BoxData[
 RowBox[{"28.`", "\[VeryThinSpace]", "+", 
  RowBox[{"38.90117799709261`", " ", 
   RowBox[{"Cos", "[", 
    RowBox[{"1.1635528346628864`*^10", " ", "x"}], "]"}]}], "-", 
  RowBox[{"33.71435426414692`", " ", 
   RowBox[{"Cos", "[", 
    RowBox[{"3.490658503988659`*^10", " ", "x"}], "]"}]}], "-", 
  RowBox[{"42.`", " ", 
   RowBox[{"Cos", "[", 
    RowBox[{"4.654211338651546`*^10", " ", "x"}], "]"}]}], "-", 
  RowBox[{"25.171350468706976`", " ", 
   RowBox[{"Cos", "[", 
    RowBox[{"5.8177641733144325`*^10", " ", "x"}], "]"}]}], "+", 
  RowBox[{"15.969957283016965`", " ", 
   RowBox[{"Cos", "[", 
    RowBox[{"8.144869842640204`*^10", " ", "x"}], "]"}]}], "+", 
  RowBox[{"16.8`", " ", 
   RowBox[{"Cos", "[", 
    RowBox[{"9.308422677303091`*^10", " ", "x"}], "]"}]}], "+", 
  RowBox[{"8.39045015623566`", " ", 
   RowBox[{"Cos", "[", 
    RowBox[{"1.0471975511965976`*^11", " ", "x"}], "]"}]}], "-", 
  RowBox[{"3.471729844134122`", " ", 
   RowBox[{"Cos", "[", 
    RowBox[{"1.279908118129175`*^11", " ", "x"}], "]"}]}], "-", 
  RowBox[{"2.8`", " ", 
   RowBox[{"Cos", "[", 
    RowBox[{"1.3962634015954636`*^11", " ", "x"}], "]"}]}], "-", 
  RowBox[{"1.006854018748279`", " ", 
   RowBox[{"Cos", "[", 
    RowBox[{"1.5126186850617523`*^11", " ", "x"}], "]"}]}], "+", 
  RowBox[{"0.12858258681978232`", " ", 
   RowBox[{"Cos", "[", 
    RowBox[{"1.7453292519943295`*^11", " ", "x"}], "]"}]}], "-", 
  RowBox[{"0.03471910409476825`", " ", 
   RowBox[{"Cos", "[", 
    RowBox[{"1.9780398189269067`*^11", " ", "x"}], "]"}]}], "+", 
  RowBox[{"0.012443476143849901`", " ", 
   RowBox[{"Cos", "[", 
    RowBox[{"2.2107503858594843`*^11", " ", "x"}], "]"}]}], "-", 
  RowBox[{"0.005260470317389128`", " ", 
   RowBox[{"Cos", "[", 
    RowBox[{"2.4434609527920612`*^11", " ", "x"}], "]"}]}], "+", 
  RowBox[{"0.0024886952287699804`", " ", 
   RowBox[{"Cos", "[", 
    RowBox[{"2.6761715197246384`*^11", " ", "x"}], "]"}]}], "-", 
  RowBox[{"0.0012795738609865449`", " ", 
   RowBox[{"Cos", "[", 
    RowBox[{"2.9088820866572156`*^11", " ", "x"}], "]"}]}], "+", 
  RowBox[{"0.0007019396799094815`", " ", 
   RowBox[{"Cos", "[", 
    RowBox[{"3.141592653589793`*^11", " ", "x"}], "]"}]}], "-", 
  RowBox[{"0.0004057185412884166`", " ", 
   RowBox[{"Cos", "[", 
    RowBox[{"3.3743032205223706`*^11", " ", "x"}], "]"}]}], "+", 
  RowBox[{"0.0002448626790381913`", " ", 
   RowBox[{"Cos", "[", 
    RowBox[{"3.6070137874549475`*^11", " ", "x"}], "]"}]}], "-", 
  RowBox[{"0.00015327144893117963`", " ", 
   RowBox[{"Cos", "[", 
    RowBox[{"3.839724354387525`*^11", " ", "x"}], "]"}]}], "+", 
  RowBox[{"0.00009898704046224753`", " ", 
   RowBox[{"Cos", "[", 
    RowBox[{"4.072434921320102`*^11", " ", "x"}], "]"}]}], "-", 
  RowBox[{"0.0000656877638276484`", " ", 
   RowBox[{"Cos", "[", 
    RowBox[{"4.3051454882526794`*^11", " ", "x"}], "]"}]}], "+", 
  RowBox[{"0.00004464121432611163`", " ", 
   RowBox[{"Cos", "[", 
    RowBox[{"4.537856055185257`*^11", " ", "x"}], "]"}]}], "-", 
  RowBox[{"0.00003098479425832472`", " ", 
   RowBox[{"Cos", "[", 
    RowBox[{"4.770566622117833`*^11", " ", "x"}], "]"}]}], "+", 
  RowBox[{"0.000021914777941909344`", " ", 
   RowBox[{"Cos", "[", 
    RowBox[{"5.003277189050411`*^11", " ", "x"}], "]"}]}], "-", 
  RowBox[{"0.000015764193570024857`", " ", 
   RowBox[{"Cos", "[", 
    RowBox[{"5.235987755982988`*^11", " ", "x"}], "]"}]}], "+", 
  RowBox[{"0.000011514544342359147`", " ", 
   RowBox[{"Cos", "[", 
    RowBox[{"5.468698322915566`*^11", " ", "x"}], "]"}]}], "-", 
  RowBox[{"8.528170291980662`*^-6", " ", 
   RowBox[{"Cos", "[", 
    RowBox[{"5.701408889848143`*^11", " ", "x"}], "]"}]}]}]], "Output",
 CellChangeTimes->{3.577683296342705*^9}]
}, Open  ]],

Cell[" ...ore a table  (less convenient)", "Text",
 CellChangeTimes->{{3.553777643614771*^9, 3.553777661656756*^9}, {
  3.5537781750300694`*^9, 3.553778214834873*^9}, {3.5752583797031946`*^9, 
  3.5752583799432077`*^9}},
 FontFamily->"Times New Roman",
 FontSize->26,
 FontColor->GrayLevel[0],
 Background->GrayLevel[0.85]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"\[Chi]tab50", "[", "x_", "]"}], "=", " ", 
  RowBox[{
   RowBox[{
    RowBox[{"ExpToTrig", "[", 
     RowBox[{"Sum", "[", 
      RowBox[{
       RowBox[{
        RowBox[{"Exp", "[", 
         RowBox[{"I", " ", 
          FractionBox[
           RowBox[{"2", "  ", "\[Pi]", " ", "n", " ", "x"}], 
           SubscriptBox["a", "0"]]}], "]"}], "*", 
        RowBox[{
         SubscriptBox["coef$tab$50FT", "at"], "[", 
         RowBox[{"[", 
          RowBox[{"n", "+", "nterm1", "+", "1"}], "]"}], "]"}], "*", " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"Exp", "[", 
           RowBox[{
            RowBox[{"-", "I"}], " ", 
            FractionBox[
             RowBox[{"2", "  ", "\[Pi]", " ", "n"}], "8"]}], "]"}], " ", "+", 
          " ", 
          RowBox[{"Exp", "[", 
           RowBox[{
            RowBox[{"-", "I"}], " ", 
            FractionBox[
             RowBox[{"2", " ", "\[Pi]", " ", "n", " ", "7", " "}], "8"]}], 
           "]"}]}], ")"}]}], ",", 
       RowBox[{"{", 
        RowBox[{"n", ",", 
         RowBox[{"-", "nterm1"}], ",", "nterm1"}], "}"}]}], "]"}], "]"}], "//",
     "N"}], " ", "//", "Chop"}]}]], "Input",
 CellChangeTimes->{{3.55323332190625*^9, 3.553233452296875*^9}, {
   3.553233546296875*^9, 3.553233643078125*^9}, {3.553233674296875*^9, 
   3.55323369940625*^9}, {3.553233745359375*^9, 3.5532337625*^9}, 
   3.55323385990625*^9, {3.553233929109375*^9, 3.55323393034375*^9}, {
   3.5532340236875*^9, 3.553234031234375*^9}, {3.55323531940625*^9, 
   3.553235327859375*^9}, {3.553235393484375*^9, 3.55323544403125*^9}, {
   3.553236356890625*^9, 3.5532363763125*^9}, {3.553249517125*^9, 
   3.5532495475*^9}, {3.55324962609375*^9, 3.553249654703125*^9}, {
   3.553251430734375*^9, 3.5532514450625*^9}, {3.553252686609375*^9, 
   3.553252692265625*^9}, {3.55325957378125*^9, 3.5532595796875*^9}, {
   3.55326007428125*^9, 3.553260080015625*^9}, {3.55326017065625*^9, 
   3.553260171640625*^9}, {3.553260240109375*^9, 3.553260240484375*^9}, {
   3.5533441132964077`*^9, 3.553344122765182*^9}, {3.5537542437890453`*^9, 
   3.5537542583883343`*^9}, {3.553754456925062*^9, 3.5537544573042583`*^9}, {
   3.553784553859783*^9, 3.553784563823162*^9}},
 FontSize->18],

Cell[BoxData[
 RowBox[{"28.`", "\[VeryThinSpace]", "+", 
  RowBox[{"38.90117799709261`", " ", 
   RowBox[{"Cos", "[", 
    RowBox[{"1.1635528346628864`*^10", " ", "x"}], "]"}]}], "-", 
  RowBox[{"33.71435426414692`", " ", 
   RowBox[{"Cos", "[", 
    RowBox[{"3.490658503988659`*^10", " ", "x"}], "]"}]}], "-", 
  RowBox[{"42.`", " ", 
   RowBox[{"Cos", "[", 
    RowBox[{"4.654211338651546`*^10", " ", "x"}], "]"}]}], "-", 
  RowBox[{"25.171350468706976`", " ", 
   RowBox[{"Cos", "[", 
    RowBox[{"5.8177641733144325`*^10", " ", "x"}], "]"}]}], "+", 
  RowBox[{"15.969957283016965`", " ", 
   RowBox[{"Cos", "[", 
    RowBox[{"8.144869842640204`*^10", " ", "x"}], "]"}]}], "+", 
  RowBox[{"16.8`", " ", 
   RowBox[{"Cos", "[", 
    RowBox[{"9.308422677303091`*^10", " ", "x"}], "]"}]}], "+", 
  RowBox[{"8.39045015623566`", " ", 
   RowBox[{"Cos", "[", 
    RowBox[{"1.0471975511965976`*^11", " ", "x"}], "]"}]}], "-", 
  RowBox[{"3.471729844134122`", " ", 
   RowBox[{"Cos", "[", 
    RowBox[{"1.279908118129175`*^11", " ", "x"}], "]"}]}], "-", 
  RowBox[{"2.8`", " ", 
   RowBox[{"Cos", "[", 
    RowBox[{"1.3962634015954636`*^11", " ", "x"}], "]"}]}], "-", 
  RowBox[{"1.006854018748279`", " ", 
   RowBox[{"Cos", "[", 
    RowBox[{"1.5126186850617523`*^11", " ", "x"}], "]"}]}], "+", 
  RowBox[{"0.12858258681978232`", " ", 
   RowBox[{"Cos", "[", 
    RowBox[{"1.7453292519943295`*^11", " ", "x"}], "]"}]}], "-", 
  RowBox[{"0.03471910409476825`", " ", 
   RowBox[{"Cos", "[", 
    RowBox[{"1.9780398189269067`*^11", " ", "x"}], "]"}]}], "+", 
  RowBox[{"0.012443476143849901`", " ", 
   RowBox[{"Cos", "[", 
    RowBox[{"2.2107503858594843`*^11", " ", "x"}], "]"}]}], "-", 
  RowBox[{"0.005260470317389128`", " ", 
   RowBox[{"Cos", "[", 
    RowBox[{"2.4434609527920612`*^11", " ", "x"}], "]"}]}], "+", 
  RowBox[{"0.0024886952287699804`", " ", 
   RowBox[{"Cos", "[", 
    RowBox[{"2.6761715197246384`*^11", " ", "x"}], "]"}]}], "-", 
  RowBox[{"0.0012795738609865449`", " ", 
   RowBox[{"Cos", "[", 
    RowBox[{"2.9088820866572156`*^11", " ", "x"}], "]"}]}], "+", 
  RowBox[{"0.0007019396799094815`", " ", 
   RowBox[{"Cos", "[", 
    RowBox[{"3.141592653589793`*^11", " ", "x"}], "]"}]}], "-", 
  RowBox[{"0.0004057185412884166`", " ", 
   RowBox[{"Cos", "[", 
    RowBox[{"3.3743032205223706`*^11", " ", "x"}], "]"}]}], "+", 
  RowBox[{"0.0002448626790381913`", " ", 
   RowBox[{"Cos", "[", 
    RowBox[{"3.6070137874549475`*^11", " ", "x"}], "]"}]}], "-", 
  RowBox[{"0.00015327144893117963`", " ", 
   RowBox[{"Cos", "[", 
    RowBox[{"3.839724354387525`*^11", " ", "x"}], "]"}]}], "+", 
  RowBox[{"0.00009898704046224753`", " ", 
   RowBox[{"Cos", "[", 
    RowBox[{"4.072434921320102`*^11", " ", "x"}], "]"}]}], "-", 
  RowBox[{"0.0000656877638276484`", " ", 
   RowBox[{"Cos", "[", 
    RowBox[{"4.3051454882526794`*^11", " ", "x"}], "]"}]}], "+", 
  RowBox[{"0.00004464121432611163`", " ", 
   RowBox[{"Cos", "[", 
    RowBox[{"4.537856055185257`*^11", " ", "x"}], "]"}]}], "-", 
  RowBox[{"0.00003098479425832472`", " ", 
   RowBox[{"Cos", "[", 
    RowBox[{"4.770566622117833`*^11", " ", "x"}], "]"}]}], "+", 
  RowBox[{"0.000021914777941909344`", " ", 
   RowBox[{"Cos", "[", 
    RowBox[{"5.003277189050411`*^11", " ", "x"}], "]"}]}], "-", 
  RowBox[{"0.000015764193570024857`", " ", 
   RowBox[{"Cos", "[", 
    RowBox[{"5.235987755982988`*^11", " ", "x"}], "]"}]}], "+", 
  RowBox[{"0.000011514544342359147`", " ", 
   RowBox[{"Cos", "[", 
    RowBox[{"5.468698322915566`*^11", " ", "x"}], "]"}]}], "-", 
  RowBox[{"8.528170291980662`*^-6", " ", 
   RowBox[{"Cos", "[", 
    RowBox[{"5.701408889848143`*^11", " ", "x"}], "]"}]}]}]], "Output",
 CellChangeTimes->{3.577683296449274*^9}]
}, Open  ]],

Cell[TextData[{
 "ii) as alternative, the two atoms may be @ ",
 Cell[BoxData[
  RowBox[{
   SubscriptBox["CG", "1"], " "}]], "Input",
  CellChangeTimes->{{3.553399171863435*^9, 3.55339917870542*^9}, {
    3.553399220329187*^9, 3.553399231455578*^9}, 3.55339927878718*^9, {
    3.553775575947589*^9, 3.5537756788945*^9}, {3.553775816643363*^9, 
    3.553775823386682*^9}, 3.5537773469258823`*^9},
  FontSize->24],
 " and ",
 Cell[BoxData[
  RowBox[{"-", " "}]], "Input",
  CellChangeTimes->{{3.553399171863435*^9, 3.55339917870542*^9}, {
    3.553399220329187*^9, 3.553399231455578*^9}, 3.55339927878718*^9, {
    3.553775575947589*^9, 3.5537756788945*^9}, {3.553775816643363*^9, 
    3.553775823386682*^9}, 3.5537773469258823`*^9},
  FontSize->24],
 Cell[BoxData[
  RowBox[{
   SubscriptBox["CG", "1"], " ", ",", 
   StyleBox[
    RowBox[{"therefore", "..."}],
    FontFamily->"Times New Roman",
    FontWeight->"Plain"]}]], "Input",
  CellChangeTimes->{{3.553399171863435*^9, 3.55339917870542*^9}, {
    3.553399220329187*^9, 3.553399231455578*^9}, 3.55339927878718*^9, {
    3.553775575947589*^9, 3.5537756788945*^9}, {3.553775816643363*^9, 
    3.553775823386682*^9}, 3.5537773469258823`*^9},
  FontSize->24]
}], "Text",
 CellChangeTimes->{{3.553261113984375*^9, 3.553261152046875*^9}, {
  3.5537540034918547`*^9, 3.553754062388558*^9}, {3.5537643309436693`*^9, 
  3.553764348539936*^9}, {3.5537777025606623`*^9, 3.553777783320912*^9}, {
  3.553777822966282*^9, 3.553777871746028*^9}, {3.553777902635889*^9, 
  3.553777949928587*^9}, {3.553778242444338*^9, 3.553778248033565*^9}, {
  3.5537782878097887`*^9, 3.553778336154874*^9}, {3.553778594940938*^9, 
  3.5537785959746313`*^9}, {3.5750975488504257`*^9, 3.5750975499751263`*^9}, {
  3.575258403616562*^9, 3.5752584246957674`*^9}},
 FontFamily->"Times New Roman",
 FontSize->26,
 FontColor->GrayLevel[0],
 Background->GrayLevel[0.85]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"\[Chi]func50sim", "[", "x_", "]"}], "=", " ", 
  RowBox[{
   RowBox[{
    RowBox[{"ExpToTrig", "[", 
     RowBox[{"Sum", "[", 
      RowBox[{
       RowBox[{
        RowBox[{
         SubscriptBox["coef$func$F50FT", "at"], "[", "n", "]"}], "*", " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"Exp", "[", 
           RowBox[{
            RowBox[{"-", "I"}], " ", 
            FractionBox[
             RowBox[{"2", "  ", "\[Pi]", " ", "n"}], "8"]}], "]"}], " ", "+", 
          " ", 
          RowBox[{"Exp", "[", 
           RowBox[{
            RowBox[{"+", "I"}], " ", 
            FractionBox[
             RowBox[{"2", " ", "\[Pi]", " ", "n", " "}], "8"]}], "]"}]}], 
         ")"}], "*", 
        RowBox[{"Exp", "[", 
         RowBox[{"I", " ", 
          FractionBox[
           RowBox[{"2", "  ", "\[Pi]", " ", "n", " ", "x"}], 
           SubscriptBox["a", "0"]]}], "]"}]}], ",", 
       RowBox[{"{", 
        RowBox[{"n", ",", 
         RowBox[{"-", "nterm1"}], ",", "nterm1"}], "}"}]}], "]"}], "]"}], "//",
     "N"}], " ", "//", "Chop"}]}]], "Input",
 CellChangeTimes->{{3.55323332190625*^9, 3.553233452296875*^9}, {
   3.553233546296875*^9, 3.553233643078125*^9}, {3.553233674296875*^9, 
   3.55323369940625*^9}, {3.553233745359375*^9, 3.5532337625*^9}, 
   3.55323385990625*^9, {3.553233929109375*^9, 3.55323393034375*^9}, {
   3.5532340236875*^9, 3.553234031234375*^9}, {3.55323531940625*^9, 
   3.553235327859375*^9}, {3.553235393484375*^9, 3.55323544403125*^9}, {
   3.553236356890625*^9, 3.5532363763125*^9}, {3.553249517125*^9, 
   3.5532495475*^9}, {3.55324962609375*^9, 3.553249654703125*^9}, {
   3.553251430734375*^9, 3.5532514450625*^9}, {3.553252686609375*^9, 
   3.553252692265625*^9}, {3.55325957378125*^9, 3.5532595796875*^9}, {
   3.55326007428125*^9, 3.553260080015625*^9}, {3.553260164421875*^9, 
   3.55326016515625*^9}, {3.553397940295739*^9, 3.553397952681242*^9}, 
   3.5537543809682827`*^9, {3.5537544752376738`*^9, 3.5537544766902113`*^9}, {
   3.5537845747719173`*^9, 3.553784579042276*^9}},
 FontSize->18],

Cell[BoxData[
 RowBox[{"28.`", "\[VeryThinSpace]", "+", 
  RowBox[{"38.90117799709261`", " ", 
   RowBox[{"Cos", "[", 
    RowBox[{"1.1635528346628864`*^10", " ", "x"}], "]"}]}], "-", 
  RowBox[{"33.71435426414692`", " ", 
   RowBox[{"Cos", "[", 
    RowBox[{"3.490658503988659`*^10", " ", "x"}], "]"}]}], "-", 
  RowBox[{"42.`", " ", 
   RowBox[{"Cos", "[", 
    RowBox[{"4.654211338651546`*^10", " ", "x"}], "]"}]}], "-", 
  RowBox[{"25.171350468706976`", " ", 
   RowBox[{"Cos", "[", 
    RowBox[{"5.8177641733144325`*^10", " ", "x"}], "]"}]}], "+", 
  RowBox[{"15.969957283016965`", " ", 
   RowBox[{"Cos", "[", 
    RowBox[{"8.144869842640204`*^10", " ", "x"}], "]"}]}], "+", 
  RowBox[{"16.8`", " ", 
   RowBox[{"Cos", "[", 
    RowBox[{"9.308422677303091`*^10", " ", "x"}], "]"}]}], "+", 
  RowBox[{"8.39045015623566`", " ", 
   RowBox[{"Cos", "[", 
    RowBox[{"1.0471975511965976`*^11", " ", "x"}], "]"}]}], "-", 
  RowBox[{"3.471729844134122`", " ", 
   RowBox[{"Cos", "[", 
    RowBox[{"1.279908118129175`*^11", " ", "x"}], "]"}]}], "-", 
  RowBox[{"2.8`", " ", 
   RowBox[{"Cos", "[", 
    RowBox[{"1.3962634015954636`*^11", " ", "x"}], "]"}]}], "-", 
  RowBox[{"1.006854018748279`", " ", 
   RowBox[{"Cos", "[", 
    RowBox[{"1.5126186850617523`*^11", " ", "x"}], "]"}]}], "+", 
  RowBox[{"0.12858258681978232`", " ", 
   RowBox[{"Cos", "[", 
    RowBox[{"1.7453292519943295`*^11", " ", "x"}], "]"}]}], "-", 
  RowBox[{"0.03471910409476825`", " ", 
   RowBox[{"Cos", "[", 
    RowBox[{"1.9780398189269067`*^11", " ", "x"}], "]"}]}], "+", 
  RowBox[{"0.012443476143849901`", " ", 
   RowBox[{"Cos", "[", 
    RowBox[{"2.2107503858594843`*^11", " ", "x"}], "]"}]}], "-", 
  RowBox[{"0.005260470317389128`", " ", 
   RowBox[{"Cos", "[", 
    RowBox[{"2.4434609527920612`*^11", " ", "x"}], "]"}]}], "+", 
  RowBox[{"0.0024886952287699804`", " ", 
   RowBox[{"Cos", "[", 
    RowBox[{"2.6761715197246384`*^11", " ", "x"}], "]"}]}], "-", 
  RowBox[{"0.0012795738609865449`", " ", 
   RowBox[{"Cos", "[", 
    RowBox[{"2.9088820866572156`*^11", " ", "x"}], "]"}]}], "+", 
  RowBox[{"0.0007019396799094815`", " ", 
   RowBox[{"Cos", "[", 
    RowBox[{"3.141592653589793`*^11", " ", "x"}], "]"}]}], "-", 
  RowBox[{"0.0004057185412884166`", " ", 
   RowBox[{"Cos", "[", 
    RowBox[{"3.3743032205223706`*^11", " ", "x"}], "]"}]}], "+", 
  RowBox[{"0.0002448626790381913`", " ", 
   RowBox[{"Cos", "[", 
    RowBox[{"3.6070137874549475`*^11", " ", "x"}], "]"}]}], "-", 
  RowBox[{"0.00015327144893117963`", " ", 
   RowBox[{"Cos", "[", 
    RowBox[{"3.839724354387525`*^11", " ", "x"}], "]"}]}], "+", 
  RowBox[{"0.00009898704046224753`", " ", 
   RowBox[{"Cos", "[", 
    RowBox[{"4.072434921320102`*^11", " ", "x"}], "]"}]}], "-", 
  RowBox[{"0.0000656877638276484`", " ", 
   RowBox[{"Cos", "[", 
    RowBox[{"4.3051454882526794`*^11", " ", "x"}], "]"}]}], "+", 
  RowBox[{"0.00004464121432611163`", " ", 
   RowBox[{"Cos", "[", 
    RowBox[{"4.537856055185257`*^11", " ", "x"}], "]"}]}], "-", 
  RowBox[{"0.00003098479425832472`", " ", 
   RowBox[{"Cos", "[", 
    RowBox[{"4.770566622117833`*^11", " ", "x"}], "]"}]}], "+", 
  RowBox[{"0.000021914777941909344`", " ", 
   RowBox[{"Cos", "[", 
    RowBox[{"5.003277189050411`*^11", " ", "x"}], "]"}]}], "-", 
  RowBox[{"0.000015764193570024857`", " ", 
   RowBox[{"Cos", "[", 
    RowBox[{"5.235987755982988`*^11", " ", "x"}], "]"}]}], "+", 
  RowBox[{"0.000011514544342359147`", " ", 
   RowBox[{"Cos", "[", 
    RowBox[{"5.468698322915566`*^11", " ", "x"}], "]"}]}], "-", 
  RowBox[{"8.528170291980662`*^-6", " ", 
   RowBox[{"Cos", "[", 
    RowBox[{"5.701408889848143`*^11", " ", "x"}], "]"}]}]}]], "Output",
 CellChangeTimes->{3.577683296694207*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"\[Chi]tab50sim", "[", "x_", "]"}], "=", " ", 
  RowBox[{
   RowBox[{
    RowBox[{"ExpToTrig", "[", 
     RowBox[{"Sum", "[", 
      RowBox[{
       RowBox[{
        RowBox[{
         SubscriptBox["coef$tab$50FT", "at"], "[", 
         RowBox[{"[", 
          RowBox[{"n", "+", "nterm1", "+", "1"}], "]"}], "]"}], "*", " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"Exp", "[", 
           RowBox[{
            RowBox[{"-", "I"}], " ", 
            FractionBox[
             RowBox[{"2", "  ", "\[Pi]", " ", "n"}], "8"]}], "]"}], " ", "+", 
          " ", 
          RowBox[{"Exp", "[", 
           RowBox[{
            RowBox[{"+", "I"}], " ", 
            FractionBox[
             RowBox[{"2", " ", "\[Pi]", " ", "n", " "}], "8"]}], "]"}]}], 
         ")"}], "*", 
        RowBox[{"Exp", "[", 
         RowBox[{"I", " ", 
          FractionBox[
           RowBox[{"2", "  ", "\[Pi]", " ", "n", " ", "x"}], 
           SubscriptBox["a", "0"]]}], "]"}]}], ",", 
       RowBox[{"{", 
        RowBox[{"n", ",", 
         RowBox[{"-", "nterm1"}], ",", "nterm1"}], "}"}]}], "]"}], "]"}], "//",
     "N"}], " ", "//", "Chop"}]}]], "Input",
 CellChangeTimes->{{3.55323332190625*^9, 3.553233452296875*^9}, {
   3.553233546296875*^9, 3.553233643078125*^9}, {3.553233674296875*^9, 
   3.55323369940625*^9}, {3.553233745359375*^9, 3.5532337625*^9}, 
   3.55323385990625*^9, {3.553233929109375*^9, 3.55323393034375*^9}, {
   3.5532340236875*^9, 3.553234031234375*^9}, {3.55323531940625*^9, 
   3.553235327859375*^9}, {3.553235393484375*^9, 3.55323544403125*^9}, {
   3.553236356890625*^9, 3.5532363763125*^9}, {3.553249517125*^9, 
   3.5532495475*^9}, {3.55324962609375*^9, 3.553249654703125*^9}, {
   3.553251430734375*^9, 3.5532514450625*^9}, {3.553252686609375*^9, 
   3.553252692265625*^9}, {3.55325957378125*^9, 3.5532595796875*^9}, {
   3.55326007428125*^9, 3.553260080015625*^9}, {3.553260164421875*^9, 
   3.55326016515625*^9}, {3.5537543506515417`*^9, 3.55375435908845*^9}, {
   3.553754480724078*^9, 3.553754481054173*^9}, {3.553784586201262*^9, 
   3.553784591193762*^9}},
 FontSize->18],

Cell[BoxData[
 RowBox[{"28.`", "\[VeryThinSpace]", "+", 
  RowBox[{"38.90117799709261`", " ", 
   RowBox[{"Cos", "[", 
    RowBox[{"1.1635528346628864`*^10", " ", "x"}], "]"}]}], "-", 
  RowBox[{"33.71435426414692`", " ", 
   RowBox[{"Cos", "[", 
    RowBox[{"3.490658503988659`*^10", " ", "x"}], "]"}]}], "-", 
  RowBox[{"42.`", " ", 
   RowBox[{"Cos", "[", 
    RowBox[{"4.654211338651546`*^10", " ", "x"}], "]"}]}], "-", 
  RowBox[{"25.171350468706976`", " ", 
   RowBox[{"Cos", "[", 
    RowBox[{"5.8177641733144325`*^10", " ", "x"}], "]"}]}], "+", 
  RowBox[{"15.969957283016965`", " ", 
   RowBox[{"Cos", "[", 
    RowBox[{"8.144869842640204`*^10", " ", "x"}], "]"}]}], "+", 
  RowBox[{"16.8`", " ", 
   RowBox[{"Cos", "[", 
    RowBox[{"9.308422677303091`*^10", " ", "x"}], "]"}]}], "+", 
  RowBox[{"8.39045015623566`", " ", 
   RowBox[{"Cos", "[", 
    RowBox[{"1.0471975511965976`*^11", " ", "x"}], "]"}]}], "-", 
  RowBox[{"3.471729844134122`", " ", 
   RowBox[{"Cos", "[", 
    RowBox[{"1.279908118129175`*^11", " ", "x"}], "]"}]}], "-", 
  RowBox[{"2.8`", " ", 
   RowBox[{"Cos", "[", 
    RowBox[{"1.3962634015954636`*^11", " ", "x"}], "]"}]}], "-", 
  RowBox[{"1.006854018748279`", " ", 
   RowBox[{"Cos", "[", 
    RowBox[{"1.5126186850617523`*^11", " ", "x"}], "]"}]}], "+", 
  RowBox[{"0.12858258681978232`", " ", 
   RowBox[{"Cos", "[", 
    RowBox[{"1.7453292519943295`*^11", " ", "x"}], "]"}]}], "-", 
  RowBox[{"0.03471910409476825`", " ", 
   RowBox[{"Cos", "[", 
    RowBox[{"1.9780398189269067`*^11", " ", "x"}], "]"}]}], "+", 
  RowBox[{"0.012443476143849901`", " ", 
   RowBox[{"Cos", "[", 
    RowBox[{"2.2107503858594843`*^11", " ", "x"}], "]"}]}], "-", 
  RowBox[{"0.005260470317389128`", " ", 
   RowBox[{"Cos", "[", 
    RowBox[{"2.4434609527920612`*^11", " ", "x"}], "]"}]}], "+", 
  RowBox[{"0.0024886952287699804`", " ", 
   RowBox[{"Cos", "[", 
    RowBox[{"2.6761715197246384`*^11", " ", "x"}], "]"}]}], "-", 
  RowBox[{"0.0012795738609865449`", " ", 
   RowBox[{"Cos", "[", 
    RowBox[{"2.9088820866572156`*^11", " ", "x"}], "]"}]}], "+", 
  RowBox[{"0.0007019396799094815`", " ", 
   RowBox[{"Cos", "[", 
    RowBox[{"3.141592653589793`*^11", " ", "x"}], "]"}]}], "-", 
  RowBox[{"0.0004057185412884166`", " ", 
   RowBox[{"Cos", "[", 
    RowBox[{"3.3743032205223706`*^11", " ", "x"}], "]"}]}], "+", 
  RowBox[{"0.0002448626790381913`", " ", 
   RowBox[{"Cos", "[", 
    RowBox[{"3.6070137874549475`*^11", " ", "x"}], "]"}]}], "-", 
  RowBox[{"0.00015327144893117963`", " ", 
   RowBox[{"Cos", "[", 
    RowBox[{"3.839724354387525`*^11", " ", "x"}], "]"}]}], "+", 
  RowBox[{"0.00009898704046224753`", " ", 
   RowBox[{"Cos", "[", 
    RowBox[{"4.072434921320102`*^11", " ", "x"}], "]"}]}], "-", 
  RowBox[{"0.0000656877638276484`", " ", 
   RowBox[{"Cos", "[", 
    RowBox[{"4.3051454882526794`*^11", " ", "x"}], "]"}]}], "+", 
  RowBox[{"0.00004464121432611163`", " ", 
   RowBox[{"Cos", "[", 
    RowBox[{"4.537856055185257`*^11", " ", "x"}], "]"}]}], "-", 
  RowBox[{"0.00003098479425832472`", " ", 
   RowBox[{"Cos", "[", 
    RowBox[{"4.770566622117833`*^11", " ", "x"}], "]"}]}], "+", 
  RowBox[{"0.000021914777941909344`", " ", 
   RowBox[{"Cos", "[", 
    RowBox[{"5.003277189050411`*^11", " ", "x"}], "]"}]}], "-", 
  RowBox[{"0.000015764193570024857`", " ", 
   RowBox[{"Cos", "[", 
    RowBox[{"5.235987755982988`*^11", " ", "x"}], "]"}]}], "+", 
  RowBox[{"0.000011514544342359147`", " ", 
   RowBox[{"Cos", "[", 
    RowBox[{"5.468698322915566`*^11", " ", "x"}], "]"}]}], "-", 
  RowBox[{"8.528170291980662`*^-6", " ", 
   RowBox[{"Cos", "[", 
    RowBox[{"5.701408889848143`*^11", " ", "x"}], "]"}]}]}]], "Output",
 CellChangeTimes->{3.5776832967638474`*^9}]
}, Open  ]],

Cell["\<\
Now we can multiply with the coefficient Vol1D and easily observe that the \
cases i) and ii) describe
the same cell (as expected) so they are equivalent.\
\>", "Text",
 CellChangeTimes->{{3.553261113984375*^9, 3.553261152046875*^9}, {
   3.5537540034918547`*^9, 3.553754062388558*^9}, {3.5537643309436693`*^9, 
   3.553764348539936*^9}, {3.5537777025606623`*^9, 3.553777783320912*^9}, {
   3.553777822966282*^9, 3.553777871746028*^9}, {3.553777902635889*^9, 
   3.553777949928587*^9}, {3.553778272869059*^9, 3.553778272869199*^9}, 
   3.553826860073675*^9, {3.57494749397497*^9, 3.574947543203638*^9}, {
   3.57509737173516*^9, 3.5750973773052464`*^9}, {3.575097898045354*^9, 
   3.5750979664479713`*^9}, {3.575107742229279*^9, 3.575107746024671*^9}, {
   3.5752584583116903`*^9, 3.5752585229023848`*^9}},
 FontFamily->"Times New Roman",
 FontSize->26,
 FontColor->GrayLevel[0],
 Background->GrayLevel[0.85]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Plot", "[", 
  RowBox[{
   RowBox[{"Vol1D", "*", 
    RowBox[{"\[Chi]func50", "[", "x", "]"}]}], ",", 
   RowBox[{"{", 
    RowBox[{"x", ",", 
     RowBox[{"-", 
      SubscriptBox["a", "0"]}], ",", 
     SubscriptBox["a", "0"]}], "}"}], ",", 
   RowBox[{"PlotRange", "\[Rule]", "All"}], ",", "\[IndentingNewLine]", 
   RowBox[{"Epilog", "->", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"PointSize", "[", "0.01", "]"}], ",", "Red", ",", 
      RowBox[{"Point", "[", "coord2CG", "]"}]}], "}"}]}], ",", 
   RowBox[{"PlotPoints", "\[Rule]", "500"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.553233790828125*^9, 3.553233829390625*^9}, {
   3.55323390053125*^9, 3.553233906671875*^9}, {3.55323409775*^9, 
   3.55323409971875*^9}, {3.553235468375*^9, 3.55323547075*^9}, {
   3.553249909921875*^9, 3.553249924453125*^9}, {3.55325006259375*^9, 
   3.55325007190625*^9}, 3.55325150846875*^9, {3.553252120078125*^9, 
   3.553252146703125*^9}, 3.55325229884375*^9, 3.55325245796875*^9, {
   3.5532525145*^9, 3.5532525275625*^9}, {3.55325269825*^9, 
   3.553252698828125*^9}, {3.553256132015625*^9, 3.553256151140625*^9}, {
   3.55325629571875*^9, 3.553256300671875*^9}, 3.553256426703125*^9, 
   3.553259368796875*^9, {3.55326020821875*^9, 3.55326020896875*^9}, 
   3.5533979773347178`*^9, {3.553754523532002*^9, 3.553754524981373*^9}, {
   3.553754634078079*^9, 3.553754635092478*^9}, {3.5537784179046926`*^9, 
   3.5537784290270643`*^9}},
 FontSize->18],

Cell[BoxData[
 GraphicsBox[{{}, {}, 
   {Hue[0.67, 0.6, 0.6], LineBox[CompressedData["
1:eJw1mnkw1X/Ux68bWtGipCgUbdZK9cXnZolkiawphGuPyBJZsu9LylahqFBI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     "]]}},
  AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
  Axes->True,
  AxesLabel->{None, None},
  AxesOrigin->{0, 0},
  AxesStyle->Directive[20, 
    Thickness[0.005], 
    RGBColor[0, 0, 1]],
  Epilog->{
    PointSize[0.01], 
    RGBColor[1, 0, 0], 
    PointBox[{{6.75*^-11, 0}, {4.725*^-10, 0}}]},
  ImageSize->700,
  LabelStyle->(FontFamily -> "Helvetica"),
  Method->{},
  PlotRange->{All, All},
  PlotRangeClipping->True,
  PlotRangePadding->{Automatic, Automatic}]], "Output",
 CellChangeTimes->{
  3.577683296845911*^9},ImageCache->GraphicsData["CompressedBitmap", "\<\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\
\>"]]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Plot", "[", 
  RowBox[{
   RowBox[{"Vol1D", "*", 
    RowBox[{"\[Chi]func50sim", "[", "x", "]"}]}], ",", 
   RowBox[{"{", 
    RowBox[{"x", ",", 
     RowBox[{"-", 
      SubscriptBox["a", "0"]}], ",", 
     SubscriptBox["a", "0"]}], "}"}], ",", 
   RowBox[{"PlotRange", "\[Rule]", "All"}], ",", "\[IndentingNewLine]", 
   RowBox[{"Epilog", "->", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"PointSize", "[", "0.01", "]"}], ",", "Red", ",", 
      RowBox[{"Point", "[", "coord1CG", "]"}]}], "}"}]}], ",", 
   RowBox[{"PlotPoints", "\[Rule]", "500"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.553233790828125*^9, 3.553233829390625*^9}, {
   3.55323390053125*^9, 3.553233906671875*^9}, {3.55323409775*^9, 
   3.55323409971875*^9}, {3.553235468375*^9, 3.55323547075*^9}, {
   3.553249909921875*^9, 3.553249924453125*^9}, {3.55325006259375*^9, 
   3.55325007190625*^9}, 3.55325150846875*^9, {3.553252120078125*^9, 
   3.553252146703125*^9}, 3.55325229884375*^9, 3.55325245796875*^9, {
   3.5532525145*^9, 3.5532525275625*^9}, {3.55325269825*^9, 
   3.553252698828125*^9}, {3.553256132015625*^9, 3.553256151140625*^9}, {
   3.55325629571875*^9, 3.553256300671875*^9}, 3.553256426703125*^9, 
   3.553259368796875*^9, {3.55326020821875*^9, 3.55326020896875*^9}, {
   3.553754529059514*^9, 3.553754529760747*^9}, {3.553754646020442*^9, 
   3.553754647719242*^9}, 3.553778439959203*^9},
 FontSize->18],

Cell[BoxData[
 GraphicsBox[{{}, {}, 
   {Hue[0.67, 0.6, 0.6], LineBox[CompressedData["
1:eJw1mnkw1X/Ux68bWtGipCgUbdZK9cXnZolkiawphGuPyBJZsu9LylahqFBI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     "]]}},
  AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
  Axes->True,
  AxesLabel->{None, None},
  AxesOrigin->{0, 0},
  AxesStyle->Directive[20, 
    Thickness[0.005], 
    RGBColor[0, 0, 1]],
  Epilog->{
    PointSize[0.01], 
    RGBColor[1, 0, 0], 
    PointBox[{{-6.75*^-11, 0}, {6.75*^-11, 0}}]},
  ImageSize->700,
  LabelStyle->(FontFamily -> "Helvetica"),
  Method->{},
  PlotRange->{All, All},
  PlotRangeClipping->True,
  PlotRangePadding->{Automatic, Automatic}]], "Output",
 CellChangeTimes->{
  3.577683296908329*^9},ImageCache->GraphicsData["CompressedBitmap", "\<\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\
\>"]]
}, Open  ]],

Cell["q.e.d.", "Text",
 CellChangeTimes->{{3.553261113984375*^9, 3.553261152046875*^9}, {
   3.5537540034918547`*^9, 3.553754062388558*^9}, {3.5537643309436693`*^9, 
   3.553764348539936*^9}, {3.5537777025606623`*^9, 3.553777783320912*^9}, {
   3.553777822966282*^9, 3.553777871746028*^9}, {3.553777902635889*^9, 
   3.553777949928587*^9}, {3.553778272869059*^9, 3.553778272869199*^9}, 
   3.553826860073675*^9, {3.57494749397497*^9, 3.574947543203638*^9}, {
   3.57509737173516*^9, 3.5750973773052464`*^9}, {3.575097898045354*^9, 
   3.5750979664479713`*^9}, {3.575107742229279*^9, 3.575107746024671*^9}, {
   3.5752584583116903`*^9, 3.57525854799082*^9}},
 FontFamily->"Times New Roman",
 FontSize->26,
 FontColor->GrayLevel[0],
 Background->GrayLevel[0.85]],

Cell[CellGroupData[{

Cell["Part II", "Text",
 CellChangeTimes->{
  3.5532355989375*^9, {3.553258656921875*^9, 3.5532587594375*^9}, {
   3.553258796640625*^9, 3.55325884934375*^9}, {3.553763675668995*^9, 
   3.553763676089476*^9}, {3.553827279529264*^9, 3.553827300511937*^9}, {
   3.5538273836431704`*^9, 3.553827409025343*^9}, {3.553827501493021*^9, 
   3.553827579968416*^9}, {3.55382761186236*^9, 3.553827632315133*^9}, {
   3.553827665416727*^9, 3.5538276667725697`*^9}, {3.553828240212757*^9, 
   3.553828307642337*^9}, {3.575108443158297*^9, 3.575108495744261*^9}, {
   3.575256096703614*^9, 3.5752560976946707`*^9}},
 FontFamily->"Times New Roman",
 FontSize->36,
 FontColor->RGBColor[0, 0, 1],
 Background->RGBColor[1, 0.9, 0.8]],

Cell[TextData[{
 "Now we consider a more complicated situation.\n\nLet us imagine the there \
are always two atoms inside the cell but let us add\nthat their electronic \
density is equivalent to a single  U-shaped function. This\nmeans that the \
effective representation of the two atoms is equivalent to the\na single \
structure U-shaped (with two ",
 StyleBox["horns",
  FontSlant->"Italic"],
 ").\n\nThis implies that it is more difficult to calculate the \
FourierTransform. Let us face this problem..."
}], "Text",
 CellChangeTimes->{
  3.5532355989375*^9, {3.553258656921875*^9, 3.5532587594375*^9}, {
   3.553258796640625*^9, 3.55325884934375*^9}, {3.553763675668995*^9, 
   3.553763676089476*^9}, {3.553827279529264*^9, 3.553827300511937*^9}, {
   3.5538273836431704`*^9, 3.553827409025343*^9}, {3.553827501493021*^9, 
   3.553827579968416*^9}, {3.55382761186236*^9, 3.553827632315133*^9}, {
   3.553827665416727*^9, 3.5538276667725697`*^9}, {3.553828240212757*^9, 
   3.553828307642337*^9}, {3.575108443158297*^9, 3.575108495744261*^9}, {
   3.575256100047806*^9, 3.5752561002158155`*^9}, {3.575258627039341*^9, 
   3.5752587945509224`*^9}},
 FontSize->24,
 Background->GrayLevel[0.85]]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"\[Rho]5", "[", "x_", "]"}], "=", 
  RowBox[{"coefnorm", " ", 
   RowBox[{
    RowBox[{"(", 
     RowBox[{"Sin", "[", 
      RowBox[{"2", " ", "\[Pi]", " ", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{"x", "+", "0"}], ")"}], "/", 
        RowBox[{"(", 
         RowBox[{"2", "*", 
          SubscriptBox["width", "at"]}], ")"}]}]}], "]"}], ")"}], "^", 
    "6"}]}]}]], "Input",
 CellChangeTimes->{{3.428806000296875*^9, 3.4288060590625*^9}, 
   3.49779292540625*^9, {3.497849788171875*^9, 3.497849791703125*^9}, {
   3.497849829203125*^9, 3.497849845859375*^9}, {3.49785269434375*^9, 
   3.497852696*^9}, {3.49785405859375*^9, 3.497854061765625*^9}, {
   3.49785507915625*^9, 3.497855079515625*^9}, 3.497856711921875*^9, {
   3.4978570273125*^9, 3.49785702796875*^9}, {3.4978689468125*^9, 
   3.497868950515625*^9}, {3.497868984640625*^9, 3.4978689888125*^9}, {
   3.4978770133125*^9, 3.49787701775*^9}, {3.497944703328125*^9, 
   3.497944735046875*^9}, {3.497944849859375*^9, 3.49794485071875*^9}, {
   3.497953876109375*^9, 3.49795387746875*^9}, 3.49795399771875*^9, 
   3.49795567959375*^9, {3.4979612845*^9, 3.49796133075*^9}, {
   3.49796154209375*^9, 3.4979615465625*^9}, {3.497962578046875*^9, 
   3.497962589390625*^9}, 3.497962635921875*^9, 3.498043147984375*^9, {
   3.498043273671875*^9, 3.498043279375*^9}, {3.49804346625*^9, 
   3.49804347503125*^9}, {3.498043753203125*^9, 3.49804375465625*^9}, {
   3.498043808703125*^9, 3.498043812453125*^9}, 3.498046689875*^9, {
   3.498047494171875*^9, 3.49804751059375*^9}, {3.55149477534375*^9, 
   3.551494781296875*^9}, {3.551494824203125*^9, 3.55149484725*^9}, 
   3.551494880015625*^9, {3.55149728784375*^9, 3.551497289421875*^9}, {
   3.5532316476875*^9, 3.553231647859375*^9}, {3.553231859171875*^9, 
   3.55323187140625*^9}, {3.55324905078125*^9, 3.55324907203125*^9}, {
   3.553250599953125*^9, 3.5532506140625*^9}, {3.5533432490792913`*^9, 
   3.553343251245709*^9}, {3.553768232527438*^9, 3.55376826212148*^9}},
 FontSize->24],

Cell[BoxData[
 RowBox[{"coefnorm", " ", 
  SuperscriptBox[
   RowBox[{"Sin", "[", 
    FractionBox[
     RowBox[{"200000000000", " ", "\[Pi]", " ", "x"}], "27"], "]"}], 
   "6"]}]], "Output",
 CellChangeTimes->{3.577683296943471*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"coe", "=", 
   RowBox[{"Solve", "[", 
    RowBox[{
     RowBox[{
      RowBox[{"Integrate", "[", 
       RowBox[{
        RowBox[{"\[Rho]5", "[", "x", "]"}], ",", 
        RowBox[{"{", 
         RowBox[{"x", ",", "0", ",", 
          RowBox[{
           SubscriptBox["width", "at"], "/", "1"}]}], "}"}]}], "]"}], 
      "\[Equal]", "14"}], ",", "coefnorm"}], "]"}]}], "\n"}]], "Input",
 CellChangeTimes->{{3.5537669006131907`*^9, 3.5537669047774553`*^9}, {
   3.55376694925909*^9, 3.553766954054886*^9}, 3.553767119280113*^9, {
   3.553768273941498*^9, 3.553768289552157*^9}, {3.553770027794999*^9, 
   3.553770029462254*^9}, {3.55377059715172*^9, 3.553770599433737*^9}, {
   3.55377139975844*^9, 3.5537714007617483`*^9}},
 FontSize->18],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"{", 
   RowBox[{"coefnorm", "\[Rule]", 
    FractionBox["8960000000000", "27"]}], "}"}], "}"}]], "Output",
 CellChangeTimes->{3.5776832969919033`*^9}]
}, Open  ]],

Cell["\<\
Let\[CloseCurlyQuote]s check that the above introduced function is properly \
normalized @ Z = 14 (Si).\
\>", "Text",
 CellChangeTimes->{{3.49795814646875*^9, 3.4979581888125*^9}, {
   3.49795824053125*^9, 3.497958316*^9}, {3.497959406296875*^9, 
   3.497959420546875*^9}, {3.498043168328125*^9, 3.498043187546875*^9}, {
   3.498106516515625*^9, 3.49810655075*^9}, 3.498811881546875*^9, {
   3.498827995140625*^9, 3.49882799565625*^9}, 3.49882868975*^9, 
   3.552473872765625*^9, {3.552473968390625*^9, 3.55247402665625*^9}, {
   3.553260807015625*^9, 3.553260815*^9}, {3.553753211917671*^9, 
   3.5537532471483917`*^9}, {3.5537532772628927`*^9, 3.553753310106073*^9}, {
   3.553775339564728*^9, 3.553775388928371*^9}, {3.5538272658268547`*^9, 
   3.553827271558619*^9}, {3.553827318764749*^9, 3.553827365915971*^9}, {
   3.553827426142563*^9, 3.553827457019126*^9}, 3.553828090670125*^9, {
   3.553828174641241*^9, 3.553828202866152*^9}, {3.574943132840713*^9, 
   3.57494313890244*^9}, {3.574943229021974*^9, 3.57494323680661*^9}, {
   3.574943304707011*^9, 3.5749433047071123`*^9}, {3.5750891979997683`*^9, 
   3.575089219260971*^9}, 3.575096334352598*^9, {3.575096473118904*^9, 
   3.575096549237656*^9}, {3.5752581595596027`*^9, 3.575258181038831*^9}, {
   3.575258941359319*^9, 3.575258960486413*^9}},
 FontFamily->"Times New Roman",
 FontSize->26,
 FontColor->GrayLevel[0],
 Background->GrayLevel[0.85]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"Integrate", "[", 
    RowBox[{
     RowBox[{
      RowBox[{"\[Rho]5", "[", "x", "]"}], "/.", 
      RowBox[{"coefnorm", "\[Rule]", 
       RowBox[{"coe", "[", 
        RowBox[{"[", 
         RowBox[{"1", ",", "1", ",", "2"}], "]"}], "]"}]}]}], ",", 
     RowBox[{"{", 
      RowBox[{"x", ",", 
       RowBox[{"-", "0"}], ",", 
       RowBox[{
        SubscriptBox["width", "at"], "/", "1"}]}], "}"}]}], "]"}], "//", 
   "N"}], "\[IndentingNewLine]"}]], "Input",
 CellChangeTimes->{{3.5537669006131907`*^9, 3.5537669092107563`*^9}, {
   3.553766959867608*^9, 3.553766965352017*^9}, 3.553767122119419*^9, {
   3.553768306947383*^9, 3.553768316098216*^9}},
 FontSize->18],

Cell[BoxData["14.`"], "Output",
 CellChangeTimes->{3.577683297031575*^9}]
}, Open  ]],

Cell[BoxData[
 RowBox[{
  RowBox[{"\[Rho]2", "[", "x_", "]"}], ":=", 
  RowBox[{
   RowBox[{"\[Rho]5", "[", "x", "]"}], "/.", 
   RowBox[{"coefnorm", "\[Rule]", 
    RowBox[{"coe", "[", 
     RowBox[{"[", 
      RowBox[{"1", ",", "1", ",", "2"}], "]"}], "]"}]}]}]}]], "Input",
 CellChangeTimes->{{3.5537669006131907`*^9, 3.5537669092107563`*^9}, {
  3.5537671233030033`*^9, 3.5537671473768787`*^9}, {3.553768322449093*^9, 
  3.5537683229387712`*^9}},
 FontSize->18],

Cell[BoxData[
 RowBox[{
  RowBox[{"\[Rho]p2", "[", "x_", "]"}], ":=", 
  RowBox[{"Piecewise", "[", 
   RowBox[{"{", "    ", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"\[Rho]2", "[", "x", "]"}], " ", ",", 
       RowBox[{"0", "\[LessEqual]", "x", "\[LessEqual]", 
        SubscriptBox["width", "at"]}]}], "}"}], ",", "\[IndentingNewLine]", 
     "                                            ", 
     RowBox[{"{", 
      RowBox[{"0", ",", 
       RowBox[{
        SubscriptBox["width", "at"], " ", "\[LessEqual]", " ", "x", " ", 
        "\[LessEqual]", " ", 
        RowBox[{
         SubscriptBox["a", "0"], " ", "-", 
         SubscriptBox["width", "at"]}]}]}], "}"}], ",", "\[IndentingNewLine]",
      "                                            ", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"\[Rho]2", "[", "x", "]"}], ",", 
       RowBox[{
        RowBox[{
         SubscriptBox["a", "0"], " ", "-", 
         SubscriptBox["width", "at"]}], "\[LessEqual]", "x", "\[LessEqual]", 
        SubscriptBox["a", "0"]}]}], "}"}]}], "\[IndentingNewLine]", 
    "                                       ", "}"}], "]"}]}]], "Input",
 CellChangeTimes->{{3.551498491640625*^9, 3.5514986003125*^9}, 
   3.55149887221875*^9, {3.551767390609375*^9, 3.5517674035625*^9}, {
   3.55176789890625*^9, 3.55176795065625*^9}, {3.551767999828125*^9, 
   3.551768017375*^9}, 3.5517681059375*^9, 3.553256913359375*^9, {
   3.553256965921875*^9, 3.553256975875*^9}, 3.553257130765625*^9, {
   3.553257186828125*^9, 3.553257189875*^9}, {3.553257288734375*^9, 
   3.5532573164375*^9}},
 FontSize->18],

Cell[BoxData[
 RowBox[{
  RowBox[{"\[Rho]p2", "[", "x_", "]"}], ":=", 
  RowBox[{
   RowBox[{"\[Rho]p2", "[", 
    RowBox[{"x", "-", 
     SubscriptBox["Sa", "0"]}], "]"}], "/;", 
   RowBox[{"x", ">", 
    SubscriptBox["a", "0"]}]}]}]], "Input",
 CellChangeTimes->{{3.553768845100535*^9, 3.5537688873714943`*^9}},
 FontSize->18],

Cell[BoxData[
 RowBox[{
  RowBox[{"\[Rho]p2", "[", "x_", "]"}], ":=", 
  RowBox[{
   RowBox[{"\[Rho]p2", "[", 
    RowBox[{"x", "+", 
     SubscriptBox["a", "0"]}], "]"}], "/;", 
   RowBox[{"x", "<", "0"}]}]}]], "Input",
 CellChangeTimes->{{3.553768845100535*^9, 3.553768855451737*^9}, 
   3.5537688921959457`*^9},
 FontSize->18],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"aq", "=", 
  RowBox[{"Plot", "[", 
   RowBox[{
    RowBox[{"\[Rho]p2", "[", "x", "]"}], ",", 
    RowBox[{"{", 
     RowBox[{"x", ",", 
      RowBox[{
       RowBox[{"-", "1"}], "*", 
       SubscriptBox["a", "0"]}], ",", 
      RowBox[{"1", "*", 
       SubscriptBox["a", "0"]}]}], " ", "}"}], ",", 
    RowBox[{"Epilog", "->", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"PointSize", "[", "0.01", "]"}], ",", "Red", ",", 
       RowBox[{"Point", "[", "coord2CG", "]"}]}], "}"}]}], ",", 
    "\[IndentingNewLine]", 
    RowBox[{"PlotRange", "\[Rule]", "All"}]}], "]"}]}]], "Input",
 CellChangeTimes->{
  3.4288042703125*^9, {3.49778604878125*^9, 3.49778605965625*^9}, 
   3.4977861058125*^9, {3.49785387028125*^9, 3.497853884921875*^9}, 
   3.49785671559375*^9, {3.497857394734375*^9, 3.497857397078125*^9}, 
   3.49786902040625*^9, 3.4978770305*^9, {3.497944771953125*^9, 
   3.49794477259375*^9}, {3.4979448625625*^9, 3.4979448636875*^9}, {
   3.4979540598125*^9, 3.497954172265625*^9}, {3.497955714734375*^9, 
   3.497955717125*^9}, {3.49795838578125*^9, 3.497958388171875*^9}, 
   3.497961577203125*^9, {3.497961713953125*^9, 3.497961715859375*^9}, {
   3.497961849203125*^9, 3.49796195371875*^9}, {3.497962691828125*^9, 
   3.497962719796875*^9}, {3.4979630325*^9, 3.49796307140625*^9}, {
   3.49796322521875*^9, 3.49796323203125*^9}, {3.497963678203125*^9, 
   3.49796369953125*^9}, {3.497963735796875*^9, 3.497963738140625*^9}, {
   3.497964055828125*^9, 3.497964059265625*^9}, {3.49796409296875*^9, 
   3.497964095546875*^9}, {3.497965051734375*^9, 3.497965055*^9}, {
   3.49804353478125*^9, 3.498043555296875*^9}, {3.498043595328125*^9, 
   3.4980435973125*^9}, {3.49804363465625*^9, 3.49804364075*^9}, 
   3.498043686078125*^9, {3.498043725515625*^9, 3.49804374590625*^9}, {
   3.49804385228125*^9, 3.498043854109375*^9}, 3.498043985703125*^9, 
   3.4980440170625*^9, 3.498046689890625*^9, 3.4980475526875*^9, {
   3.55149489528125*^9, 3.55149489840625*^9}, {3.551495004671875*^9, 
   3.55149501709375*^9}, {3.551497540078125*^9, 3.5514975621875*^9}, {
   3.5514976541875*^9, 3.551497654796875*^9}, 3.5514979865*^9, {
   3.551498275953125*^9, 3.5514982804375*^9}, {3.551498313609375*^9, 
   3.551498354703125*^9}, 3.5514984259375*^9, {3.551498623046875*^9, 
   3.5514986278125*^9}, {3.55149871228125*^9, 3.551498712859375*^9}, {
   3.551498783921875*^9, 3.55149879471875*^9}, 3.551498872234375*^9, {
   3.55158288580766*^9, 3.5515828866717463`*^9}, {3.551767493671875*^9, 
   3.551767503609375*^9}, {3.551767559015625*^9, 3.551767560015625*^9}, {
   3.551767594671875*^9, 3.551767598328125*^9}, 3.551767963671875*^9, 
   3.553256982484375*^9, {3.553257338390625*^9, 3.553257343859375*^9}, {
   3.553257431625*^9, 3.5532574321875*^9}, 3.553767213558557*^9, 
   3.5537672646063223`*^9, {3.553768355582003*^9, 3.5537683622791243`*^9}, {
   3.553768916359557*^9, 3.553768917539007*^9}, {3.5537714715590143`*^9, 
   3.553771474985599*^9}, {3.553771513891637*^9, 3.5537715164408617`*^9}, {
   3.553784651534971*^9, 3.553784665638814*^9}},
 FontSize->24],

Cell[BoxData[
 GraphicsBox[{{{}, {}, 
    {Hue[0.67, 0.6, 0.6], LineBox[CompressedData["
1:eJxN2Hc4lW/4APBzDslKVoNUtpLslZHzPEgZ4ZxsZcvWkGQUZeVbqWzZlSJZ
IdHzkpnIluxDhIwKDZxz/Pyu63fl9/7xvtfnuv+47+e+3y3k6EtyIeBwuPOb
u/89nmu6PfDlLgETkSr3fjQXoiYSEr22GkPAJHymeNV7SrRmFKL2cUYTsFvq
cSisi4tY+C1CQzyCgJWRwt9esD1FvJwdflbjJgHr6TD83vbxIlHV8tZ10g0C
prRdSVTr730ineNmplswAXPPTx1JMc0j1jeG1l6/RsAmrhzkezVVQ4wOvjEe
70/A1hvU3ZJqu4hGCtcJLy4TsD/dQbXfVseJ3N+CRd5dIGDnzUrHaid/ED9n
Ben0exOwVQX35LUvNGK6RaDLggcBiycJtcxKsABHjmuRDG4EbK6fK0DPiBcc
arz6jM+FgF36z7/UK+MgWAjyfy/jSMB2U06sb6dIgFL5K7O6dgTsvxWVqqk7
cuDq7GVWW1sCtsCoymGocAxoZF06csmKgDnXXHFpew0AweKiYbQ5Aev/nNIt
7HcSNO+44J1BJmBBmoctZJNNwJ0Gn3tlJgTMoV/Fl0/GHJCCvIs+GBGwDnvC
ij3xLNgj79VJ0Sdgxb+5L9xncwLDMx4/f+sRsCSyQqBjuBvIznTn3qFLwD49
/LNnQc0XuJq7KYhAAlbolaFRWXoZSO04f+aY1ma/t/0inswKAD/rXa4YaxAw
vOXewrGo66Ai0DnR5RgBczMeZfdovgmC5ZxeBykTMF13OS/x75EAzDh8fqBA
wBYzdqxUd/0HmDLtV5/JEjCsqjP+e/190Gpmx48d3Zw3Q9Ivzd3x4D77OfVe
yc3+5dGdzy8mAfN6W9tvEgSsdNJn5rhtGtgXaBOCEyNgTmlHJLwqswBF1jpj
tzABU5WTnDuV+RjkTlvWSB0kYBRH7rL4+VzgmWFBgQIELKVTK3cgPx/Impnj
rfgImOx05FHbqULwi81M2Hc3AdMY1XTe0VsCqurI2hE8BOxA1ULt7I0yEHqN
5PyIk4AdjWVhYQx5DXRlTSNKdhCwq4RbXaHdVYB12ji3mZWABcvK7v0WhYHO
9NPNI9sJ2K/Kt3bJpHcg4YzRzDIjAVPLvjhrnlIPrNkMWVgJBIyILb9/INAE
DtbpSwpu4LFeC4uDY5T3YDLglIEyFY/JFUlZsM61gnyZk16Gq3gsjWBmyEvs
AL5fT9x1/I3HxEaJeSmXuoBium5hwDIeK+oouzPr2wPWyDod937gMeQ2q/wh
tQ+EvwNc1d/wGEEoh4khYhDoBxDlu6bx2CVD0+fX9UfAThkt8vQkHqM0JD6Z
EaWA3ilNP9o4HnPYODcmVj8OUtM0EnjG8JgMw+OEF2FfgB1ZveLwMB77bid0
VM1xCoiyqvVrDeCxb8+ehKe7ToOiqyp8Xj147IHK8PjJiTmQ4XsgRLsTjy3a
ZKaj+EVw5/y2cf6PeIwWdpBHFf0AgXbzOksteMwjsVrmt/4ScLPoed7ShMdg
+N7pyZVlYG5cxZ5dj8c+yamSzd7+Ajp62RcCavEYT9dOl/ScP0BQxVdVogqP
Xb4gfkyoax1wyJin0Svw2PLzbyICAnRAFdfEfXqFx75KEGbLdXFwYDfb+/CX
eOyR82CiySIBvudYOmKbv5nP+sCDfHtGWME0EKvwbDM+yh5Gnd4GH/7OtZjI
wmNze77InVFlgaGLd6vfpOMx36FnwYjABn2++h18kIrHMrWfskxNskODT3Ba
Kx6PXXG4dv7BNU6o1n7YYM8DPMZ7l3jixH0ueKiJs2jxLh7bNdNof7SMGzJW
jPqnR+Exos5RsR7RXXDpZeOgXzge45zl/iZ1aTekPC04bhiGx864F5YuftwD
UUIg03rg5nr4ui42lPBD/yu7Ey198Fiy4/FASrIgdPamrcp44jEptUpQFSwE
SS6TZ7e74bE8rM6/wk0YypiVilU44DHM4M1+NytROKN4upzHDI/pJ5iKu2ce
gp+klPjmTPHYxyfiffubDsMGUYGQutN4jD+y3c/ylyTM5v2mc/EkHrt6jW/0
rPdRaL0S0duujsciUi+eC3SQgyfnvVRzVfGYFpcVX9pueag8SU4LUcJjMbwf
mPs75CFPr5CzlAwew3nJMLicVoRtr9DybWE8ZsrjYMAfqAI1L//i1mXBY0d4
WCl8AcfhdUIBO4kJj31OLmz0N9OCtQ8cmewYNvNRI/+G8xOhTnHHagANhwkR
k6IO04hQfyGPUvATh6U1L6V8boPQ/Py5Qt5BHLbRCexEI07A5N+8z4X6cZil
cUDFd+oJOBDRmi3di8Pkao9HpfnpQdsnqgkn23GY7ir13nGnk9BxnDs4uA6H
eaYJ+vOo60Mfm+ZTk/k4LLSapMBaawSLv4Vo/3yGwzRXHFW6JU/Dn9cUNelP
cJhx90l7etxp6JecLbs3E4fNdb92FXMwhoF9QXsM43DYrdrHxN2XTOBbZ3ku
q/s4TDYr2L4l0wTSlmdYXe/isK5k/qwzbSYwlNucfiNqs77oCbYPQqYwylh2
6lUQDttHD5ITQKbw/ejX0doAHGZ0kiU4kGIKWX3SP3+8gsOur3q1OBNI8N4d
1rZpXxz2IXZt/S0gwc597xpXvHDY664zYfvsSJDrxdUavAcO8+LyMp4OJMH4
lsnSfc6b/VG3WH3xkgQ/WT4qOOSAwzwe2DskN5DgnhnTXKVzOOx5Co/MwAAJ
Wl5lzoI2OKz3yKSo+wIJpjLVpBhb4jBf/ffe2hskOJxwJc7WDIcVSKxlOO0k
w/1iUnfdSTisfj3uTeN+MjxXNhHpb4zDGlYYpVwlyTBLOyX0liEOi0o51wOU
yDDYqPtU5ikcNppH/iB1nAwtLdh4qk/gsOMB/t12umSo6KAz/Ekbh51VfyI/
oE+GnJ4hT5eIOMzJCj5KOk2G834VPhzHcdiTgDLxVBMyfH/9u4qkOg7bZfjS
irLpJ9GH8CdUcdjsXysRD2MyDHvo8MFBCYcFENxGVAw360tLjQuRx2Grb6YM
9PXIUC23xzZFBoflaNHScohkuLuYXbxcanO+8jFuUJUMl97ofu88jMMytWKK
jkiTYXv99cp5cRz2ptFtyF6YDPM/vg5jFsVhT2fF0CQvGUb2/9AXFcJh0+5W
d6q2kTfPt8O8xAM4rPgZ19epFRI8Puc4YrMPh7Gei231mCBB/l+Pcq/u3Vxv
3GiWUTsJ/qb3+sbtwmFH7IyOxFWSYDczx7EibhzGe/RdLDGbBAu59QitO3HY
d4U5E5toEowRCG39yo7D2qdsjWa9SRDKLp09sB2HEQ3s5AIUSfCA2hEJNcbN
elyC70XuIsE1becfZngc1hNuskPklyl0KSrYtu/PBmKaY5sQLTaFJ+h+xqtj
Gyj1wrmrcrtNIZ1relx2cAOZbzAfip83gRViVn5uvRsorf6XZMs7EyhupJnS
/34DyXB60DrdTOD2tG1fyks20LuM9VtTZ4zh+2OJ/pdubaAYlvbyYlZDaHDl
dfqc+AaSbH/qq9ipA83Z1sqfCm4gxy7FpIumOtA+W6Pdjn8DXeDAp/L1aEO/
j+/oPTs2kLBdWSn7ZwjTxNrs3q7QUb6N38TOOSLMreYI8F+kIxf5YgnVS0RY
bGp6X3aGjjxKzybhfmnBhpBPtU+G6Gjp4ulnQfuPw/k+itDdOjoqG+FgbYpV
g789RdT03tLRIZ29TcxlxyCO4ErCV9BRXe1EacqQKuSVnrt5JY+ObP36ZjiU
Nu9nkb++nL1PR886QWAzjyI8KaBK3ROzmT/kCHW7mQIklQbydt+ioyTNjgOa
qfLQdXRD58RVOmoY5tr7RlYO3lNmzZU+R0dZNeNUzgNHYXKbITZjQUeCrTol
vBNHYI5j7KccUzqC4H7U9UJJWHGPd/seXTqy2iCcvm1/CNaKWhzsOk5Hsk1P
I8VOSMAPVSkq/6nS0YPvfxMPKIrDsa8H3DaO0FFxHGaEOywKvwU7hL4RoyOG
67IyHTIicIX7SfLlg3TE4Xoopvm4MGTWOtwyzU1H6v+xGU37CULZJAXJzlUa
yor9JZF5nR+qHfWHMcs0lHjirWQHCx/Uqa+01lmgIaaFQL7yx3ug5XfN/yop
NHT0yPv6h4Rd0DEi9PGlQRoKiHZ6s97EA7321VdL9dLQLvOUa7Rkbhiqd3I+
q5mGuO/t8Ix35oQxIzGMNu9o6AgZG+Ku5oDxlz8K7KqmoWCPoXuFjezweSbJ
6HYhDW2w6iZaCbPAUqUEF+3nNBR5wLiH+/J2+La1P4SWTUMfTQkW3QPbYNcf
28KLCTT0fFve0+dfCfDm2+NLibE0lC6OD/iZjYfyYYLKb2/TENV6cnqnDw7G
s04ipus0NJhWd0bMmwp0OxrxUgE0pO0SnFbutAZ+xz3TNb1EQ/LXlPTDrv4F
Fvs9Pz5ypSGnZcYdvksrgHnCkOudPQ29CLi518NiGVTmSpt9taYh6Tt31Mh9
P4G7J2cKmxkN2SddDjzo+QPwyy4NyxrTkMjkhb5YmUXQutIjaH6Khj7o/1iJ
K5sDwW/KnYO0aQi1Td8ydpoFI/DafKPK5jxQcYaM8hS4t91Gdk6OhgTmnGix
5l/A8TYNP04pGqoIv3hWMGUcfL9/oFJJnIYWKKwGyn/HQJYZjmotSEO6mg5P
764PA1P+Ca1QfhoKGpJJnFcdBISx+ltPeWnIYkTJiPtlP3Byi2L7wUxDnopD
qbJHewDvUXfjXQw0NL/7XrSkQhdo+Kkfp0ajovnVke0jze3gSoVUv90fKooJ
bcCHXWsF4kEc+yJ+UpErk4f+xpX3oF/rx7n8OSpiyXn/3LCyEUQzdud0TFHR
rq5ccrx6PVBtefV1ZYyKIm3G61XWa8Hs3QRJ/kEq+mZ1sjVtCoFU0lUfrV4q
eqbvSdbXqAL6e6xKndupiNDJ9SNoqQKsD6n9vv2eioDta5YMXBkoyBJQK6qj
orr7rjzhdiXgrAs9pPctFUVYedz7yFkIOCQp71YrqEjdXMu+YTYPYIvvth0s
oSKnWT/mac1c4Pvq8SmdF1R0SOL2kwX8YyAYEHHX/SkVqeheZTt1JAt0apzv
updJRfdjbnOr2z8CYfhTu8pSqMh05tvzQI4kIN8kaTUQR0WnBBijdU3iwJcY
9nT6XSr6LMiU0rvrPog3XqSIRG/mkzp1VC47BujwdoqeuklFP4ffp1h/jQC/
Ppe4+QRTkW+FnmDKRBjITY8riPOnougKzUmGjWBg7njlR+UFKrLZ+6nNwfQq
2C5hoTjqQUUC3y4XWSddApVzqgEMLlQ0G+J3Rd3OG7gX8789ZEdFZU68C1F/
XQH/FeqGkdVmP25M/KfQ6AA+HBvVvkymogalIXrOERsQRK+JSjaiokxLeR3m
sDNAqj67FeltrieQMG148zQYjrq18wugImZ+uVOclifAXUMXMrMGFWUoOZl2
8BLBcS69pKPKVDRAF85//EoZfO87NESSpaJF0SeFLdYyICuV9WCAJBVVX1vN
KjgoBkzs5h3TRakICyi1j3yxD+BF23PrDlDRp1tMMQsxXIDRM/SCx14quqd2
gNJ+kxEwlcqrcXNTkUFkfczA299EltVJhio2Kjopuf7SKHOayE5M+uiwjYo2
VESGXuR8InJEnUpi2VhHCoYmlmn36olc7ev2JX/X0e6or9k3rrwk8u4qlLRa
Wkc5uk19HmceEnfb2q/g5teRz4Jc1Y0jF4l8j7mx51PraG9pRkGDmA5R4FtD
lMnYOgp5KCfL1UcgHpC7avr38zq6cc64fZvcTS2hgMP7srrXEe7/NtGaoUm9
ti2LM90r/N64Zan4JaD1ZsvSQ0/Ypku3LCds0XevYMvKxdVuo5lbBm3hsSGR
WzZn3DNSTd6ypUFLrpPRlm0eBl1g09uyvSCFwUZty54aeZJrglsO9VMPUF1c
++cXk3Y85dFbnhDcExx4c8v8Z9sntYK3HNOnUfHBd8tuTXxWFPMtiz/vyWAT
23KOp56k47vVf05dkgY71/7+s2J+i7li5J9/Pvk7nLK29OufmebZSHcCV/6Z
RaYzPIJl+Z+jmMqPCF77+c+FUS5VEQw//jlTzTuQb2T+n71wMYQ/72b/+S7f
cWuP4a//nLioqTDQseWMek32k/VbLvTWxMTyt9z5TkN4/OqWuT3Uv1nwbDm5
SjVQV3/qn7NiVcllmlvOc1aVEpHbchWH6ihu75aHHFXg26nJfz7ApsyqELbl
xzYKqYKVX/75792LH1wKtny6tmgtP2vLa6JSNkq3t2yyKCqgb73lXEEnw9jT
W6aSsoN74Zafvd4/cu7IlumhuzMuUyf++cyrM+2VP7acN/WQTpv8f3H9nXbR
H7ecH2wU+/HdlnFF/9VwV2z5BQ+zYHrG/4ufOGEy8XDL5gHhoRJRE+h9AQPX
CHDRKsivK/YKmkDLvCcI4Rk/tQgjuPES3wkk2AihCbsS0XKnFtcfpwmUkfbZ
9U+/I/ElCAEalhMoXK9t91RROJHgV30xzHACRfxa4tNYyCJa5q5mNxEn0MNU
5aTSugpi4WeVbjalCXQR7vbzTPpAZGTzJ5genkCh9tyMa8tDRGvNMvnE/RNo
z1l/CUHOOWKR75LjENcEEhV9OxAd9ZfImCMbJ8g0gSIF570tObcB616fepe1
cdSjMMDvps8FipleLucvjiNaDuuzctI+wHRsTuTHxDjK4QtT9ZwUBbaeh88o
9Y+j1KhBnZkdMqAk/Xx4YOs4cq/nb2W+pQyYOp+W1dSMI/En2J7sBS1gS5ic
ZCzbtMJl9EXhBChVFN6l/3wc2RJfLD+zOA2Yz9vrxqaNI3w0ve6q2xlwLiXj
Su/9cdRL22tH4LQBr1qHn/JFjCMDAQcaZ4UDYKbzfzp3bRwFvVAs9p1xBedk
rZieeI+jMYaivDenvUGZY5LyrMM4anRnqNKLvQRYE/pcpc3HkX7W8Vt4/avA
vpkn6bL+OCouWRkmrAaD8lXT5srj46j1YHtWOSUMsErd/0OTH0c1opwEgc3n
p/25dgltiXE01Bcarfk4BlTcZ7eM3jeOBoW6DJz33gfs9frRH3eOow8l1yb6
zsQBx1/RldyMm/XPpnIn70oCryWaZyz+UlD5Lq1btz0eAXbrbXzp8xR0c+kT
dl4+Czje0T41QaGgK/LjTBfZHoNKLOyaRB8FVTjn9Rvo5wKOnzV5Xi0UpHLo
nmbyah5gPpQ5VfGWgs6yno0duFUI8HbXhfDFFOQZyVl0ub8ErCWcPWvwmII+
tonczmwsAyttGikJiRTkNuTmd2xXJVhkEOgbu01BDBePjiR1VINptXVOyRAK
CrdZZs+m1wDKxUFDvwsUJMNlVexqXgcGn7+JxpwoiOIRez9+qQH0jiU3MFtQ
0GiBNDV/oBl83B2AI+tTUO21s7gmrlbQZGShka5JQbkthxSNsttBbbhywLQs
BWV/8569ptcFqqp3lcmJUtD1ntunhy/0gFdLK9+D9lDQg8d+NZc6+0DB4d4j
TawU1KY4GLzd4zMwfOfaIUgdQ/hbzM9vgyGgJSOmVz4xhpjErr9htxkF8ulf
sFMtY+gyX92c0wgFiLHlKI8WjaH8j4qRMaUTYO81+8JLiWOI05xJWrVoErBN
HxDfHjKG7CzUbav7vgL6mZH0R05jKD611OPSoVkwKWt9t0F2DCU1Dq0RbRdB
f8bebVZ7xtC1n+flZbJ/gA/s/cELtFG0YfDxu63MEkCBCSthk6PoiCT7jvWB
ZVA8Q/ba3TqKdpDyHe1zfoHH5tyT+SWjqK/yRNPM7T8gsaHTRit5FN27Ont9
5cEqCM4yMnBzGUVx/N+aD7PQgS8Hez3VYBRd1RJ0faiJg47BH9QeyI+ihNB6
h5zbeHjSUk+yamMEBX2eLuw9ywjVm7blnP46grYhw27n6W1QWrGB70vbCNJl
mj8zEbkd8nICFvbUETSQaxQXyMoGt1/fCM0KHUEZ5X521O/scG0O/VU8P4Js
1IUGVRc5IKVZbeas4ghqNG8cbH3EBXuUVu2W+EdQNcNAPlMdN2x6/Lo/Ej+C
mu0Cc37+4oEFNxSbi9qH0VuPkJe7onfDzIWl4zrlw8hnaCFm+use+NCmpOLz
o2F09Y9daeoZPhigIp2Ldx9Gvg7+Aq/PCkDPp/P7E42HkVeQ6PHs1f3wHM+L
BEnlYSR9nfLH++lBqPNdIoLMMIwS9mSv1icKQZWzX6nTs0NI9e9K4r4IYSjZ
+sQvuHMI7RYx1GkKEoGcz4Scn6YPoVSiZdHZm2Jw+Nw+7T8qQ+jctdhext+H
4ePsBWXCwSFkDbDWNuEj0GOyRnIH0xDKkMw+PWUhBVfdnblFegdRwc4a0uqg
NNx95eX46QuD6IV5pUiXkDwcfX2jz8piEB2LKIxY/ywPn66ZtjgfH0RiTcJJ
e+MVoGLo7+JA9kEUsdPOe2mXEjT9Tys09/kAkuihTGmdUIV727n8SmIH0Mgx
wz9i+45BCufk+bf+A8jES3HEafkY9EmMNu7WGUCP19Bc4Et1eCe76wCd8hk1
MLyIa9bRgk2vnZAZ32cUnxbprnxBG95dUyqxx31GgfMqUkEL2vCMJvNTz+l+
ZPZfIqempw78UldwJ6y8Hz0zLejsO68Lce2/bF6a9iOLbyL7Yh31oPpk1Bpj
zCc0Mzu2N+yEASRIWC/uvPgJtR0VVDtWYwA/uEtN8Ft+QuCqZmK1suHm93ln
i6z4J+R1kp5ZIGQE/df4Umzr+pB91vMzYpOnoabm/J3zeX1o58B0I6+JMWQM
xUIv3e9DCje6SxfeGMO4bU5u0ef60MGLd0wDtE1gMWeBStlaL2IxM6orwZtC
bo71Ac8vvegF6xT1t6Qp9GPTDxZp60XJAsPHqSRTqMo0U/swvRdlWMQJCGea
wlQGFSf9yF5UzuLEKFdvCqm4yG0E316kGtTxYHjKFNaui+hfJPaib7+KnWbF
SVB49dL8ocO96O/Ee5K6LgmG/353j8LVi1K690M2RxL8uswpl7zWgyqMXa1J
ISR48qddj/GXHsSNs9jPmkSC+YuFV7a39aA+kbnzUkUkyD5P21NT1oPyf971
e9VIgj6zhlX+6T0ITxEZSRkkwY6vj2ylI3tQx9+ltMEFEpSd/Eaf8ulB35zd
uS9ukODD8WPZ6RY96J3bO5zVTjJcGY3WNiP2IAWBmw/u7SdD8+H+KfbDPShQ
ediMQ5IMKwfEoxu4etB7swm9PkUy5O+/Ihm81o141dNaKZpkGNzb0KbwpRv1
h60USeuS4WgXj+9cazc65xUqg/TJkNjhyPW4rBvpeQv9jDlNhjltJa+s07vR
F4lQ5iQTMmT8gDPnjuxGPSX2v//3/6drs/HfFp9uRP3R8dzNmAzfN2Skhll0
IyaCZJC0IRlK1i1oHCN2o84nq0oKemR4p0Zj7MehbtTytpgjgEiGi2//C3vO
1Y2uMqo9o6uQoUnVoIj9WhfKFXXe0XKUDEtfH27a86UL3fAVrxoQIkPe8gC3
jtYutPKg5r4CLxn6lzazRpV1IdP0wpEBRjL8XLT75fH0LmQ9FGnWuUyCai9d
jH9HdKH/fmTw7BsnQfozhngXiy5UGfn5fU0FCdo/JSnvJ3YhpvP530QySbAu
J/tz76Eu5Kgd/uRHBAlGpmvt11nrREtFCaeHT5PgTOq9mvWJTpSgVmLFLEeC
+skjDq9aO1FlAF76NRcJ7ogLyhVO70Tmt/gOVrebQt/7H04ORnSincNetIMv
TGHXXb65Bz6dyHPurrBEpClMiH4tgyd2oqnYjG1aqqZQjfr1Yk1jBwrZyHZO
umsC6b/DK6STOpAWRfgBh70JrPspvJ7u1oGQnzWnn5wJ1J8+Fx7M1oE0PnUY
uOUYQ6vuT4nHTNvRuRSN8Qtsp2HB2F8WdKAdXW/425WbbARxC/whxPmPqJ45
0VlS1Ajmbrdz0ov6iHhbx/NjN6/fJY1pGTPUho5mT6TvMNSHd579eX/hcCvK
4TZWTCGfgGNlfBorvz8g2pBXjkePLpSvUy+62vAB1evdnrIk68KB4RsJ1+0+
IJUdYYG/yTpQnJvZ8U5CC7IceX2YwQbCmuC968/w71GDx0+2J4c1IXeMms+R
jmbkXnqszk9bA7om2Y4XpjWjvytF3Lr26pC9NKu5XKUZlV+zKnd8fAxaTh+K
r/duQrwSjhzPScrwxYr+dj31JnT5k8mOpCglSMd7B35gbkLSD3oczWsV4VOB
Evuux41oxuem/D1NBbhkeuzo2EADitkv3hLsJgt17WyyHJ81oE92tG+Hg2Rg
slcIz1e/BvTKRDey4ag01Ip6tzq/swEZPAEP7QqOwIfxX7wujNSjsVs/+zwD
JOHX7G2U5fx69DlzWmjN8DC88/ZU05puPfJgHfoTt1MCjrV4HrvOU48+cQ5x
xNPEoHz/3QL8eB3i3HPhwsayKPz8s+shc3Adupxgum1yVRiKSVjb7S59hxwv
N6iPdxyAhXlXZJZvvkPLzrMZBP39UFnqwUYH+R1ieuI2VNG1D56Qe595+1ct
eoo/asbLwgfbX33xdW2qRcqGglZmlXughfKGlnZSLeLuqOK08tsN3dSVKVTV
WlQpbMBUw8ULfyDT4gGWWpTsE3/72RI3XAodxHmX16Au8Z0pdmNckPe/k4Dy
F0PebSYzFyp2QrH7N8ZTUjEUq46hpz07oHJCRRhZA0OJ5UW19kzs0DJTtK7p
BkK+bFVcqvnM0P2JjWOoEELPAkb7Vfi3w8C8hwS1+rco3bvFMCJ9G0x7hdN+
yfQWrb6r4WgcIsCXlSpfXJ9XozdyZ/bFJ+AhhnxuCepXo7mKU0Me9rjN94/h
+ri7VSjLyXa624gKfrbxOBvJVKFrlNrTY3ANELr1Gbd3vUEnlab8r5j9BTz9
YU9qL71BAg7LoQHhv4HocKVOIO8blOPOotnevgKUxr9PKlRUIibTUw/sFJbB
ia/iEQsWlejgotzw3pKf4PyP+Eb7R6/RN/efL+5PL4CAX60u/Jqvka/m0RQL
7zkQvUZg6h2tQFdKBz6J7p8FKRvHcu+GVqBzRvEM9JWvIJ/x4gk94QrkbY8P
XF6aBNUsz7/iGsrRjHd6u+CuL6CNYyyyyqUc1Wrt0H5pNQ4W9xo1H80rQ3mP
GN8GRgyDjf3h56f1y5Bmquf71OYBwClSvT17/hVqHE/8+ILYD4QOLT2zvvcK
9fnsfB200Avkjx4+ySv7Cu2x3ha0/KEbaMvbz3zsKkUVf7p993zqBGdUkqKj
Lpcikpj+vp1724GLRvshsKsU5XOdOrbR8wH4g20taxUlaIKZO6twsBlEndBw
L7MsQbr9HOmMEo0g2eAyi89aMYrPkzcVLKsDeSb5eRJpxWhf1alAy5BaUGU2
fmpcsxjduG2p6E99CxLLZXuVaopQowrPGp/LG/C6JoM3j1CEUg+JEh9KVYDP
LexmAicK0Xf2wmUtg1dgrScwIfb2S6TcEGuw8KYYCIzO9BE+FqD+4O1dSV8K
wPEZ893+nAUoJrPv5tTn58B+qcF8lvwCNXfXodd6T0EYVT7JNikfxbzK664X
zQE5TNn9HYN56P6j2wq/P2SABs6de7UP5CGTOd8BVlwq+MofYlnh8Bwlr/i/
8v+UAJjF5pIPP32GLBpeHSVqPgRtfX/emMznovpuaQNt13vgfiTj0FWFXDTB
KPlxj/TtzX5yUTMCnyI31102s5XhgG9m//6md09QVGquY9X3UDCaLHl8gfkJ
sr3DW7E7KAjknFKx4zV5jAKClPfdOuAPXNe0Q9WTctD7eR2zfc8uAskXJtmO
o9lInZWH7dScJ1i0OVt3WywbcZUI/T407AJK2T2+FHtloUMO+vFo0R4sBC4w
F5/PRFlnuf4wL1gB/2EmA/qvdOQkK6Znk0wGG5qCdw3D0xC3ZazAF0UjEJ15
rCOV+xF69LdHmuSjCzjxZK7ZrBTUpTqlRJ89DlIcvcgqMsmo/pfNc/cxJSDc
EJEQgRLR5RBOh0x9aZAvltnfY5CAOmt/pV8MEAXyUZV8woNx6JCF5auuGX5Q
PdNlc8HtIbqQsLPvihAX0NGfS8d+30dd+45YLzFsA8kWLLV8rLFIbp+UvuPL
v8R8fg2dCvE7SPKsdbBy6ByxesTnPUn7NmouDG9SqxsmtmVlG363i0S1Ej28
tS2txBGn3s7/gm+hnznn6yt1K4mL4tvNDqWEIiPolF53N4e40XO59LZnECpI
zojwTogiClkPVNU9uYKINoFS9T2uxKjakMg/1b7o4zXA4GSrQWxrO5nkLu2M
svVhshkTXSvi+rLcD3VLNJm8f5bnZoXW/wDv+Vgm
      "]], LineBox[CompressedData["
1:eJwlWHk0FO77RQpRWT8SImtKtmyVJ/O+2XczREgSSgnRIqlERCmUVEplC9mX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      "]], LineBox[CompressedData["
1:eJxTTMoPSmViYGBwBGIQPTct/B7jrEe2DFBQ9E5z76O5CH5ZwXrrylUIfuUn
k1382xH8hm/2220uIPh9/0I3TmN6DOdParitr8uP4E9lSlx3WBrBn8OWs/qD
CYK/iq9pqVc6gn9Mbt3Mf6cR/Brnrwf2XUfwjTJsXtQ9RvDnbTxl9v8Xgl/u
8vzyf80ncL5GlgIfYweC3711UhOzy1M4P8CnPJtjzzME//7RXU5zX8L50Z6X
Fa32voHzhRI8d85e/h7Of6lmbxKb8RHOl//Cu0Tx0Sc4X6BkflBdyBc4vz1e
oNfy2Vc4P2Th1vuasd/h/GV+VvsqPv+A89Vy1kdt+YngL+tU+f7+P4K//Aif
QTrPTzh/hdXjhaGqCP5KtZ5Wo3AEf82/uz5vdiH4OjLBL9UPIslbnmhNPo7g
ry3ZtO/WZQR/3as2g5NvEPwN1/RFlsn9gvM3r2u8Hd+E4PfMDfcx6EDw03p0
9zL0IfhSWTfnLZyJ4DeoGiY93oDg+8x58CLtPoKv1r0t0vwpgv+/sucU+2sE
f1O4xZoV3xB8CeEJ+a94f8P5Tzrtv+XaIPj7KkTT7ZwQ/Onpr6/zeSD4Xq7T
d64PRvA3MLyv+ZiF4He9P/L2YAGCn3xvVtykMgRfbI+bg3ETgl9bPo+5dCaC
H5ZWUuI6H8E3CPV6KroUyb1G345t24DkXsUz5u3bkNwrsGhF+B4k977z7fpx
HMFXuav8+8RZBD9XLfDusXMIPgCd2Bca
      "]], LineBox[CompressedData["
1:eJwVl3dcz98Xx9/vd5OWkoZKGmiQtpJ7+9xbSkPjU5IIadAiURJKVuqbVEZE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      "]]}, {}}, {{}, {}, {}}},
  AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
  Axes->True,
  AxesLabel->{None, None},
  AxesOrigin->{0, 0},
  AxesStyle->Directive[20, 
    Thickness[0.005], 
    RGBColor[0, 0, 1]],
  Epilog->{
    PointSize[0.01], 
    RGBColor[1, 0, 0], 
    PointBox[{{6.75*^-11, 0}, {4.725*^-10, 0}}]},
  ImageSize->700,
  LabelStyle->(FontFamily -> "Helvetica"),
  Method->{},
  PlotRange->{All, All},
  PlotRangeClipping->True,
  PlotRangePadding->{Automatic, Automatic}]], "Output",
 CellChangeTimes->{
  3.577683297312971*^9},ImageCache->GraphicsData["CompressedBitmap", "\<\
eJzdXQe4FtXRvt5+4dKlidI0doxd7DX2mJiosSQqMbbYEWOLscTEFntJLDEG
G6KiIkXpiF1AqqhIV+lFinTOf9/dd989s7vfd5uJ/nkeQe7e2dk5s+fMmfKe
2Z9263HBuZd063HhOd06HtW92+UXXHjOlR2PvKx71aWizQoKCnctKNjs/I4F
+LcrKIj+clX/hX/tjr9wudYXfhL8r2gzt8kVbAp/U1ASXivetD78GX9OrSFd
v++Y3xmhmF3DXx28bIRb3azc7XjN5Kqfwms3fnqT21S+mTvg6FHRteJit971
e/o4d/pZz7qCtc4Vh6SHLh7m3j9wH9dg/CpXUBZe+8vk69zS8qau+aDFkQSl
h88f4t47vatb3bTczW/Yyt1/1KWucuIK6qzouIX9nGtSEOqzJPi7dEzl7q54
Vii4L9F/VqB7fmgC7fODeE9HVTtpzpz9bzf4mCPcztdMrBIjFGaHVZ+4GSd0
dKee9XwgTGF4+eAlI9zsrlu5Q64d7go2OJclT8ihfNeVH7sVu1a6l9v/wh3x
wmB37uuPuSX7NXOvtv6ZK/lyndstvHWXVePd2s6l7slO3aqG0uOuu6qG8pv7
e7rC5RuD1+UL91+T7e4fsGx7/9Be5JHhBNsj5NBp1XR3yMjh7pDhVYwLg79L
Lut3n1vbqNSdffq/3AHDR7niJVVLsSLkvuOqyW7m8R3cKd1eCOQ7aMlIN3vf
rdzB140IBCvPEIwLpshtcENePNxNL+/kGr2/nEMrOu3r59zq5uVu94vGuIJw
lhU3dCvdtMs6u2HND3XlU1cH9uE///C7v8+H7/aDfB92soBLwDG21UVLC8gV
FKFQpTutnORmHtfB3XD6LW7Wvu3dQdePDISpyC1M802L3aKjWrj7O13qClZp
3rfcuMAtPbipu3Obq1zBt45WqOSwxUPdyp0bujfaHuU69JsZbsON/9MPv/v7
fPiuP5RXEHpdBT8KGZW71W7SdTu5NWVlVU8N/i6aX9bKNRuyJJSHs+qX815y
y9o0cftd/07VtaZLl1ZJf9ysfm5N0zLX9fL3XJOly9xm66scqobhU8/68im3
oVmRu77Lra5gtXMNcsu93ZpP3bc7VLgT9+3jCjZK7gr3rfviyq3dW00OdJst
3OQ611Dg0IyW7L/4bffpydu5VcUN3F1H93DNRi+J3vJ/QLh7vo+H7vpDeTU/
8a1MORyrZ145w01o2sVVfrQieCv+9lkZzvADlo5ys/fbyp172WNuxrEd3Ynn
Vz1jXb4ZXrTrqo/d2g6l7sCj3pKIpW6tm/C3Lm505R6uePZ6FwpRWr5ptbtq
4J1u6a5N3aKSFu7n3V8J7GvD/+jD7/0+H77rD0H9nAp7Bv8ra7Zxifvi91u7
B7a5xBUu3Wjk4HQs33fZu272gVu5w68aEli4LisnuJnHdpBAuXfAUKCOGQLd
3cV9VLmnK56z3u0VrsyW6xe4/nce674trXBdu78XGv2K/4oE93/vEuz2g3kb
nB7hSynde/kHbtlOTdzxZ77uDl4UCxNapOK9v/nAzT5oK3dk9zcDWWh9dlkx
3s06qr1EyvKlE/brl/u+lGW/RjY9KLBf4ZIoLnQb3bsv7evO2PsZ73mle3wz
2o079cfu24YVbkyb3d0uD48PXl6b8Lklbp3rPHuaazRnuZ4LTX/563ZuWLND
XeG8jdTaD31APf7XBrTF/8I06xIumTAOLblm4m3u6+Zt3ekPPxuv3dCKBBmN
Xs//yh3dfaArWK+Mxm4rxrohPzvcNZi4KvKOSlutm++uePQehyB7aI/D3NLi
cESeK7n4J83dwx1/77uSrTfOc8sObOL+ts2VgSsZDqgyOSBcrXQr3OcX/8id
f9Q/XPHK9e7icQ+6KVts7xqOXcmFU7zl+jluxZ6VrsfOd/mhMsKa93vt46aU
b+/Kp6ym3v/fDC54T0VIke7/vzzMdv8709EusDK3xg17+NAgp7emqCwcUThj
Szusmen6XvBTt3D7zZ3brMBFgZsXkA9/4RA3q6y9azp8aRSQnzvzMbemSZnb
87yPXEGj3DLusWK0m9aps5y2Rm65m3FmR7fb+WOjJYPUxowLO7qPGu3pSr9Y
K0VsmOfmndjaDWrxE1e4YKNr9X2LG+zvxd4i+P8ieLsf8iTgRA3z3MXt1n3p
5v28tVtTEMoXbnbFiD1e7HmSW1oSisWs4u4rxriVuzR0w1se4s544Bl33ZN/
cSt2qnQDNj/GlcxeF4m55bo5rv9vj3VDDj+86qfw78GHH+F26THeTwc0yhL9
jK+ecR+03dsVfbUh+Bnrf/Q/93And+0d7IpUYMWFMx5x65sXu9c7Hu9Offh5
d86LT7gJp3dxK4or3W7Xjw0d4zY/+NHsqTl+wP/UuNr9f51eO4fLg5WXny7o
65Zv2ShcuuGYiuCnzd2hjanjHDZ/qBt15gHu2+YVbl5la3f/0Ze6RuOXu8a5
JbloxkNuVNsDAp8OP4PmnT77uXN3fyzY6PiSy3H9rPFPuTEn7B6s/RWllW7w
Tke4/R98O6Db4r8r1Z7yTA78Qcq35ff/4jiFuuefhR+23cvOwif2kOtfcEo9
7o3f0PXfkwRUwOXB/xqjQn7V+Dvdo+ef5+b9pLXdqFaOdtM7hZUH/NzELXMz
T+vgdr3gY3dy/W7fS2q49nuVg/vtFaE+d1s81v3hmTvcNz9unHYtL/2R+8NB
d7imXy91Nwy/xX3aejvX8OOVehd1ujdWw3XfkwRUwJXhIrzpkxvdGQfxVgat
CJLf77aPW1NZ5t7fch+38z8mBvvcqbW/JR7uH/8rz+PgAi201rODH9tk/qp9
uANu46ZOvcv16HGnu+qqTm769LezL5M9UwQhbMaFf+8Z/LN0++0LpmzcWFAY
PKrqz4YNBUWdOhVMfyv/r3fErwur4170wAMFl0S3hkwKiu66q6CHiEfUkG77
7/F5ZVJ+mJ4sarB69frB3S/vd/C4j7/2fttK/2Ix4+6HH3q339V/GBB6Zvpt
y4w7sv4V04XF46I/P/H4R3947tlx4bvOuCOMPYsOGzPmq1GX/P610vXrNxaU
6rfMHZWvXbv+3d9f8Mp+EyfOK6jUbxkE7+gmT97kNtss0s5GV1iIWRUTEqT0
+jVXD3zg/vveCa1bPQZHZVUpauBD9937dkJZpfnFapAc3Tn9+3065TdnvFC0
ceOmMJ3s/bYgDO2K2s+bt+KDC857pRBEO4XXtlywYOX7F5z/SvGGDRsLYrZn
61/bhXT4/Zhzz3l5i4ULV0X3gs+H55/bZ6v581d4E4Jp6q2/+vKbty/6/Wub
bara8FuELw/jedBdfPED7pJLtndTpmweCzb6vN+9HLy57TKEoLJKqn4PIVov
WfJtNSwh70fnndsHrDn+gtbhrx6sUvfx774zK/hpx/DaPQ89+O7PR701I/gp
Sw3bh3S/Gjr0i7seefg9/94T3xo542+PPBRei9XAYs7D994z6pj335vt33H/
A/e/87O3R4VPyxovV9wZgwZNvfWJxz/07zUS2IFtO3v2Msyn4KcdNO03jP/t
2S8G7/fRWDczTzn5ucpVq9ZHbAf84aoBP5ozZ1n2IHacMWPJa9dd84bPuWLN
mvUfn/Pbl4LZ9Gj8gvA0/D/iPOSKy/sFb8ETmOn7qvX46ubLlq0OfqKGoZe/
PvboB8FPj4XXnrv5pqG/HDF8mk/XqmoODL/s0teDn8qTMwWcmy1fvsa/4+Th
w6ZJm+R874MPvHvkhx/O8enaLlq0SpxbG4Gvev65cWcNHPiZT/7UbX8Zvs8n
k+f7bPedNGne43feMdKn+23VEr2yV6/x2QJf8+wzH/960Juf+3c8c+stQ3f/
7LOFPucDx4+f+8g9d4/y6S547dXJl7704sQMgbtMm7b4hZv+NDieaQVFWJB6
cY/HS3lCt7Ne9Nm++KcbBm8/a9bSWOBib0qA89O3/nmYzxlcwDn4iZxhkTAl
fM6vXH/dmzAPGQJDuE/O/HXvKlZii0c9d8vNQ4OfngivvXzD9YMw34Ofto3v
1SAqkgLjtxKEnHed+vkiDYKcX73u2li4beOB6V56KG3DX006+ze9u06aNN8n
P/+11z65qE+fST7by1/sPQFTwKc77t13Z437bbekwJwSb1zVY8DO06Yt8e8A
V3D3OWNSnfkGJyXpfvzF1EWYPhkCd3+h1/jfvPnG5z75v2776/A9Pvt0oc92
z0+nLHjizttH+nS/6/f6FM20eLeiuYImr33m6bH+Hc/ffNOQnadPX+xz3vuT
T+Y/+re73vLpfv9Kn8nn9eXArMDYsR+67563ffL5Pz+hZ2DSPLb4GdubT4cB
dJ3Mt5MSeP+JE+Y+GG2+vGPq6af2ClaGxxlGdPS5v3vZp/vnHbeP0OK0AsMy
vnfhBaEgxPo0WrVq3fsXnh9eezK8Bhqw9ukwADha2QJXfvvtulEXX/Saf0fj
lSvXTT3j1F4+55mnnPRs41Wr1vp0eFrZunUbfIGZZcDU1pi3iU0Y9i6f7WN3
3TlS02SbeH1jTw5+indO+mSyM94dB40b97VMGDm/du01A/ea8skCnw5qnHPS
L58JfmprBIZp2uZLrlGSY/Zc+Oork322WC7n9Os3xafbbvaspZiV2QJj9Xf+
6ivD+ZKXX5qoRfdkvIrOHjjgM59u16lTF8IuZQh8yz+f+Ah+gk+OmRf40h5b
+LDwRXw67FvYHrIFhnd83HvvzvLvwHvTlkTOP/noozl3/v2R95Ocr444W4FP
HTrki+ue7jnWJ3+jx5X9Wy5dutpn227hgpX9r75qoE93fc9/jz3h7bdnZgsM
p0buPO8YdvmlrzddsWJtkrN8DtJh+5bjZAXGJgEz5pPLZOPPv8JrY3/325d1
bevYcMHFiQUu9hYdZjw2+eo4y/Z4nLH3YsJlCIyVD//YJ29YtfLhjQc/PRVe
A42sxNbxo7SWUwLDSrx1yUWGM7Srp5EzfPeiaHGSTrGAJzATgXCnNT4iAmHa
e/7l1mE+22f/fPNQmXyyrdrlXtK9scCVsSBJzrCt0jo5Y3F1+vrr5T5nc68V
GE4c7K7PFk4+5qfPFrNK85V0Lb75ZjXme/BTHFA1ijlDy/4dJ1U5qFqm5IwF
d9SHH8xJcoa3Hfy0hREYLiN2bp8chgaL0WcLF/SyF7kNkw7r/R93c1NNCfzk
7beNwArx7+jR6/nxpwwbNs3nDDOHrTjJWfuvFRgW4hcjR073yREdY/Pw2R4w
Yfzc+x68/x2f7vTBg6dKXymBb/j3U2N++o59JxACvoPP+YjRH30pg0m604YM
nnpF7xcmZAgMxwfj9sn7XnvNG0FY67HtMG/uChkf0kFYWMxsgbEZJN8JgjEZ
TI+zNonOsRoVfVqBsVnKRemcYWjIFmtWpo102Ab2mjJlQbbAh44d+1VSc1mc
YSEQTvl0xhGwAiPUwybqk8t3wp9/h9cmnn1mbEE7hdeQXAli+0yBsfJ738hY
JktgcjZ2ipwHXXlF/1YRZyswxieb2yleo0OvuCwMAXuG12BRq3yttT4dBib3
JiVw6bp1G+UH8g6EuwOrHHufs/HMSKc4xhOYRRpj8TqG13b54ovYDpMtdrUd
Zs5c6rM1djgQuNgT2PzW46wwgJxfuuGPg5QsIGezI1qBMXugC5/t0R+8P/v2
R//xgc/2L48/9iHWs09nPN7KpMBQhTTHO459771ZN/3rydE+Z4T5cK18OuyI
esftjMBYn1inPjlit4v7vDzJaLhK4/c9cP+7Ph2CUuyA2QLDpnScO3e5fwfC
93Nf7zvF54xoUekA0sFDkYdjBYbNDRKbHjksqFxOsv3lyBHT//TUv8b4dId8
PPYrJZTifGdYyiv6+91/G6UAqmP8npRAI2fsfjKspENi5bboHVuBq8LE2JZ2
jB8lc0W22Ehk/kiHWFfmPSUwhq0tiXdg95O5ImdsSTJ/3juWDbcCw7zjpfjk
eJlIFvlsYf6wPHw6uNjawlMC46FKFvAOeB5tFi82nBGVKJVDOrzLk6LEmBUY
/r6ykh1jQyNzRbZYPjLvHePlgu0hW2A4NIg6/DuMK+lxlhtKOmzhSGFlCLzT
jOlLtHA8tjIqT4fXFGziT4fwGuI5udkpgWHCEK77nM2WRM7aBTzOeJfKBlmB
sUkgcElqOMnWWEayheFpEm0mKYHhM8hF5B3Y4MU9jIntTkc6GEuZRAq8VYbm
2seDkJ/7TCyc3BayNWFTbNYaZwhCzojfsKEnOTeMshsdMu61ApvdnWyxo2E9
+2wxbTB9fLbmZaYENu+EnJHw0jQhZyw4pRmzVGEFNtET2R4+ZvSXsoJkC8Oj
BUY67JCK0BolBca70wLjHdjpkpxRWlBSgXSIgbSHbmkExguSoSE5HHOZOrJF
4luGhnQoHfX54/VvxgL7VTvjcfEOY0TJGcEYtiWfDqkd+chWYLx6pd1Ijs1A
CVCy7Taw/2cXv8ztOqvBQKv4pcObzR4EXCpNLD4N6VZEGP7TkGNShoh0CJuU
5bSDuOMff4/DwvbxNVUi7gj+LgPg6+r+t7sph2zv1laWugUNW7onD+3m2g76
2uU5Xp/zfDzPSQN58uGN+619ef/zxn+Hp+8L41mJdFe2Ru9++KH3kjMfUbK8
M2oUsZ88FdIh8yPPzmoUL0VJbZKbDO3twd8VGHrvXie71aXl7u6ju7uTe/Z2
Vzx1j5t5TAc3q7y9a/PSXB27NEfMw2vVHhCnhk8Z22/58p2afVvnk+gNq3sQ
qOSuNE5qOWu5YuUoyUUtI5qGxfDpwBUuaYaWzfolOWI9OUGhlot3XD3Zfbtt
hbtiz3tcwRoNv/26WW7JIc3cQx0vcgUrHUvqNTpLHWqlAjvx4KvPn5Lv1HZB
rY9tl5pHVV2B+lBnTekVClCOmQpA+kCG7pnYgKli1T5+JzJ0Vq/I32rJkBx7
fVBGjfVa1Hz9YnfQqJGuwYxVGhKgZu+90NVNrtjRlX22JlJqDQ8kh0zKox3i
Ozv5XJp8EGI97IQplSKQSC50bKPa7KhSeEvYU3w6hC0IXzJUipmNgCLJVvb/
nlh9OAoytWwbVzHp20h9NTx8S/RIFDfX+3RvafIBfa+9+o29p0yZn1Ibdhdl
1Dg+4y49G08jXfP2UCUGrNqwwFBc8dkaV5krHOfUjn27v9tl0Hj/3BYwxosP
a+76b36s22zRpgg0U5PDq6Eqy6ocs5dyHY8tqN352NLkI1B/227WrGWBMku8
qBzLVaEHR208xGczFEyNIQhUzsoqE6tKGQZeg5enqCbc5itwQGPm+R3cysKG
7oZTbnGH9xviuvV9MjjNvry4kety8wQXAppqdtCTuPDPf3P85O/uOGlp8imY
WSjRpbQJ3MWbPbr394cNQi2/53JrE0zlQFObfCEmFmQIBtdVgRK1iS3+o3/t
GWznw089xK1tVurWbVbihv/oENf1offCPaLUrsJqDg9SzzisuLpdo2UnX9Rn
zXd5WLFB8nkRhqKWpxUL9SYaZyx+qsyEZXwTmKQqOm+V897oTZiIjWxhT1Su
uTP4u6TX+79ynzTcwZV9uiYYSuH6jTqgVsNjZbwcHWd7a9/TR247ffay7/o4
W/Pkc6Mh1vY8W6HsdNOMPYe6Qj5CiTy+AiS2lRjcKue9mVsZ2SKjBffaewVF
l0+71y2s3Dw4DRX1oKjJKSkabpTplVcMd7O6ncFq7nMHEida/LU9h5VScJZZ
QIAhTVDBcAYQ7Pl0JqeylVHw4O5X9FPtkOTIpv6x57/H+Ao+eOkIt3rzcnfr
SddX/RT0zSrqftfdrvXAeaFIoaWp9pAOFQ4vUAVunlnOPvbTtjqOfmanTmd6
AoE8TaPoCTvuqwQOLXK5vqaRG0R636fDDql6mtV0r5tvHKIMG8kRTysGoaa3
Xz3Frd6+3IV9e8K/1xcUuz3OHh3KGtrdnGdTuIEiYBIOiztWxhGXNrnY4Leo
fUT+Qp3OuiTmsKk3UAWoCABu5WsWtWDBD7MMr9UsHLkjP2CageQoYqroS7ZA
ZCh3H9I1Q84/KvrW6TRLcvaghpRcf5g5ytVTmG4D+n+qGJN0KIIiJ50xRkRZ
Z71hVYK0t+pIZIvUisCfIV0T5Bj+/MRjY+pyPqUgZYh63/SnwcmXA0kUoFAS
FHpvfvKfHyUti4IgO0BkNlQJInm/a/4w8JCxli10qyo9B4hw9YreL0ys0wGU
1ACRodLKoSQmqfBc/LYEkfcWNGBUGQMES/1qy9jU7DR9mmELG6H6R0hXhgWh
zF/Vn9qcQQl+XeyFVACQKYlHQUx2g4JgvAruSYfgXm/Jjg/vW++W5HC4hB8h
W9hr7Do+HWasUBCNkwKjgCbjyzuQQZaRJmd4yXLISYcanmDpVmDUZ7TaSG5i
QLKNjgT4dJiBQFVmC4wEgDBovGPpccf8K8nZBEmkw/4tTJsV2JhAkguGjD/P
h9dM/aNdbD80geMom1N+t88/X6jsMDmb9D85m8I5OWNfE0bRCozdUBiJLTNY
PJ+hdbIFeEAzMiUwdhHF7+Rs3PXnM9RDznAWmn/zzZoMgYE/G3HpJX198uiE
RfBTiD4NnLHgvIdHF8WJ2QLDx9Ks5x2mcNgrtyrgQ+ppFLhD/CuRE3AH6IUe
RbZYFjon0C7jTcQCNwt/azzvLeIFppiKnA1ErF3GIKzAxo0lW8weAV56xbNK
+NQ6C4wZL3g4OaOUg5KOz9msGCuwmVVka4opZAtMmrLwNRLYRJ7kjCBEOABy
HnHZJX0PHTv6K5+zWZxWYFObI1sYJGxrPltkKlWNIB1qliMvvTic/01qomHY
Vu3y5FylmrfwRJ+u7cKFK7/6xYlhqbi9ERjrUadjSA5/W6A5ssXP8qJIBzyb
/O1A4GJv0ZngxgP8yu8iZ2ApBIwkncF3WYExNwULIrmpjJEtPHs5EqTDQRPZ
8JTAMGnBKTPvDnCFs+hzxtkE+WCkM9G2FRjlOSFOSA5/Sw4y2aLcB1fDp8Ne
pNJJSmAgOfFg/46r/fdEznBepHXSmf3XCoy5CmCHT45wS4XDXvHsE0SDdCg4
qsiQmsNIpcNx8++IcvY+Z1ODI11GrS4SGO6JtElyrGNpvVfG+iYd7tOBqZTA
BmS+RWxrhPMhZxTDlSgnHTw1uZxWYFR3dA6F5ADSCQRAtrCgOjlEOtwnIFdK
YMBqk3MTuBX5COSMerPmK+kAPEuUNyOBMTcFpye5wVGSrcn7kQ5eq95OSmCE
hcm5Ce9D0JBesa0RDoB0SJPo7ViBMTeF/CO5wbiTLWyu8BCkg9eqwnlKYMxD
zXDegc1E2ENyxraMU4k+nYnUrMDAoKmURHKzz7wQXjO7Go8CwR8WfC4lMBac
bEgezmaDIWfE03BPMwSGP6xyBtkah49sze5OtvAKVBtKmTWcl5OVzsPZuF/k
bJBUVmD4syij+myNNsnW+E9t47mOuZ0tMFyl5NzMEjjjFEFwcFX7rxUY/qyO
iJI8Og0d/NQ7tx5QZ5VjmBLYII95B/xhTQFyNu5X23gQmusUuGOGIDxqiYqq
/GGyxaPlGbTNeBOpOYw6rd4L74DtUcDZO2OJZ3G2ApsXQoHheii4IVs4OfJa
22a84Fjg5hkPJWd4LUnOqCvJiLbNWJxWYDM3yRanYIRV6x0vMJ2OqbPA2OWE
VSNnuF+Js0ZZwLxIYLP6yRahuwwS2aIGoJC+bca9NRIYKXk5NeSMUEHnOdrE
q0gBQAcjMEJCzU2SAzmBTcFnC0icUhukw31asE2TAr9z0YWvCpbIO+DoyIEn
Z2wScohIBxi5AP1WYBz/0NwkOcB1OnJHtnCSADfx6WDS5GanBDZJAN4B/0BO
KjkbDLi3ipRHswJj01AyhORw1gV5IVvAleXokA4O/L//yq0hJTDCWLlQvANO
jTLc5IzsvJwkbxXpBIIV2CSFSA5nCFr22UI3ciVJh5mnNGUgcLFn1ky6mnfA
5RRonZyRYtWxANLBmRW03AqM7JdS0yRHkk9w+t4Zs490cPzl1KcExgMVtraJ
n6bQgJwRgehgJ+lQrZFTbwWGI5ecQdCaYgWyNQdXSYdgVXWFlMB4oEpdvAMO
vN4nOWPByV8kHZxWzXUrMEJApYRJDpcFrovPFi9XLRpIh6BUzn9qDhuMYZt4
xahHAjkjttH5ZtJhnmvFWIExg4T/JzlcFmV5Qq+1OPpkFpYRTD1r4AbUSkkB
iNUSSI0DciQfCC9KBoXjMCdZ2sScZarsOExqguTGhbovvJaBdqwDiLXE/4RU
268XrQoOIRO+Ulck6/s7HzHjl88OndUsqTIMOTk2QP8FmqDKkAiUI0u6G6vm
ubYjqzKs6NsSU9s4cXlUVg90avSdpLN+3XP9qAsveq3W6NTMB63u3GDj2y0O
WYIHpeYcFJAcqfFJqUA41ko0kw6VfDkgVoHmaCrJjTOVpUD2T68J7DScJ/pQ
0IxtDx3w3XwoaNgfT1u6tknZhuApKW0ByaHeC9680LBezNAgmwDBpumkr9UW
4jpt0bXUVg3xpFxYwJGu3apyef2/oNPnpqvGfdO18aboASln0/Sh4aBMvJxH
V3CDVHe3ujKHG2qpqxqCR4lBm3H6wQvq90mYgVd3HzXz9x3FOKUjjFHOZC11
hDBIFRKro8Z+AEnyQr8dyP05dVQjSCgnE+Cga1s3XFLPr6W8ffEFQybdtpO4
B1oq8UJv1L4UenvDkabCl2/rE6RDdCu0NrXUKUPRPHWC0Ftmrjot1QztGX08
ZNJuJwwsWbN+Yz0/HjLunLMH+k9JaQt7lOZL63hYmhDUFmIrnTkkXca5tUhb
OoroaQsRi/qa5dZW7dCcDfxPTwzs0WNAVPqs/7cnxp579mD/gbychNEUZV+O
UZzNMsyOpxJ00fI1bWqZ1LRJWFSvaQR/cvlChHxOQKW3MdQYyFma/C5BZIG5
LX533ycYd+6v388AktbmHQQWtEXud4BEvc7c8x0AySUYZ+uMe+07MJs62Zru
WHwHHdZkYy49V6Y6RCensXEPyvNzz99Vf+bpBy4S9xx6rKl6TbcD6sE0oKJ6
4b2orFY39SKc1LnocBNPISz5ZajqEJZUKcJe+acNsjnmaNV+/T9vdRual2yM
ONZTjVmz1BzCpxrhMsPH9OmQ/4KtDn7qaNSIyrcQHCQ3dUDaZAOjJFo4F4yS
2xHyGQqOGmawyWg4XhWpbZrdcdfxYFNcP4XBBiqG48hwbk4JEioMChSklXQm
yW0VZvq+kBw1RyVDyNaAMUkHx1OWvZ7Dg3g6mkb+KJmr9unJoeOCpEP6QWdw
7fCAmVIbJpKbuinZouKpBB/pkCyR0eQXB/L1CM/5u9RgIaxyJnwakkHq0kap
kPpQipF0sCmKjOxgjcFsFetLR4DJ1nSlIB0yQTJh4UsrycRiFlb3u2LPmzdG
kE9CalJv0JNIeR7SYdUr6WkHiux80iggta7mcmSLbOCN0conHbL7MjKEshss
ZnHGtdTAoKqkBGbleRIoG0M60Ajfawdm8OgkB9ZAfSheytgZSIcatiCWzZIC
m0oD70DmT4MgZ2R8VaUgHdJlqttbgU2jKZKj2KPWYGRrPAXSoWivDp1xHotr
BHYtyRmrUROcnFGyVh2IdFgzKgRYgXFZUJxWsZHQciRb0+LDMxwCA6UExlCS
nM1CJ2cMQDWCVvFChzoyBEYaV0aQ5MZoky3cbIEmSIfqjVKgKYENmpl3GDPs
cUYWN2lWlBG3AmPKax6SHAGktmWyRTVKdS7SYVloEacExv6j7Y53wA/QtkjO
CI8UhHnmQfUwK7BxO0hu3DGyRdCs66QDXEdLKCWwSSXyDlNxJGeDIiUd5nSi
m1EksOkyS3ITuodxlPWxWsaLU1iMlMAmm9cqgws5m+yLx1nVYiswprywGGRr
UhN5BEbYJaReSmCzG2a9u5cz1EPOmNPq9m0FRpyn1kitMsZMtiYYaBkvTtUn
UnbY+Cp5VGGueZwVNVuBUblQbxyyNWV+sjVBNtnCZxbKIyVwK993zDPZTIxO
zsCPJLqpRQKblqIkh1+vZdAnZqseQS0z3kRK4AZ+dMA7kP6TremTe0oYzhS4
c4bm2LkffrUMDdlCV4Kmt8zQTTyHN8+wCLyGmnqSszmJ0TJjEFbgLLaYfTLl
ZIvZqGVQI4HNeXNeg7OskybkDMCLOvZUL3CWhk0/LLLFepehyWKbEtjYFV4D
LEXbMDljwxfuK0sV1QtsvFayha1WqbjOAsMHFDqUnAEqkH9NzsZyWIExvZX6
JVuzR5HtE3fcPvKk4cOn+3RYVsoDN08KDJub5GwAL+QMp1X7JelM74FORmBc
lsUjuekxTbbwkat8r898OphELaGUwBiKuprxmimdkjNAmvLISWcwgFZgXNZi
IrkJY8kWzqLK3qTDpqMllBIYQ8nirBa45IwBqHcL6fxDoAmBTQdkkgMkIj+X
bAGOV9BMOuPJBgIXe1szAMPCG3icFdCSM7xqoSBIBw9F4YIV2HR53Dwes7oW
ki1+VpBLOuTptDhTAiN81vEPj7O0Sc4QVtGFtziFGbMCmyOeJMdXQ+Tn9omX
i9o9k840ZEsJjGxecjGBs+YrOSPaFpAra3FagTHldZKP5DA86tVGtvhZwpHO
BKGpOYwsHHpuJTlrEH1imyR09Obx+9TitALjcnIxAbAn5D7ZAkcj75Z0uE99
NFMCA3WuIHTzeJrI5pKz6WdAOtOF1QpsMlCbxwtRgDayNacFSQeQmzJVKYHB
WVkkj7OCUHIGxEgtuL3FqS8QWIEx5aWlLINEtvhZx8BIB/CT3k5KYOQapSWP
s+Cs5GwQPt7iVG7LCmyCUJIDBaPNhGwRhGqTIB2QiFqcKYENdojX4FoKlEnO
8OC0SZDO5KiswAZfQ3L4CPJ9yRbutBokkg6QMzWqSwmMxaSvFHnbdfAvjzN2
Qx012Dy2MILPWYFhS5V3yXJbQifEutQ0XEg8ySFKCWxcKF6TQ+8JbPC3pMOc
VnhrBTa7VZbr/Uqs9aTAxuVM2WEsJjmp5Gy8sFcytN4iXpw6VmMFRnFOX//I
cr3JVmGUxxbBqxZnSmBArxUGkLMpdJOzcXB5r+kkbAU24VAtpwRgwjhQkC0w
DtQlORtgdx6B0YmtiW2GHgmMsFBnJUlueqwTbBLhGYOfWJ71BwFgI6NPrE1l
ulJTu0nGA7HCtaJfzXgZLTJeM8fBD0uYSL95/Ch51Q+G16rFM4Zjy9/M0+vM
GYEa476RJVHIX1tc48bSoo0+dDIVEpkz3FSJ6Qj8ajy51JCvRcaEs6ozs4iq
MydSc6uukcE1urCxSLUdO8N7G0TAxqjtJq72v/qqN46bM3BDHZCNnx9+zFtJ
CGWM1WuZsTo4VhgJgceoQmyUWjHVq9AscS/Npe06S4WEA9Sw/SZHHIEbo36a
w68+a/pXe26xoXpwY0US3BhNJYOhTGnM7A8eik8H0qkxc3yCGjP7iNWYSRt6
bOWR5dZYLRprlvotMle2b/rNby7uvSw/tLFBEtoYqSkJnmxSE03BRRC6nJrC
pNDJH2rKbO5WU1lTFv6BYq0sTTWOteL3yySIMep8+UHbY0bvMeHThblBjA2S
IMZokEl4ZEobWWLj2IE+XkBtmJCz+pWGKaUsC9mieiH3Ls9Kq1UbzFK/r+Wy
nVt8e/1J987PD2Rs4AMZ4QxHe1oSKhnD8zhgzDF1O+Co4CWrcktlIVJUIZR0
2Gq1oXY2yjJ960mOBjdy3nMrq2ZtLom4jtCMUe/Khx67dc78/dqsqx7N2MBH
MyLPHh3OSuImUyrDkJNjQ4As1AZVZvIMpDPVMasyk70iOUI3Za/yqKxGvSy5
+fl4xgg9gSMrPfo/sahmeMYGPp6x41dzl0fVmiSCsq6AxhaxYVc3B2oEWTfl
f6joa/xKq7e1ysu2ijZncUgOlgrsQ7RXTkBhuAyzu1bSzCXhi/TPogRB7eGL
DXz4YpdJ0/QRnxyNMGuNBPLKctohqBtkCFQffzW+pno76UxDAqtypBMVGZIc
y0WpCaq8Qw6EIS2f6VLZOF4iSsOW5mfjuSMRUPHIJ9/VNmlwkHWF2FGROM6b
HLHJZ1KRJlFFOpMqs4o0WUeSo6WG7MwDoXzZSMXqu1CWZ5jq8myWCajiuGZ7
rHj9V92mJsGP9dSjgSA2zzCsr8YGWBKTDskTpXWsHoF1UDKU5KahD42twRhS
idU2mKQS4RzoHGZFBj8Ps/jJ0busX9ewdJMPfawrqI+aw8iTQ0TOSLs4NQdN
yofxPABk4jI0ZzCAJMcC0qf8yNZkZb3tDFldb63WeXgGyUb+8Oh0GJdyIFEu
h9U7pqdjvnZ4MCU6vElyg3wiW/ysZh8BXSGse/hK64tU5BBRQUnKYjLVlAX4
LkUvpDNfILBDNL8iOXZw4dHJFsVYhZHe2VbtBeFg64hU9Adqzo7zSYBTyR3y
lJ6UCC9MEtmBongg6BzJTbcGskVGTceeSGfOM9MVqgVS0StwJCWAayyMAiUw
zbK83UIS2IGZT9d5uS91PSBb8y0ED4uoGlWLpMAw/DcmOKMIr44c5IwBCJhC
OhSNEh8xjQSGMVD/NJKbzEWYXLPBKI+1mB0gJTCM7O2mSJfI01JgRG5K9JHO
1MOtwNi6FT2T3MSVFDiNJEhAMFsk5zoemORs4ndyNvlqcsZ9ie++RgIbvDTZ
mswk2abhOyEEUyivlMAG5ZVHFSZtSs5I1YizFdg0acmjhyyBERiol09KYNMO
Mc9kM1UCcjbNDa3AqFbpC9ZkaxKYeeZwOqnnC2zwRuRsslR5JhuiVnG2Apvc
NskR6kvAvrn1gGs2kesLjAcmOZsPcPbN0DrpQCPOFHibjPnaNH6UTFjfWJsW
M5eVtPcFNs2HeAcwvEnOEE61xGYZC9EKbF4IBTbnMvrG81WbTrOMJRQLnIX7
9Hq2apPoG79+gZGbZawYK7DBU5GtwaeQLcJAndzI0kNsh6lhY3PJ2WzXfeMF
JkejWcaKqX5KwALKgpItDJRctKz+oCmBja0hZ5RF5dSRMwaQ5GzeuxXYWASy
Na4w2ZpuSTnnsC9w1pQw32b2OAujU/2UwJRXApBs4R8ocCJbbN/CcJMOCUBh
RjdPzmGoQid6eQcCCx2/IGdsw6qge6eGZU22NgKbkiLJDS6AbE1Y7B3dtqVM
X2A8MMkZEIckZwR1Sc64T7uDFRjVLKWxSA63XgApskVCRIgK0pkmTCmB8UB9
kZx3AESihAI5G4iWx1n7rxUYU15NmEgO91z9WfvG14R3IR1iE4ua8QXGA1Vw
5x0G8EbOcOqVXiKd8XCswEgvqW8PyRGpKL1EtogTdNKJdKYLT0pgE/o1jbWp
90TOJqbymoKLsxXY4K5IjsMVQn6RLZowafaRDgHt7Qas4gtsjhXxDoN8IWcD
t/TslLx0KzASBDrBRPLb/HwJ2YJG69tb84opNk+aNfSeUqta3oF4XU02+8Zc
1OmKdIiDxNkKbJodkxzZD6Up+sZjVnrAW/MWsucLbPpR8Q7Tj4qckX2SNkmH
hIXiQSswQKn6MgDJgaPT7Osbzyr1zvbWvAVF+gJf7SP0msZLPMnZrATPTomz
FRjtoZJTHmzlN/SN1628gKbxYAVFTc1hY2t4B4yo0gHkjISzbSUX3quciRXY
ZJ9Ibjrgkq05zOWteZ3ATQlsznTyDmxTamnlcZY1Jx2mg/JYVmDTL5nkyB40
jvYoskVkog9Me4tTaz4lMDIjOszFOwBxke9LzsB4aL8k3Y0+jtQKDKStTBPJ
jRdGtohMdJ10VVHzyGPe97HevsAYym0JziZEImdTkiQdFqFMohUYHlhyyhvn
LtRpRuPN0Kn/adSOLyUwsqy2a2DC5Sdn41WTMyRSYdoKbA5zka3xkck23Ys1
7G6nlr0pgc2RjKYZw349niZJzliEqqhZgZFEVDBOtsbPfT1jEGQLb8Gi7n2B
zSHRPAIb3zeLsxUYycDklDdzOI/A8MeU2kvZ4Sy7YsKm1zPU4002LPMMgU0w
3jRjVuWZEibeTQlsvjTDO5AIVBTZL2PFeJx1+swKjE9xSHskR+ZS67ZfzEJo
viYZSyglsI98iO4A6FhQPHI2YXCTDJVR4B9lPJRlx1Y+3JJsEYzr9TfJmJHx
HG6d8fobx9MkydnAKZpkTEorcPq7GSGgVXsPjw0aaCUT2sGp6blfrsivdX8Q
Zr7yaaa1eL94DutEGjmb0L/6QRjzx24ixy3sF0KiUIgrCf4uHVO5uyueFTa8
9DGWNWoZmUJXUjODr+82c/xeu66uDlU5/bQjJ2Rxb5ZUnHmDHCHsvuDMVJw5
Q0DFGatW/XQ1aDAqbpdV493azqXuyU7dqmQPisGlv7m/pytcvjG410dY1q1x
ZMZnzVd0aLr8vPN7LqoBvHJji5INuR7UNKlLow8OGpu+jmpTl9ji5PhWr0uz
fMkWMY98kVCXxcAsTbussxvW/FBXPnW18z6hWcvekcnPlfc6+vKPDhg3fm41
vSOHvnCYW1PUaFqup6QUlrVq4dZpZFQYTvfp056kQzpVdnYbozBcln9KcvPp
7hCgUHLY4qFu5c4N3Rttj3Id+s0MzZD3zdca95Asy/oW+c1P/DPM0OTRWoCo
OaK5m9P4xyPzPKVJUnFmZ+MIkX/SFz+pOChSR89IBxuuJuBWcbis5g8etkUR
S4hIKNl/8dsBEm5VcQN319E9XLPRS+rWULI0+RXyCJ6SR2d4wOptyzeNbnfi
0DwPSOkMOHG5Lxwcgl0V4akzFPXtd+zC6ohA0lZn5qAFyU1Y+lA4UkBXrhp4
p1u6a1O3qKSF+3n3V4I15n8ru0Y9JsuyPjl+4cuvTA4i92paJ65rV7JpyDbd
RuR6RAw0pDuDZL8dXoAxCCsW9mgXB49cvuDRVlfYNmX4SI5TZQqWHwnnV8v1
C1z/O49135ZWuK7d3wsXpv999tq1mUx+VPyBY2+YBoVVp6stSzb12/b8t3M9
JaUr7JEKbjg8JFQFDeAMM6f/SIcKpzZHqzXAsHSSkeQGxsW9FADfzrOnuUZz
lkszzTYucV/+up0b1uxQVzhvI6dQHb4l7qM1SY3mkwv3arX2qSO6f1KD5pNr
OpdtGtDx7A/yPK+uWE3qHylYfVKJioJFVA6uX2zSdJjR26fVUMnqH0ZUR18b
x9eUgOD+u+X6OW7FnpWux853+R4Hdkag0KeUb+/Kp6yOXkHdPioegTnpDl46
7Kml03bf8eta9qBcvk/jTWNaHDyx+ufWGhlFY2ug2p7OlL/lqzDHNElnPv5l
X4Wpp5AcGVWlVjxXaMaFHd1HjfZ0pV+s1SA3zHPzTmztBrX4iStcoNVQk5aU
7PeHMck7ocI75EV6Btwn3rzbxqXFLRbl4l5XgGLrWLNJtRjISr9Ys5K+cfwG
lIS32sa2r5INyc2BhdCPqrhwxiNuffNi93rH492pDz/vznnxCTfh9C5uRXGl
2+36saH5ruG3xalnIOhkDonSywH+vK7vI0vWdijblItjPXVrvgpHJZgeSv1i
A6LjsFm4YKtb00qsccb+Eeq2HPKdNf4pN+aE3YPpsqK00g3e6Qi3/4NvB4aA
bVFzta4MP8se5KkUs9JOGxhoqMuyKqk+ubfnLfMyPyZeVywoFWk+l8IRA/Wj
pB0VidK6PnbRONaWqnxWkch7q9ZIcnMynWxN3pt0xn0pr9/wsKHL5/PkUNWV
cphz7KSDC6rDA3Z4mHpaniRHJkaeLNmaLDnp4MmqShQuovqiQlvHEzsplcEX
USpzbNfbkWWs7GBNTwqSI0GhM/Bk28DvE+XtLqrhhVO8PqhQDhTtLFTx8yQS
WoESmcO2nkQ6O28HagDBJJ990i+fDf6FP/SvTYK3UXgNwbAMOyHdtUCFMnON
qFCft6YEJhznwIBZVI6IdHBIBXG2AzMwYJJ/cdqpzyUHZrKfHJhJi7RMCmzK
JORsgC7kbDJP5IwTIQIsW4FNBr9xBguyNfmZRrH1st2ifIHNxx7I2SR4ydnk
GMnZdKazAuOyziaTrckQ9c/QTaPYHunofsvkXEd6Tz3vyNnkRqvhrLSzFRiX
hXEjW5Nz7p8x+xpl2JSUwBgKsNQ+Z/Oe8giMRL8AxVZgXFZmieSoDejagHgO
C1vUKLYN+sx3SmBTJuEdpl4wIEM9jTIGRoG3zZhB3PFRUNbJeLI1GfwstimB
MRStBt6BDWzq6ac973M234lslLHErcDmhVBg1AaUYhkQzyphbMnWmMRY4DYZ
S5ect/7yy2/6XnvNQJ8zcOPCLHrvLofARkuV8fqW5SBb08yjUcaaTwlslq7H
WZaDnE0epvopYR5Ktib/Traml1GWHmKzxilhKt7kjNxskrNBd1QvcNaUME2O
yRb1bO1+OTXsC5w1JQD1Ey6GnJE90BceSVfoJ5l/ZATGZfklJDcf9SVbeAE6
kVAZr3m10muVFNi00uMd8IyUviZn05KLdFjeWvZWYPNxHJIbP45sgcnAEQyf
zrTSa5Wcw6aVHu+AO6vDyORsMIukA3RQUGUrsCmQk9xkVsnWfEGOdOmWxb7A
Jj7gHQY9R86mfTLpsLy17K3AgCAofiM5oh5FLmRrjhqRznx+NSWwaaXHOxBY
atjkbOIk0pnMohXYgDxIbuLdAfE0UZqcdFgqtgexLzAi5CRnTDRNLHJGalQR
MulMKs4KDGCP0kqV8QLTrCJbPEa1ENKZbnUpgY1XzTsAItQnKcnZoCFJh+Wt
Q5ZWYJOwIrk5AEm2pgW1t+bVDzAlsBk27zAnc8nZNJuvjNWjQViBTShKcnOk
cUD8knQ+mHSm42JKYNPPnXfA5mqT8DgrNvLslKaJFdj0cye5OaA4IF4GWmCk
A2ZRIL+UHcb35JWw8DjL5SdnoH6FhqzMWIhWYIxFCYvKDINEtqijyISRDn0Y
tOZTAhvjyDvQ0UEuPznjcL1MWGX83rXsrcBmtpDctNIjW5w60SbhrXkV01IC
m+2HdxgnlZwNHIV0pkmfFRhpAJ0mJrlJI5CtacZFOtynIwapOYwqsjZ4j3Pw
rwRntZv27JTSAVZg8ylrkhunnmyRdZCz41kTHbVICQycgGwp7zBQKXI2X0gj
nQnzrcBYs8rRkdwELeGrst5tw9ia2I+U+AJjKDr+Qs7GNyRn49WRswnzrcCI
bdVatzJDuIEZWidb3KcvL6YENmFAHoGN30zOyEdq2VuBAVJKTvksgY3WG8bW
xH7SxxfYHOHKmhJ53p1pQG8FRoQsnzZrDudhi6ViP23kC2wOyfEOBKYS+o3c
nE2YT4G3C39looYG8SDk778R60aWg2xNIJMSGO69IKoNY4sgfHQegQ1nK7D5
FQU2YT7ZGgtKtiaPE9vhNhlzk5zhmGsCkvP0X/3qudYReo6cTZhvBTYZHbIF
Ml9hPtkaXD3ZGquaEthojpzNGUJyHnXJxa9VbUsraihwFlsTjJOtOZyUc0pU
J7ApdJAzYh7B7BpmTFQrsDE0ZGsSpWyLaUCWBFKgZ6UOc1fmnddtcw/ClL04
CNhhWfiGGXPBDgJzU/Eu2cIfVoDOPii1AVnWo48lL0f9K++7/t7ggD5xOgbd
ED6lws8S5IJ1ei3+2+ZedKYXP7WJIEvgN9KZo4nbGm0CLK3iEMlR41UrFWoz
A3nZNBfyMpjNNehtmRd6WeJ/sxvguKADRG61NohyGdUBPpsmNWsQ5VSBOZ1J
zRp0HOmwuymnbDVrzBTJgblSyBNqNhcOs1adLhvkgmJGnS5xZAdjyq2/kuAU
+B+vG+6DPwvy4zKpQJMd5UhRZ9XHuqhA5Ark3ZMOGlIVwSrQhGUkN1ioECqX
D5dZi+6XFVmgzKjUqSNaefQHC//Cn68b58NAo+a/uRGaVCFyWjpj7o1VDd6o
QvMdCNIhF6QzZVaFqK0JC0ZyTAWxeDiUPROhWbO2mBEUkzPFnL4rya0tRMHP
3Xn1TB/7GWkrNzazbTwztGNwWObIILUFxIRmC+lw5lH7ndUWDrwrQ0pyVHMV
N4Z4w2qwmbXrnFmRBc8EPA6/1Yf0ck+7Ymw2T91/3fwIDVotUpPBtGmAlTVY
6hDZHQAffDqEiTo0Z3VokrYkR0Sps7H/CN9/HsxmbbppNsgF2ozUiF0Dw8qj
Qeyi/3j0pgURTLRa/GbreFiK/b2hqjEANWiS8aQz5yStBs1ZbZIjxFVszR25
5vjN2vTazIHeLPE/HX7AWGZc81hDTN07e94914eNJtd3hONMafa+Bx94R594
aRDPV51XpmYx94VKIJ1JPlvNmo+2NohNiZLw3JFriMwMR1+rpprUcdRMc+8B
E4MezjzjkwuKSZUiQdjjladn+TDQSKXfFR6TBvbv9/xt1HVP9/w4qSkZXb4A
0y+AdKZcYV8ARiAkLclNqwnPJaoBHpPTz7TYZC8i0wguvD0n8JLqRZL114Pf
nO5DOyP/5ztBX7bN0A+VYMq11K0JUElnOkRY3SJXLmgsyfF5DoX2obdUG/Rl
9b03GQci+6RjopzjSfglvXRYN6CkqgN21lPJposdtWGOt1PJyHULHkM62GXh
4KySzZlukpu+U6GSq4VhElNZbVtO6hd5JuWH6VQZPCYjS4gW7Ui5IJ51xmW2
jXcuNbCgCpAj0bFXaraxn8EiHUJ0ge6sZmHKUVTzyU16IUwB2cQAnXxz3qtB
/YYHPyX5hk0ig3KYLEtFvEVJDjs8ZFlejerWZGuyMXnYmmMw9RyeAUpTDpN2
fTND9ZQDaS3JYYe315RPFoy4jKWRWg4P0Z9yWCGqtr6wUw4W+7oCI0plCgF5
pEJAJotsB2tQqg0ypuWbGQogWyQo1LyDXbnr8dl0pgvNRzkokQE+vZlxrSK2
ioLi2YGaghfJTTe+QRk6JZ1pzcGkXi1gp21iCZTL9yRQLn9QblWbPCEHtn2G
HsrjR6k9KNkiM6RCA9maCkrrpMAQTrnoipizehLk4WymoRXYFFzKM1462SIV
1cpOrwyBgzWyRW5VgLNANuSMPhFJznkENlnz8ng5qhsW2ZoENtkac5sS2Ew2
ckaWSEl3ckaxLMnZWDUrsPkV2RpjSbYwxkLA1Uhgo39yNn2LyBlogyTnPBrO
enEGs0K2KMsK5EE682XyNkmBzXB4B2LaJGeDrfM4q5a1nREYCHyBPkkOf0rA
G7I1575IhzSrnImUwJhsWky8A6V3oWHI2XQEiz6P48ONrcAG/kxyBOYAevhs
zeFKbwnpa34pgWFntAvwDnPK0OMsDAzpTD3WCgz4h+pMJEe8C6CHzxb95HSG
lnRIIiraSAmMPVpAVd4BJIw+/0jO5hsLpIPLoGVvBQaEXycwSQ4dKP1BtuYL
qqQzlf9A4GJv60dNSUeueAeyWMKskDMiUn2txOMsrJIVGBhKZbJIbpAlZJvx
MYIAZqLv+aQExmIS3IN3mM+fkrMJ80hnujtYgZGOU8qd5MiY6FGDYhbCwJAO
ZSDlqFICmw59vMMAysjZ1KhIh+hK6rECm+w0yfGa9TLJFrZZeELSmQ6VqTls
8mrl8QSUzSVn04KjPJ6A6sLoCxycbqexxvJR52gyA3ZKLiiZmbx+SkxT4eAd
6EalvYycIbbO6JXHy095M6tXExCXxwZO3W3IFnV8eRXlsea0cFICm6YIvANu
ripC5IyUjCo9pAPITw3jrcCYtUJJkhzOqLYQskVsLO8qOqJfNTfVMD4lMGaf
WtHzDhPBkjMstDxC0iGCVQ3QCgy7oO+tk9z4peFZQuvLMRGAkrgix5TAWJxq
xpvFmQJjD5Rv7q0dpU2twLC86tuTR2Djy1Fg3KcPnKYEhnsjiCM5G7+NnE3k
Sc6Tzj6zd5WpzNIw9jY1ZqulwLhP8VxKYICl9elUcjYhHTkb16gsXkVKYFqB
4T2od0otpwTuU2E+ZX1N/3VyNi4sORsvsSxeRcoKWoGxuOS+kdw4i0NyC2y6
pKcEBmedweQd5uRUHs6YOjolRYF3yJhBzFrCpdPhSrKFhVCPn7IMfcUCc0oY
17s0tgjqmEzOyMvJcpRlTBMrsIkGyBaFX8VbZIueZppVZRkvM57D7TKGUxqv
GJ1iJme4pbL61Qts1i3Zmp5mZAuPSxYhi21K4CwNw3II5ETO6A6j0wzVC5zF
1sCOyNbYXNJh/mqBtk0KbPTPO7AZCDFLzqZURTrzOdrtjcCAQQp0SHK4fUIO
ky12Q4Uv3lxXYJQS2GAReQciFYF7yBm1XJ1c8Djr895WYAMSJznA/CoTky0O
9KghBOkA6NNcTwmMSEx+A+9AEV9IEnI2hwO8VST/wgpsinwkR1Ck8IVs4XcJ
4B91Wpr6+SLN9ZTA2FYUGPEOuKA6CEDOiDH0NNIBSaf91wpsivMkR3sNjXlI
rHV5dVHRZtzHX2uuBwL7Zg3bsk7a8A44QzppQ84YgHxp0uEUivwQKzBiB3lc
pfE1HWUbEs9rHS8hHfwxzfWUwAiZFHLxDpz3UJWdnDEAeXWkM5V3K/DVvk9L
cvhKwsYPiS2H6hKkg4stjzclMLIOqHD5dyC3I62TM7w6fQiBdDjfpLluBca8
VNRAckDNhZAiWxNul8azT/em5jCiBqUDeAe2Hx1cIWfTbpd0CIoU8FuBzRfL
SI7NUyd0+YmYDLBpCcCmwb+q/iDhEZToaPqRL1L36dRgEI0ooOdTYcZU+ONg
sGj1LYHS+M0pkWMHg3msxg4kh6utFHcIDSpvvPEbd+8/L3df7trObSwpdIsa
tHDP73eq2+alqcEgWU82H1GvT4fPUvPd9KorcBnhkoS/LvGhGVhJQfWtmgc2
S+oUi1bLiIPHXqbsOnUKHSuXRjrsjSr5WZ1ii1TARHLjHoXgtAoAcYY9fKhb
WdLQ/eWk69zJz/R2l/R8wH1xwtZuQUlL1+HxmSrUGxjqd9EBtMyHoaoEFZ1z
z9AyDGxwLriGT2+a1DZ8kqRdMG4utQ1fRb4O6bA8hROy2kYmQvtYFttQ28U/
XjXOrelU5n63/+MBgIrYiw7rZrpl+zdxj3Y4L8Cder2w6tktNIKoFsUTSzIR
NODrF+5s9LnXmjw9pV84AjrZl6WIMAdqvb2S2Cxqu7f6RXFESILcs7no2AX9
3fv77eO27DknWvrFZW6Nm3zrju6DRnu7oq82+D3fatxUtDQXfpWFNuMWZ+gV
mY6owFPDBzdJqhZOoZy7PKo1oQpVi4gNXYkyVAv4uuqQJIfDrFjxiVhfc09q
495scaTbbPGmZPfCGrUYTeFa+TwTl2aoz//Ueg0fmFIfwsgkzAPXlM8YliEL
6RC1KPqm+nbM0HZx/KZ0EOjR0NIBsdN13HvuF4NfdoO7H+FWlFW6fXu8m26n
WaO+o6W5gK1Ra+qqiFxnw6ghX6FYfoU1f2iMIaQbZk4EeaNWPobKhMK1i5dk
zFmrTKP74tiiKHsUKrM0gPZsF0J7VhRWuiMuHxysRr9/a/3akkb6pN00ldQM
fWIWFNb84TXSpxk49YnalI4/lmTYweonp+kPQn3CS6xcvcJ1mTPBvX7H8W5e
RWvXpvfcaNV+Zx1K/c/JU13IR6hKlaFZTInCWolR18alW+TWmenWwldhimDV
T22k4uTSka1psRb6uMVbrPvK9b74ZLf3NR94Pm1xl28nuDVbl7kTDngtuPxd
Ni41X58n2A3uLLIvWajZtgPmbggsaWFdhKg1uGrLUErT4YmSow6tgJfvxYSv
pIPfrvOwO5j3gnSLoBckR5ijfil8L9ielxzWzN3fuWrXXqHpe8TiwW5dmxJ3
+FFDhEuuSQvT8LscFX/691OjTxsy+IsOGejZHV6aGu73hTVnW1dgJ3UMhIvc
BCoDuQrlnqhjQBTVyJd0MEuqbVkdo0an0jnJTc4m1HEF5Ht8+O/cmrIyd98R
l7kTn+njLnn+ATfv8NZuVml713zw4ihHWW3vUioYtca7H37o3WhV+sDZ/Z4e
uyTwVYtqxrKeyjVf1aUWTEcaKhcZA2mGdMhmKTtglWt6DpAc8aRyTn8PR4eR
39LnBjdtn85ufUVxEDy/0PUUt/XLXwQWpZrmpfxwJPIO+hSaZ5cBlv3ZI8OD
Slpxfk51hchSjQAPKP9bHM9HZYWoRuSftIhJB7ugIw1WjeYrbiQ3jZPJFghg
AQ1Ih4SJgDaN6jc8mDNV/skfAasSlpQDxll7B+mQXtFXvOzwMNHU4rY4XpZK
/Q/LmGikQ+JWDV9CtGF9MaQcLOyKkrmeVFEIGkmF7B7a0ySlAto/Y7DItyk5
RnIg6GXnydb0uyId9KfUZYgQr0/r0i0zjCifZMr4lAhFVBVhSYfEmVJydqDI
HQlYQnKDmCdbxHOqXZPO5I7YsLEWGFJGVcaF4R1IMiQlQBCggoc3rbVT24Gh
UpWchsZHDjMttlJFXx0mXR7lFkmBYTpUPSdnUzUmZxPRk7P5YJoVGMFBcirV
VGA49crbpgRGRkSVF3I2Ln8ezihia9JbgQFnUOhLcrw0CT0i1o0a7JIO9+mL
J1sk5zriTgXaRRlPI2fjaBfF1zR1KPBOGWOm74OSsYCAZIscqeB/ZGviyljg
rcLfGq+9MF6I8mbIGfNXQTU5mzyWFdi8ELI1VSmyBbYWnW+TeqidwMZEkjOi
R5lScjadDqzAWLd6rWQLC6HeD2SL7U/feSUdLIywDe2SAkNLmkS8wyT9yRm+
jM4Ikw5gCmEbdjQC49Xrc8ckN5aWbPGz+qiRruvkyfPVOTUlMEopmkS8A5UY
wdTIGbuFbDPpoHEVP6zAOI6YCHaDU2dCzpEtNjDBVSXwpPl6wSmBMal0fKQw
Fk4VlxGxelTBIR0KgKppWoHhFR0ffdOS5HDxhHAkW9PBmnSAnqlmGAhc7FkJ
1NtV0+Qd5jMJI+IJKKQa6fAuBT+2AqOQJ4AfyQ10kGxNq2nSwZuQj5QSGK9e
v+UdsMtJzngLWuKkA6hZ91qBjZZIjmytsmZki7BMWATSYfmoBpwSGAHajQnO
WKJCQ5AzfBB12SAdMKV6O1ZgGBptzSQ3myVLmAbaUvUHOgGscsvk1MWOrDbl
hbEpSjI0u3TVH+zGqM/u5ItXijKZspBVf5AygCXm1yuMpFV/oGrY9KRUpchm
amvB77g3ks+0U0953ucTJTopzM7B/0r8p2GHDwQLOZTg34q1q/4E+9tWSTFQ
DPM3A+xL8BfIBHg+FV+r/gTb0c5GBryHKG+C3F8A6+btvj3CAIN3FsvQPqTy
9zhU59+8snv/iANmQlR7R3orQwB43hHYCpmVwLDx9qs92DASCIGjkxIAnnIE
ifldv9c/uebZZ8b6HCLgBpywwPJaAQb1uKL/pS+FNg/O4RmDB02Nbsfyi3Yh
fa04JcAzf75l2C9oSW+L4DzkgGUWYcbhjwfGygrgH0oeeenFr+1TtfdEt8O9
i0BkMMxBNiAlAJz8P9LiwakLvqlNDsCFRZgEfUTDCoCSabRmNR94e6GHygKb
IKe5lYzJVjGHCDoG9yNADJIDdvZotWNuVq3yRVaAYpDgIWiDg7cZ7jXFMGhY
A5j7IEk+thgFGiwiTHvYKN6H1YZpP/fEnz1dXDXr+LAuofHAhAOqJDhKEt6B
TetdTK7AR2+vx4TqDUIx5A2DnZF3YIPBuYFgQnUxD0AsrqabJMfcg30IllN7
vb8O4W9xQhXuY4CSfCe2uxhIsHz4gGCNxYecgh/b/EB/Vaxftf5uflVrMYK/
dg8vFGz2f8T4J9Q=\
\>"]]
}, Open  ]],

Cell["On the positive x-axis we see the two horns of the function.", "Text",
 CellChangeTimes->{{3.49795814646875*^9, 3.4979581888125*^9}, {
   3.49795824053125*^9, 3.497958316*^9}, {3.497959406296875*^9, 
   3.497959420546875*^9}, {3.498043168328125*^9, 3.498043187546875*^9}, {
   3.498106516515625*^9, 3.49810655075*^9}, 3.498811881546875*^9, {
   3.498827995140625*^9, 3.49882799565625*^9}, 3.49882868975*^9, 
   3.552473872765625*^9, {3.552473968390625*^9, 3.55247402665625*^9}, {
   3.553260807015625*^9, 3.553260815*^9}, {3.553753211917671*^9, 
   3.5537532471483917`*^9}, {3.5537532772628927`*^9, 3.553753310106073*^9}, {
   3.553775339564728*^9, 3.553775388928371*^9}, {3.5538272658268547`*^9, 
   3.553827271558619*^9}, {3.553827318764749*^9, 3.553827365915971*^9}, {
   3.553827426142563*^9, 3.553827457019126*^9}, 3.553828090670125*^9, {
   3.553828174641241*^9, 3.553828202866152*^9}, {3.574943132840713*^9, 
   3.57494313890244*^9}, {3.574943229021974*^9, 3.57494323680661*^9}, {
   3.574943304707011*^9, 3.5749433047071123`*^9}, {3.5750891979997683`*^9, 
   3.575089219260971*^9}, 3.575096334352598*^9, {3.575096473118904*^9, 
   3.575096549237656*^9}, {3.5752581595596027`*^9, 3.575258181038831*^9}, {
   3.575258975016244*^9, 3.575258998670597*^9}},
 FontFamily->"Times New Roman",
 FontSize->26,
 FontColor->GrayLevel[0],
 Background->GrayLevel[0.85]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  SubscriptBox["dueFT", "at"], "=", 
  RowBox[{"Timing", "[", 
   RowBox[{"FourierTransform", "[", 
    RowBox[{
     RowBox[{"\[Rho]p2", "[", "x", "]"}], ",", "x", ",", 
     SubscriptBox["g", "x"], 
     StyleBox[",",
      FontColor->RGBColor[0, 0, 1]], 
     RowBox[{"FourierParameters", "->", 
      RowBox[{"{", 
       RowBox[{"1", ",", "1"}], "}"}]}]}], "]"}], "]"}]}]], "Input",
 CellChangeTimes->{3.5537649867081633`*^9},
 FontSize->18],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"27.58999999999999985789145284797996282578`7.46135161375881", ",", 
   RowBox[{"-", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{
      "45875200000000000000000000000000000000000000000000000000000000000000000\
000000000000", " ", "\[ImaginaryI]", " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"-", "1"}], "+", 
         SuperscriptBox["\[ExponentialE]", 
          FractionBox[
           RowBox[{"27", " ", "\[ImaginaryI]", " ", 
            SubscriptBox["g", "x"]}], "200000000000"]], "-", 
         SuperscriptBox["\[ExponentialE]", 
          FractionBox[
           RowBox[{"81", " ", "\[ImaginaryI]", " ", 
            SubscriptBox["g", "x"]}], "200000000000"]], "+", 
         SuperscriptBox["\[ExponentialE]", 
          FractionBox[
           RowBox[{"27", " ", "\[ImaginaryI]", " ", 
            SubscriptBox["g", "x"]}], "50000000000"]]}], ")"}], " ", 
       SuperscriptBox["\[Pi]", "6"]}], ")"}], "/", 
     RowBox[{"(", 
      RowBox[{"27", " ", 
       SubscriptBox["g", "x"], " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{
          RowBox[{"-", "27"}], " ", 
          SubscriptBox["g", "x"]}], "+", 
         RowBox[{"400000000000", " ", "\[Pi]"}]}], ")"}], " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{
          RowBox[{"-", "9"}], " ", 
          SubscriptBox["g", "x"]}], "+", 
         RowBox[{"400000000000", " ", "\[Pi]"}]}], ")"}], " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"9", " ", 
          SubscriptBox["g", "x"]}], "+", 
         RowBox[{"400000000000", " ", "\[Pi]"}]}], ")"}], " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"27", " ", 
          SubscriptBox["g", "x"]}], "+", 
         RowBox[{"400000000000", " ", "\[Pi]"}]}], ")"}], " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{
          RowBox[{"-", "27"}], " ", 
          SubscriptBox["g", "x"]}], "+", 
         RowBox[{"800000000000", " ", "\[Pi]"}]}], ")"}], " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"27", " ", 
          SubscriptBox["g", "x"]}], "+", 
         RowBox[{"800000000000", " ", "\[Pi]"}]}], ")"}]}], ")"}]}]}]}], 
  "}"}]], "Output",
 CellChangeTimes->{3.577683323838892*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"Limit", "[", 
   RowBox[{
    RowBox[{
     SubscriptBox["dueFT", "at"], "[", 
     RowBox[{"[", "2", "]"}], "]"}], ",", 
    RowBox[{
     SubscriptBox["g", "x"], " ", "\[Rule]", "0"}]}], "]"}], 
  "\[IndentingNewLine]"}]], "Input",
 CellChangeTimes->{{3.553762022200302*^9, 3.553762058704142*^9}, 
   3.553762277885459*^9, 3.553763515414506*^9, 3.55376505098954*^9},
 FontSize->18],

Cell[BoxData["28"], "Output",
 CellChangeTimes->{3.5776833242226887`*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"Limit", "[", 
   RowBox[{
    RowBox[{
     SubscriptBox["dueFT", "at"], "[", 
     RowBox[{"[", "2", "]"}], "]"}], ",", 
    RowBox[{
     SubscriptBox["g", "x"], " ", "\[Rule]", "  ", 
     FractionBox[
      RowBox[{"2", " ", "\[Pi]"}], 
      SubscriptBox["a", "0"]]}]}], "]"}], "//", "N"}]], "Input",
 CellChangeTimes->{{3.553762022200302*^9, 3.553762027781721*^9}, {
   3.5537620612407827`*^9, 3.553762062335894*^9}, {3.5537622812269363`*^9, 
   3.553762302266633*^9}, 3.553763520333001*^9, 3.553765054187447*^9},
 FontSize->18],

Cell[BoxData["19.4505889985463`"], "Output",
 CellChangeTimes->{3.577683324300861*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  RowBox[{
   RowBox[{"Limit", "[", 
    RowBox[{
     RowBox[{
      SubscriptBox["dueFT", "at"], "[", 
      RowBox[{"[", "2", "]"}], "]"}], ",", 
     RowBox[{
      SubscriptBox["g", "x"], " ", "\[Rule]", 
      RowBox[{"2", "*", 
       FractionBox[
        RowBox[{"2", " ", "\[Pi]"}], 
        SubscriptBox["a", "0"]]}]}]}], "]"}], "//", "N"}]}]], "Input",
 CellChangeTimes->{{3.553762022200302*^9, 3.553762066016841*^9}, {
   3.553762284742817*^9, 3.553762320511552*^9}, 3.5537635251648493`*^9, 
   3.5537650573021193`*^9},
 FontSize->18],

Cell[BoxData["0.`"], "Output",
 CellChangeTimes->{3.57768332441815*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  SubscriptBox["coef$tab2$50FT", "at"], "=", " ", 
  RowBox[{
   RowBox[{"Table", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"n", ",", 
       RowBox[{"Limit", "[", 
        RowBox[{
         RowBox[{
          SubscriptBox["dueFT", "at"], "[", 
          RowBox[{"[", "2", "]"}], "]"}], ",", " ", 
         RowBox[{
          SubscriptBox["g", "x"], " ", "\[Rule]", 
          RowBox[{"n", "  ", 
           FractionBox[
            RowBox[{"2", " ", "\[Pi]"}], 
            SubscriptBox["a", "0"]]}]}]}], "]"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"n", ",", 
       RowBox[{"-", "nterm1"}], ",", "nterm1"}], "}"}]}], "]"}], "//", 
   "N"}]}]], "Input",
 CellChangeTimes->{{3.5532323323125*^9, 3.553232383328125*^9}, {
  3.553232425828125*^9, 3.55323251878125*^9}, {3.553232588921875*^9, 
  3.55323259021875*^9}, {3.553233253515625*^9, 3.553233254453125*^9}, {
  3.55323393575*^9, 3.5532339373125*^9}, {3.553236095828125*^9, 
  3.553236099984375*^9}, {3.553236160828125*^9, 3.55323616578125*^9}, {
  3.553249281984375*^9, 3.553249283984375*^9}, {3.55324960325*^9, 
  3.55324960446875*^9}, {3.553251364921875*^9, 3.553251411*^9}, {
  3.553252667828125*^9, 3.5532526681875*^9}, {3.553259518484375*^9, 
  3.553259536875*^9}, {3.553398138359424*^9, 3.553398140819633*^9}, {
  3.553754177079156*^9, 3.5537541787979593`*^9}, {3.5537718163220673`*^9, 
  3.55377186287658*^9}},
 FontSize->24],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", "50.`"}], ",", "0.`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", "49.`"}], ",", 
     RowBox[{"-", "4.26408514599033`*^-6"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", "48.`"}], ",", "0.`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", "47.`"}], ",", "5.757272171179573`*^-6"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", "46.`"}], ",", "0.`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", "45.`"}], ",", 
     RowBox[{"-", "7.882096785012428`*^-6"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", "44.`"}], ",", "0.`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", "43.`"}], ",", "0.000010957388970954672`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", "42.`"}], ",", "0.`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", "41.`"}], ",", 
     RowBox[{"-", "0.000015492397129162356`"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", "40.`"}], ",", "0.`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", "39.`"}], ",", "0.000022320607163055814`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", "38.`"}], ",", "0.`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", "37.`"}], ",", 
     RowBox[{"-", "0.0000328438819138242`"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", "36.`"}], ",", "0.`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", "35.`"}], ",", "0.00004949352023112376`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", "34.`"}], ",", "0.`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", "33.`"}], ",", 
     RowBox[{"-", "0.0000766357244655898`"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", "32.`"}], ",", "0.`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", "31.`"}], ",", "0.0001224313395190956`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", "30.`"}], ",", "0.`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", "29.`"}], ",", 
     RowBox[{"-", "0.00020285927064420827`"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", "28.`"}], ",", "0.`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", "27.`"}], ",", "0.00035096983995474076`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", "26.`"}], ",", "0.`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", "25.`"}], ",", 
     RowBox[{"-", "0.0006397869304932723`"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", "24.`"}], ",", "0.`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", "23.`"}], ",", "0.0012443476143849902`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", "22.`"}], ",", "0.`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", "21.`"}], ",", 
     RowBox[{"-", "0.002630235158694564`"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", "20.`"}], ",", "0.`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", "19.`"}], ",", "0.00622173807192495`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", "18.`"}], ",", "0.`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", "17.`"}], ",", 
     RowBox[{"-", "0.01735955204738412`"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", "16.`"}], ",", "0.`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", "15.`"}], ",", "0.06429129340989115`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", "14.`"}], ",", "0.`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", "13.`"}], ",", 
     RowBox[{"-", "0.5034270093741395`"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", "12.`"}], ",", 
     RowBox[{"-", "1.4`"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", "11.`"}], ",", 
     RowBox[{"-", "1.7358649220670612`"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", "10.`"}], ",", "0.`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", "9.`"}], ",", "4.195225078117829`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", "8.`"}], ",", "8.4`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", "7.`"}], ",", "7.984978641508481`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", "6.`"}], ",", "0.`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", "5.`"}], ",", 
     RowBox[{"-", "12.585675234353488`"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", "4.`"}], ",", 
     RowBox[{"-", "21.`"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", "3.`"}], ",", 
     RowBox[{"-", "16.85717713207346`"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", "2.`"}], ",", "0.`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", "1.`"}], ",", "19.4505889985463`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"0.`", ",", "28.`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"1.`", ",", "19.4505889985463`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"2.`", ",", "0.`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"3.`", ",", 
     RowBox[{"-", "16.85717713207346`"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"4.`", ",", 
     RowBox[{"-", "21.`"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"5.`", ",", 
     RowBox[{"-", "12.585675234353488`"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"6.`", ",", "0.`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"7.`", ",", "7.984978641508481`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"8.`", ",", "8.4`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"9.`", ",", "4.195225078117829`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"10.`", ",", "0.`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"11.`", ",", 
     RowBox[{"-", "1.7358649220670612`"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"12.`", ",", 
     RowBox[{"-", "1.4`"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"13.`", ",", 
     RowBox[{"-", "0.5034270093741395`"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"14.`", ",", "0.`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"15.`", ",", "0.06429129340989115`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"16.`", ",", "0.`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"17.`", ",", 
     RowBox[{"-", "0.01735955204738412`"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"18.`", ",", "0.`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"19.`", ",", "0.00622173807192495`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"20.`", ",", "0.`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"21.`", ",", 
     RowBox[{"-", "0.002630235158694564`"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"22.`", ",", "0.`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"23.`", ",", "0.0012443476143849902`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"24.`", ",", "0.`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"25.`", ",", 
     RowBox[{"-", "0.0006397869304932723`"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"26.`", ",", "0.`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"27.`", ",", "0.00035096983995474076`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"28.`", ",", "0.`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"29.`", ",", 
     RowBox[{"-", "0.00020285927064420827`"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"30.`", ",", "0.`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"31.`", ",", "0.0001224313395190956`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"32.`", ",", "0.`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"33.`", ",", 
     RowBox[{"-", "0.0000766357244655898`"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"34.`", ",", "0.`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"35.`", ",", "0.00004949352023112376`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"36.`", ",", "0.`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"37.`", ",", 
     RowBox[{"-", "0.0000328438819138242`"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"38.`", ",", "0.`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"39.`", ",", "0.000022320607163055814`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"40.`", ",", "0.`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"41.`", ",", 
     RowBox[{"-", "0.000015492397129162356`"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"42.`", ",", "0.`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"43.`", ",", "0.000010957388970954672`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"44.`", ",", "0.`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"45.`", ",", 
     RowBox[{"-", "7.882096785012428`*^-6"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"46.`", ",", "0.`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"47.`", ",", "5.757272171179573`*^-6"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"48.`", ",", "0.`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"49.`", ",", 
     RowBox[{"-", "4.26408514599033`*^-6"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"50.`", ",", "0.`"}], "}"}]}], "}"}]], "Output",
 CellChangeTimes->{3.577683328087888*^9}]
}, Open  ]],

Cell[BoxData[
 RowBox[{
  RowBox[{"nterm1", "=", "50"}], ";"}]], "Input",
 CellChangeTimes->{{3.553762093074861*^9, 3.553762097748625*^9}, {
  3.553769435197905*^9, 3.553769436031226*^9}, {3.5537706570955544`*^9, 
  3.553770657708028*^9}, {3.5537707024285917`*^9, 3.553770726745496*^9}, {
  3.553771242148036*^9, 3.5537712426805153`*^9}, {3.575347486628652*^9, 
  3.5753474884245653`*^9}},
 FontSize->18],

Cell[BoxData[
 RowBox[{
  RowBox[{
   SubscriptBox["coeffuncdueFT", "at"], "[", "n_", "]"}], ":=", 
  RowBox[{
   RowBox[{"Limit", "[", 
    RowBox[{
     RowBox[{
      SubscriptBox["dueFT", "at"], "[", 
      RowBox[{"[", "2", "]"}], "]"}], ",", 
     RowBox[{
      SubscriptBox["g", "x"], " ", "\[Rule]", 
      RowBox[{"n", "  ", 
       FractionBox[
        RowBox[{"2", " ", "\[Pi]"}], 
        SubscriptBox["a", "0"]]}]}]}], "]"}], "//", "N"}]}]], "Input",
 CellChangeTimes->{{3.553762093074861*^9, 3.553762126026986*^9}, {
   3.553762167991078*^9, 3.55376218964124*^9}, 3.5537622365956984`*^9, 
   3.553762408366288*^9, 3.553763556004435*^9, {3.553765083488873*^9, 
   3.5537650953917513`*^9}},
 FontSize->18],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Vol1D", "=", " ", 
  RowBox[{
   RowBox[{"-", 
    FractionBox["1", 
     SubscriptBox["a", "0"]]}], 
   FractionBox[
    RowBox[{
     SubscriptBox["r", "e"], " ", 
     SuperscriptBox["\[Lambda]", "2"]}], "\[Pi]"]}]}]], "Input",
 CellChangeTimes->{
  3.553235597390625*^9, {3.553251523203125*^9, 3.553251554421875*^9}, {
   3.553251837703125*^9, 3.55325188546875*^9}, {3.553259297875*^9, 
   3.553259303359375*^9}, 3.553260996109375*^9},
 FontSize->24],

Cell[BoxData[
 RowBox[{"-", "8.326359493145908`*^-27"}]], "Output",
 CellChangeTimes->{3.577683328296583*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"\[Chi]funcdue50", "[", "x_", "]"}], "=", 
  RowBox[{
   RowBox[{
    RowBox[{"ExpToTrig", "[", 
     RowBox[{"Sum", "[", 
      RowBox[{
       RowBox[{
        RowBox[{"Exp", "[", 
         RowBox[{"I", " ", 
          RowBox[{
           RowBox[{"(", 
            RowBox[{"2", " ", "\[Pi]", " ", "n", " ", "x"}], ")"}], "/", 
           SubscriptBox["a", "0"]}]}], "]"}], "*", 
        RowBox[{
         SubscriptBox["coeffuncdueFT", "at"], "[", "n", "]"}], "*", 
        RowBox[{"(", 
         RowBox[{"Exp", "[", 
          RowBox[{
           RowBox[{"-", "I"}], " ", 
           RowBox[{
            RowBox[{"(", 
             RowBox[{"2", " ", "\[Pi]", " ", "n", " ", "8"}], ")"}], "/", 
            "8"}]}], "]"}], ")"}]}], ",", 
       RowBox[{"{", 
        RowBox[{"n", ",", 
         RowBox[{"-", "nterm1"}], ",", "nterm1"}], "}"}]}], "]"}], "]"}], "//",
     "N"}], "//", "Chop"}]}]], "Input",
 CellChangeTimes->{{3.553769595368762*^9, 3.553769631262694*^9}, {
  3.553769905949944*^9, 3.55376991178036*^9}, {3.5537704101564503`*^9, 
  3.5537704151483717`*^9}, {3.553771097358181*^9, 3.553771102295986*^9}, {
  3.553771330467588*^9, 3.553771331894312*^9}, {3.553771362129407*^9, 
  3.5537713631343393`*^9}, {3.5537847407279787`*^9, 3.553784744696533*^9}},
 FontSize->18],

Cell[BoxData[
 RowBox[{"28.`", "\[VeryThinSpace]", "+", 
  RowBox[{"38.9011779970926`", " ", 
   RowBox[{"Cos", "[", 
    RowBox[{"1.1635528346628864`*^10", " ", "x"}], "]"}]}], "-", 
  RowBox[{"33.71435426414692`", " ", 
   RowBox[{"Cos", "[", 
    RowBox[{"3.490658503988659`*^10", " ", "x"}], "]"}]}], "-", 
  RowBox[{"42.`", " ", 
   RowBox[{"Cos", "[", 
    RowBox[{"4.654211338651546`*^10", " ", "x"}], "]"}]}], "-", 
  RowBox[{"25.171350468706976`", " ", 
   RowBox[{"Cos", "[", 
    RowBox[{"5.8177641733144325`*^10", " ", "x"}], "]"}]}], "+", 
  RowBox[{"15.969957283016962`", " ", 
   RowBox[{"Cos", "[", 
    RowBox[{"8.144869842640204`*^10", " ", "x"}], "]"}]}], "+", 
  RowBox[{"16.8`", " ", 
   RowBox[{"Cos", "[", 
    RowBox[{"9.308422677303091`*^10", " ", "x"}], "]"}]}], "+", 
  RowBox[{"8.390450156235659`", " ", 
   RowBox[{"Cos", "[", 
    RowBox[{"1.0471975511965976`*^11", " ", "x"}], "]"}]}], "-", 
  RowBox[{"3.4717298441341224`", " ", 
   RowBox[{"Cos", "[", 
    RowBox[{"1.279908118129175`*^11", " ", "x"}], "]"}]}], "-", 
  RowBox[{"2.8`", " ", 
   RowBox[{"Cos", "[", 
    RowBox[{"1.3962634015954636`*^11", " ", "x"}], "]"}]}], "-", 
  RowBox[{"1.006854018748279`", " ", 
   RowBox[{"Cos", "[", 
    RowBox[{"1.5126186850617523`*^11", " ", "x"}], "]"}]}], "+", 
  RowBox[{"0.1285825868197823`", " ", 
   RowBox[{"Cos", "[", 
    RowBox[{"1.7453292519943295`*^11", " ", "x"}], "]"}]}], "-", 
  RowBox[{"0.03471910409476824`", " ", 
   RowBox[{"Cos", "[", 
    RowBox[{"1.9780398189269067`*^11", " ", "x"}], "]"}]}], "+", 
  RowBox[{"0.0124434761438499`", " ", 
   RowBox[{"Cos", "[", 
    RowBox[{"2.2107503858594843`*^11", " ", "x"}], "]"}]}], "-", 
  RowBox[{"0.005260470317389128`", " ", 
   RowBox[{"Cos", "[", 
    RowBox[{"2.4434609527920612`*^11", " ", "x"}], "]"}]}], "+", 
  RowBox[{"0.0024886952287699804`", " ", 
   RowBox[{"Cos", "[", 
    RowBox[{"2.6761715197246384`*^11", " ", "x"}], "]"}]}], "-", 
  RowBox[{"0.0012795738609865446`", " ", 
   RowBox[{"Cos", "[", 
    RowBox[{"2.9088820866572156`*^11", " ", "x"}], "]"}]}], "+", 
  RowBox[{"0.0007019396799094815`", " ", 
   RowBox[{"Cos", "[", 
    RowBox[{"3.141592653589793`*^11", " ", "x"}], "]"}]}], "-", 
  RowBox[{"0.00040571854128841655`", " ", 
   RowBox[{"Cos", "[", 
    RowBox[{"3.3743032205223706`*^11", " ", "x"}], "]"}]}], "+", 
  RowBox[{"0.0002448626790381912`", " ", 
   RowBox[{"Cos", "[", 
    RowBox[{"3.6070137874549475`*^11", " ", "x"}], "]"}]}], "-", 
  RowBox[{"0.0001532714489311796`", " ", 
   RowBox[{"Cos", "[", 
    RowBox[{"3.839724354387525`*^11", " ", "x"}], "]"}]}], "+", 
  RowBox[{"0.00009898704046224752`", " ", 
   RowBox[{"Cos", "[", 
    RowBox[{"4.072434921320102`*^11", " ", "x"}], "]"}]}], "-", 
  RowBox[{"0.0000656877638276484`", " ", 
   RowBox[{"Cos", "[", 
    RowBox[{"4.3051454882526794`*^11", " ", "x"}], "]"}]}], "+", 
  RowBox[{"0.00004464121432611163`", " ", 
   RowBox[{"Cos", "[", 
    RowBox[{"4.537856055185257`*^11", " ", "x"}], "]"}]}], "-", 
  RowBox[{"0.00003098479425832471`", " ", 
   RowBox[{"Cos", "[", 
    RowBox[{"4.770566622117833`*^11", " ", "x"}], "]"}]}], "+", 
  RowBox[{"0.000021914777941909344`", " ", 
   RowBox[{"Cos", "[", 
    RowBox[{"5.003277189050411`*^11", " ", "x"}], "]"}]}], "-", 
  RowBox[{"0.000015764193570024857`", " ", 
   RowBox[{"Cos", "[", 
    RowBox[{"5.235987755982988`*^11", " ", "x"}], "]"}]}], "+", 
  RowBox[{"0.000011514544342359147`", " ", 
   RowBox[{"Cos", "[", 
    RowBox[{"5.468698322915566`*^11", " ", "x"}], "]"}]}], "-", 
  RowBox[{"8.52817029198066`*^-6", " ", 
   RowBox[{"Cos", "[", 
    RowBox[{"5.701408889848143`*^11", " ", "x"}], "]"}]}]}]], "Output",
 CellChangeTimes->{3.5776833284881487`*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Plot", "[", 
  RowBox[{
   RowBox[{"Vol1D", "*", 
    RowBox[{"\[Chi]funcdue50", "[", "x", "]"}]}], ",", 
   RowBox[{"{", 
    RowBox[{"x", ",", 
     RowBox[{"-", 
      SubscriptBox["a", "0"]}], ",", 
     SubscriptBox["a", "0"]}], "}"}], ",", 
   RowBox[{"PlotRange", "\[Rule]", "All"}], ",", "\[IndentingNewLine]", 
   RowBox[{"Epilog", "->", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"PointSize", "[", "0.01", "]"}], ",", "Red", ",", 
      RowBox[{"Point", "[", "coord2CG", "]"}]}], "}"}]}], ",", 
   RowBox[{"PlotPoints", "\[Rule]", "500"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.553233790828125*^9, 3.553233829390625*^9}, {
   3.55323390053125*^9, 3.553233906671875*^9}, {3.55323409775*^9, 
   3.55323409971875*^9}, {3.553235468375*^9, 3.55323547075*^9}, {
   3.553249909921875*^9, 3.553249924453125*^9}, {3.55325006259375*^9, 
   3.55325007190625*^9}, 3.55325150846875*^9, {3.553252120078125*^9, 
   3.553252146703125*^9}, 3.55325229884375*^9, 3.55325245796875*^9, {
   3.5532525145*^9, 3.5532525275625*^9}, {3.55325269825*^9, 
   3.553252698828125*^9}, {3.553256132015625*^9, 3.553256151140625*^9}, {
   3.55325629571875*^9, 3.553256300671875*^9}, 3.553256426703125*^9, 
   3.553259368796875*^9, {3.55326020821875*^9, 3.55326020896875*^9}, 
   3.5533979773347178`*^9, {3.553754523532002*^9, 3.553754524981373*^9}, {
   3.553754634078079*^9, 3.553754635092478*^9}, {3.553762849794499*^9, 
   3.553762856882823*^9}, {3.553764834014532*^9, 3.5537648362131166`*^9}, {
   3.553765164501225*^9, 3.5537651685172873`*^9}, {3.5537686737459183`*^9, 
   3.553768679342163*^9}, {3.553769144186157*^9, 3.553769153087062*^9}, {
   3.5537692176318197`*^9, 3.553769218205139*^9}, {3.5537702739963284`*^9, 
   3.553770274255484*^9}, {3.553771272370907*^9, 3.55377127578743*^9}, 
   3.553784785613023*^9},
 FontSize->18],

Cell[BoxData[
 GraphicsBox[{{}, {}, 
   {Hue[0.67, 0.6, 0.6], LineBox[CompressedData["
1:eJw1Wmk01W/UvVdokDRLUahUMkf60XNNDTJEZhXhmjJkjlDmuVBERdKgQhER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     "]]}},
  AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
  Axes->True,
  AxesLabel->{None, None},
  AxesOrigin->{0, 0},
  AxesStyle->Directive[20, 
    Thickness[0.005], 
    RGBColor[0, 0, 1]],
  Epilog->{
    PointSize[0.01], 
    RGBColor[1, 0, 0], 
    PointBox[{{6.75*^-11, 0}, {4.725*^-10, 0}}]},
  ImageSize->700,
  LabelStyle->(FontFamily -> "Helvetica"),
  Method->{},
  PlotRange->{All, All},
  PlotRangeClipping->True,
  PlotRangePadding->{Automatic, Automatic}]], "Output",
 CellChangeTimes->{
  3.577683328571027*^9},ImageCache->GraphicsData["CompressedBitmap", "\<\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\
\>"]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Part III", "Text",
 CellChangeTimes->{
  3.5532355989375*^9, {3.553258656921875*^9, 3.5532587594375*^9}, {
   3.553258796640625*^9, 3.55325884934375*^9}, {3.553763675668995*^9, 
   3.553763676089476*^9}, {3.5537719682980347`*^9, 3.553771985673956*^9}, {
   3.553772034435471*^9, 3.553772035687415*^9}, {3.5537720661717978`*^9, 
   3.55377212627013*^9}, {3.553772343671762*^9, 3.553772359107634*^9}, {
   3.553828318948316*^9, 3.553828381540613*^9}, {3.5538284330237093`*^9, 
   3.5538284334058247`*^9}, {3.5538284636143093`*^9, 
   3.5538284752584143`*^9}, {3.553828520391618*^9, 3.553828540643159*^9}, {
   3.575108128855081*^9, 3.575108141104501*^9}, {3.575108322993868*^9, 
   3.575108323487466*^9}, {3.575256116007718*^9, 3.575256117070779*^9}},
 FontFamily->"Times New Roman",
 FontSize->36,
 FontColor->RGBColor[0, 0, 1],
 Background->RGBColor[1, 0.9, 0.8]],

Cell[TextData[{
 "We can get the useful equation for the Fourier coefficients:\n\n",
 Cell[BoxData[
  FormBox[
   StyleBox[
    RowBox[{
     SubscriptBox["c", "n"], "  ", "=", " ", 
     RowBox[{
      FractionBox["1", "L"], 
      StyleBox[" ",
       FontColor->RGBColor[1, 0, 0]], 
      RowBox[{
       SubscriptBox["F", "0"], 
       StyleBox["[",
        FontColor->RGBColor[1, 0, 0]], 
       RowBox[{
        StyleBox["n",
         FontColor->RGBColor[1, 0, 0]], 
        StyleBox[" ",
         FontColor->RGBColor[1, 0, 0]], 
        FractionBox[
         RowBox[{"2", " ", "\[Pi]"}], "L"]}], 
       StyleBox["]",
        FontColor->RGBColor[1, 0, 0]]}]}]}],
    FontColor->GrayLevel[0]], TraditionalForm]],
  FontColor->RGBColor[1, 0, 0]],
 "  \n\nLet us calculate the coefficients ",
 Cell[BoxData[
  FormBox[
   StyleBox[
    SubscriptBox["c", "n"],
    FontColor->GrayLevel[0]], TraditionalForm]],
  FontColor->RGBColor[1, 0, 0]],
 " of the Fourier expansion related to the U-shaped electronic density.\n\n\
The \[Chi] confirms the data in Part I and Part II."
}], "Text",
 CellChangeTimes->{
  3.5532355989375*^9, {3.553258656921875*^9, 3.5532587594375*^9}, {
   3.553258796640625*^9, 3.55325884934375*^9}, {3.553763675668995*^9, 
   3.553763676089476*^9}, {3.5537719682980347`*^9, 3.553771985673956*^9}, {
   3.553772034435471*^9, 3.553772035687415*^9}, {3.5537720661717978`*^9, 
   3.55377212627013*^9}, {3.553772343671762*^9, 3.553772359107634*^9}, {
   3.553828318948316*^9, 3.553828381540613*^9}, {3.5538284330237093`*^9, 
   3.5538284334058247`*^9}, {3.5538284636143093`*^9, 
   3.5538284752584143`*^9}, {3.553828520391618*^9, 3.553828540643159*^9}, {
   3.575108128855081*^9, 3.575108141104501*^9}, {3.575108322993868*^9, 
   3.575108323487466*^9}, 3.575256113873596*^9, {3.5752594110741854`*^9, 
   3.575259474198796*^9}},
 FontFamily->"Times New Roman",
 FontSize->24,
 Background->GrayLevel[0.85]]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"\[Rho]pcoef", "[", "m_", "]"}], "=", 
  RowBox[{"Simplify", "[", 
   RowBox[{
    FractionBox["1", 
     RowBox[{"(", 
      SubscriptBox["a", "0"], ")"}]], " ", 
    RowBox[{"Integrate", "[", 
     RowBox[{
      RowBox[{
       RowBox[{"\[Rho]p2", "[", "x", "]"}], 
       RowBox[{"Exp", "[", 
        RowBox[{
         RowBox[{"-", "\[ImaginaryI]"}], " ", 
         FractionBox[
          RowBox[{"2", " ", "\[Pi]"}], 
          SubscriptBox["a", "0"]], " ", "m", " ", "x"}], "]"}]}], " ", ",", 
      RowBox[{"{", 
       RowBox[{"x", ",", "0", ",", 
        SubscriptBox["a", "0"]}], "}"}]}], "]"}]}], "]"}]}]], "Input",
 CellChangeTimes->{{3.4977845411875*^9, 3.49778455453125*^9}, 
   3.49778590590625*^9, {3.49787031784375*^9, 3.49787032003125*^9}, {
   3.497871937328125*^9, 3.4978719393125*^9}, {3.497877034265625*^9, 
   3.497877045921875*^9}, {3.4978777676875*^9, 3.497877771515625*^9}, {
   3.497956136140625*^9, 3.497956143921875*^9}, 3.497962101890625*^9, {
   3.4979646226875*^9, 3.4979646295*^9}, {3.49796525903125*^9, 
   3.49796526528125*^9}, {3.49804413359375*^9, 3.498044188484375*^9}, {
   3.49804668990625*^9, 3.49804668990625*^9}, {3.498047568421875*^9, 
   3.49804757196875*^9}, {3.551583107481226*^9, 3.551583152279571*^9}, {
   3.551768201703125*^9, 3.55176820990625*^9}, {3.552045533390625*^9, 
   3.55204553815625*^9}, {3.552474224421875*^9, 3.552474229578125*^9}, 
   3.553257495609375*^9},
 FontSize->18],

Cell[BoxData[
 FractionBox[
  RowBox[{"22937600000000000", " ", "\[ImaginaryI]", " ", 
   SuperscriptBox["\[ExponentialE]", 
    RowBox[{
     RowBox[{"-", "2"}], " ", "\[ImaginaryI]", " ", "m", " ", "\[Pi]"}]], " ", 
   RowBox[{"(", 
    RowBox[{
     RowBox[{"-", "1"}], "+", 
     SuperscriptBox["\[ExponentialE]", 
      FractionBox[
       RowBox[{"\[ImaginaryI]", " ", "m", " ", "\[Pi]"}], "2"]]}], ")"}], " ", 
   RowBox[{"(", 
    RowBox[{"1", "+", 
     SuperscriptBox["\[ExponentialE]", 
      FractionBox[
       RowBox[{"3", " ", "\[ImaginaryI]", " ", "m", " ", "\[Pi]"}], "2"]]}], 
    ")"}]}], 
  RowBox[{"3", " ", "m", " ", 
   RowBox[{"(", 
    RowBox[{
     RowBox[{"-", "144"}], "+", 
     SuperscriptBox["m", "2"]}], ")"}], " ", 
   RowBox[{"(", 
    RowBox[{
     RowBox[{"-", "64"}], "+", 
     SuperscriptBox["m", "2"]}], ")"}], " ", 
   RowBox[{"(", 
    RowBox[{
     RowBox[{"-", "16"}], "+", 
     SuperscriptBox["m", "2"]}], ")"}], " ", "\[Pi]"}]]], "Output",
 CellChangeTimes->{3.5776833316521263`*^9}]
}, Open  ]],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"ntermx1", "=", " ", "50"}], ";"}], "   "}]], "Input",
 CellChangeTimes->{{3.428805952859375*^9, 3.428805953796875*^9}, 
   3.497790041265625*^9, {3.497872552578125*^9, 3.49787255678125*^9}, {
   3.497878751484375*^9, 3.497878752171875*^9}, {3.497958456328125*^9, 
   3.497958459125*^9}, {3.49795850165625*^9, 3.497958509921875*^9}, 
   3.497958636109375*^9, {3.551583386908333*^9, 3.5515834150336246`*^9}, {
   3.5517689236875*^9, 3.55176892559375*^9}, {3.55325539653125*^9, 
   3.55325539765625*^9}, {3.55325774984375*^9, 3.553257750859375*^9}, 
   3.55325779746875*^9},
 FontSize->24],

Cell[BoxData[
 RowBox[{"Do", "[", 
  RowBox[{
   RowBox[{
    RowBox[{"limit\[Rho]pcoef", "[", "kk", "]"}], "=", 
    RowBox[{"Limit", "[", 
     RowBox[{
      RowBox[{"\[Rho]pcoef", "[", "m", "]"}], ",", 
      RowBox[{"m", "\[Rule]", "kk"}], ",", 
      RowBox[{"Direction", "\[Rule]", 
       RowBox[{"-", "1"}]}]}], "]"}]}], ",", 
   RowBox[{"{", 
    RowBox[{"kk", ",", 
     RowBox[{"-", "ntermx1"}], ",", "ntermx1"}], "}"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.497785910640625*^9, 3.497785911875*^9}, {
   3.497789488453125*^9, 3.497789495515625*^9}, 3.497851175*^9, {
   3.497872168921875*^9, 3.497872200640625*^9}, {3.4978725600625*^9, 
   3.497872563453125*^9}, {3.49787259540625*^9, 3.4978725961875*^9}, {
   3.497964689515625*^9, 3.497964692046875*^9}, {3.49804422484375*^9, 
   3.498044239484375*^9}, {3.498046689921875*^9, 3.498046689921875*^9}, {
   3.4980475730625*^9, 3.49804757359375*^9}, {3.552474388265625*^9, 
   3.552474411078125*^9}},
 FontSize->24],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Do", "[", 
  RowBox[{
   RowBox[{"Print", "[", 
    RowBox[{"{", 
     RowBox[{"kk", ",", 
      RowBox[{"Chop", "[", 
       RowBox[{
        SubscriptBox["a", "0"], "*", 
        RowBox[{"N", "[", 
         RowBox[{"limit\[Rho]pcoef", "[", "kk", "]"}], "]"}]}], "]"}]}], 
     "}"}], "]"}], ",", 
   RowBox[{"{", 
    RowBox[{"kk", ",", 
     RowBox[{"-", "ntermx1"}], ",", "ntermx1"}], "}"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.428807411671875*^9, 3.428807420390625*^9}, {
   3.4977715176875*^9, 3.497771518328125*^9}, {3.497772150734375*^9, 
   3.49777215484375*^9}, {3.49778591253125*^9, 3.497785913640625*^9}, {
   3.4977895053125*^9, 3.4977895100625*^9}, {3.49787220571875*^9, 
   3.497872209109375*^9}, {3.497872565984375*^9, 3.497872569609375*^9}, {
   3.49796469515625*^9, 3.49796469790625*^9}, {3.498044251625*^9, 
   3.498044256359375*^9}, {3.498046689921875*^9, 3.498046689921875*^9}, {
   3.49804757421875*^9, 3.498047574796875*^9}, 3.5517689348125*^9, {
   3.552047635109375*^9, 3.55204765134375*^9}, {3.55247445515625*^9, 
   3.5524744585*^9}, {3.552474504609375*^9, 3.55247452640625*^9}, {
   3.553766620345311*^9, 3.553766621600258*^9}},
 FontSize->24],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"-", "50"}], ",", "0"}], "}"}]], "Print",
 CellChangeTimes->{3.577683335797913*^9}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"-", "49"}], ",", 
   RowBox[{"-", "4.26408514599033`*^-6"}]}], "}"}]], "Print",
 CellChangeTimes->{3.5776833359358273`*^9}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"-", "48"}], ",", "0"}], "}"}]], "Print",
 CellChangeTimes->{3.577683335949469*^9}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"-", "47"}], ",", "5.757272171179573`*^-6"}], "}"}]], "Print",
 CellChangeTimes->{3.5776833359513206`*^9}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"-", "46"}], ",", "0"}], "}"}]], "Print",
 CellChangeTimes->{3.577683335953494*^9}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"-", "45"}], ",", 
   RowBox[{"-", "7.882096785012427`*^-6"}]}], "}"}]], "Print",
 CellChangeTimes->{3.577683335955056*^9}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"-", "44"}], ",", "0"}], "}"}]], "Print",
 CellChangeTimes->{3.577683335957286*^9}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"-", "43"}], ",", "0.000010957388970954672`"}], "}"}]], "Print",
 CellChangeTimes->{3.577683335958893*^9}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"-", "42"}], ",", "0"}], "}"}]], "Print",
 CellChangeTimes->{3.5776833359609423`*^9}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"-", "41"}], ",", 
   RowBox[{"-", "0.00001549239712916236`"}]}], "}"}]], "Print",
 CellChangeTimes->{3.5776833359625196`*^9}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"-", "40"}], ",", "0"}], "}"}]], "Print",
 CellChangeTimes->{3.577683335964549*^9}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"-", "39"}], ",", "0.000022320607163055814`"}], "}"}]], "Print",
 CellChangeTimes->{3.5776833359660053`*^9}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"-", "38"}], ",", "0"}], "}"}]], "Print",
 CellChangeTimes->{3.5776833359680357`*^9}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"-", "37"}], ",", 
   RowBox[{"-", "0.0000328438819138242`"}]}], "}"}]], "Print",
 CellChangeTimes->{3.5776833359696407`*^9}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"-", "36"}], ",", "0"}], "}"}]], "Print",
 CellChangeTimes->{3.577683335971738*^9}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"-", "35"}], ",", "0.00004949352023112376`"}], "}"}]], "Print",
 CellChangeTimes->{3.577683335973338*^9}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"-", "34"}], ",", "0"}], "}"}]], "Print",
 CellChangeTimes->{3.5776833359754066`*^9}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"-", "33"}], ",", 
   RowBox[{"-", "0.00007663572446558979`"}]}], "}"}]], "Print",
 CellChangeTimes->{3.577683335977302*^9}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"-", "32"}], ",", "0"}], "}"}]], "Print",
 CellChangeTimes->{3.577683335979398*^9}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"-", "31"}], ",", "0.00012243133951909564`"}], "}"}]], "Print",
 CellChangeTimes->{3.577683335980961*^9}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"-", "30"}], ",", "0"}], "}"}]], "Print",
 CellChangeTimes->{3.5776833359829483`*^9}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"-", "29"}], ",", 
   RowBox[{"-", "0.00020285927064420833`"}]}], "}"}]], "Print",
 CellChangeTimes->{3.5776833359845257`*^9}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"-", "28"}], ",", "0"}], "}"}]], "Print",
 CellChangeTimes->{3.577683335986603*^9}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"-", "27"}], ",", "0.00035096983995474076`"}], "}"}]], "Print",
 CellChangeTimes->{3.577683335988199*^9}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"-", "26"}], ",", "0"}], "}"}]], "Print",
 CellChangeTimes->{3.5776833359901037`*^9}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"-", "25"}], ",", 
   RowBox[{"-", "0.0006397869304932722`"}]}], "}"}]], "Print",
 CellChangeTimes->{3.57768333599163*^9}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"-", "24"}], ",", "0"}], "}"}]], "Print",
 CellChangeTimes->{3.577683335993669*^9}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"-", "23"}], ",", "0.00124434761438499`"}], "}"}]], "Print",
 CellChangeTimes->{3.5776833359955273`*^9}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"-", "22"}], ",", "0"}], "}"}]], "Print",
 CellChangeTimes->{3.577683335997542*^9}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"-", "21"}], ",", 
   RowBox[{"-", "0.002630235158694564`"}]}], "}"}]], "Print",
 CellChangeTimes->{3.5776833359990997`*^9}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"-", "20"}], ",", "0"}], "}"}]], "Print",
 CellChangeTimes->{3.577683336001107*^9}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"-", "19"}], ",", "0.00622173807192495`"}], "}"}]], "Print",
 CellChangeTimes->{3.5776833360943413`*^9}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"-", "18"}], ",", "0"}], "}"}]], "Print",
 CellChangeTimes->{3.5776833360964413`*^9}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"-", "17"}], ",", 
   RowBox[{"-", "0.01735955204738412`"}]}], "}"}]], "Print",
 CellChangeTimes->{3.577683336098784*^9}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"-", "16"}], ",", "0"}], "}"}]], "Print",
 CellChangeTimes->{3.577683336101758*^9}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"-", "15"}], ",", "0.06429129340989115`"}], "}"}]], "Print",
 CellChangeTimes->{3.577683336104051*^9}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"-", "14"}], ",", "0"}], "}"}]], "Print",
 CellChangeTimes->{3.577683336106957*^9}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"-", "13"}], ",", 
   RowBox[{"-", "0.5034270093741395`"}]}], "}"}]], "Print",
 CellChangeTimes->{3.577683336109209*^9}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"-", "12"}], ",", 
   RowBox[{"-", "1.4000000000000001`"}]}], "}"}]], "Print",
 CellChangeTimes->{3.5776833361121073`*^9}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"-", "11"}], ",", 
   RowBox[{"-", "1.7358649220670612`"}]}], "}"}]], "Print",
 CellChangeTimes->{3.57768333611467*^9}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"-", "10"}], ",", "0"}], "}"}]], "Print",
 CellChangeTimes->{3.577683336117547*^9}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"-", "9"}], ",", "4.195225078117829`"}], "}"}]], "Print",
 CellChangeTimes->{3.577683336119787*^9}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"-", "8"}], ",", "8.4`"}], "}"}]], "Print",
 CellChangeTimes->{3.577683336122484*^9}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"-", "7"}], ",", "7.98497864150848`"}], "}"}]], "Print",
 CellChangeTimes->{3.577683336124858*^9}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"-", "6"}], ",", "0"}], "}"}]], "Print",
 CellChangeTimes->{3.577683336127543*^9}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"-", "5"}], ",", 
   RowBox[{"-", "12.58567523435349`"}]}], "}"}]], "Print",
 CellChangeTimes->{3.577683336129759*^9}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"-", "4"}], ",", 
   RowBox[{"-", "20.999999999999996`"}]}], "}"}]], "Print",
 CellChangeTimes->{3.577683336132565*^9}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"-", "3"}], ",", 
   RowBox[{"-", "16.85717713207346`"}]}], "}"}]], "Print",
 CellChangeTimes->{3.577683336134988*^9}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"-", "2"}], ",", "0"}], "}"}]], "Print",
 CellChangeTimes->{3.577683336137714*^9}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"-", "1"}], ",", "19.4505889985463`"}], "}"}]], "Print",
 CellChangeTimes->{3.577683336139956*^9}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"0", ",", "28.`"}], "}"}]], "Print",
 CellChangeTimes->{3.577683336142695*^9}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"1", ",", "19.4505889985463`"}], "}"}]], "Print",
 CellChangeTimes->{3.577683336145015*^9}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"2", ",", "0"}], "}"}]], "Print",
 CellChangeTimes->{3.577683336146796*^9}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"3", ",", 
   RowBox[{"-", "16.85717713207346`"}]}], "}"}]], "Print",
 CellChangeTimes->{3.577683336148321*^9}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"4", ",", 
   RowBox[{"-", "20.999999999999996`"}]}], "}"}]], "Print",
 CellChangeTimes->{3.577683336150095*^9}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"5", ",", 
   RowBox[{"-", "12.58567523435349`"}]}], "}"}]], "Print",
 CellChangeTimes->{3.5776833361518717`*^9}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"6", ",", "0"}], "}"}]], "Print",
 CellChangeTimes->{3.577683336153636*^9}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"7", ",", "7.98497864150848`"}], "}"}]], "Print",
 CellChangeTimes->{3.577683336154997*^9}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"8", ",", "8.4`"}], "}"}]], "Print",
 CellChangeTimes->{3.577683336157322*^9}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"9", ",", "4.195225078117829`"}], "}"}]], "Print",
 CellChangeTimes->{3.57768333615897*^9}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"10", ",", "0"}], "}"}]], "Print",
 CellChangeTimes->{3.5776833361608*^9}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"11", ",", 
   RowBox[{"-", "1.7358649220670612`"}]}], "}"}]], "Print",
 CellChangeTimes->{3.577683336162347*^9}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"12", ",", 
   RowBox[{"-", "1.4000000000000001`"}]}], "}"}]], "Print",
 CellChangeTimes->{3.577683336164172*^9}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"13", ",", 
   RowBox[{"-", "0.5034270093741395`"}]}], "}"}]], "Print",
 CellChangeTimes->{3.577683336165812*^9}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"14", ",", "0"}], "}"}]], "Print",
 CellChangeTimes->{3.577683336167762*^9}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"15", ",", "0.06429129340989115`"}], "}"}]], "Print",
 CellChangeTimes->{3.577683336169271*^9}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"16", ",", "0"}], "}"}]], "Print",
 CellChangeTimes->{3.577683336171129*^9}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"17", ",", 
   RowBox[{"-", "0.01735955204738412`"}]}], "}"}]], "Print",
 CellChangeTimes->{3.577683336172676*^9}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"18", ",", "0"}], "}"}]], "Print",
 CellChangeTimes->{3.5776833361745358`*^9}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"19", ",", "0.00622173807192495`"}], "}"}]], "Print",
 CellChangeTimes->{3.5776833361759853`*^9}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"20", ",", "0"}], "}"}]], "Print",
 CellChangeTimes->{3.577683336177862*^9}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"21", ",", 
   RowBox[{"-", "0.002630235158694564`"}]}], "}"}]], "Print",
 CellChangeTimes->{3.57768333617941*^9}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"22", ",", "0"}], "}"}]], "Print",
 CellChangeTimes->{3.577683336181396*^9}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"23", ",", "0.00124434761438499`"}], "}"}]], "Print",
 CellChangeTimes->{3.57768333618289*^9}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"24", ",", "0"}], "}"}]], "Print",
 CellChangeTimes->{3.577683336184825*^9}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"25", ",", 
   RowBox[{"-", "0.0006397869304932722`"}]}], "}"}]], "Print",
 CellChangeTimes->{3.57768333618641*^9}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"26", ",", "0"}], "}"}]], "Print",
 CellChangeTimes->{3.5776833361888943`*^9}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"27", ",", "0.00035096983995474076`"}], "}"}]], "Print",
 CellChangeTimes->{3.577683336190421*^9}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"28", ",", "0"}], "}"}]], "Print",
 CellChangeTimes->{3.577683336192264*^9}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"29", ",", 
   RowBox[{"-", "0.00020285927064420833`"}]}], "}"}]], "Print",
 CellChangeTimes->{3.5776833361937532`*^9}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"30", ",", "0"}], "}"}]], "Print",
 CellChangeTimes->{3.577683336195709*^9}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"31", ",", "0.00012243133951909564`"}], "}"}]], "Print",
 CellChangeTimes->{3.577683336197299*^9}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"32", ",", "0"}], "}"}]], "Print",
 CellChangeTimes->{3.577683336199294*^9}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"33", ",", 
   RowBox[{"-", "0.00007663572446558979`"}]}], "}"}]], "Print",
 CellChangeTimes->{3.577683336200899*^9}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"34", ",", "0"}], "}"}]], "Print",
 CellChangeTimes->{3.577683336202977*^9}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"35", ",", "0.00004949352023112376`"}], "}"}]], "Print",
 CellChangeTimes->{3.577683336204588*^9}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"36", ",", "0"}], "}"}]], "Print",
 CellChangeTimes->{3.577683336206657*^9}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"37", ",", 
   RowBox[{"-", "0.0000328438819138242`"}]}], "}"}]], "Print",
 CellChangeTimes->{3.5776833362081413`*^9}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"38", ",", "0"}], "}"}]], "Print",
 CellChangeTimes->{3.5776833362102337`*^9}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"39", ",", "0.000022320607163055814`"}], "}"}]], "Print",
 CellChangeTimes->{3.577683336211788*^9}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"40", ",", "0"}], "}"}]], "Print",
 CellChangeTimes->{3.577683336213847*^9}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"41", ",", 
   RowBox[{"-", "0.00001549239712916236`"}]}], "}"}]], "Print",
 CellChangeTimes->{3.577683336215406*^9}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"42", ",", "0"}], "}"}]], "Print",
 CellChangeTimes->{3.577683336217497*^9}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"43", ",", "0.000010957388970954672`"}], "}"}]], "Print",
 CellChangeTimes->{3.577683336219067*^9}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"44", ",", "0"}], "}"}]], "Print",
 CellChangeTimes->{3.577683336221025*^9}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"45", ",", 
   RowBox[{"-", "7.882096785012427`*^-6"}]}], "}"}]], "Print",
 CellChangeTimes->{3.577683336222609*^9}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"46", ",", "0"}], "}"}]], "Print",
 CellChangeTimes->{3.577683336224703*^9}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"47", ",", "5.757272171179573`*^-6"}], "}"}]], "Print",
 CellChangeTimes->{3.577683336226252*^9}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"48", ",", "0"}], "}"}]], "Print",
 CellChangeTimes->{3.577683336228394*^9}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"49", ",", 
   RowBox[{"-", "4.26408514599033`*^-6"}]}], "}"}]], "Print",
 CellChangeTimes->{3.5776833362299843`*^9}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"50", ",", "0"}], "}"}]], "Print",
 CellChangeTimes->{3.577683336232202*^9}]
}, Open  ]],

Cell["\<\
Let\[CloseCurlyQuote]s plot the Fourier Coefficients...\
\>", "Text",
 CellChangeTimes->{{3.551584959555848*^9, 3.551584970267025*^9}, 
   3.551768680171875*^9, {3.55176900090625*^9, 3.551769002203125*^9}, 
   3.55204570290625*^9, 3.552047902484375*^9, 3.5524748724375*^9, {
   3.553255498140625*^9, 3.55325550059375*^9}, {3.55325785421875*^9, 
   3.553257864*^9}, 3.553784851824059*^9, {3.5752594860794754`*^9, 
   3.5752594913267756`*^9}},
 FontSize->24,
 Background->GrayLevel[0.85]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"DiscretePlot", "[", 
  RowBox[{
   RowBox[{
    SubscriptBox["a", "0"], "*", 
    RowBox[{"limit\[Rho]pcoef", "[", "m", "]"}]}], ",", 
   RowBox[{"{", 
    RowBox[{"m", ",", 
     RowBox[{"-", "ntermx1"}], ",", "ntermx1", ",", "1"}], "}"}], ",", 
   RowBox[{"PlotRange", "\[Rule]", "All"}], ",", "\[IndentingNewLine]", 
   RowBox[{"PlotStyle", "\[Rule]", 
    RowBox[{"PointSize", "[", "0.01", "]"}]}], ",", 
   RowBox[{"PlotLabel", "\[Rule]", " ", "\"\<coefficienti di Fourier\>\""}]}],
   "]"}]], "Input",
 CellChangeTimes->{{3.498830789328125*^9, 3.49883081171875*^9}, {
   3.498830863421875*^9, 3.498830871296875*^9}, {3.498830911046875*^9, 
   3.49883093903125*^9}, {3.498830978640625*^9, 3.4988309796875*^9}, {
   3.552474482609375*^9, 3.552474486875*^9}, {3.553255455046875*^9, 
   3.55325546090625*^9}, {3.5532565415625*^9, 3.553256545234375*^9}, {
   3.5537722689765863`*^9, 3.553772271248589*^9}, {3.5537723031707993`*^9, 
   3.553772303574485*^9}, 3.553828511859182*^9},
 FontSize->18],

Cell[BoxData[
 GraphicsBox[{
   {RGBColor[0.24720000000000014`, 0.24, 0.6], PointSize[0.01], {
     {RGBColor[0.24720000000000014`, 0.24, 0.6], PointSize[0.01], Opacity[
      0.2], LineBox[{{{-50., 
         0.}, {-50., 0}}, {{-49., -4.26408514599033*^-6}, {-49., 0}}, {{-48., 
         0.}, {-48., 0}}, {{-46., 
         0.}, {-46., 0}}, {{-45., -7.882096785012428*^-6}, {-45., 0}}, {{-44.,
          0.}, {-44., 0}}, {{-42., 
         0.}, {-42., 0}}, {{-41., -0.000015492397129162356`}, {-41., 
          0}}, {{-40., 0.}, {-40., 0}}, {{-38., 
         0.}, {-38., 0}}, {{-37., -0.0000328438819138242}, {-37., 0}}, {{-36.,
          0.}, {-36., 0}}, {{-34., 
         0.}, {-34., 0}}, {{-33., -0.0000766357244655898}, {-33., 0}}, {{-32.,
          0.}, {-32., 0}}, {{-30., 
         0.}, {-30., 0}}, {{-29., -0.00020285927064420827`}, {-29., 
          0}}, {{-28., 0.}, {-28., 0}}, {{-26., 
         0.}, {-26., 0}}, {{-25., -0.0006397869304932723}, {-25., 0}}, {{-24.,
          0.}, {-24., 0}}, {{-22., 
         0.}, {-22., 0}}, {{-21., -0.002630235158694564}, {-21., 0}}, {{-20., 
         0.}, {-20., 0}}, {{-18., 
         0.}, {-18., 0}}, {{-17., -0.01735955204738412}, {-17., 0}}, {{-16., 
         0.}, {-16., 0}}, {{-14., 
         0.}, {-14., 0}}, {{-13., -0.5034270093741395}, {-13., 
          0}}, {{-12., -1.4}, {-12., 
          0}}, {{-11., -1.7358649220670612`}, {-11., 0}}, {{-10., 
         0.}, {-10., 0}}, {{-6., 
         0.}, {-6., 0}}, {{-5., -12.585675234353488`}, {-5., 
          0}}, {{-4., -21.}, {-4., 0}}, {{-3., -16.85717713207346}, {-3., 
          0}}, {{-2., 0.}, {-2., 0}}, {{2., 0.}, {2., 0}}, {{
         3., -16.85717713207346}, {3., 0}}, {{4., -21.}, {4., 0}}, {{
         5., -12.585675234353488`}, {5., 0}}, {{6., 0.}, {6., 0}}, {{10., 
         0.}, {10., 0}}, {{11., -1.7358649220670612`}, {11., 0}}, {{
         12., -1.4}, {12., 0}}, {{13., -0.5034270093741395}, {13., 0}}, {{14.,
          0.}, {14., 0}}, {{16., 0.}, {16., 0}}, {{
         17., -0.01735955204738412}, {17., 0}}, {{18., 0.}, {18., 0}}, {{20., 
         0.}, {20., 0}}, {{21., -0.002630235158694564}, {21., 0}}, {{22., 
         0.}, {22., 0}}, {{24., 0.}, {24., 0}}, {{
         25., -0.0006397869304932723}, {25., 0}}, {{26., 0.}, {26., 0}}, {{
         28., 0.}, {28., 0}}, {{29., -0.00020285927064420827`}, {29., 0}}, {{
         30., 0.}, {30., 0}}, {{32., 0.}, {32., 0}}, {{
         33., -0.0000766357244655898}, {33., 0}}, {{34., 0.}, {34., 0}}, {{
         36., 0.}, {36., 0}}, {{37., -0.0000328438819138242}, {37., 0}}, {{
         38., 0.}, {38., 0}}, {{40., 0.}, {40., 0}}, {{
         41., -0.000015492397129162356`}, {41., 0}}, {{42., 0.}, {42., 0}}, {{
         44., 0.}, {44., 0}}, {{45., -7.882096785012428*^-6}, {45., 0}}, {{
         46., 0.}, {46., 0}}, {{48., 0.}, {48., 0}}, {{
         49., -4.26408514599033*^-6}, {49., 0}}, {{50., 0.}, {50., 0}}},
       VertexColors->None]}, 
     {RGBColor[0.24720000000000014`, 0.24, 0.6], PointSize[0.01], Opacity[
      0.2], LineBox[{{{-47., 5.757272171179573*^-6}, {-47., 0}}, {{-43., 
         0.000010957388970954672`}, {-43., 0}}, {{-39., 
         0.000022320607163055814`}, {-39., 0}}, {{-35., 
         0.00004949352023112376}, {-35., 0}}, {{-31., 
         0.0001224313395190956}, {-31., 0}}, {{-27., 
         0.00035096983995474076`}, {-27., 0}}, {{-23., 
         0.0012443476143849902`}, {-23., 0}}, {{-19., 
         0.00622173807192495}, {-19., 0}}, {{-15., 
         0.06429129340989115}, {-15., 0}}, {{-9., 
         4.195225078117829}, {-9., 0}}, {{-8., 8.4}, {-8., 0}}, {{-7., 
         7.984978641508481}, {-7., 0}}, {{-1., 
         19.4505889985463}, {-1., 0}}, {{0., 28.}, {0., 0}}, {{1., 
         19.4505889985463}, {1., 0}}, {{7., 7.984978641508481}, {7., 0}}, {{
         8., 8.4}, {8., 0}}, {{9., 4.195225078117829}, {9., 0}}, {{15., 
         0.06429129340989115}, {15., 0}}, {{19., 0.00622173807192495}, {
         19., 0}}, {{23., 0.0012443476143849902`}, {23., 0}}, {{27., 
         0.00035096983995474076`}, {27., 0}}, {{31., 0.0001224313395190956}, {
         31., 0}}, {{35., 0.00004949352023112376}, {35., 0}}, {{39., 
         0.000022320607163055814`}, {39., 0}}, {{43., 
         0.000010957388970954672`}, {43., 0}}, {{47., 
         5.757272171179573*^-6}, {47., 0}}},
       VertexColors->None]}}}, 
   {RGBColor[0.24720000000000014`, 0.24, 0.6], PointSize[0.01], {}, 
    PointBox[CompressedData["
1:eJxdlUtoE2EQx1cPGsFDiFGDRBtDDTXGkiZNkzavyTulF7F68KrGXEqLqIh4
CQj14qWIIlLswXgQKcQXeGoGDxUkIjUgghSKolYrbVD7QD1ozbQ4/w+Wj5nf
/nb3e83uPT50uLDRMIzC32u1b7ZeNv5vpTxfCj+vDb+bmmgm8sBzPH/w6tdX
+97Emokc8CyXn7Y4712eET8LPMPmneOWRz8/ip8Bnua7KyMDj2MN8dPAUzwe
en26XFwWPwU8yZ/iw95waEO1mUgCT/Ahy/fi7Lct8WYiAZz4/djok4UdVvFJ
cyPOg9de+nZvdYgfAx7lTVGerl93ix8BHmYqbv7dZwTF7wHezXu8lZW5pbT4
IeBBHpzgbZ4TR8TvAh7g8O0bVeNKQfxO4H42zVdsyxcviO8D3sHn+9NTDydH
xPcCb2fzwuiXk+cq4nuAu7k8d2fRYp8Rv41P/WtLErt4oD7bt2vyl8St4DvZ
UQpu//zMTM3YwS9qq80hsZ2Puh5EbzVaJLaBb2Uv1cemD+yXvFn6gPQmPuv8
sDj0dn1c4DeqN+//qB074yedj0jciAOH+0ykn782jrX3W0l/nw18O+nxOUiP
30l6flrBd5Ge3zbS8+8mvT4e8NtJr68XeAfp/eED7ie9vzqBB0jvzy7gQdL7
OwS8m/T56AEeJn2+IsCjpM9nDHic9PkmzUtEuj4kgCdI15ck8CTp+pQCniJd
39LA06TrYwZ4hnR9zQLPkq7POeA50vU9DzxP+v/Qu87/AMMONN4=
     "]], {}}},
  AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
  Axes->True,
  AxesOrigin->{0, 0},
  AxesStyle->Directive[20, 
    Thickness[0.005], 
    RGBColor[0, 0, 1]],
  ImageSize->700,
  LabelStyle->(FontFamily -> "Helvetica"),
  Method->{"MessagesHead" -> DiscretePlot},
  PlotLabel->FormBox["\"coefficienti di Fourier\"", TraditionalForm],
  PlotRange->{{-50., 50.}, {-21., 28.}},
  PlotRangePadding->{{
     Scaled[0.02], 
     Scaled[0.02]}, {
     Scaled[0.02], 
     Scaled[0.02]}}]], "Output",
 CellChangeTimes->{
  3.577683336386874*^9},ImageCache->GraphicsData["CompressedBitmap", "\<\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\
\>"]]
}, Open  ]],

Cell[BoxData[
 RowBox[{
  RowBox[{"twoatomsreconstructed", "[", 
   RowBox[{"x_", ",", "ntermx_"}], "]"}], ":=", "\[IndentingNewLine]", 
  RowBox[{"Sum", "[", 
   RowBox[{
    RowBox[{
     RowBox[{"N", "[", 
      RowBox[{"limit\[Rho]pcoef", "[", "m", "]"}], "]"}], 
     RowBox[{"Exp", "[", 
      RowBox[{"\[ImaginaryI]", " ", 
       FractionBox[
        RowBox[{"2", " ", "\[Pi]"}], 
        SubscriptBox["a", "0"]], " ", "m", " ", "x"}], "]"}]}], ",", 
    RowBox[{"{", 
     RowBox[{"m", ",", 
      RowBox[{"-", "ntermx"}], ",", "ntermx", ",", "1"}], "}"}]}], 
   "]"}]}]], "Input",
 CellChangeTimes->{{3.4977846765625*^9, 3.49778468925*^9}, 
   3.49778591696875*^9, {3.497790098984375*^9, 3.497790107625*^9}, 
   3.497851247328125*^9, {3.4978722359375*^9, 3.497872243625*^9}, 
   3.497877119921875*^9, {3.497956206296875*^9, 3.497956230015625*^9}, {
   3.497964733078125*^9, 3.497964746265625*^9}, {3.49804435278125*^9, 
   3.498044379703125*^9}, {3.4980466899375*^9, 3.4980466899375*^9}, {
   3.498047581515625*^9, 3.498047582359375*^9}, {3.55158393296852*^9, 
   3.5515839339627743`*^9}, 3.551768633875*^9, {3.55247460209375*^9, 
   3.552474606171875*^9}, {3.552474841828125*^9, 3.5524748549375*^9}},
 FontSize->24],

Cell["twoatomsreconstructed[x, 50]", "Text",
 CellChangeTimes->{{3.551584959555848*^9, 3.551584970267025*^9}, 
   3.551768680171875*^9, {3.55176900090625*^9, 3.551769002203125*^9}, 
   3.55204570290625*^9, 3.552047902484375*^9, 3.5524748724375*^9, {
   3.553255498140625*^9, 3.55325550059375*^9}, {3.55325785421875*^9, 
   3.553257864*^9}, 3.553784851824059*^9},
 FontSize->24,
 Background->GrayLevel[0.85]],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"ntermx1", "=", "50"}], ";"}], "   "}]], "Input",
 CellChangeTimes->{{3.428805952859375*^9, 3.428805953796875*^9}, 
   3.497790041265625*^9, {3.497871850125*^9, 3.49787186378125*^9}, {
   3.551583906613091*^9, 3.551583907878812*^9}, {3.5515849098069477`*^9, 
   3.551584914468207*^9}, {3.55176901425*^9, 3.551769015296875*^9}, {
   3.553255509125*^9, 3.553255509921875*^9}, {3.55325788025*^9, 
   3.553257881234375*^9}, 3.5753474990973797`*^9},
 FontSize->24],

Cell["Now only Cos-terms appear....", "Text",
 CellChangeTimes->{{3.55210326834375*^9, 3.55210329003125*^9}, {
  3.5752593537679076`*^9, 3.5752593613583417`*^9}},
 FontFamily->"Times New Roman",
 FontSize->24,
 Background->GrayLevel[0.85]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"twoatomsevenfunction", "=", 
  RowBox[{"Simplify", "[", 
   RowBox[{"ExpToTrig", "[", 
    RowBox[{"twoatomsreconstructed", "[", 
     RowBox[{"x", ",", "ntermx1"}], "]"}], "]"}], "]"}]}]], "Input",
 CellChangeTimes->{{3.49787224809375*^9, 3.497872253078125*^9}, 
   3.49796475559375*^9, {3.49804440078125*^9, 3.498044411578125*^9}, {
   3.4980466899375*^9, 3.4980466899375*^9}, 3.498047585875*^9, {
   3.498049256078125*^9, 3.498049260109375*^9}, 3.55176911434375*^9, 
   3.552045717640625*^9, 3.552102932265625*^9, {3.5524746964375*^9, 
   3.552474702203125*^9}, {3.552474888578125*^9, 3.552474914859375*^9}, {
   3.553255109859375*^9, 3.553255161578125*^9}, {3.553255209453125*^9, 
   3.55325521509375*^9}},
 FontSize->24],

Cell[BoxData[
 RowBox[{"5.185185185185185`*^10", "+", 
  RowBox[{"7.203921851313445`*^10", " ", 
   RowBox[{"Cos", "[", 
    FractionBox[
     RowBox[{"100000000000", " ", "\[Pi]", " ", "x"}], "27"], "]"}]}], "-", 
  RowBox[{"6.243398937804985`*^10", " ", 
   RowBox[{"Cos", "[", 
    FractionBox[
     RowBox[{"100000000000", " ", "\[Pi]", " ", "x"}], "9"], "]"}]}], "-", 
  RowBox[{"7.777777777777777`*^10", " ", 
   RowBox[{"Cos", "[", 
    FractionBox[
     RowBox[{"400000000000", " ", "\[Pi]", " ", "x"}], "27"], "]"}]}], "-", 
  RowBox[{"4.6613611979087`*^10", " ", 
   RowBox[{"Cos", "[", 
    FractionBox[
     RowBox[{"500000000000", " ", "\[Pi]", " ", "x"}], "27"], "]"}]}], "+", 
  RowBox[{"2.9573994968549927`*^10", " ", 
   RowBox[{"Cos", "[", 
    FractionBox[
     RowBox[{"700000000000", " ", "\[Pi]", " ", "x"}], "27"], "]"}]}], "+", 
  RowBox[{"3.111111111111111`*^10", " ", 
   RowBox[{"Cos", "[", 
    FractionBox[
     RowBox[{"800000000000", " ", "\[Pi]", " ", "x"}], "27"], "]"}]}], "+", 
  RowBox[{"1.5537870659695665`*^10", " ", 
   RowBox[{"Cos", "[", 
    FractionBox[
     RowBox[{"100000000000", " ", "\[Pi]", " ", "x"}], "3"], "]"}]}], "-", 
  RowBox[{"6.429129340989116`*^9", " ", 
   RowBox[{"Cos", "[", 
    FractionBox[
     RowBox[{"1100000000000", " ", "\[Pi]", " ", "x"}], "27"], "]"}]}], "-", 
  RowBox[{"5.185185185185185`*^9", " ", 
   RowBox[{"Cos", "[", 
    FractionBox[
     RowBox[{"400000000000", " ", "\[Pi]", " ", "x"}], "9"], "]"}]}], "-", 
  RowBox[{"1.8645444791634798`*^9", " ", 
   RowBox[{"Cos", "[", 
    FractionBox[
     RowBox[{"1300000000000", " ", "\[Pi]", " ", "x"}], "27"], "]"}]}], "+", 
  RowBox[{"2.3811590151811537`*^8", " ", 
   RowBox[{"Cos", "[", 
    FractionBox[
     RowBox[{"500000000000", " ", "\[Pi]", " ", "x"}], "9"], "]"}]}], "-", 
  RowBox[{"6.429463721253379`*^7", " ", 
   RowBox[{"Cos", "[", 
    FractionBox[
     RowBox[{"1700000000000", " ", "\[Pi]", " ", "x"}], "27"], "]"}]}], "+", 
  RowBox[{"2.3043474340462778`*^7", " ", 
   RowBox[{"Cos", "[", 
    FractionBox[
     RowBox[{"1900000000000", " ", "\[Pi]", " ", "x"}], "27"], "]"}]}], "-", 
  RowBox[{"9.741611698868755`*^6", " ", 
   RowBox[{"Cos", "[", 
    FractionBox[
     RowBox[{"700000000000", " ", "\[Pi]", " ", "x"}], "9"], "]"}]}], "+", 
  RowBox[{"4.608694868092556`*^6", " ", 
   RowBox[{"Cos", "[", 
    FractionBox[
     RowBox[{"2300000000000", " ", "\[Pi]", " ", "x"}], "27"], "]"}]}], "-", 
  RowBox[{"2.3695812240491565`*^6", " ", 
   RowBox[{"Cos", "[", 
    FractionBox[
     RowBox[{"2500000000000", " ", "\[Pi]", " ", "x"}], "27"], "]"}]}], "+", 
  RowBox[{"1.2998882961286695`*^6", " ", 
   RowBox[{"Cos", "[", 
    RowBox[{"100000000000", " ", "\[Pi]", " ", "x"}], "]"}]}], "-", 
  RowBox[{"751330.6320155864`", " ", 
   RowBox[{"Cos", "[", 
    FractionBox[
     RowBox[{"2900000000000", " ", "\[Pi]", " ", "x"}], "27"], "]"}]}], "+", 
  RowBox[{"453449.4056262801`", " ", 
   RowBox[{"Cos", "[", 
    FractionBox[
     RowBox[{"3100000000000", " ", "\[Pi]", " ", "x"}], "27"], "]"}]}], "-", 
  RowBox[{"283836.01653922145`", " ", 
   RowBox[{"Cos", "[", 
    FractionBox[
     RowBox[{"1100000000000", " ", "\[Pi]", " ", "x"}], "9"], "]"}]}], "+", 
  RowBox[{"183309.33418934725`", " ", 
   RowBox[{"Cos", "[", 
    FractionBox[
     RowBox[{"3500000000000", " ", "\[Pi]", " ", "x"}], "27"], "]"}]}], "-", 
  RowBox[{"121644.00708823778`", " ", 
   RowBox[{"Cos", "[", 
    FractionBox[
     RowBox[{"3700000000000", " ", "\[Pi]", " ", "x"}], "27"], "]"}]}], "+", 
  RowBox[{"82668.91541872524`", " ", 
   RowBox[{"Cos", "[", 
    FractionBox[
     RowBox[{"1300000000000", " ", "\[Pi]", " ", "x"}], "9"], "]"}]}], "-", 
  RowBox[{"57379.24862652726`", " ", 
   RowBox[{"Cos", "[", 
    FractionBox[
     RowBox[{"4100000000000", " ", "\[Pi]", " ", "x"}], "27"], "]"}]}], "+", 
  RowBox[{"40582.922114646935`", " ", 
   RowBox[{"Cos", "[", 
    FractionBox[
     RowBox[{"4300000000000", " ", "\[Pi]", " ", "x"}], "27"], "]"}]}], "-", 
  RowBox[{"29192.95105560158`", " ", 
   RowBox[{"Cos", "[", 
    FractionBox[
     RowBox[{"500000000000", " ", "\[Pi]", " ", "x"}], "3"], "]"}]}], "+", 
  RowBox[{"21323.23026362805`", " ", 
   RowBox[{"Cos", "[", 
    FractionBox[
     RowBox[{"4700000000000", " ", "\[Pi]", " ", "x"}], "27"], "]"}]}], "-", 
  RowBox[{"15792.907948112332`", " ", 
   RowBox[{"Cos", "[", 
    FractionBox[
     RowBox[{"4900000000000", " ", "\[Pi]", " ", "x"}], "27"], 
    "]"}]}]}]], "Output",
 CellChangeTimes->{3.577683336623425*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"graphtwoatoms", "=", 
  RowBox[{"Plot", "[", 
   RowBox[{
    RowBox[{"Vol1D", "*", 
     SubscriptBox["a", "0"], "*", "twoatomsevenfunction"}], ",", 
    RowBox[{"{", 
     RowBox[{"x", ",", "0", ",", 
      RowBox[{
       SubscriptBox["a", "0"], "/", "1"}]}], "}"}], ",", 
    "\[IndentingNewLine]", 
    RowBox[{"PlotRange", "\[Rule]", "All"}], ",", 
    RowBox[{"PlotPoints", "\[Rule]", "500"}], ",", 
    RowBox[{"PlotLabel", "\[Rule]", 
     RowBox[{"{", "\"\<Somma parziale  con 50 termini\>\"", "}"}]}], ",", 
    RowBox[{"PlotStyle", "\[Rule]", 
     RowBox[{"{", 
      RowBox[{"Hue", "[", "0.03", "]"}], "}"}]}]}], "]"}]}]], "Input",
 CellChangeTimes->{{3.4978512726875*^9, 3.497851283875*^9}, 
   3.497872260125*^9, {3.497872310390625*^9, 3.497872334546875*^9}, {
   3.49787712753125*^9, 3.497877130953125*^9}, {3.497877959171875*^9, 
   3.497877961453125*^9}, 3.497956241875*^9, 3.49796475821875*^9, {
   3.4980444443125*^9, 3.49804446215625*^9}, {3.498044733015625*^9, 
   3.49804473346875*^9}, {3.498044781859375*^9, 3.49804479678125*^9}, 
   3.498046689953125*^9, {3.498049228421875*^9, 3.498049232453125*^9}, {
   3.498049267046875*^9, 3.4980492711875*^9}, 3.4980494680625*^9, 
   3.49810709121875*^9, {3.551584005731084*^9, 3.5515840124204206`*^9}, {
   3.55176872721875*^9, 3.551768748625*^9}, {3.551769042859375*^9, 
   3.5517690636875*^9}, 3.551769124734375*^9, {3.55247494009375*^9, 
   3.552474973921875*^9}, {3.55247501121875*^9, 3.55247501428125*^9}, {
   3.553254977875*^9, 3.5532550053125*^9}, {3.5532550615*^9, 
   3.553255080125*^9}, {3.5532552733125*^9, 3.553255356453125*^9}, {
   3.5532579200625*^9, 3.553257923859375*^9}, {3.553772529194261*^9, 
   3.553772535675271*^9}, {3.553772574912265*^9, 3.553772576887972*^9}},
 FontSize->24],

Cell[BoxData[
 GraphicsBox[{{}, {}, 
   {Hue[0.03], LineBox[CompressedData["
1:eJw1WXkw13/Q5+tKQhGlpJCjEKnwKftRSK4otxK57zv9HJH7Sq6kcqTooCJU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     "]]}},
  AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
  Axes->True,
  AxesLabel->{None, None},
  AxesOrigin->{0, 0},
  AxesStyle->Directive[20, 
    Thickness[0.005], 
    RGBColor[0, 0, 1]],
  ImageSize->700,
  LabelStyle->(FontFamily -> "Helvetica"),
  Method->{},
  PlotLabel->FormBox[
    RowBox[{"{", "\"Somma parziale  con 50 termini\"", "}"}], TraditionalForm],
  PlotRange->{All, All},
  PlotRangeClipping->True,
  PlotRangePadding->{Automatic, Automatic}]], "Output",
 CellChangeTimes->{
  3.5776833367389193`*^9},ImageCache->GraphicsData["CompressedBitmap", "\<\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\
\>"]]
}, Open  ]]
},
CellGrouping->Manual,
WindowSize->{1438, 813},
WindowMargins->{{0, Automatic}, {Automatic, 0}},
Magnification->0.7999999523162842,
FrontEndVersion->"9.0 for Linux x86 (64-bit) (January 25, 2013)",
StyleDefinitions->"StyleZo2.nb"
]
(* End of Notebook Content *)

(* Internal cache information *)
(*CellTagsOutline
CellTagsIndex->{}
*)
(*CellTagsIndex
CellTagsIndex->{}
*)
(*NotebookFileOutline
Notebook[{
Cell[557, 20, 370, 6, 98, "Text"],
Cell[930, 28, 5317, 122, 724, "Text"],
Cell[6250, 152, 1674, 33, 77, "Input"],
Cell[CellGroupData[{
Cell[7949, 189, 503, 10, 56, "Text"],
Cell[8455, 201, 286, 7, 34, "Input"],
Cell[8744, 210, 533, 13, 34, "Input"],
Cell[9280, 225, 449, 8, 34, "Input"],
Cell[9732, 235, 506, 9, 34, "Input"],
Cell[10241, 246, 616, 10, 34, "Input"],
Cell[10860, 258, 646, 11, 34, "Input"],
Cell[11509, 271, 650, 11, 34, "Input"],
Cell[12162, 284, 453, 8, 34, "Input"],
Cell[12618, 294, 498, 9, 34, "Input"],
Cell[13119, 305, 547, 9, 34, "Input"],
Cell[13669, 316, 608, 10, 34, "Input"],
Cell[14280, 328, 661, 11, 34, "Input"],
Cell[CellGroupData[{
Cell[14966, 343, 488, 10, 34, "Input"],
Cell[15457, 355, 235, 7, 47, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[15729, 367, 475, 10, 34, "Input"],
Cell[16207, 379, 233, 7, 47, "Output"]
}, Open  ]],
Cell[16455, 389, 322, 8, 34, "Input"],
Cell[16780, 399, 346, 8, 34, "Input"],
Cell[17129, 409, 391, 8, 34, "Input"],
Cell[17523, 419, 444, 9, 34, "Input"],
Cell[17970, 430, 232, 6, 34, "Input"],
Cell[18205, 438, 352, 8, 34, "Input"],
Cell[18560, 448, 470, 9, 34, "Input"],
Cell[19033, 459, 425, 9, 34, "Input"],
Cell[CellGroupData[{
Cell[19483, 472, 500, 12, 31, "Input"],
Cell[19986, 486, 81, 1, 36, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[20104, 492, 512, 13, 31, "Input"],
Cell[20619, 507, 93, 1, 36, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[20749, 513, 757, 18, 69, "Input"],
Cell[21509, 533, 103, 2, 53, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[21649, 540, 1176, 26, 60, "Input"],
Cell[22828, 568, 101, 2, 53, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[22966, 575, 214, 4, 30, "Input"],
Cell[23183, 581, 79, 1, 36, "Output"]
}, Open  ]],
Cell[23277, 585, 517, 13, 48, "Text"],
Cell[CellGroupData[{
Cell[23819, 602, 561, 13, 69, "Input"],
Cell[24383, 617, 79, 1, 36, "Output"]
}, Open  ]],
Cell[24477, 621, 553, 15, 48, "Text"],
Cell[CellGroupData[{
Cell[25055, 640, 710, 16, 69, "Input"],
Cell[25768, 658, 82, 1, 36, "Output"]
}, Open  ]],
Cell[25865, 662, 478, 9, 48, "Text"],
Cell[CellGroupData[{
Cell[26368, 675, 948, 23, 29, "Input"],
Cell[27319, 700, 252, 8, 40, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[27608, 713, 1110, 27, 29, "Input"],
Cell[28721, 742, 233, 7, 40, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[28991, 754, 1220, 30, 29, "Input"],
Cell[30214, 786, 233, 7, 40, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[30484, 798, 954, 22, 29, "Input"],
Cell[31441, 822, 232, 7, 40, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[31710, 834, 1121, 27, 29, "Input"],
Cell[32834, 863, 233, 7, 40, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[33104, 875, 1171, 29, 29, "Input"],
Cell[34278, 906, 233, 7, 40, "Output"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[34560, 919, 1252, 20, 56, "Text"],
Cell[35815, 941, 9386, 181, 472, "Text"],
Cell[45204, 1124, 1335, 22, 47, "Text"],
Cell[46542, 1148, 1328, 21, 47, "Text"],
Cell[CellGroupData[{
Cell[47895, 1173, 4244, 122, 247, "Input"],
Cell[52142, 1297, 2320, 45, 32, 1389, 28, "CachedBoxData", "BoxData", "Output"]
}, Open  ]],
Cell[54477, 1345, 1331, 21, 47, "Text"],
Cell[CellGroupData[{
Cell[55833, 1370, 4340, 123, 247, "Input"],
Cell[60176, 1495, 2306, 45, 32, 1389, 28, "CachedBoxData", "BoxData", "Output"]
}, Open  ]]
}, Open  ]],
Cell[62509, 1544, 1636, 28, 131, "Text"],
Cell[CellGroupData[{
Cell[64170, 1576, 2057, 40, 34, "Input"],
Cell[66230, 1618, 322, 10, 55, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[66589, 1633, 1677, 33, 70, "Input"],
Cell[68269, 1668, 188, 5, 53, "Output"]
}, Open  ]],
Cell[68472, 1676, 541, 10, 47, "Text"],
Cell[CellGroupData[{
Cell[69038, 1690, 828, 23, 118, "Input"],
Cell[69869, 1715, 73, 1, 34, "Output"]
}, Open  ]],
Cell[69957, 1719, 376, 10, 34, "Input"],
Cell[70336, 1731, 948, 23, 78, "Text"],
Cell[CellGroupData[{
Cell[71309, 1758, 403, 11, 34, "Input"],
Cell[71715, 1771, 353, 11, 55, "Output"]
}, Open  ]],
Cell[72083, 1785, 562, 11, 47, "Text"],
Cell[CellGroupData[{
Cell[72670, 1800, 3115, 55, 64, "Input"],
Cell[75788, 1857, 32843, 551, 368, 18114, 308, "CachedBoxData", "BoxData", \
"Output"]
}, Open  ]],
Cell[108646, 2411, 630, 13, 74, "Text"],
Cell[109279, 2426, 1434, 36, 93, "Input"],
Cell[CellGroupData[{
Cell[110738, 2466, 2843, 51, 64, "Input"],
Cell[113584, 2519, 20380, 348, 336, 9115, 161, "CachedBoxData", "BoxData", \
"Output"]
}, Open  ]],
Cell[133979, 2870, 4770, 90, 301, "Text"],
Cell[CellGroupData[{
Cell[138774, 2964, 3538, 58, 29, "Input",
 CellID->53852264],
Cell[142315, 3024, 1228, 32, 174, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[143580, 3061, 208, 6, 29, "Input"],
Cell[143791, 3069, 1071, 29, 166, "Output"]
}, Open  ]],
Cell[144877, 3101, 1071, 39, 49, "Text"],
Cell[CellGroupData[{
Cell[145973, 3144, 430, 11, 34, "Input"],
Cell[146406, 3157, 71, 1, 34, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[146514, 3163, 608, 16, 73, "Input"],
Cell[147125, 3181, 88, 1, 34, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[147250, 3187, 714, 19, 73, "Input"],
Cell[147967, 3208, 88, 1, 34, "Output"]
}, Open  ]],
Cell[148070, 3212, 293, 6, 47, "Text"],
Cell[148366, 3220, 331, 7, 34, "Input"],
Cell[CellGroupData[{
Cell[148722, 3231, 1301, 31, 73, "Input"],
Cell[150026, 3264, 3360, 58, 307, "Output"]
}, Open  ]],
Cell[153401, 3325, 1203, 27, 73, "Input"],
Cell[CellGroupData[{
Cell[154629, 3356, 478, 14, 77, "Input"],
Cell[155110, 3372, 109, 2, 36, "Output"]
}, Open  ]],
Cell[155234, 3377, 1547, 32, 128, "Text"],
Cell[156784, 3411, 315, 7, 47, "Text"],
Cell[157102, 3420, 172, 3, 35, "Text"],
Cell[CellGroupData[{
Cell[157299, 3427, 2232, 50, 63, "Input"],
Cell[159534, 3479, 3711, 86, 312, "Output"]
}, Open  ]],
Cell[163260, 3568, 323, 7, 47, "Text"],
Cell[CellGroupData[{
Cell[163608, 3579, 2251, 51, 91, "Input"],
Cell[165862, 3632, 3711, 86, 312, "Output"]
}, Open  ]],
Cell[169588, 3721, 1890, 42, 48, "Text"],
Cell[CellGroupData[{
Cell[171503, 3767, 2095, 48, 63, "Input"],
Cell[173601, 3817, 3711, 86, 312, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[177349, 3908, 2139, 50, 91, "Input"],
Cell[179491, 3960, 3713, 86, 312, "Output"]
}, Open  ]],
Cell[183219, 4049, 919, 17, 74, "Text"],
Cell[CellGroupData[{
Cell[184163, 4070, 1472, 30, 53, "Input"],
Cell[185638, 4102, 38801, 649, 359, 11554, 200, "CachedBoxData", "BoxData", \
"Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[224476, 4756, 1419, 29, 53, "Input"],
Cell[225898, 4787, 38792, 648, 359, 11554, 200, "CachedBoxData", "BoxData", \
"Output"]
}, Open  ]],
Cell[264705, 5438, 760, 13, 47, "Text"],
Cell[CellGroupData[{
Cell[265490, 5455, 716, 13, 56, "Text"],
Cell[266209, 5470, 1198, 22, 232, "Text"]
}, Open  ]],
Cell[CellGroupData[{
Cell[267444, 5497, 2036, 38, 34, "Input"],
Cell[269483, 5537, 233, 7, 55, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[269753, 5549, 772, 19, 53, "Input"],
Cell[270528, 5570, 190, 5, 53, "Output"]
}, Open  ]],
Cell[270733, 5578, 1420, 24, 48, "Text"],
Cell[CellGroupData[{
Cell[272178, 5606, 715, 20, 53, "Input"],
Cell[272896, 5628, 73, 1, 34, "Output"]
}, Open  ]],
Cell[272984, 5632, 465, 12, 29, "Input"],
Cell[273452, 5646, 1602, 37, 99, "Input"],
Cell[275057, 5685, 328, 10, 29, "Input"],
Cell[275388, 5697, 329, 10, 29, "Input"],
Cell[CellGroupData[{
Cell[275742, 5711, 3088, 55, 64, "Input"],
Cell[278833, 5768, 51513, 860, 370, 25470, 431, "CachedBoxData", "BoxData", \
"Output"]
}, Open  ]],
Cell[330361, 6631, 1369, 21, 47, "Text"],
Cell[CellGroupData[{
Cell[331755, 6656, 470, 14, 29, "Input"],
Cell[332228, 6672, 2240, 62, 136, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[334505, 6739, 418, 12, 53, "Input"],
Cell[334926, 6753, 73, 1, 34, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[335036, 6759, 569, 15, 63, "Input"],
Cell[335608, 6776, 86, 1, 34, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[335731, 6782, 593, 17, 89, "Input"],
Cell[336327, 6801, 71, 1, 34, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[336435, 6807, 1430, 34, 73, "Input"],
Cell[337868, 6843, 9127, 285, 452, "Output"]
}, Open  ]],
Cell[347010, 7131, 404, 8, 29, "Input"],
Cell[347417, 7141, 718, 20, 63, "Input"],
Cell[CellGroupData[{
Cell[348160, 7165, 478, 14, 77, "Input"],
Cell[348641, 7181, 109, 2, 36, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[348787, 7188, 1316, 34, 29, "Input"],
Cell[350106, 7224, 3710, 86, 312, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[353853, 7315, 1844, 35, 53, "Input"],
Cell[355700, 7352, 38789, 649, 359, 11542, 200, "CachedBoxData", "BoxData", \
"Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[394526, 8006, 869, 15, 56, "Text"],
Cell[395398, 8023, 1923, 50, 211, "Text"]
}, Open  ]],
Cell[CellGroupData[{
Cell[397358, 8078, 1470, 33, 63, "Input"],
Cell[398831, 8113, 1030, 31, 81, "Output"]
}, Open  ]],
Cell[399876, 8147, 633, 12, 34, "Input"],
Cell[400512, 8161, 978, 22, 34, "Input"],
Cell[CellGroupData[{
Cell[401515, 8187, 1200, 26, 34, "Input"],
Cell[402718, 8215, 134, 4, 19, "Print"],
Cell[402855, 8221, 175, 5, 24, "Print"],
Cell[403033, 8228, 134, 4, 19, "Print"],
Cell[403170, 8234, 157, 4, 24, "Print"],
Cell[403330, 8240, 134, 4, 19, "Print"],
Cell[403467, 8246, 174, 5, 24, "Print"],
Cell[403644, 8253, 134, 4, 19, "Print"],
Cell[403781, 8259, 157, 4, 19, "Print"],
Cell[403941, 8265, 136, 4, 19, "Print"],
Cell[404080, 8271, 177, 5, 19, "Print"],
Cell[404260, 8278, 134, 4, 19, "Print"],
Cell[404397, 8284, 159, 4, 19, "Print"],
Cell[404559, 8290, 136, 4, 19, "Print"],
Cell[404698, 8296, 176, 5, 19, "Print"],
Cell[404877, 8303, 134, 4, 19, "Print"],
Cell[405014, 8309, 156, 4, 19, "Print"],
Cell[405173, 8315, 136, 4, 19, "Print"],
Cell[405312, 8321, 175, 5, 19, "Print"],
Cell[405490, 8328, 134, 4, 19, "Print"],
Cell[405627, 8334, 156, 4, 19, "Print"],
Cell[405786, 8340, 136, 4, 19, "Print"],
Cell[405925, 8346, 177, 5, 19, "Print"],
Cell[406105, 8353, 134, 4, 19, "Print"],
Cell[406242, 8359, 156, 4, 19, "Print"],
Cell[406401, 8365, 136, 4, 19, "Print"],
Cell[406540, 8371, 173, 5, 19, "Print"],
Cell[406716, 8378, 134, 4, 19, "Print"],
Cell[406853, 8384, 155, 4, 19, "Print"],
Cell[407011, 8390, 134, 4, 19, "Print"],
Cell[407148, 8396, 175, 5, 19, "Print"],
Cell[407326, 8403, 134, 4, 19, "Print"],
Cell[407463, 8409, 155, 4, 19, "Print"],
Cell[407621, 8415, 136, 4, 19, "Print"],
Cell[407760, 8421, 172, 5, 19, "Print"],
Cell[407935, 8428, 134, 4, 19, "Print"],
Cell[408072, 8434, 153, 4, 19, "Print"],
Cell[408228, 8440, 134, 4, 19, "Print"],
Cell[408365, 8446, 171, 5, 19, "Print"],
Cell[408539, 8453, 173, 5, 19, "Print"],
Cell[408715, 8460, 170, 5, 19, "Print"],
Cell[408888, 8467, 134, 4, 19, "Print"],
Cell[409025, 8473, 150, 4, 19, "Print"],
Cell[409178, 8479, 136, 4, 19, "Print"],
Cell[409317, 8485, 149, 4, 19, "Print"],
Cell[409469, 8491, 133, 4, 19, "Print"],
Cell[409605, 8497, 169, 5, 19, "Print"],
Cell[409777, 8504, 170, 5, 19, "Print"],
Cell[409950, 8511, 169, 5, 19, "Print"],
Cell[410122, 8518, 133, 4, 19, "Print"],
Cell[410258, 8524, 149, 4, 19, "Print"],
Cell[410410, 8530, 117, 3, 19, "Print"],
Cell[410530, 8535, 130, 3, 19, "Print"],
Cell[410663, 8540, 114, 3, 19, "Print"],
Cell[410780, 8545, 150, 4, 19, "Print"],
Cell[410933, 8551, 151, 4, 19, "Print"],
Cell[411087, 8557, 152, 4, 19, "Print"],
Cell[411242, 8563, 114, 3, 19, "Print"],
Cell[411359, 8568, 130, 3, 19, "Print"],
Cell[411492, 8573, 117, 3, 19, "Print"],
Cell[411612, 8578, 130, 3, 19, "Print"],
Cell[411745, 8583, 113, 3, 19, "Print"],
Cell[411861, 8588, 152, 4, 19, "Print"],
Cell[412016, 8594, 152, 4, 19, "Print"],
Cell[412171, 8600, 152, 4, 19, "Print"],
Cell[412326, 8606, 115, 3, 19, "Print"],
Cell[412444, 8611, 134, 3, 19, "Print"],
Cell[412581, 8616, 115, 3, 19, "Print"],
Cell[412699, 8621, 153, 4, 19, "Print"],
Cell[412855, 8627, 117, 3, 19, "Print"],
Cell[412975, 8632, 136, 3, 19, "Print"],
Cell[413114, 8637, 115, 3, 19, "Print"],
Cell[413232, 8642, 153, 4, 19, "Print"],
Cell[413388, 8648, 115, 3, 19, "Print"],
Cell[413506, 8653, 133, 3, 19, "Print"],
Cell[413642, 8658, 115, 3, 19, "Print"],
Cell[413760, 8663, 154, 4, 19, "Print"],
Cell[413917, 8669, 117, 3, 19, "Print"],
Cell[414037, 8674, 137, 3, 19, "Print"],
Cell[414177, 8679, 115, 3, 19, "Print"],
Cell[414295, 8684, 158, 4, 19, "Print"],
Cell[414456, 8690, 115, 3, 19, "Print"],
Cell[414574, 8695, 137, 3, 19, "Print"],
Cell[414714, 8700, 115, 3, 19, "Print"],
Cell[414832, 8705, 156, 4, 19, "Print"],
Cell[414991, 8711, 115, 3, 19, "Print"],
Cell[415109, 8716, 137, 3, 19, "Print"],
Cell[415249, 8721, 115, 3, 19, "Print"],
Cell[415367, 8726, 157, 4, 19, "Print"],
Cell[415527, 8732, 117, 3, 19, "Print"],
Cell[415647, 8737, 138, 3, 19, "Print"],
Cell[415788, 8742, 115, 3, 19, "Print"],
Cell[415906, 8747, 156, 4, 19, "Print"],
Cell[416065, 8753, 115, 3, 19, "Print"],
Cell[416183, 8758, 138, 3, 19, "Print"],
Cell[416324, 8763, 115, 3, 19, "Print"],
Cell[416442, 8768, 155, 4, 24, "Print"],
Cell[416600, 8774, 115, 3, 19, "Print"],
Cell[416718, 8779, 136, 3, 24, "Print"],
Cell[416857, 8784, 115, 3, 19, "Print"],
Cell[416975, 8789, 156, 4, 24, "Print"],
Cell[417134, 8795, 115, 3, 19, "Print"]
}, Open  ]],
Cell[417264, 8801, 496, 10, 47, "Text"],
Cell[CellGroupData[{
Cell[417785, 8815, 1020, 21, 53, "Input"],
Cell[418808, 8838, 12865, 222, 373, 5732, 103, "CachedBoxData", "BoxData", \
"Output"]
}, Open  ]],
Cell[431688, 9063, 1226, 27, 105, "Input"],
Cell[432917, 9092, 407, 7, 47, "Text"],
Cell[433327, 9101, 505, 10, 34, "Input"],
Cell[433835, 9113, 239, 5, 46, "Text"],
Cell[CellGroupData[{
Cell[434099, 9122, 749, 14, 34, "Input"],
Cell[434851, 9138, 4527, 114, 503, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[439415, 9257, 1791, 34, 64, "Input"],
Cell[441209, 9293, 31393, 525, 315, 11416, 196, "CachedBoxData", "BoxData", \
"Output"]
}, Open  ]]
}
]
*)

(* End of internal cache information *)
