(* Content-type: application/mathematica *)

(*** Wolfram Notebook File ***)
(* http://www.wolfram.com/nb *)

(* CreatedBy='Mathematica 7.0' *)

(*CacheID: 234*)
(* Internal cache information:
NotebookFileLineBreakTest
NotebookFileLineBreakTest
NotebookDataPosition[       145,          7]
NotebookDataLength[    124470,       3225]
NotebookOptionsPosition[    118209,       3056]
NotebookOutlinePosition[    118584,       3072]
CellTagsIndexPosition[    118541,       3069]
WindowFrame->Normal*)

(* Beginning of Notebook Content *)
Notebook[{
Cell["\<\
Evaluation time
\[CapitalDelta]t  <  5 min\
\>", "Text",
 CellChangeTimes->{{3.552825182304793*^9, 3.552825225090515*^9}, 
   3.552826287262672*^9, {3.5529856190149317`*^9, 3.55298562337449*^9}, {
   3.552985761083598*^9, 3.552985763576391*^9}, {3.5529884258416758`*^9, 
   3.5529884385962954`*^9}, {3.552988943909775*^9, 3.5529889485819893`*^9}, {
   3.573989568546638*^9, 3.573989585869432*^9}, {3.574045246477895*^9, 
   3.5740452925494137`*^9}, {3.5751118320059023`*^9, 
   3.5751118384042683`*^9}, {3.575112307749113*^9, 3.5751123129164085`*^9}},
 FontSize->24,
 FontColor->RGBColor[0, 0, 1],
 Background->RGBColor[1, 0.9, 0.8]],

Cell[TextData[{
 "In this notebook we refer to section (2.1.5) \[OpenCurlyDoubleQuote]Lattice \
function and reciprocal lattices\[CloseCurlyDoubleQuote] and in particular to \
equations (2.1.45) and (2.1.46). For simplicity, we just consider a doubly \
periodic function \[Rho](r) = \[Rho](x, y). \n\nOur goal is to calculate the  \
Fourier coefficients,  given by\n\n",
 Cell[BoxData[
  FormBox[
   StyleBox[
    RowBox[{
     SubscriptBox["\[Rho]", "hk"], 
     StyleBox[" ",
      FontFamily->"Courier New"]}],
    FontColor->RGBColor[0, 0, 1]], TraditionalForm]],
  FontColor->RGBColor[1, 0, 0]],
 " = ",
 Cell[BoxData[
  FormBox[
   RowBox[{
    FractionBox[
     StyleBox["1",
      FontSlant->"Plain"], 
     StyleBox[
      RowBox[{"\[Lambda]x", " ", "\[Lambda]y"}],
      FontSize->24]], " "}], TraditionalForm]]],
 Cell[BoxData[
  FormBox[
   RowBox[{
    SubsuperscriptBox["\[Integral]", "0", "\[Lambda]x"], 
    RowBox[{
     SubsuperscriptBox["\[Integral]", "0", "\[Lambda]y"], 
     RowBox[{
      RowBox[{"\[Rho]", "[", 
       RowBox[{"x", ",", "y"}], "]"}], 
      RowBox[{"Exp", "[", 
       RowBox[{
        RowBox[{"-", "2"}], 
        RowBox[{"\[Pi]\[ImaginaryI]", "(", 
         RowBox[{
          RowBox[{"h", 
           StyleBox[
            FractionBox["x", "\[Lambda]x"],
            FontFamily->"Courier New"]}], 
          StyleBox["+",
           FontFamily->"Courier New"], 
          StyleBox[
           RowBox[{"k", " ", 
            FractionBox["y", "\[Lambda]y"]}],
           FontFamily->"Courier New"]}], 
         StyleBox[")",
          FontFamily->"Courier New"]}]}], 
       StyleBox["]",
        FontFamily->"Courier New"]}], 
      RowBox[{"\[DifferentialD]", 
       StyleBox["x",
        FontFamily->"Courier New"]}]}]}]}], TraditionalForm]]],
 " \[DifferentialD]",
 StyleBox["y (1)\n\n",
  FontFamily->"Courier New",
  FontSlant->"Italic"],
 "when we consider a cell with periods \[Lambda]x and \[Lambda]y along the x \
and y. \nThis equation is analogous to the eq. 2.1.46 if we are dealing with \
a 2D lattice.\n\nWe consider two cases, corresponding to the two part of the \
notebook:\n\nPart I - intrinsically periodic charge density: \n\n             \
  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{"\[Rho]", "[", 
    RowBox[{"x", ",", "y"}], "]"}], "=", 
   RowBox[{"Z", "*", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{
       RowBox[{"(", 
        RowBox[{"Sin", "[", 
         FractionBox[
          RowBox[{"2", " ", "\[Pi]", " ", "x"}], "\[Lambda]x"], "]"}], ")"}], 
       "^", "6"}], 
      RowBox[{
       RowBox[{"(", 
        RowBox[{"Sin", "[", 
         FractionBox[
          RowBox[{"2", " ", "\[Pi]", " ", "y"}], "\[Lambda]y"], "]"}], ")"}], 
       "^", "6"}]}], ")"}]}]}]], "Input",
  CellChangeTimes->{{3.48057427009375*^9, 3.480574279546875*^9}, {
   3.506853337774859*^9, 3.506853348250214*^9}},
  FontSize->24],
 "\n                with Z=1, \[Lambda]x = \[Lambda]y =1 (chosen for \
semplicity)\n\nPart II - gaussian-like charge density:\n              ",
 Cell[BoxData[
  RowBox[{
   RowBox[{
    RowBox[{"\[Rho]", "[", 
     RowBox[{"x", ",", "y"}], "]"}], "=", 
    RowBox[{"Z", "*", 
     RowBox[{"(", 
      RowBox[{"Exp", "[", 
       RowBox[{"-", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{
           RowBox[{"(", 
            FractionBox["x", "Rn"], ")"}], "^", "2"}], "+", 
          RowBox[{
           RowBox[{"(", 
            FractionBox["y", "Rm"], ")"}], "^", "2"}]}], ")"}]}], "]"}], 
      ")"}]}]}], ";"}]], "Input",
  CellChangeTimes->{{3.48057427009375*^9, 3.480574279546875*^9}, {
   3.506853337774859*^9, 3.506853348250214*^9}},
  FontSize->24],
 "\n                 with Z=1, Rn=Rm = 1/2, \[Lambda]x=\[Lambda]y=2 (chosen \
for semplicity)\n"
}], "Text",
 CellGroupingRules->{GroupTogetherGrouping, 10001.},
 CellChangeTimes->{{3.43609917853125*^9, 3.436099224875*^9}, {
   3.451201105219131*^9, 3.4512011607417097`*^9}, {3.451202261049141*^9, 
   3.4512022642358913`*^9}, {3.451380513178369*^9, 3.45138054907161*^9}, {
   3.451380621354679*^9, 3.4513806318446302`*^9}, {3.451380663944434*^9, 
   3.451380665324871*^9}, 3.451380835741723*^9, {3.451380883232542*^9, 
   3.451380932025751*^9}, {3.45138098428447*^9, 3.451381101560313*^9}, {
   3.451381137605834*^9, 3.4513812892934093`*^9}, {3.451381335947049*^9, 
   3.4513813424192867`*^9}, {3.451381406000942*^9, 3.4513815693796167`*^9}, {
   3.451381599587194*^9, 3.4513816160378428`*^9}, {3.451381648755763*^9, 
   3.451381662300729*^9}, {3.451381704127902*^9, 3.45138171648451*^9}, {
   3.451382259750657*^9, 3.451382312554418*^9}, {3.4513832778456984`*^9, 
   3.4513833884064627`*^9}, {3.4513834207689877`*^9, 
   3.4513834284008837`*^9}, {3.45138347707425*^9, 3.451383535066996*^9}, {
   3.451383600079137*^9, 3.451383608542776*^9}, {3.451383641804398*^9, 
   3.4513836594058237`*^9}, {3.4513837085029287`*^9, 
   3.4513837950532207`*^9}, {3.451383842090927*^9, 3.451383869607256*^9}, {
   3.451383972789274*^9, 3.451384074278797*^9}, {3.451384120558514*^9, 
   3.4513841250309677`*^9}, {3.451623575273048*^9, 3.451623576629842*^9}, {
   3.451623723281217*^9, 3.4516237502320232`*^9}, {3.4516252629844713`*^9, 
   3.451625277865951*^9}, 3.4516301683616*^9, {3.451630274543489*^9, 
   3.451630319368353*^9}, {3.45163038029524*^9, 3.4516304496679487`*^9}, {
   3.45163048058594*^9, 3.451630508022175*^9}, {3.451630543243938*^9, 
   3.451630554396184*^9}, {3.4516305844061337`*^9, 3.4516305965389*^9}, {
   3.451630671518499*^9, 3.45163074097786*^9}, {3.451630789384632*^9, 
   3.451630834297195*^9}, {3.451630882513088*^9, 3.451630887383438*^9}, {
   3.451630958466445*^9, 3.4516310233802843`*^9}, {3.451631107681582*^9, 
   3.45163115383357*^9}, {3.4516357609731703`*^9, 3.451635762360878*^9}, {
   3.451635972151944*^9, 3.451636005181984*^9}, {3.4516402816594057`*^9, 
   3.4516402868771152`*^9}, {3.451718418411845*^9, 3.451718532230791*^9}, {
   3.451718572022703*^9, 3.451718636750465*^9}, {3.45171873269027*^9, 
   3.45171874852979*^9}, 3.451718817600716*^9, 3.451719631281345*^9, {
   3.4517197104528837`*^9, 3.4517200758146763`*^9}, {3.451720168016982*^9, 
   3.451720322906805*^9}, 3.451720357930373*^9, {3.451720392408083*^9, 
   3.4517204987574453`*^9}, {3.451720545320046*^9, 3.45172055124533*^9}, {
   3.451721255481255*^9, 3.451721275242407*^9}, {3.4517271352554398`*^9, 
   3.451727156645337*^9}, {3.4517274572440367`*^9, 3.451727461141712*^9}, {
   3.451727558386169*^9, 3.4517275648990917`*^9}, {3.451727605239909*^9, 
   3.451727641435083*^9}, 3.451729695420402*^9, {3.451729750634655*^9, 
   3.451729873244254*^9}, {3.451730002795368*^9, 3.4517300120559387`*^9}, {
   3.45911542234375*^9, 3.45911547275*^9}, {3.459115723375*^9, 
   3.459115747234375*^9}, {3.459115777421875*^9, 3.45911580071875*^9}, {
   3.459115838765625*^9, 3.4591158911875*^9}, {3.459116171578125*^9, 
   3.459116177234375*^9}, {3.4591162725625*^9, 3.459116291234375*^9}, {
   3.459116326796875*^9, 3.459116403703125*^9}, {3.45911644571875*^9, 
   3.459116532390625*^9}, {3.45911656446875*^9, 3.4591166079375*^9}, {
   3.459116653375*^9, 3.459116755828125*^9}, {3.45911682465625*^9, 
   3.459116869296875*^9}, {3.459116900890625*^9, 3.459116947375*^9}, {
   3.459117026890625*^9, 3.459117030734375*^9}, {3.459117113984375*^9, 
   3.45911717959375*^9}, {3.45911742165625*^9, 3.45911745671875*^9}, {
   3.459117496234375*^9, 3.459117656375*^9}, {3.459117804515625*^9, 
   3.4591178465*^9}, {3.459117889671875*^9, 3.459117943828125*^9}, {
   3.459117976109375*^9, 3.45911821184375*^9}, {3.459118252421875*^9, 
   3.4591183270625*^9}, {3.45911839728125*^9, 3.45911849109375*^9}, {
   3.459118552953125*^9, 3.45911865771875*^9}, {3.459118706015625*^9, 
   3.459118713484375*^9}, {3.459118798359375*^9, 3.4591188668125*^9}, {
   3.459118963578125*^9, 3.459119082375*^9}, {3.459119116703125*^9, 
   3.459119161234375*^9}, {3.459119315609375*^9, 3.459119323359375*^9}, {
   3.459119359296875*^9, 3.4591193660625*^9}, {3.4591587146875*^9, 
   3.4591587818125*^9}, {3.4591588135625*^9, 3.459158919328125*^9}, {
   3.459158956921875*^9, 3.45915908328125*^9}, {3.459159124390625*^9, 
   3.45915912540625*^9}, {3.459159513953125*^9, 3.4591595305625*^9}, {
   3.4591595785625*^9, 3.459159586203125*^9}, {3.45915961928125*^9, 
   3.45915977559375*^9}, {3.459159896625*^9, 3.459159970953125*^9}, {
   3.459160013484375*^9, 3.45916006021875*^9}, {3.45916009496875*^9, 
   3.459160140640625*^9}, {3.459160177390625*^9, 3.459160238515625*^9}, {
   3.459160746703125*^9, 3.459160773671875*^9}, 3.45916106203125*^9, {
   3.459162807875*^9, 3.45916287228125*^9}, {3.45916662953125*^9, 
   3.459166635515625*^9}, {3.459170302734375*^9, 3.459170322953125*^9}, {
   3.459256788703125*^9, 3.459256930734375*^9}, {3.459256975046875*^9, 
   3.459256983671875*^9}, {3.459257393546875*^9, 3.45925739578125*^9}, {
   3.45925748825*^9, 3.459257492609375*^9}, {3.45925753084375*^9, 
   3.459257588625*^9}, {3.45925765596875*^9, 3.459257697421875*^9}, {
   3.45925781*^9, 3.459257812046875*^9}, {3.459257846640625*^9, 
   3.459257951828125*^9}, {3.45925839284375*^9, 3.45925842496875*^9}, {
   3.459258501234375*^9, 3.4592585533125*^9}, {3.459258611859375*^9, 
   3.459258645703125*^9}, {3.459555263109375*^9, 3.459555263109375*^9}, {
   3.459555300484375*^9, 3.459555300484375*^9}, {3.45955545609375*^9, 
   3.459555456203125*^9}, {3.506854853985186*^9, 3.506854906046125*^9}, {
   3.506855002933634*^9, 3.5068550831139107`*^9}, {3.506855398979718*^9, 
   3.506855427601761*^9}, {3.506855476575438*^9, 3.5068554808734694`*^9}, {
   3.506855719767253*^9, 3.506855810874752*^9}, {3.5068558568836184`*^9, 
   3.5068559455358763`*^9}, {3.5068560111366863`*^9, 3.506856036913972*^9}, {
   3.506856071231394*^9, 3.506856118285461*^9}, {3.506856332070056*^9, 
   3.506856484232737*^9}, {3.506856777715743*^9, 3.506856835042203*^9}, {
   3.506856899498397*^9, 3.5068570048524017`*^9}, {3.506857073484508*^9, 
   3.506857175645664*^9}, {3.506857398942502*^9, 3.506857422086784*^9}, {
   3.5068574727721863`*^9, 3.506857540979109*^9}, {3.506857815482833*^9, 
   3.506857865135755*^9}, {3.506857908755039*^9, 3.506857939620152*^9}, {
   3.506858751469297*^9, 3.506858790392499*^9}, {3.5068600451529493`*^9, 
   3.5068600595700703`*^9}, {3.506860124576549*^9, 3.506860196791506*^9}, {
   3.506860254350823*^9, 3.506860327999488*^9}, {3.5068668929637127`*^9, 
   3.506866893543358*^9}, {3.506866938016555*^9, 3.506867065179174*^9}, {
   3.506920042859375*^9, 3.5069200433125*^9}, {3.5069298726875*^9, 
   3.50692990803125*^9}, {3.506929978125*^9, 3.506930010796875*^9}, {
   3.506930440578125*^9, 3.506930470125*^9}, {3.506930515546875*^9, 
   3.50693052821875*^9}, {3.50693157134375*^9, 3.506931626765625*^9}, {
   3.50693165765625*^9, 3.506931661921875*^9}, {3.574045320194807*^9, 
   3.574045326392522*^9}, 3.575111856927327*^9, {3.57511192410717*^9, 
   3.5751121662670207`*^9}, {3.575112197923831*^9, 3.575112240932291*^9}},
 FontFamily->"Times New Roman",
 FontSize->36,
 FontColor->RGBColor[0, 0, 1],
 Background->RGBColor[1, 1, 0.85]],

Cell[CellGroupData[{

Cell[TextData[StyleBox["Part I",
 FontColor->RGBColor[0, 0, 1]]], "Text",
 CellGroupingRules->{GroupTogetherGrouping, 10000.},
 CellChangeTimes->{{3.4561278892666187`*^9, 3.4561279023146544`*^9}, 
   3.456128006313026*^9, {3.4561281092059317`*^9, 3.456128161981234*^9}, {
   3.456138326441684*^9, 3.456138335084655*^9}, 3.457086838266417*^9, {
   3.457161408546215*^9, 3.4571614091944523`*^9}, 3.459076271296875*^9, {
   3.459077388375*^9, 3.459077392921875*^9}, {3.459077439234375*^9, 
   3.459077449953125*^9}, {3.459077842734375*^9, 3.45907785384375*^9}, {
   3.459077980265625*^9, 3.45907799534375*^9}, {3.459080904375*^9, 
   3.45908092684375*^9}, {3.45908103925*^9, 3.459081047125*^9}, {
   3.459081272515625*^9, 3.459081273359375*^9}, 3.45908270415625*^9, {
   3.45908301365625*^9, 3.459083043859375*^9}, 3.45908372865625*^9, {
   3.459112126203125*^9, 3.459112164203125*^9}, 3.45916170553125*^9, 
   3.459161890421875*^9, {3.459170302734375*^9, 3.45917031409375*^9}, {
   3.506858006512697*^9, 3.506858006982812*^9}, {3.506861249547703*^9, 
   3.506861281541944*^9}, {3.506929782109375*^9, 3.506929846890625*^9}, {
   3.50692998321875*^9, 3.506929984734375*^9}, {3.5069301465*^9, 
   3.50693015609375*^9}, {3.506930539078125*^9, 3.506930557125*^9}, {
   3.575112331351463*^9, 3.5751123320275016`*^9}},
 FontSize->36,
 Background->RGBColor[1, 0.9, 0.8]],

Cell[TextData[{
 StyleBox[" ",
  FontSize->22],
 Cell[BoxData[
  RowBox[{
   RowBox[{"\[Rho]", "[", 
    RowBox[{"x", ",", "y"}], "]"}], "=", 
   RowBox[{"Z", "*", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{
       RowBox[{"(", 
        RowBox[{"Sin", "[", 
         FractionBox[
          RowBox[{"2", " ", "\[Pi]", " ", "x"}], "\[Lambda]x"], "]"}], ")"}], 
       "^", "6"}], 
      RowBox[{
       RowBox[{"(", 
        RowBox[{"Sin", "[", 
         FractionBox[
          RowBox[{"2", " ", "\[Pi]", " ", "y"}], "\[Lambda]y"], "]"}], ")"}], 
       "^", "6"}]}], ")"}]}]}]], "Input",
  CellChangeTimes->{{3.48057427009375*^9, 3.480574279546875*^9}, {
   3.506853337774859*^9, 3.506853348250214*^9}},
  FontSize->24],
 "\n\nIn section I.A we develop the trigonometric function with complex \
exponentials\nIn section I.B we use formula (1) to evaluate symbolically and \
numerically\nthe coefficients ",
 Cell[BoxData[
  FormBox[
   RowBox[{
    SubscriptBox["\[Rho]", "hk"], "."}], TraditionalForm]]],
 "\nIn section I.C we construct the expression\n",
 Cell[BoxData[
  RowBox[{
   RowBox[{
    OverscriptBox["\[Rho]", "\[Tilde]"], "[", 
    RowBox[{"x", ",", "y"}], "]"}], "=", 
   RowBox[{
    UnderoverscriptBox["\[Sum]", 
     RowBox[{"m", "=", 
      RowBox[{"-", "ntx"}]}], "ntx"], 
    RowBox[{
     UnderoverscriptBox["\[Sum]", 
      RowBox[{"n", "=", 
       StyleBox[
        RowBox[{"-", "nty"}],
        FontColor->GrayLevel[0]]}], "nty"], 
     RowBox[{
      RowBox[{"coefmn\[Rho]limit", "[", 
       RowBox[{"m", ",", "n"}], "]"}], "*", 
      SuperscriptBox["\[ExponentialE]", 
       RowBox[{"I", "*", 
        RowBox[{"(", 
         StyleBox[
          RowBox[{
           RowBox[{
            FractionBox[
             RowBox[{"2", " ", "\[Pi]", " ", "m"}], "\[Lambda]x"], " ", "x"}],
            "+", 
           RowBox[{
            FractionBox[
             RowBox[{"2", " ", "\[Pi]", " ", "n"}], "\[Lambda]y"], " ", 
            "y"}]}],
          FontSize->24], ")"}]}]], " "}]}]}]}]], "Input",
  CellChangeTimes->{{3.431321031421875*^9, 3.4313210425625*^9}, {
    3.500441560609375*^9, 3.500441595578125*^9}, {3.500443328765625*^9, 
    3.50044334603125*^9}, {3.5068385855625*^9, 3.506838626171875*^9}, {
    3.50683870196875*^9, 3.50683870434375*^9}, {3.506838765125*^9, 
    3.506838799234375*^9}, 3.506839273375*^9, {3.50684428521875*^9, 
    3.506844355421875*^9}},
  FontSize->24],
 "\nand calculate   ",
 Cell[BoxData[
  RowBox[{"\[Rho]", "[", 
   RowBox[{"x", ",", "y"}], "]"}]], "Input",
  CellChangeTimes->{{3.431321031421875*^9, 3.4313210425625*^9}, {
    3.500441560609375*^9, 3.500441595578125*^9}, {3.500443328765625*^9, 
    3.50044334603125*^9}, {3.5068385855625*^9, 3.506838626171875*^9}, {
    3.50683870196875*^9, 3.50683870434375*^9}, {3.506838765125*^9, 
    3.506838799234375*^9}, 3.506839273375*^9, {3.50684428521875*^9, 
    3.506844355421875*^9}},
  FontSize->24],
 " - ",
 Cell[BoxData[
  RowBox[{
   OverscriptBox["\[Rho]", "\[Tilde]"], "[", 
   RowBox[{"x", ",", "y"}], "]"}]], "Input",
  CellChangeTimes->{{3.431321031421875*^9, 3.4313210425625*^9}, {
    3.500441560609375*^9, 3.500441595578125*^9}, {3.500443328765625*^9, 
    3.50044334603125*^9}, {3.5068385855625*^9, 3.506838626171875*^9}, {
    3.50683870196875*^9, 3.50683870434375*^9}, {3.506838765125*^9, 
    3.506838799234375*^9}, 3.506839273375*^9, {3.50684428521875*^9, 
    3.506844355421875*^9}},
  FontSize->24],
 ",\nwhere ntx and nty denote a specified number of terms."
}], "Text",
 CellGroupingRules->{GroupTogetherGrouping, 10000.},
 CellChangeTimes->{{3.4561278892666187`*^9, 3.4561279023146544`*^9}, 
   3.456128006313026*^9, {3.4561281092059317`*^9, 3.456128161981234*^9}, {
   3.456138326441684*^9, 3.456138335084655*^9}, 3.457086838266417*^9, {
   3.457161408546215*^9, 3.4571614091944523`*^9}, 3.459076271296875*^9, {
   3.459077388375*^9, 3.459077392921875*^9}, {3.459077439234375*^9, 
   3.459077449953125*^9}, {3.459077842734375*^9, 3.45907785384375*^9}, {
   3.459077980265625*^9, 3.45907799534375*^9}, {3.459080904375*^9, 
   3.45908092684375*^9}, {3.45908103925*^9, 3.459081047125*^9}, {
   3.459081272515625*^9, 3.459081273359375*^9}, 3.45908270415625*^9, {
   3.45908301365625*^9, 3.459083043859375*^9}, 3.45908372865625*^9, {
   3.459112126203125*^9, 3.459112164203125*^9}, 3.45916170553125*^9, 
   3.459161890421875*^9, {3.459170302734375*^9, 3.45917031409375*^9}, {
   3.506858006512697*^9, 3.506858006982812*^9}, {3.506861249547703*^9, 
   3.506861281541944*^9}, {3.506929782109375*^9, 3.506929846890625*^9}, {
   3.50692998321875*^9, 3.506929984734375*^9}, {3.5069301465*^9, 
   3.50693015609375*^9}, {3.506930539078125*^9, 3.506930557125*^9}, {
   3.5751123923879538`*^9, 3.575112395173113*^9}, {3.5751125470538006`*^9, 
   3.575112548189865*^9}},
 FontFamily->"Times New Roman",
 FontSize->24,
 Background->GrayLevel[0.85]],

Cell[CellGroupData[{

Cell[TextData[StyleBox["Initialization, Definitions and Graphs",
 FontSize->22]], "Text",
 CellGroupingRules->{GroupTogetherGrouping, 10000.},
 CellChangeTimes->{{3.4561278892666187`*^9, 3.4561279023146544`*^9}, 
   3.456128006313026*^9, {3.4561281092059317`*^9, 3.456128161981234*^9}, {
   3.456138326441684*^9, 3.456138335084655*^9}, 3.457086838266417*^9, {
   3.457161408546215*^9, 3.4571614091944523`*^9}, 3.459076271296875*^9, {
   3.459077388375*^9, 3.459077392921875*^9}, {3.459077439234375*^9, 
   3.459077449953125*^9}, {3.459077842734375*^9, 3.45907785384375*^9}, {
   3.459077980265625*^9, 3.45907799534375*^9}, {3.459080904375*^9, 
   3.45908092684375*^9}, {3.45908103925*^9, 3.459081047125*^9}, {
   3.459081272515625*^9, 3.459081273359375*^9}, 3.45908270415625*^9, {
   3.45908301365625*^9, 3.459083043859375*^9}, 3.45908372865625*^9, {
   3.459112126203125*^9, 3.459112164203125*^9}, 3.45916170553125*^9, 
   3.459161890421875*^9, {3.459170302734375*^9, 3.45917031409375*^9}, {
   3.506858006512697*^9, 3.506858006982812*^9}, {3.506861249547703*^9, 
   3.506861281541944*^9}},
 FontFamily->"Times New Roman",
 FontSize->24,
 Background->GrayLevel[0.85]],

Cell[BoxData[
 RowBox[{
  RowBox[{"Clear", "[", "\"\<Global`*\>\"", "]"}], ";", 
  RowBox[{"Remove", "[", "\"\<Global`*\>\"", "]"}], ";", 
  RowBox[{"$Line", "=", "0"}], ";", 
  RowBox[{"Off", "[", 
   RowBox[{"General", "::", "spell1"}], "]"}], ";"}]], "Input",
 CellChangeTimes->{{3.480336963921875*^9, 3.480336966421875*^9}, 
   3.506866868823389*^9}],

Cell[BoxData[
 RowBox[{
  RowBox[{"SetOptions", "[", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{
     "Plot", ",", "ListPlot", ",", "ListPlot3D", ",", "Plot3D", ",", 
      "BarChart", ",", "DensityPlot"}], "}"}], ",", 
    RowBox[{"ImageSize", "\[Rule]", "600"}], ",", "\[IndentingNewLine]", 
    RowBox[{"LabelStyle", "\[Rule]", 
     RowBox[{"(", 
      RowBox[{"FontFamily", "\[Rule]", "\"\<Helvetica\>\""}], ")"}]}], ",", 
    RowBox[{"AxesStyle", "\[Rule]", 
     RowBox[{"Directive", "[", 
      RowBox[{"20", ",", 
       RowBox[{"Thickness", "[", "0.005", "]"}], ",", "Black"}], "]"}]}]}], 
   "]"}], ";"}]], "Input",
 CellGroupingRules->{GroupTogetherGrouping, 10001.},
 CellChangeTimes->{{3.431404133265625*^9, 3.431404152625*^9}, {
   3.431404184828125*^9, 3.43140419784375*^9}, {3.431404229828125*^9, 
   3.431404286*^9}, {3.431404358734375*^9, 3.431404362015625*^9}, 
   3.43140449659375*^9, {3.431404585328125*^9, 3.431404586390625*^9}, {
   3.431404647765625*^9, 3.431404694953125*^9}, {3.43140617875*^9, 
   3.4314062495625*^9}, {3.431406282875*^9, 3.4314063513125*^9}, {
   3.43140679328125*^9, 3.43140680225*^9}, {3.4314068341875*^9, 
   3.431406876078125*^9}, 3.431586168296875*^9, {3.456133135516242*^9, 
   3.45613315371024*^9}, 3.456133192744998*^9, {3.456139127607568*^9, 
   3.456139168352964*^9}, 3.456139229399897*^9, {3.456139834402177*^9, 
   3.456139847710493*^9}, 3.459112164203125*^9, {3.48033814621875*^9, 
   3.480338159609375*^9}, {3.50685442999006*^9, 3.5068544332318783`*^9}, {
   3.506865896770195*^9, 3.506865909318581*^9}},
 FontSize->18],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{
    RowBox[{"<<", 
     RowBox[{"/", "home"}]}], "/", "MyDir"}], "/", "Book"}], "-", 
  RowBox[{"Mathematica", "/", 
   RowBox[{"TellName2", ".", "m"}]}]}]], "Input",
 CellChangeTimes->{{3.5516932889290123`*^9, 3.55169338504627*^9}, {
  3.578549442991768*^9, 3.5785494494551373`*^9}},
 FontSize->16],

Cell[BoxData[
 RowBox[{"Date", "[", "]"}]], "Input",
 CellChangeTimes->{{3.48057813115625*^9, 3.4805781326875*^9}}],

Cell["\<\
We define the atomic density \[Rho](x,y) and the parameters  Z, \[Lambda]x, \
\[Lambda]y\
\>", "Text",
 CellChangeTimes->{{3.506858170041534*^9, 3.506858192511097*^9}, {
  3.5068582336528873`*^9, 3.506858254029193*^9}},
 FontFamily->"Times New Roman",
 FontSize->24,
 Background->GrayLevel[0.85]],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"\[Rho]", "[", 
    RowBox[{"x_", ",", "y_"}], "]"}], "=", 
   RowBox[{"Z", "*", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{
       RowBox[{"(", 
        RowBox[{"Sin", "[", 
         FractionBox[
          RowBox[{"2", " ", "\[Pi]", " ", "x"}], "\[Lambda]x"], "]"}], ")"}], 
       "^", "6"}], 
      RowBox[{
       RowBox[{"(", 
        RowBox[{"Sin", "[", 
         FractionBox[
          RowBox[{"2", " ", "\[Pi]", " ", "y"}], "\[Lambda]y"], "]"}], ")"}], 
       "^", "6"}]}], ")"}]}]}], ";"}]], "Input",
 CellChangeTimes->{{3.48057427009375*^9, 3.480574279546875*^9}, {
  3.506853337774859*^9, 3.506853348250214*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"Z", "=", "1"}], ";"}]], "Input",
 CellChangeTimes->{3.5067792936275167`*^9}],

Cell[BoxData[{
 RowBox[{
  RowBox[{"\[Lambda]x", "=", "1"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"\[Lambda]y", "=", "1"}], ";"}]}], "Input",
 CellChangeTimes->{{3.4803372055*^9, 3.480337209703125*^9}, {
  3.48033724053125*^9, 3.4803372446875*^9}, {3.4805742560625*^9, 
  3.480574257234375*^9}, {3.4805759023125*^9, 3.4805759023125*^9}, {
  3.480578178390625*^9, 3.48057817990625*^9}}],

Cell[TextData[{
 "Remark: The period of the periodic function ",
 Cell[BoxData[
  RowBox[{
   RowBox[{"(", 
    RowBox[{"Sin", "[", 
     FractionBox[
      RowBox[{"2", " ", "\[Pi]", " ", "x"}], "\[Lambda]x"], "]"}], ")"}], "^", 
   RowBox[{"(", 
    RowBox[{"2", " ", "n"}], ")"}]}]], "Input",
  CellChangeTimes->{{3.480337071578125*^9, 3.48033709375*^9}, {
    3.480337124234375*^9, 3.480337146171875*^9}, 3.48057422071875*^9, {
    3.506835460796875*^9, 3.50683546996875*^9}, 3.50685328752837*^9}],
 " is \[Lambda]x/2, with N integer. In fact"
}], "Text",
 CellChangeTimes->{{3.50685326579817*^9, 3.506853276839466*^9}, {
  3.506858270047806*^9, 3.5068583701802683`*^9}},
 FontFamily->"Times New Roman",
 FontSize->24,
 Background->GrayLevel[0.85]],

Cell[BoxData[
 RowBox[{"Plot", "[", 
  RowBox[{
   RowBox[{"Z", "*", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{"Sin", "[", 
       FractionBox[
        RowBox[{"2", " ", "\[Pi]", " ", "x"}], "\[Lambda]x"], "]"}], ")"}], 
     "^", "6"}]}], ",", 
   RowBox[{"{", 
    RowBox[{"x", ",", "0", ",", "\[Lambda]x"}], "}"}], ",", 
   RowBox[{"AxesLabel", "\[Rule]", 
    RowBox[{"{", 
     RowBox[{"\"\<x\>\"", ",", "\"\<\[Rho](x,y)\>\""}], "}"}]}]}], 
  "]"}]], "Input",
 CellChangeTimes->{{3.480337071578125*^9, 3.48033709375*^9}, {
   3.480337124234375*^9, 3.480337146171875*^9}, 3.48057422071875*^9, {
   3.506835460796875*^9, 3.50683546996875*^9}, 3.50685328752837*^9, {
   3.506858383138094*^9, 3.506858385820675*^9}}],

Cell[BoxData[
 RowBox[{"gra3D\[Rho]1", " ", "=", 
  RowBox[{"Plot3D", "[", 
   RowBox[{
    RowBox[{"Z", "*", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{
        RowBox[{"(", 
         RowBox[{"Sin", "[", 
          FractionBox[
           RowBox[{"2", " ", "\[Pi]", " ", "x"}], "\[Lambda]x"], "]"}], ")"}],
         "^", "6"}], 
       RowBox[{
        RowBox[{"(", 
         RowBox[{"Sin", "[", 
          FractionBox[
           RowBox[{"2", " ", "\[Pi]", " ", "y"}], "\[Lambda]y"], "]"}], ")"}],
         "^", "6"}]}], ")"}]}], ",", "\[IndentingNewLine]", 
    "                 ", 
    RowBox[{"{", 
     RowBox[{"x", ",", 
      RowBox[{
       RowBox[{"-", 
        FractionBox["\[Lambda]x", "2"]}], "-", 
       RowBox[{"0.1", "*", "\[Lambda]x"}]}], ",", 
      RowBox[{
       FractionBox["\[Lambda]x", "2"], "+", 
       RowBox[{"0.1", "*", "\[Lambda]x"}]}]}], "}"}], ",", 
    RowBox[{"{", 
     RowBox[{"y", ",", 
      RowBox[{
       RowBox[{"-", 
        FractionBox["\[Lambda]y", "2"]}], "-", 
       RowBox[{"0.1", "*", "\[Lambda]y"}]}], ",", 
      RowBox[{
       FractionBox["\[Lambda]y", "2"], "+", 
       RowBox[{"0.1", "*", "\[Lambda]y"}]}]}], "}"}], ",", "   ", 
    "\[IndentingNewLine]", "                          ", 
    RowBox[{"PlotLabel", "\[Rule]", "\"\<\[Rho](x,y)\>\""}], ",", " ", 
    RowBox[{"AxesLabel", "\[Rule]", 
     RowBox[{"{", 
      RowBox[{"\"\<x\>\"", ",", "\"\<y\>\"", ",", "\"\<\[Rho](x,y)\>\""}], 
      "}"}]}]}], "]"}]}]], "Input",
 CellChangeTimes->{{3.480337071578125*^9, 3.48033709375*^9}, {
  3.480574240953125*^9, 3.480574249765625*^9}, {3.506778996714982*^9, 
  3.506779013303349*^9}, {3.5068532998025417`*^9, 3.506853310817412*^9}, {
  3.506858443591165*^9, 3.506858488931209*^9}, {3.5068585246951647`*^9, 
  3.5068585308139687`*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"DensityPlot", "[", 
   RowBox[{
    RowBox[{"\[Rho]", "[", 
     RowBox[{"x", ",", "y"}], "]"}], ",", 
    RowBox[{"{", 
     RowBox[{"x", ",", 
      RowBox[{
       RowBox[{"-", 
        FractionBox["\[Lambda]x", "2"]}], "-", 
       RowBox[{"0.1", "*", "\[Lambda]x"}]}], ",", 
      RowBox[{
       FractionBox["\[Lambda]x", "2"], "+", 
       RowBox[{"0.1", "*", "\[Lambda]x"}]}]}], "}"}], ",", 
    RowBox[{"{", 
     RowBox[{"y", ",", 
      RowBox[{
       RowBox[{"-", 
        FractionBox["\[Lambda]y", "2"]}], "-", 
       RowBox[{"0.1", "*", "\[Lambda]y"}]}], ",", 
      RowBox[{
       FractionBox["\[Lambda]y", "2"], "+", 
       RowBox[{"0.1", "*", "\[Lambda]y"}]}]}], "}"}], ",", 
    RowBox[{"PlotLabel", "\[Rule]", "\"\<\[Rho](x,y) top view\>\""}]}], "]"}],
   "\[IndentingNewLine]"}]], "Input",
 CellChangeTimes->{{3.48057433596875*^9, 3.480574341609375*^9}, 
   3.480585905515625*^9, {3.5068585642131243`*^9, 3.506858585575338*^9}, {
   3.5068599890229673`*^9, 3.506859993113852*^9}}]
}, Open  ]],

Cell[CellGroupData[{

Cell["Section I.A", "Text",
 CellChangeTimes->{{3.480337450140625*^9, 3.48033745403125*^9}, {
  3.506858615413578*^9, 3.506858654687529*^9}, {3.5068587174772*^9, 
  3.5068587179122353`*^9}, {3.506861393525679*^9, 3.506861395850875*^9}, {
  3.506930066703125*^9, 3.50693006828125*^9}},
 FontFamily->"Times New Roman",
 FontSize->24,
 Background->GrayLevel[0.85]],

Cell["\<\
We express the \[Rho](x,y)  in terms of complex exponentials\
\>", "Text",
 CellChangeTimes->{{3.480337450140625*^9, 3.48033745403125*^9}, {
  3.506858615413578*^9, 3.506858654687529*^9}, {3.5068587174772*^9, 
  3.5068587179122353`*^9}},
 FontFamily->"Times New Roman",
 FontSize->24,
 Background->GrayLevel[0.85]],

Cell[BoxData[
 RowBox[{"\[Rho]withexp", "=", 
  RowBox[{"Apart", "[", 
   RowBox[{"TrigToExp", "[", 
    RowBox[{"\[Rho]", "[", 
     RowBox[{"x", ",", "y"}], "]"}], "]"}], "]"}]}]], "Input",
 CellChangeTimes->{
  3.480337466640625*^9, {3.5068355679375*^9, 3.50683557375*^9}}],

Cell["\<\
We observe that  only a finite number of terms of the Fourier expansions are \
necessary, that is, those with 
h = k = 2, 4 , 6.\
\>", "Text",
 CellChangeTimes->{{3.480337450140625*^9, 3.48033745403125*^9}, {
  3.506858615413578*^9, 3.506858654687529*^9}, {3.5068587174772*^9, 
  3.5068587179122353`*^9}, {3.50685905976334*^9, 3.506859071295389*^9}, {
  3.5068591391619663`*^9, 3.506859219644981*^9}},
 FontFamily->"Times New Roman",
 FontSize->24,
 Background->GrayLevel[0.85]],

Cell[BoxData[
 RowBox[{
  RowBox[{"\[Rho]expExpand", "[", 
   RowBox[{"x_", ",", "y_"}], "]"}], "=", 
  RowBox[{"Expand", "[", "\[Rho]withexp", "]"}]}]], "Input",
 CellChangeTimes->{{3.480337466640625*^9, 3.4803374896875*^9}, {
   3.480574449015625*^9, 3.4805744523125*^9}, 3.480574512796875*^9, {
   3.50683558378125*^9, 3.506835625734375*^9}}],

Cell["Just to verify ...", "Text",
 CellChangeTimes->{{3.480337450140625*^9, 3.48033745403125*^9}, {
  3.506858615413578*^9, 3.506858654687529*^9}, {3.50685870271108*^9, 
  3.506858712233265*^9}},
 FontFamily->"Times New Roman",
 FontSize->24,
 Background->GrayLevel[0.85]],

Cell[BoxData[
 RowBox[{
  RowBox[{"gra3D\[Rho]2", "=", 
   RowBox[{"Plot3D", "[", 
    RowBox[{
     RowBox[{"Evaluate", "[", 
      RowBox[{"\[Rho]expExpand", "[", 
       RowBox[{"x", ",", "y"}], "]"}], "]"}], ",", 
     RowBox[{"{", 
      RowBox[{"x", ",", 
       RowBox[{
        RowBox[{"-", 
         FractionBox["\[Lambda]x", "2"]}], "-", 
        RowBox[{"0.1", "*", "\[Lambda]x"}]}], ",", 
       RowBox[{
        FractionBox["\[Lambda]x", "2"], "+", 
        RowBox[{"0.1", "*", "\[Lambda]x"}]}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"y", ",", 
       RowBox[{
        RowBox[{"-", 
         FractionBox["\[Lambda]y", "2"]}], "-", 
        RowBox[{"0.1", "*", "\[Lambda]y"}]}], ",", 
       RowBox[{
        FractionBox["\[Lambda]y", "2"], "+", 
        RowBox[{"0.1", "*", "\[Lambda]y"}]}]}], "}"}], ",", 
     RowBox[{
     "PlotLabel", "\[Rule]", 
      "\"\<\[Rho](x,y)=Z*((Sin[\!\(\*FractionBox[\(2\\\ \[Pi]\\\ x\), \(\
\[Lambda]x\)]\)])^6(Sin[\!\(\*FractionBox[\(2\\\ \[Pi]\\\ y\), \
\(\[Lambda]y\)]\)])^6)\>\""}], ",", "\[IndentingNewLine]", 
     RowBox[{"AxesLabel", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{"\"\<x\>\"", ",", "\"\<y\>\"", ",", "\"\<\[Rho](x,y)\>\""}], 
       "}"}]}]}], "]"}]}], "\[IndentingNewLine]"}]], "Input",
 CellChangeTimes->{{3.480574317015625*^9, 3.480574322265625*^9}, {
   3.480585863078125*^9, 3.480585890265625*^9}, {3.4805859986875*^9, 
   3.48058600234375*^9}, {3.480586229921875*^9, 3.4805862333125*^9}, {
   3.506779425688333*^9, 3.506779432367873*^9}, 3.50683565321875*^9, {
   3.506836124921875*^9, 3.5068361550625*^9}, {3.506857316884266*^9, 
   3.506857366180129*^9}, {3.506865945318768*^9, 3.5068659517695007`*^9}}]
}, Open  ]],

Cell[CellGroupData[{

Cell["Section I.B", "Text",
 CellChangeTimes->{{3.480337450140625*^9, 3.48033745403125*^9}, {
  3.506858615413578*^9, 3.506858654687529*^9}, {3.5068587174772*^9, 
  3.5068587179122353`*^9}, {3.506861393525679*^9, 3.506861395850875*^9}, {
  3.5068614865007753`*^9, 3.506861487054907*^9}, {3.506930072859375*^9, 
  3.5069300735625*^9}},
 FontFamily->"Times New Roman",
 FontSize->24,
 Background->GrayLevel[0.85]],

Cell["\<\
 With the following expression we can calculate the  Fourier coefficients \
one-by-one.
In the following we  h \[LongLeftArrow] m,  k \[LongLeftArrow] n.\
\>", "Text",
 CellChangeTimes->{{3.506854537832323*^9, 3.5068545865961437`*^9}, 
   3.5068546736373568`*^9, {3.506854759123962*^9, 3.506854796157324*^9}, {
   3.506858886085376*^9, 3.506858894423806*^9}, {3.506866018175528*^9, 
   3.5068660303742027`*^9}, {3.506866091384695*^9, 3.5068661130472*^9}},
 FontFamily->"Times New Roman",
 FontSize->24,
 Background->GrayLevel[0.85]],

Cell[BoxData[
 RowBox[{
  RowBox[{"coef\[Rho]", "[", 
   RowBox[{"m_", ",", "n_"}], "]"}], ":=", "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    FractionBox["1", 
     RowBox[{"\[Lambda]x", "*", "\[Lambda]y"}]], "*", 
    RowBox[{
     SubsuperscriptBox["\[Integral]", "0", 
      RowBox[{"\[Lambda]x", " "}]], 
     RowBox[{
      SubsuperscriptBox["\[Integral]", "0", "\[Lambda]y"], " ", 
      RowBox[{
       RowBox[{"\[Rho]", "[", 
        RowBox[{"x", ",", "y"}], "]"}], "*", 
       RowBox[{"Exp", "[", 
        RowBox[{
         RowBox[{"-", "\[ImaginaryI]"}], " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{
            FractionBox[
             RowBox[{"2", " ", "\[Pi]", " ", "m"}], "\[Lambda]x"], " ", "x"}],
            " ", "+", " ", 
           RowBox[{
            FractionBox[
             RowBox[{"2", " ", "\[Pi]", " ", "n"}], "\[Lambda]y"], " ", 
            "y"}]}], ")"}]}], "]"}], 
       RowBox[{"\[DifferentialD]", "y"}], " ", 
       RowBox[{"\[DifferentialD]", "x"}]}]}]}]}], " ", "//", 
   "Chop"}]}]], "Input",
 CellChangeTimes->{{3.506853413608817*^9, 3.506853420386717*^9}, {
   3.50685346087473*^9, 3.506853512467503*^9}, 3.506853607316888*^9, {
   3.5068536598817263`*^9, 3.506853677239573*^9}, {3.506853737622998*^9, 
   3.5068537419545813`*^9}, {3.506853853965234*^9, 3.506853870822291*^9}, {
   3.506858862063613*^9, 3.506858864759335*^9}},
 FontSize->18],

Cell["It is useful for further checking", "Text",
 CellChangeTimes->{{3.506858910448209*^9, 3.506858929547999*^9}},
 FontFamily->"Times New Roman",
 FontSize->24,
 Background->GrayLevel[0.85]],

Cell[BoxData[
 RowBox[{
  StyleBox["coef\[Rho]00",
   FontColor->RGBColor[1, 0, 0]], "=", "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    FractionBox["1", 
     RowBox[{"\[Lambda]x", "*", "\[Lambda]y"}]], "*", 
    RowBox[{
     SubsuperscriptBox["\[Integral]", "0", 
      RowBox[{"\[Lambda]x", " "}]], 
     RowBox[{
      SubsuperscriptBox["\[Integral]", "0", "\[Lambda]y"], " ", 
      RowBox[{
       RowBox[{"\[Rho]", "[", 
        RowBox[{"x", ",", "y"}], "]"}], "*", 
       RowBox[{"Exp", "[", 
        RowBox[{
         RowBox[{"-", "\[ImaginaryI]"}], " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{
            FractionBox[
             RowBox[{"2", " ", "\[Pi]", " ", "0"}], "\[Lambda]x"], " ", "x"}],
            " ", "+", " ", 
           RowBox[{
            FractionBox[
             RowBox[{"2", " ", "\[Pi]", " ", "0"}], "\[Lambda]y"], " ", 
            "y"}]}], ")"}]}], "]"}], 
       RowBox[{"\[DifferentialD]", "y"}], " ", 
       RowBox[{"\[DifferentialD]", "x"}]}]}]}]}], " ", "//", 
   "Chop"}]}]], "Input",
 CellChangeTimes->{{3.506853413608817*^9, 3.506853420386717*^9}, {
   3.50685346087473*^9, 3.506853512467503*^9}, 3.506853607316888*^9, {
   3.506853881062399*^9, 3.5068539526224203`*^9}},
 FontSize->18],

Cell[BoxData[
 RowBox[{
  StyleBox["coef\[Rho]10",
   FontColor->RGBColor[1, 0, 0]], "=", "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    FractionBox["1", 
     RowBox[{"\[Lambda]x", "*", "\[Lambda]y"}]], "*", 
    RowBox[{
     SubsuperscriptBox["\[Integral]", "0", 
      RowBox[{"\[Lambda]x", " "}]], 
     RowBox[{
      SubsuperscriptBox["\[Integral]", "0", "\[Lambda]y"], " ", 
      RowBox[{
       RowBox[{"\[Rho]", "[", 
        RowBox[{"x", ",", "y"}], "]"}], "*", 
       RowBox[{"Exp", "[", 
        RowBox[{
         RowBox[{"-", "\[ImaginaryI]"}], " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{
            FractionBox[
             RowBox[{"2", " ", "\[Pi]", " ", "1"}], "\[Lambda]x"], " ", "x"}],
            " ", "+", " ", 
           RowBox[{
            FractionBox[
             RowBox[{"2", " ", "\[Pi]", " ", "0"}], "\[Lambda]y"], " ", 
            "y"}]}], ")"}]}], "]"}], 
       RowBox[{"\[DifferentialD]", "y"}], " ", 
       RowBox[{"\[DifferentialD]", "x"}]}]}]}]}], " ", "//", 
   "Chop"}]}]], "Input",
 CellChangeTimes->{{3.506853413608817*^9, 3.506853420386717*^9}, {
   3.50685346087473*^9, 3.506853512467503*^9}, 3.506853607316888*^9, {
   3.506853881062399*^9, 3.506853972390997*^9}},
 FontSize->18],

Cell[BoxData[
 RowBox[{
  StyleBox["coef\[Rho]20",
   FontColor->RGBColor[1, 0, 0]], "=", "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    FractionBox["1", 
     RowBox[{"\[Lambda]x", "*", "\[Lambda]y"}]], "*", 
    RowBox[{
     SubsuperscriptBox["\[Integral]", "0", 
      RowBox[{"\[Lambda]x", " "}]], 
     RowBox[{
      SubsuperscriptBox["\[Integral]", "0", "\[Lambda]y"], " ", 
      RowBox[{
       RowBox[{"\[Rho]", "[", 
        RowBox[{"x", ",", "y"}], "]"}], "*", 
       RowBox[{"Exp", "[", 
        RowBox[{
         RowBox[{"-", "\[ImaginaryI]"}], " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{
            FractionBox[
             RowBox[{"2", " ", "\[Pi]", " ", "2"}], "\[Lambda]x"], " ", "x"}],
            " ", "+", " ", 
           RowBox[{
            FractionBox[
             RowBox[{"2", " ", "\[Pi]", " ", "0"}], "\[Lambda]y"], " ", 
            "y"}]}], ")"}]}], "]"}], 
       RowBox[{"\[DifferentialD]", "y"}], " ", 
       RowBox[{"\[DifferentialD]", "x"}]}]}]}]}], " ", "//", 
   "Chop"}]}]], "Input",
 CellChangeTimes->{{3.506853413608817*^9, 3.506853420386717*^9}, {
   3.50685346087473*^9, 3.506853512467503*^9}, 3.506853607316888*^9, {
   3.506853881062399*^9, 3.5068539930009604`*^9}, {3.506854050740521*^9, 
   3.506854060952449*^9}},
 FontSize->18],

Cell["Now  BarChart when h= 6 and k = -6,-5,...+6", "Text",
 CellChangeTimes->{{3.506858976513879*^9, 3.506858983597492*^9}, {
  3.506859237242876*^9, 3.5068592856911497`*^9}},
 FontFamily->"Times New Roman",
 FontSize->24,
 Background->GrayLevel[0.85]],

Cell[BoxData[
 RowBox[{"Timing", "[", 
  RowBox[{"BarChart", "[", 
   RowBox[{
    RowBox[{"Table", "[", 
     RowBox[{
      RowBox[{"Limit", "[", 
       RowBox[{
        RowBox[{"coef\[Rho]", "[", 
         RowBox[{"6", ",", "nn"}], "]"}], ",", 
        RowBox[{"nn", "\[Rule]", "jj"}], ",", 
        RowBox[{"Direction", "\[Rule]", "1"}]}], "]"}], ",", 
      RowBox[{"{", 
       RowBox[{"jj", ",", 
        RowBox[{"-", "6"}], ",", "6"}], "}"}]}], "]"}], ",", 
    RowBox[{"ImageSize", "\[Rule]", "500"}]}], "]"}], " ", "]"}]], "Input",
 CellChangeTimes->{
  3.506854111427039*^9, {3.5068543090943623`*^9, 3.506854316722907*^9}, {
   3.506854371438354*^9, 3.506854380597989*^9}, {3.506858993558634*^9, 
   3.506858995965232*^9}},
 FontSize->24],

Cell["\<\
We can find also a general expression for the Fourier coefficients. Timing \
indicates that a small difference appears depending on the interval of \
integration and a significant difference when the complex exponential form is \
used.\
\>", "Text",
 CellChangeTimes->{{3.480574783203125*^9, 3.48057480971875*^9}, {
   3.506859305136689*^9, 3.506859332877553*^9}, {3.506859368976349*^9, 
   3.506859474573471*^9}, 3.506919854265625*^9, {3.50691998978125*^9, 
   3.50691999478125*^9}},
 FontFamily->"Times New Roman",
 FontSize->24,
 Background->GrayLevel[0.85]],

Cell[BoxData[
 RowBox[{"Timing", "[", 
  RowBox[{
   RowBox[{"coef1mn\[Rho]", "[", 
    RowBox[{"m_", ",", "n_"}], "]"}], "=", 
   RowBox[{
    RowBox[{"Simplify", "[", 
     RowBox[{
      FractionBox["1", 
       RowBox[{"\[Lambda]x", " ", "\[Lambda]y"}]], 
      RowBox[{"Integrate", "[", 
       RowBox[{
        RowBox[{
         RowBox[{"\[Rho]", "[", 
          RowBox[{"x", ",", "y"}], "]"}], 
         RowBox[{"Exp", "[", 
          RowBox[{
           RowBox[{"-", "\[ImaginaryI]"}], " ", 
           FractionBox[
            RowBox[{"2", " ", "\[Pi]", " ", "m"}], "\[Lambda]x"], " ", "x"}], 
          "]"}], " ", 
         RowBox[{"Exp", "[", 
          RowBox[{
           RowBox[{"-", "\[ImaginaryI]"}], " ", 
           FractionBox[
            RowBox[{"2", " ", "\[Pi]", " ", "n"}], "\[Lambda]y"], " ", "y"}], 
          "]"}]}], ",", 
        RowBox[{"{", 
         RowBox[{"x", ",", "0", ",", "\[Lambda]x"}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{"y", ",", "0", ",", "\[Lambda]y"}], "}"}]}], "]"}]}], "]"}], 
    "//", "Chop"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.480337719296875*^9, 3.480337724421875*^9}, {
  3.480337799859375*^9, 3.48033780553125*^9}, {3.506779500343532*^9, 
  3.506779516425398*^9}, {3.50683572903125*^9, 3.506835772734375*^9}, {
  3.506844410671875*^9, 3.50684442384375*^9}}],

Cell["\<\
There are three values of m and n which nullify the denominator\
\>", "Text",
 CellChangeTimes->{{3.480574783203125*^9, 3.48057480971875*^9}, {
   3.506859305136689*^9, 3.506859332877553*^9}, {3.506859368976349*^9, 
   3.506859474573471*^9}, 3.506919854265625*^9, {3.506919899796875*^9, 
   3.506919945046875*^9}},
 FontFamily->"Times New Roman",
 FontSize->24,
 Background->GrayLevel[0.85]],

Cell[BoxData[
 RowBox[{"denom", " ", "=", " ", 
  RowBox[{
   RowBox[{"Denominator", "[", 
    RowBox[{"coef1mn\[Rho]", "[", 
     RowBox[{"m", ",", "n"}], "]"}], "]"}], "[", 
   RowBox[{"[", "3", "]"}], "]"}]}]], "Input",
 CellChangeTimes->{{3.506867713208016*^9, 3.506867739015609*^9}, {
  3.506867840764373*^9, 3.5068678452241383`*^9}, {3.506867893744417*^9, 
  3.506867943454496*^9}}],

Cell[BoxData[
 RowBox[{"roots", " ", "=", " ", 
  RowBox[{"Reduce", "[", 
   RowBox[{
    RowBox[{"denom", " ", "==", " ", "0"}], ",", " ", "m"}], "]"}]}]], "Input",\

 CellChangeTimes->{{3.5068676714547873`*^9, 3.5068676714561853`*^9}, {
  3.5068679607436533`*^9, 3.506868003310894*^9}}],

Cell[BoxData[
 RowBox[{"Plot", "[", 
  RowBox[{
   FormBox[
    RowBox[{
     SuperscriptBox["m", "6"], "-", 
     RowBox[{"56", " ", 
      SuperscriptBox["m", "4"]}], "+", 
     RowBox[{"784", " ", 
      SuperscriptBox["m", "2"]}], "-", "2304"}],
    TraditionalForm], ",", " ", 
   RowBox[{"{", 
    RowBox[{"m", ",", " ", "0", ",", " ", "8"}], "}"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.5068676714547873`*^9, 3.5068676714561853`*^9}, 
   3.5068679607436533`*^9}],

Cell[BoxData[
 RowBox[{"Timing", "[", 
  RowBox[{
   RowBox[{"coef2mn\[Rho]", "[", 
    RowBox[{"m_", ",", "n_"}], "]"}], "=", 
   RowBox[{
    RowBox[{"Simplify", "[", 
     RowBox[{
      FractionBox["1", 
       RowBox[{"\[Lambda]x", " ", "\[Lambda]y"}]], 
      RowBox[{"Integrate", "[", 
       RowBox[{
        RowBox[{
         RowBox[{"\[Rho]", "[", 
          RowBox[{"x", ",", "y"}], "]"}], 
         RowBox[{"Exp", "[", 
          RowBox[{
           RowBox[{"-", "\[ImaginaryI]"}], " ", 
           FractionBox[
            RowBox[{"2", " ", "\[Pi]", " ", "m"}], "\[Lambda]x"], " ", "x"}], 
          "]"}], " ", 
         RowBox[{"Exp", "[", 
          RowBox[{
           RowBox[{"-", "\[ImaginaryI]"}], " ", 
           FractionBox[
            RowBox[{"2", " ", "\[Pi]", " ", "n"}], "\[Lambda]y"], " ", "y"}], 
          "]"}]}], ",", 
        RowBox[{"{", 
         RowBox[{"x", ",", 
          RowBox[{
           RowBox[{"-", "\[Lambda]x"}], "/", "2"}], ",", 
          RowBox[{"\[Lambda]x", "/", "2"}]}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{"y", ",", 
          RowBox[{
           RowBox[{"-", "\[Lambda]y"}], "/", "2"}], ",", 
          RowBox[{"\[Lambda]y", "/", "2"}]}], "}"}]}], "]"}]}], "]"}], "//", 
    "Chop"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.480337719296875*^9, 3.480337724421875*^9}, {
   3.480337799859375*^9, 3.48033780553125*^9}, {3.506835761765625*^9, 
   3.5068357754375*^9}, 3.5068444376875*^9}],

Cell[BoxData[
 RowBox[{"Timing", "[", 
  RowBox[{
   RowBox[{"coef3mn\[Rho]", "[", 
    RowBox[{"m_", ",", "n_"}], "]"}], "=", 
   RowBox[{
    RowBox[{"Simplify", "[", 
     RowBox[{
      FractionBox["1", 
       RowBox[{"\[Lambda]x", " ", "\[Lambda]y"}]], 
      RowBox[{"Integrate", "[", 
       RowBox[{
        RowBox[{
         RowBox[{"\[Rho]expExpand", "[", 
          RowBox[{"x", ",", "y"}], "]"}], 
         RowBox[{"Exp", "[", 
          RowBox[{
           RowBox[{"-", "\[ImaginaryI]"}], " ", 
           FractionBox[
            RowBox[{"2", " ", "\[Pi]", " ", "m"}], "\[Lambda]x"], " ", "x"}], 
          "]"}], " ", 
         RowBox[{"Exp", "[", 
          RowBox[{
           RowBox[{"-", "\[ImaginaryI]"}], " ", 
           FractionBox[
            RowBox[{"2", " ", "\[Pi]", " ", "n"}], "\[Lambda]y"], " ", "y"}], 
          "]"}]}], ",", 
        RowBox[{"{", 
         RowBox[{"x", ",", 
          RowBox[{
           RowBox[{"-", "\[Lambda]x"}], "/", "2"}], ",", 
          RowBox[{"\[Lambda]x", "/", "2"}]}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{"y", ",", 
          RowBox[{
           RowBox[{"-", "\[Lambda]y"}], "/", "2"}], ",", 
          RowBox[{"\[Lambda]y", "/", "2"}]}], "}"}]}], "]"}]}], "]"}], "//", 
    "Chop"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.48033776678125*^9, 3.480337774765625*^9}, {
   3.506779767889539*^9, 3.506779788701531*^9}, {3.506779822887382*^9, 
   3.50677983100067*^9}, 3.5068358368125*^9, {3.506835878953125*^9, 
   3.506835898171875*^9}, 3.506841614578125*^9, 3.50684445875*^9}],

Cell["\<\
To construct a general view of the coefficients we need the built-in command \
Limit and
define the numers of terms\
\>", "Text",
 CellChangeTimes->{{3.480574783203125*^9, 3.48057480971875*^9}, {
   3.506859305136689*^9, 3.506859332877553*^9}, {3.506859368976349*^9, 
   3.506859474573471*^9}, 3.506859532665609*^9, {3.506859604900346*^9, 
   3.5068596839529133`*^9}, {3.506859769303937*^9, 3.506859790731352*^9}},
 FontFamily->"Times New Roman",
 FontSize->24,
 Background->GrayLevel[0.85]],

Cell[BoxData[
 RowBox[{
  RowBox[{"ntx2", "=", "6"}], ";"}]], "Input",
 CellChangeTimes->{{3.48057590903125*^9, 3.48057595640625*^9}, {
  3.480578082828125*^9, 3.480578083578125*^9}, {3.506838654765625*^9, 
  3.506838657359375*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"nty2", "=", "6"}], ";"}]], "Input",
 CellChangeTimes->{{3.48057590903125*^9, 3.48057596015625*^9}, {
   3.5068386608125*^9, 3.506838664546875*^9}, 3.5068597205293016`*^9}],

Cell[BoxData[
 RowBox[{
  RowBox[{"Timing", "[", 
   RowBox[{"Do", "[", 
    RowBox[{
     RowBox[{"Do", "[", 
      RowBox[{
       RowBox[{
        RowBox[{"coefmn\[Rho]limit", "[", 
         RowBox[{"m", ",", "n"}], "]"}], "=", 
        RowBox[{
         RowBox[{"Simplify", "[", 
          RowBox[{"Limit", "[", 
           RowBox[{
            RowBox[{"Limit", "[", 
             RowBox[{
              RowBox[{"coef2mn\[Rho]", "[", 
               RowBox[{"mm", ",", "nn"}], "]"}], ",", 
              RowBox[{"mm", "\[Rule]", "m"}]}], "]"}], ",", 
            RowBox[{"nn", "\[Rule]", "n"}]}], "]"}], "]"}], "//", "Chop"}]}], 
       ",", 
       RowBox[{"{", 
        RowBox[{"m", ",", 
         RowBox[{
          RowBox[{"-", "ntx2"}], "-", "1"}], ",", 
         RowBox[{"ntx2", "+", "1"}], ",", "1"}], "}"}]}], "]"}], ",", 
     RowBox[{"{", 
      RowBox[{"n", ",", 
       RowBox[{
        RowBox[{"-", "nty2"}], " ", "-", "1"}], ",", 
       RowBox[{"nty2", "+", "1"}], ",", "1"}], "}"}]}], "]"}], "]"}], 
  "  "}]], "Input",
 CellChangeTimes->{
  3.506830240171875*^9, {3.5068358901875*^9, 3.506835969375*^9}, {
   3.5068365601875*^9, 3.50683658525*^9}, {3.50683663303125*^9, 
   3.506836647765625*^9}, {3.50683676696875*^9, 3.506836795671875*^9}, {
   3.506837456375*^9, 3.50683749284375*^9}, {3.5068390136875*^9, 
   3.506839025625*^9}, {3.506859538058672*^9, 3.5068595400924263`*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"tabcoef\[Rho]", "=", 
   RowBox[{"Table", "[", 
    RowBox[{
     RowBox[{"Table", "[", 
      RowBox[{
       RowBox[{"coefmn\[Rho]limit", "[", 
        RowBox[{"m", ",", "n"}], "]"}], ",", 
       RowBox[{"{", 
        RowBox[{"m", ",", 
         RowBox[{
          RowBox[{"-", "ntx2"}], "-", "1"}], ",", 
         RowBox[{"ntx2", "+", "1"}], ",", "1"}], "}"}]}], "]"}], ",", 
     RowBox[{"{", 
      RowBox[{"n", ",", 
       RowBox[{
        RowBox[{"-", "nty2"}], " ", "-", "1"}], ",", 
       RowBox[{"nty2", "+", "1"}], ",", "1"}], "}"}]}], "]"}]}], 
  ";"}]], "Input",
 CellChangeTimes->{{3.5067755878888273`*^9, 3.506775587911757*^9}, {
   3.5067756310422173`*^9, 3.506775636444723*^9}, {3.5067766236405497`*^9, 
   3.5067766307929792`*^9}, {3.50683693915625*^9, 3.50683697946875*^9}, 
   3.5068370549375*^9, {3.50683904903125*^9, 3.50683907084375*^9}, {
   3.50683917209375*^9, 3.50683919328125*^9}, {3.506859554500267*^9, 
   3.506859560130862*^9}},
 FontSize->24],

Cell[BoxData[
 RowBox[{"tabcoef\[Rho]", "//", "MatrixForm"}]], "Input",
 CellChangeTimes->{{3.506837013546875*^9, 3.50683703409375*^9}, 
   3.5068595675644207`*^9, 3.5068619485926247`*^9}],

Cell[BoxData[
 RowBox[{"Date", "[", "]"}]], "Input",
 CellChangeTimes->{{3.480574883328125*^9, 3.4805748845625*^9}}],

Cell[BoxData[
 RowBox[{"ListPlot3D", "[", 
  RowBox[{"tabcoef\[Rho]", ",", 
   RowBox[{
   "PlotLabel", "\[Rule]", 
    "\"\<discrete view of coefmn\[Rho]limit[m,n]\>\""}]}], "]"}]], "Input",
 CellChangeTimes->{{3.480338125078125*^9, 3.480338130625*^9}, 
   3.506843882734375*^9, 3.506859573834304*^9, {3.506859815165773*^9, 
   3.506859842605032*^9}}],

Cell[BoxData[
 RowBox[{"ListContourPlot", "[", 
  RowBox[{"tabcoef\[Rho]", ",", 
   RowBox[{
   "PlotLabel", "\[Rule]", 
    "\"\<another view of coefmn\[Rho]limit[m,n]\>\""}]}], "]"}]], "Input",
 CellChangeTimes->{
  3.506843884625*^9, 3.506859579670528*^9, {3.506859861984846*^9, 
   3.50685987345465*^9}}]
}, Open  ]],

Cell[CellGroupData[{

Cell["Section I.C", "Text",
 CellChangeTimes->{{3.480337450140625*^9, 3.48033745403125*^9}, {
  3.506858615413578*^9, 3.506858654687529*^9}, {3.5068587174772*^9, 
  3.5068587179122353`*^9}, {3.506861393525679*^9, 3.506861395850875*^9}, {
  3.5068614865007753`*^9, 3.506861487054907*^9}, {3.506861557089506*^9, 
  3.506861557745035*^9}, {3.50693007821875*^9, 3.506930078921875*^9}},
 FontFamily->"Times New Roman",
 FontSize->24,
 Background->GrayLevel[0.85]],

Cell["It is wise to reconstruct the original", "Text",
 CellChangeTimes->{{3.506859907876388*^9, 3.506859947977003*^9}, {
  3.506866167393362*^9, 3.5068661816322947`*^9}},
 FontFamily->"Times New Roman",
 FontSize->24,
 Background->GrayLevel[0.85]],

Cell[BoxData[
 RowBox[{
  RowBox[{"S", "[", 
   RowBox[{"x_", ",", "y_", ",", "ntx_", ",", "nty_"}], "]"}], ":=", 
  RowBox[{
   RowBox[{
    UnderoverscriptBox["\[Sum]", 
     RowBox[{"m", "=", 
      RowBox[{"-", "ntx"}]}], "ntx"], 
    RowBox[{
     UnderoverscriptBox["\[Sum]", 
      RowBox[{"n", "=", 
       StyleBox[
        RowBox[{"-", "nty"}],
        FontColor->RGBColor[1, 0, 0]]}], "nty"], 
     RowBox[{
      RowBox[{"coefmn\[Rho]limit", "[", 
       RowBox[{"m", ",", "n"}], "]"}], "*", 
      SuperscriptBox["\[ExponentialE]", 
       RowBox[{"I", "*", 
        RowBox[{"(", 
         StyleBox[
          RowBox[{
           RowBox[{
            FractionBox[
             RowBox[{"2", " ", "\[Pi]", " ", "m"}], "\[Lambda]x"], " ", "x"}],
            "+", 
           RowBox[{
            FractionBox[
             RowBox[{"2", " ", "\[Pi]", " ", "n"}], "\[Lambda]y"], " ", 
            "y"}]}],
          FontSize->24], ")"}]}]]}]}]}], " ", "//", "Chop"}]}]], "Input",
 CellChangeTimes->{{3.431321031421875*^9, 3.4313210425625*^9}, {
   3.500441560609375*^9, 3.500441595578125*^9}, {3.500443328765625*^9, 
   3.50044334603125*^9}, {3.5068385855625*^9, 3.506838626171875*^9}, {
   3.50683870196875*^9, 3.50683870434375*^9}, {3.506838765125*^9, 
   3.506838799234375*^9}, 3.506839273375*^9, {3.50684428521875*^9, 
   3.506844355421875*^9}},
 FontSize->24],

Cell["We consider the partial sums when ntx=nty=4 and ntx=nty=6", "Text",
 CellChangeTimes->{{3.506860414073595*^9, 3.5068604579039183`*^9}, 
   3.506866220971305*^9},
 FontFamily->"Times New Roman",
 FontSize->24,
 Background->GrayLevel[0.85]],

Cell[BoxData[
 RowBox[{
  RowBox[{"ntx1", "=", "4"}], ";"}]], "Input",
 CellChangeTimes->{{3.48057590903125*^9, 3.48057595640625*^9}, {
  3.480578082828125*^9, 3.480578083578125*^9}, {3.506838654765625*^9, 
  3.506838657359375*^9}, {3.506862089177499*^9, 3.506862093291448*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"nty1", "=", "4"}], ";"}]], "Input",
 CellChangeTimes->{{3.48057590903125*^9, 3.48057596015625*^9}, {
   3.5068386608125*^9, 3.506838664546875*^9}, 3.5068597205293016`*^9, {
   3.506862096474998*^9, 3.506862099636944*^9}}],

Cell[BoxData[
 RowBox[{"Sumntx4", "=", 
  RowBox[{"S", "[", 
   RowBox[{"x", ",", "y", ",", "ntx1", ",", "nty1"}], "]"}]}]], "Input",
 CellChangeTimes->{
  3.48033838653125*^9, {3.506838722296875*^9, 3.50683872475*^9}, {
   3.506840016546875*^9, 3.506840052796875*^9}, {3.506860596902791*^9, 
   3.506860605224491*^9}, {3.5068620142061243`*^9, 3.506862017053617*^9}, {
   3.506862102498674*^9, 3.506862106452075*^9}}],

Cell[BoxData[
 RowBox[{"Sumntx6", "=", 
  RowBox[{"S", "[", 
   RowBox[{"x", ",", "y", ",", "ntx2", ",", "nty2"}], "]"}]}]], "Input",
 CellChangeTimes->{{3.480338368734375*^9, 3.480338376859375*^9}, {
   3.50683929953125*^9, 3.50683931421875*^9}, {3.50684004434375*^9, 
   3.5068400564375*^9}, {3.506840179140625*^9, 3.506840179765625*^9}, {
   3.5068404640625*^9, 3.506840467453125*^9}, {3.506841040921875*^9, 
   3.50684104215625*^9}, {3.506841297546875*^9, 3.50684129821875*^9}, {
   3.506841491234375*^9, 3.50684149875*^9}, {3.50684216059375*^9, 
   3.506842164140625*^9}, {3.506860612926467*^9, 3.5068606164550877`*^9}, 
   3.506861138399109*^9}],

Cell[BoxData[
 RowBox[{"graSum4", "=", 
  RowBox[{"Plot3D", "[", 
   RowBox[{
    RowBox[{"Evaluate", "[", "Sumntx4", "]"}], ",", 
    RowBox[{"{", 
     RowBox[{"x", ",", "0", ",", "\[Lambda]x"}], "}"}], ",", 
    RowBox[{"{", 
     RowBox[{"y", ",", "0", ",", "\[Lambda]y"}], "}"}], ",", 
    RowBox[{"PlotLabel", "\[Rule]", "\"\<Partial sum with \!\(\*
StyleBox[\"ntx\",
FontColor->RGBColor[1, 0, 0]]\)\!\(\*
StyleBox[\"=\",
FontColor->RGBColor[1, 0, 0]]\)\!\(\*
StyleBox[\"nty\",
FontColor->RGBColor[1, 0, 0]]\)\!\(\*
StyleBox[\"=\",
FontColor->RGBColor[1, 0, 0]]\)\!\(\*
StyleBox[\"4\",
FontColor->RGBColor[1, 0, 0]]\) terms\>\""}]}], "]"}]}]], "Input",
 CellChangeTimes->{{3.480338398*^9, 3.480338413765625*^9}, {
   3.50683154534375*^9, 3.5068315755*^9}, {3.50683790234375*^9, 
   3.50683793021875*^9}, 3.50684008390625*^9, {3.506842193015625*^9, 
   3.506842200703125*^9}, {3.50686053576528*^9, 3.506860563915483*^9}, {
   3.506860637086513*^9, 3.506860669360257*^9}}],

Cell[BoxData[
 RowBox[{"graSum6", "=", 
  RowBox[{"Plot3D", "[", 
   RowBox[{
    RowBox[{"Evaluate", "[", "Sumntx6", "]"}], ",", 
    RowBox[{"{", 
     RowBox[{"x", ",", "0", ",", "\[Lambda]x"}], "}"}], ",", 
    RowBox[{"{", 
     RowBox[{"y", ",", "0", ",", "\[Lambda]y"}], "}"}], ",", 
    RowBox[{"PlotLabel", "\[Rule]", "\"\<Partial sum with \!\(\*
StyleBox[\"ntx\",
FontColor->RGBColor[1, 0, 0]]\)\!\(\*
StyleBox[\"=\",
FontColor->RGBColor[1, 0, 0]]\)\!\(\*
StyleBox[\"nty\",
FontColor->RGBColor[1, 0, 0]]\)\!\(\*
StyleBox[\"=\",
FontColor->RGBColor[1, 0, 0]]\)\!\(\*
StyleBox[\"6\",
FontColor->RGBColor[1, 0, 0]]\) terms\>\""}]}], "]"}]}]], "Input",
 CellChangeTimes->{{3.480338398*^9, 3.480338413765625*^9}, {
   3.50683154534375*^9, 3.5068315755*^9}, {3.50683790234375*^9, 
   3.50683793021875*^9}, {3.5068379865625*^9, 3.5068379909375*^9}, 
   3.506840197046875*^9, {3.506842211171875*^9, 3.5068422206875*^9}, {
   3.506860642626095*^9, 3.506860657782949*^9}, {3.5068658433750677`*^9, 
   3.5068658480061502`*^9}}],

Cell[BoxData[
 RowBox[{"Timing", "[", 
  RowBox[{"graErrornt4", "=", 
   RowBox[{"Plot3D", "[", 
    RowBox[{
     RowBox[{"Evaluate", "[", 
      RowBox[{
       RowBox[{"\[Rho]", "[", 
        RowBox[{"x", ",", "y"}], "]"}], "-", "Sumntx4"}], "]"}], ",", 
     RowBox[{"{", 
      RowBox[{"x", ",", "0", ",", "\[Lambda]x"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"y", ",", "0", ",", "\[Lambda]y"}], "}"}], ",", 
     RowBox[{"PlotLabel", "\[Rule]", "\"\<\[Rho][x,y]-Sumntx4\>\""}]}], 
    "]"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.480338503078125*^9, 3.48033853475*^9}, {
   3.5068315895625*^9, 3.50683161496875*^9}, {3.506838014984375*^9, 
   3.50683813771875*^9}, {3.50683819265625*^9, 3.506838209421875*^9}, 
   3.50684013528125*^9, {3.506840848703125*^9, 3.506840866390625*^9}, {
   3.506860709139802*^9, 3.5068607169728107`*^9}, 3.5068607628142653`*^9, 
   3.5068608181765413`*^9, 3.506865295889846*^9}],

Cell["The values (-1,1) on the vertical axis are measleding... ", "Text",
 CellChangeTimes->{{3.506860414073595*^9, 3.5068604579039183`*^9}, 
   3.506866220971305*^9, {3.506866517793024*^9, 3.506866561611034*^9}, {
   3.5751124476121125`*^9, 3.575112450164259*^9}},
 FontFamily->"Times New Roman",
 FontSize->24,
 Background->GrayLevel[0.85]],

Cell[BoxData[
 RowBox[{"Timing", "[", 
  RowBox[{"graErrornt4", "=", 
   RowBox[{"Plot3D", "[", 
    RowBox[{
     RowBox[{"Evaluate", "[", 
      RowBox[{
       RowBox[{"\[Rho]", "[", 
        RowBox[{"x", ",", "y"}], "]"}], "-", "Sumntx6"}], "]"}], ",", 
     RowBox[{"{", 
      RowBox[{"x", ",", "0", ",", "\[Lambda]x"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"y", ",", "0", ",", "\[Lambda]y"}], "}"}], ",", 
     RowBox[{"PlotPoints", "\[Rule]", "25"}], ",", 
     RowBox[{"AxesLabel", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{"\"\<x\>\"", ",", "\"\<y\>\"", ",", "\"\<err\>\""}], "}"}]}], 
     ",", 
     RowBox[{"ImageSize", "\[Rule]", "500"}], ",", "\[IndentingNewLine]", 
     RowBox[{
     "PlotLabel", "\[Rule]", "\"\<Evaluate[\[Rho][x,y]-Sumntx6]\>\""}], ",", 
     "\[IndentingNewLine]", 
     RowBox[{"AxesStyle", "\[Rule]", 
      RowBox[{"Directive", "[", 
       RowBox[{"Blue", ",", "20", ",", 
        RowBox[{"FontFamily", "\[Rule]", "\"\<Helvetica\>\""}]}], "]"}]}], 
     ",", 
     RowBox[{"ImageSize", "\[Rule]", "500"}]}], "]"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.480338503078125*^9, 3.48033853475*^9}, {
   3.5068315895625*^9, 3.50683161496875*^9}, {3.506838014984375*^9, 
   3.50683815946875*^9}, 3.5068401425*^9, {3.506840611625*^9, 
   3.5068408125*^9}, {3.506840885765625*^9, 3.506840976453125*^9}, {
   3.50684143809375*^9, 3.5068414520625*^9}, {3.50684195609375*^9, 
   3.506841973046875*^9}, 3.506842005390625*^9, {3.50684226315625*^9, 
   3.506842302078125*^9}, {3.50684357353125*^9, 3.506843576890625*^9}, {
   3.50684361421875*^9, 3.50684362009375*^9}, 3.506860726731629*^9, 
   3.506860762824346*^9, {3.506860824061234*^9, 3.5068608273085012`*^9}, {
   3.506862342690421*^9, 3.506862368908675*^9}, {3.506865321619494*^9, 
   3.5068653305835457`*^9}, {3.506865409149466*^9, 3.506865417441761*^9}, 
   3.506865472150667*^9}],

Cell[BoxData[
 RowBox[{"Timing", "[", 
  RowBox[{"graErrornt4", "=", 
   RowBox[{"Plot3D", "[", 
    RowBox[{
     RowBox[{"Evaluate", "[", 
      RowBox[{
       RowBox[{"\[Rho]", "[", 
        RowBox[{"x", ",", "y"}], "]"}], "-", "Sumntx6"}], "]"}], ",", 
     RowBox[{"{", 
      RowBox[{"x", ",", "0", ",", "\[Lambda]x"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"y", ",", "0", ",", "\[Lambda]y"}], "}"}], ",", 
     RowBox[{"PlotPoints", "\[Rule]", "25"}], ",", 
     RowBox[{"PlotRange", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{
         RowBox[{"-", "1"}], " ", 
         SuperscriptBox["10", 
          RowBox[{"-", "17"}]]}], ",", " ", 
        RowBox[{"1", " ", 
         SuperscriptBox["10", 
          RowBox[{"-", "17"}]]}]}], "}"}]}], ",", 
     RowBox[{"AxesLabel", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{"\"\<x\>\"", ",", "\"\<y\>\"", ",", "\"\<err\>\""}], "}"}]}], 
     ",", 
     RowBox[{"ImageSize", "\[Rule]", "500"}], ",", 
     RowBox[{
     "PlotLabel", "\[Rule]", "\"\<Evaluate[\[Rho][x,y]-Sumntx6]\>\""}], ",", 
     "\[IndentingNewLine]", 
     RowBox[{"AxesStyle", "\[Rule]", 
      RowBox[{"Directive", "[", 
       RowBox[{"Blue", ",", "20", ",", 
        RowBox[{"FontFamily", "\[Rule]", "\"\<Helvetica\>\""}]}], "]"}]}], 
     ",", 
     RowBox[{"ImageSize", "\[Rule]", "500"}]}], "]"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.480338503078125*^9, 3.48033853475*^9}, {
   3.5068315895625*^9, 3.50683161496875*^9}, {3.506838014984375*^9, 
   3.50683815946875*^9}, 3.5068401425*^9, {3.506840611625*^9, 
   3.5068408125*^9}, {3.506840885765625*^9, 3.506840976453125*^9}, {
   3.50684143809375*^9, 3.5068414520625*^9}, {3.50684195609375*^9, 
   3.506841973046875*^9}, 3.506842005390625*^9, {3.50684226315625*^9, 
   3.506842302078125*^9}, {3.50684357353125*^9, 3.506843576890625*^9}, {
   3.50684361421875*^9, 3.50684362009375*^9}, 3.506860726731629*^9, 
   3.506860762824346*^9, {3.506860824061234*^9, 3.5068608273085012`*^9}, 
   3.506862342690421*^9, {3.506865426193884*^9, 3.5068654366812687`*^9}}],

Cell[BoxData[
 RowBox[{"Timing", "[", 
  RowBox[{"graErrornt4bis", "=", 
   RowBox[{"Plot3D", "[", 
    RowBox[{
     RowBox[{
      RowBox[{"\[Rho]", "[", 
       RowBox[{"x", ",", "y"}], "]"}], "-", "Sumntx6"}], ",", 
     RowBox[{"{", 
      RowBox[{"x", ",", "0", ",", "\[Lambda]x"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"y", ",", "0", ",", "\[Lambda]y"}], "}"}], ",", 
     RowBox[{"PlotPoints", "\[Rule]", "25"}], ",", 
     RowBox[{"AxesLabel", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{"\"\<x\>\"", ",", "\"\<y\>\"", ",", "\"\<err\>\""}], "}"}]}], 
     ",", 
     RowBox[{"ImageSize", "\[Rule]", "500"}], ",", "\[IndentingNewLine]", 
     RowBox[{"PlotLabel", "\[Rule]", "\"\<\[Rho][x,y]-Sumntx6\>\""}], ",", 
     "\[IndentingNewLine]", 
     RowBox[{"AxesStyle", "\[Rule]", 
      RowBox[{"Directive", "[", 
       RowBox[{"Blue", ",", "20", ",", 
        RowBox[{"FontFamily", "\[Rule]", "\"\<Helvetica\>\""}]}], "]"}]}], 
     ",", 
     RowBox[{"ImageSize", "\[Rule]", "500"}]}], "]"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.480338503078125*^9, 3.48033853475*^9}, {
   3.5068315895625*^9, 3.50683161496875*^9}, {3.506838014984375*^9, 
   3.50683815946875*^9}, 3.5068401425*^9, {3.506840611625*^9, 
   3.5068408125*^9}, {3.506840885765625*^9, 3.506840976453125*^9}, {
   3.50684143809375*^9, 3.5068414520625*^9}, {3.50684195609375*^9, 
   3.506841973046875*^9}, 3.506842005390625*^9, {3.50684226315625*^9, 
   3.506842302078125*^9}, {3.50684357353125*^9, 3.506843576890625*^9}, {
   3.506860736738038*^9, 3.506860762833057*^9}, {3.506860834225421*^9, 
   3.506860836008856*^9}, {3.5068654909509993`*^9, 3.5068655383913717`*^9}}],

Cell[BoxData[
 RowBox[{"Timing", "[", 
  RowBox[{"Err2", "=", 
   RowBox[{"Plot3D", "[", 
    RowBox[{
     RowBox[{
      StyleBox["Re",
       FontColor->RGBColor[1, 0, 0]], "[", 
      RowBox[{
       RowBox[{"\[Rho]", "[", 
        RowBox[{"x", ",", "y"}], "]"}], "-", "Sumntx6"}], "]"}], ",", 
     RowBox[{"{", 
      RowBox[{"x", ",", "0", ",", "\[Lambda]x"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"y", ",", "0", ",", "\[Lambda]y"}], "}"}], ",", 
     RowBox[{"PlotLabel", "\[Rule]", "\"\<Re[\[Rho][x,y]-Sumntx6]\>\""}]}], 
    "]"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.480338503078125*^9, 3.48033853475*^9}, {
   3.5068315895625*^9, 3.50683161496875*^9}, {3.506838014984375*^9, 
   3.50683815946875*^9}, 3.5068401425*^9, {3.506840611625*^9, 
   3.5068408125*^9}, {3.506840885765625*^9, 3.50684090815625*^9}, {
   3.50684113065625*^9, 3.506841140921875*^9}, 3.506860762863057*^9, {
   3.5068609008311443`*^9, 3.506860909396472*^9}, 3.506860961298822*^9}],

Cell[BoxData[
 RowBox[{"Timing", "[", 
  RowBox[{"Err2", "=", 
   RowBox[{"Plot3D", "[", 
    RowBox[{
     RowBox[{
      StyleBox["Im",
       FontColor->RGBColor[1, 0, 0]], "[", 
      RowBox[{
       RowBox[{"\[Rho]", "[", 
        RowBox[{"x", ",", "y"}], "]"}], "-", "Sumntx6"}], "]"}], ",", 
     RowBox[{"{", 
      RowBox[{"x", ",", "0", ",", "\[Lambda]x"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"y", ",", "0", ",", "\[Lambda]y"}], "}"}], ",", 
     RowBox[{"(*", 
      RowBox[{
       RowBox[{"PlotRange", "\[Rule]", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"-", 
           SuperscriptBox["10", 
            RowBox[{"-", "14"}]]}], ",", 
          SuperscriptBox["10", "14"]}], "}"}]}], ","}], "*)"}], 
     RowBox[{"PlotLabel", "\[Rule]", "\"\<Im[\[Rho][x,y]-Sumntx6]\>\""}]}], 
    "]"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.480338503078125*^9, 3.48033853475*^9}, {
   3.5068315895625*^9, 3.50683161496875*^9}, {3.506838014984375*^9, 
   3.50683815946875*^9}, 3.5068401425*^9, {3.506840611625*^9, 
   3.5068408125*^9}, {3.506840885765625*^9, 3.50684090815625*^9}, {
   3.50684113065625*^9, 3.506841140921875*^9}, {3.506843644*^9, 
   3.506843644921875*^9}, 3.5068607628555117`*^9, 3.506860895879064*^9, 
   3.5068609451096582`*^9}],

Cell[BoxData[
 RowBox[{"graErrsectionnt4", "=", 
  RowBox[{"Plot", "[", 
   RowBox[{
    RowBox[{
     RowBox[{"\[Rho]", "[", 
      RowBox[{
       RowBox[{
        RowBox[{"-", "\[Lambda]x"}], "/", "4"}], ",", "y"}], "]"}], "-", 
     RowBox[{"S", "[", 
      RowBox[{
       RowBox[{
        RowBox[{"-", "\[Lambda]x"}], "/", "4"}], ",", "y", ",", "ntx1", ",", 
       "nty1"}], "]"}]}], ",", 
    RowBox[{"{", 
     RowBox[{"y", ",", "0", ",", "\[Lambda]y"}], "}"}], ",", 
    RowBox[{"PlotStyle", "\[Rule]", 
     RowBox[{"{", 
      RowBox[{"Hue", "[", "0.05", "]"}], "}"}]}], ",", 
    RowBox[{
    "PlotLabel", "\[Rule]", 
     "\"\<\[Rho][-\[Lambda]x/4,y]-S[-\[Lambda]x/4,y,ntx1,nty1\>\""}]}], 
   "]"}]}]], "Input",
 CellChangeTimes->{{3.480338553359375*^9, 3.480338579921875*^9}, {
   3.506839472796875*^9, 3.506839475046875*^9}, 3.506860762878305*^9, {
   3.5068611000210876`*^9, 3.506861108456558*^9}, {3.506862195302443*^9, 
   3.506862200967244*^9}, 3.5068655688364*^9}],

Cell[BoxData[
 RowBox[{"graErrsectionnt6", "=", 
  RowBox[{"Plot", "[", 
   RowBox[{
    RowBox[{
     RowBox[{"\[Rho]", "[", 
      RowBox[{
       RowBox[{
        RowBox[{"-", "\[Lambda]x"}], "/", "2"}], ",", "y"}], "]"}], "-", 
     RowBox[{"S", "[", 
      RowBox[{
       RowBox[{
        RowBox[{"-", "\[Lambda]x"}], "/", "2"}], ",", "y", ",", "ntx2", ",", 
       "nty2"}], "]"}]}], ",", 
    RowBox[{"{", 
     RowBox[{"y", ",", "0", ",", "\[Lambda]y"}], "}"}], ",", 
    "\[IndentingNewLine]", 
    RowBox[{"PlotRange", "\[Rule]", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        RowBox[{"-", "1"}], " ", 
        SuperscriptBox["10", 
         RowBox[{"-", "16"}]]}], ",", " ", 
       RowBox[{"1", " ", 
        SuperscriptBox["10", 
         RowBox[{"-", "16"}]]}]}], "}"}]}], ",", 
    RowBox[{"PlotStyle", "\[Rule]", 
     RowBox[{"{", 
      RowBox[{"Hue", "[", "0.05", "]"}], "}"}]}], ",", 
    RowBox[{
    "PlotLabel", "\[Rule]", 
     "\"\<\[Rho][-\[Lambda]x/2,y]-S[-\[Lambda]x/2,y,ntx2,nty2]\>\""}]}], 
   "]"}]}]], "Input",
 CellChangeTimes->{{3.480338553359375*^9, 3.480338579921875*^9}, {
   3.506839472796875*^9, 3.506839475046875*^9}, 3.506860762878305*^9, {
   3.506860995879436*^9, 3.506861051188295*^9}, {3.506861085789925*^9, 
   3.50686112179174*^9}, {3.506862248080908*^9, 3.506862312314608*^9}, 
   3.5068655916590643`*^9, {3.506865639909278*^9, 3.5068656887627077`*^9}, {
   3.506866609234321*^9, 3.506866612402614*^9}}],

Cell["...the following picture is more realistic.", "Text",
 CellChangeTimes->{{3.506860414073595*^9, 3.5068604579039183`*^9}, 
   3.506866220971305*^9, {3.506866517793024*^9, 3.506866561611034*^9}, {
   3.506866669481344*^9, 3.506866687661016*^9}, {3.5751124528604126`*^9, 
   3.5751124543794994`*^9}},
 FontFamily->"Times New Roman",
 FontSize->24,
 Background->GrayLevel[0.85]],

Cell[BoxData[
 RowBox[{"graErrsectionnt6shift", "=", 
  RowBox[{"Plot", "[", 
   RowBox[{
    RowBox[{
     RowBox[{"\[Rho]", "[", 
      RowBox[{
       RowBox[{
        RowBox[{
         RowBox[{"-", "\[Lambda]x"}], "/", "2"}], "+", 
        StyleBox["0.1",
         FontColor->RGBColor[1, 0, 0]]}], ",", "y"}], "]"}], "-", 
     RowBox[{"S", "[", 
      RowBox[{
       RowBox[{
        RowBox[{
         RowBox[{"-", "\[Lambda]x"}], "/", "2"}], "+", 
        StyleBox["0.1",
         FontColor->RGBColor[1, 0, 0]]}], ",", "y", ",", "ntx2", ",", 
       "nty2"}], "]"}]}], ",", 
    RowBox[{"{", 
     RowBox[{"y", ",", "0", ",", "\[Lambda]y"}], "}"}], ",", 
    "\[IndentingNewLine]", 
    RowBox[{"PlotRange", "\[Rule]", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        RowBox[{"-", "1"}], " ", 
        SuperscriptBox["10", 
         RowBox[{"-", "16"}]]}], ",", " ", 
       RowBox[{"1", " ", 
        SuperscriptBox["10", 
         RowBox[{"-", "16"}]]}]}], "}"}]}], ",", 
    RowBox[{"PlotStyle", "\[Rule]", 
     RowBox[{"{", 
      RowBox[{"Hue", "[", "0.05", "]"}], "}"}]}], ",", 
    RowBox[{
    "PlotLabel", "\[Rule]", 
     "\"\<\[Rho][-\[Lambda]x/2,y]-S[-\[Lambda]x/2,y,ntx2,nty2]\>\""}]}], 
   "]"}]}]], "Input",
 CellChangeTimes->{{3.480338553359375*^9, 3.480338579921875*^9}, {
   3.506839472796875*^9, 3.506839475046875*^9}, 3.506860762878305*^9, {
   3.506860995879436*^9, 3.506861051188295*^9}, {3.506861085789925*^9, 
   3.50686112179174*^9}, {3.506862248080908*^9, 3.506862312314608*^9}, 
   3.5068655916590643`*^9, {3.506865639909278*^9, 3.5068656887627077`*^9}, {
   3.5068666218216543`*^9, 3.506866628542622*^9}}]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[StyleBox["Part II",
 FontColor->RGBColor[0, 0, 1]]], "Text",
 CellGroupingRules->{GroupTogetherGrouping, 10000.},
 CellChangeTimes->{{3.4561278892666187`*^9, 3.4561279023146544`*^9}, 
   3.456128006313026*^9, {3.4561281092059317`*^9, 3.456128161981234*^9}, {
   3.456138326441684*^9, 3.456138335084655*^9}, 3.457086838266417*^9, {
   3.457161408546215*^9, 3.4571614091944523`*^9}, 3.459076271296875*^9, {
   3.459077388375*^9, 3.459077392921875*^9}, {3.459077439234375*^9, 
   3.459077449953125*^9}, {3.459077842734375*^9, 3.45907785384375*^9}, {
   3.459077980265625*^9, 3.45907799534375*^9}, {3.459080904375*^9, 
   3.45908092684375*^9}, {3.45908103925*^9, 3.459081047125*^9}, {
   3.459081272515625*^9, 3.459081273359375*^9}, 3.45908270415625*^9, {
   3.45908301365625*^9, 3.459083043859375*^9}, 3.45908372865625*^9, {
   3.459112126203125*^9, 3.459112164203125*^9}, 3.45916170553125*^9, 
   3.459161890421875*^9, {3.459170302734375*^9, 3.45917031409375*^9}, {
   3.506858006512697*^9, 3.506858006982812*^9}, {3.506861249547703*^9, 
   3.506861281541944*^9}, {3.506929782109375*^9, 3.50692981553125*^9}, {
   3.50693013178125*^9, 3.506930171765625*^9}, {3.506930204328125*^9, 
   3.506930204328125*^9}, {3.5751123421350794`*^9, 3.5751123429561267`*^9}},
 FontSize->36,
 Background->RGBColor[1, 0.9, 0.8]],

Cell[TextData[{
 Cell[BoxData[
  RowBox[{
   RowBox[{
    RowBox[{"\[Rho]", "[", 
     RowBox[{"x", ",", "y"}], "]"}], "=", 
    RowBox[{"Z", "*", 
     RowBox[{"(", 
      RowBox[{"Exp", "[", 
       RowBox[{"-", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{
           RowBox[{"(", 
            FractionBox["x", "Rn"], ")"}], "^", "2"}], "+", 
          RowBox[{
           RowBox[{"(", 
            FractionBox["y", "Rm"], ")"}], "^", "2"}]}], ")"}]}], "]"}], 
      ")"}]}]}], ";"}]], "Input",
  CellChangeTimes->{{3.48057427009375*^9, 3.480574279546875*^9}, {
   3.506853337774859*^9, 3.506853348250214*^9}},
  FontSize->24],
 "\nIn section II.A we use formula (1) to evaluate symbolically and \
numerically\nthe coefficients ",
 Cell[BoxData[
  FormBox[
   RowBox[{
    SubscriptBox["\[Rho]", "hk"], 
    StyleBox[" ",
     FontFamily->"Courier New"]}], TraditionalForm]]],
 "\nIn section II.B we construct the expression\n",
 Cell[BoxData[
  RowBox[{
   RowBox[{
    OverscriptBox["\[Rho]", "\[Tilde]"], "[", 
    RowBox[{"x", ",", "y"}], "]"}], "=", 
   RowBox[{
    UnderoverscriptBox["\[Sum]", 
     RowBox[{"m", "=", 
      RowBox[{"-", "ntx"}]}], "ntx"], 
    RowBox[{
     UnderoverscriptBox["\[Sum]", 
      RowBox[{"n", "=", 
       StyleBox[
        RowBox[{"-", "nty"}],
        FontColor->GrayLevel[0]]}], "nty"], 
     RowBox[{
      RowBox[{"N", "[", 
       RowBox[{"coef1mn\[Rho]", "[", 
        RowBox[{"m", ",", "n"}], "]"}], "]"}], "*", 
      SuperscriptBox["\[ExponentialE]", 
       RowBox[{"I", "*", 
        RowBox[{"(", 
         StyleBox[
          RowBox[{
           RowBox[{
            FractionBox[
             RowBox[{"2", " ", "\[Pi]", " ", "m"}], "\[Lambda]x"], " ", "x"}],
            "+", 
           RowBox[{
            FractionBox[
             RowBox[{"2", " ", "\[Pi]", " ", "n"}], "\[Lambda]y"], " ", 
            "y"}]}],
          FontSize->24], ")"}]}]], " "}]}]}]}]], "Input",
  CellChangeTimes->{{3.431321031421875*^9, 3.4313210425625*^9}, {
    3.500441560609375*^9, 3.500441595578125*^9}, {3.500443328765625*^9, 
    3.50044334603125*^9}, {3.5068385855625*^9, 3.506838626171875*^9}, {
    3.50683870196875*^9, 3.50683870434375*^9}, {3.506838765125*^9, 
    3.506838799234375*^9}, 3.506839273375*^9, {3.50684428521875*^9, 
    3.506844355421875*^9}},
  FontSize->24],
 "\nand calculate   ",
 Cell[BoxData[
  RowBox[{"\[Rho]", "[", 
   RowBox[{"x", ",", "y"}], "]"}]], "Input",
  CellChangeTimes->{{3.431321031421875*^9, 3.4313210425625*^9}, {
    3.500441560609375*^9, 3.500441595578125*^9}, {3.500443328765625*^9, 
    3.50044334603125*^9}, {3.5068385855625*^9, 3.506838626171875*^9}, {
    3.50683870196875*^9, 3.50683870434375*^9}, {3.506838765125*^9, 
    3.506838799234375*^9}, 3.506839273375*^9, {3.50684428521875*^9, 
    3.506844355421875*^9}},
  FontSize->24],
 " - ",
 Cell[BoxData[
  RowBox[{
   OverscriptBox["\[Rho]", "\[Tilde]"], "[", 
   RowBox[{"x", ",", "y"}], "]"}]], "Input",
  CellChangeTimes->{{3.431321031421875*^9, 3.4313210425625*^9}, {
    3.500441560609375*^9, 3.500441595578125*^9}, {3.500443328765625*^9, 
    3.50044334603125*^9}, {3.5068385855625*^9, 3.506838626171875*^9}, {
    3.50683870196875*^9, 3.50683870434375*^9}, {3.506838765125*^9, 
    3.506838799234375*^9}, 3.506839273375*^9, {3.50684428521875*^9, 
    3.506844355421875*^9}},
  FontSize->24],
 ",\nwhere ntx and nty denote a specified number of terms."
}], "Text",
 CellGroupingRules->{GroupTogetherGrouping, 10000.},
 CellChangeTimes->{{3.4561278892666187`*^9, 3.4561279023146544`*^9}, 
   3.456128006313026*^9, {3.4561281092059317`*^9, 3.456128161981234*^9}, {
   3.456138326441684*^9, 3.456138335084655*^9}, 3.457086838266417*^9, {
   3.457161408546215*^9, 3.4571614091944523`*^9}, 3.459076271296875*^9, {
   3.459077388375*^9, 3.459077392921875*^9}, {3.459077439234375*^9, 
   3.459077449953125*^9}, {3.459077842734375*^9, 3.45907785384375*^9}, {
   3.459077980265625*^9, 3.45907799534375*^9}, {3.459080904375*^9, 
   3.45908092684375*^9}, {3.45908103925*^9, 3.459081047125*^9}, {
   3.459081272515625*^9, 3.459081273359375*^9}, 3.45908270415625*^9, {
   3.45908301365625*^9, 3.459083043859375*^9}, 3.45908372865625*^9, {
   3.459112126203125*^9, 3.459112164203125*^9}, 3.45916170553125*^9, 
   3.459161890421875*^9, {3.459170302734375*^9, 3.45917031409375*^9}, {
   3.506858006512697*^9, 3.506858006982812*^9}, {3.506861249547703*^9, 
   3.506861281541944*^9}, {3.506929782109375*^9, 3.50692981553125*^9}, {
   3.50693013178125*^9, 3.506930171765625*^9}, {3.506930204328125*^9, 
   3.506930204328125*^9}, {3.575112600673867*^9, 3.575112601055889*^9}, {
   3.5751126548349648`*^9, 3.5751126561000376`*^9}},
 FontFamily->"Times New Roman",
 FontSize->24,
 Background->GrayLevel[0.85]],

Cell[CellGroupData[{

Cell[TextData[StyleBox["Initialization, Definitions and Graphs",
 FontSize->22]], "Text",
 CellGroupingRules->{GroupTogetherGrouping, 10000.},
 CellChangeTimes->{{3.4561278892666187`*^9, 3.4561279023146544`*^9}, 
   3.456128006313026*^9, {3.4561281092059317`*^9, 3.456128161981234*^9}, {
   3.456138326441684*^9, 3.456138335084655*^9}, 3.457086838266417*^9, {
   3.457161408546215*^9, 3.4571614091944523`*^9}, 3.459076271296875*^9, {
   3.459077388375*^9, 3.459077392921875*^9}, {3.459077439234375*^9, 
   3.459077449953125*^9}, {3.459077842734375*^9, 3.45907785384375*^9}, {
   3.459077980265625*^9, 3.45907799534375*^9}, {3.459080904375*^9, 
   3.45908092684375*^9}, {3.45908103925*^9, 3.459081047125*^9}, {
   3.459081272515625*^9, 3.459081273359375*^9}, 3.45908270415625*^9, {
   3.45908301365625*^9, 3.459083043859375*^9}, 3.45908372865625*^9, {
   3.459112126203125*^9, 3.459112164203125*^9}, 3.45916170553125*^9, 
   3.459161890421875*^9, {3.459170302734375*^9, 3.45917031409375*^9}, {
   3.506858006512697*^9, 3.506858006982812*^9}, {3.506861249547703*^9, 
   3.506861281541944*^9}},
 FontFamily->"Times New Roman",
 FontSize->24,
 Background->GrayLevel[0.85]],

Cell[BoxData[
 RowBox[{
  RowBox[{"Clear", "[", "\"\<Global`*\>\"", "]"}], ";", 
  RowBox[{"Remove", "[", "\"\<Global`*\>\"", "]"}], ";", 
  RowBox[{"$Line", "=", "0"}], ";", 
  RowBox[{"Off", "[", 
   RowBox[{"General", "::", "spell1"}], "]"}], ";"}]], "Input",
 CellChangeTimes->{{3.480336963921875*^9, 3.480336966421875*^9}, 
   3.506866868823389*^9}],

Cell[BoxData[
 RowBox[{
  RowBox[{"SetOptions", "[", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{
     "Plot", ",", "ListPlot", ",", "ListPlot3D", ",", "Plot3D", ",", 
      "BarChart", ",", "DensityPlot"}], "}"}], ",", 
    RowBox[{"ImageSize", "\[Rule]", "600"}], ",", "\[IndentingNewLine]", 
    RowBox[{"LabelStyle", "\[Rule]", 
     RowBox[{"(", 
      RowBox[{"FontFamily", "\[Rule]", "\"\<Helvetica\>\""}], ")"}]}], ",", 
    RowBox[{"AxesStyle", "\[Rule]", 
     RowBox[{"Directive", "[", 
      RowBox[{"20", ",", 
       RowBox[{"Thickness", "[", "0.005", "]"}], ",", "Black"}], "]"}]}]}], 
   "]"}], ";"}]], "Input",
 CellGroupingRules->{GroupTogetherGrouping, 10001.},
 CellChangeTimes->{{3.431404133265625*^9, 3.431404152625*^9}, {
   3.431404184828125*^9, 3.43140419784375*^9}, {3.431404229828125*^9, 
   3.431404286*^9}, {3.431404358734375*^9, 3.431404362015625*^9}, 
   3.43140449659375*^9, {3.431404585328125*^9, 3.431404586390625*^9}, {
   3.431404647765625*^9, 3.431404694953125*^9}, {3.43140617875*^9, 
   3.4314062495625*^9}, {3.431406282875*^9, 3.4314063513125*^9}, {
   3.43140679328125*^9, 3.43140680225*^9}, {3.4314068341875*^9, 
   3.431406876078125*^9}, 3.431586168296875*^9, {3.456133135516242*^9, 
   3.45613315371024*^9}, 3.456133192744998*^9, {3.456139127607568*^9, 
   3.456139168352964*^9}, 3.456139229399897*^9, {3.456139834402177*^9, 
   3.456139847710493*^9}, 3.459112164203125*^9, {3.48033814621875*^9, 
   3.480338159609375*^9}, {3.50685442999006*^9, 3.5068544332318783`*^9}, {
   3.506865896770195*^9, 3.506865909318581*^9}},
 FontSize->18],

Cell[BoxData["$Version"], "Input",
 CellChangeTimes->{{3.50683062553125*^9, 3.506830627765625*^9}}],

Cell[BoxData[
 RowBox[{"Date", "[", "]"}]], "Input",
 CellChangeTimes->{{3.48057813115625*^9, 3.4805781326875*^9}}],

Cell["\<\
We define the atomic density \[Rho](x,y) and the parameters  Z, Rx, Ry\
\>", "Text",
 CellChangeTimes->{{3.506858170041534*^9, 3.506858192511097*^9}, {
  3.5068582336528873`*^9, 3.506858254029193*^9}, {3.506926768828125*^9, 
  3.506926774859375*^9}, {3.506930811765625*^9, 3.506930815078125*^9}},
 FontFamily->"Times New Roman",
 FontSize->24,
 Background->GrayLevel[0.85]],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"\[Rho]", "[", 
    RowBox[{"x_", ",", "y_"}], "]"}], "=", 
   RowBox[{"Z", "*", 
    RowBox[{"(", 
     RowBox[{"Exp", "[", 
      RowBox[{"-", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{
          RowBox[{"(", 
           FractionBox["x", "Rx"], ")"}], "^", "2"}], "+", 
         RowBox[{
          RowBox[{"(", 
           FractionBox["y", "Ry"], ")"}], "^", "2"}]}], ")"}]}], "]"}], 
     ")"}]}]}], ";"}]], "Input",
 CellChangeTimes->{{3.48057427009375*^9, 3.480574279546875*^9}, {
   3.506853337774859*^9, 3.506853348250214*^9}, 3.5069266010625*^9, 
   3.506930756703125*^9, 3.506930821484375*^9}],

Cell[BoxData[
 RowBox[{
  RowBox[{"Z", "=", "14"}], ";"}]], "Input",
 CellChangeTimes->{
  3.5067792936275167`*^9, {3.506928365953125*^9, 3.5069283699375*^9}}],

Cell[BoxData[{
 RowBox[{
  RowBox[{"Rx", "=", 
   RowBox[{"1", "/", "2"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"Ry", "=", 
   RowBox[{"1", "/", "2"}]}], ";"}]}], "Input",
 CellChangeTimes->{3.50693075734375*^9, 3.506930822046875*^9}],

Cell[BoxData[{
 RowBox[{
  RowBox[{"\[Lambda]x", "=", "2"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"\[Lambda]y", "=", "2"}], ";"}]}], "Input",
 CellChangeTimes->{{3.4803372055*^9, 3.480337209703125*^9}, {
  3.48033724053125*^9, 3.4803372446875*^9}, {3.4805742560625*^9, 
  3.480574257234375*^9}, {3.4805759023125*^9, 3.4805759023125*^9}, {
  3.480578178390625*^9, 3.48057817990625*^9}, {3.506926607796875*^9, 
  3.50692661078125*^9}}],

Cell[BoxData[
 RowBox[{"gra3D\[Rho]1", " ", "=", 
  RowBox[{"Plot3D", "[", 
   RowBox[{
    RowBox[{"Z", "*", 
     RowBox[{"(", 
      RowBox[{"Exp", "[", 
       RowBox[{"-", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{
           RowBox[{"(", 
            FractionBox["x", "Rx"], ")"}], "^", "2"}], "+", 
          RowBox[{
           RowBox[{"(", 
            FractionBox["y", "Ry"], ")"}], "^", "2"}]}], ")"}]}], "]"}], 
      ")"}]}], ",", "\[IndentingNewLine]", "                 ", 
    RowBox[{"{", 
     RowBox[{"x", ",", 
      RowBox[{
       RowBox[{"-", 
        FractionBox["\[Lambda]x", "2"]}], "-", 
       RowBox[{"0.1", "*", "\[Lambda]x"}]}], ",", 
      RowBox[{
       FractionBox["\[Lambda]x", "2"], "+", 
       RowBox[{"0.1", "*", "\[Lambda]x"}]}]}], "}"}], ",", 
    RowBox[{"{", 
     RowBox[{"y", ",", 
      RowBox[{
       RowBox[{"-", 
        FractionBox["\[Lambda]y", "2"]}], "-", 
       RowBox[{"0.1", "*", "\[Lambda]y"}]}], ",", 
      RowBox[{
       FractionBox["\[Lambda]y", "2"], "+", 
       RowBox[{"0.1", "*", "\[Lambda]y"}]}]}], "}"}], ",", "   ", 
    "\[IndentingNewLine]", "                          ", 
    RowBox[{"PlotLabel", "\[Rule]", "\"\<\[Rho](x,y)\>\""}], ",", " ", 
    RowBox[{"AxesLabel", "\[Rule]", 
     RowBox[{"{", 
      RowBox[{"\"\<x\>\"", ",", "\"\<y\>\"", ",", "\"\<\[Rho](x,y)\>\""}], 
      "}"}]}]}], "]"}]}]], "Input",
 CellChangeTimes->{{3.480337071578125*^9, 3.48033709375*^9}, {
   3.480574240953125*^9, 3.480574249765625*^9}, {3.506778996714982*^9, 
   3.506779013303349*^9}, {3.5068532998025417`*^9, 3.506853310817412*^9}, {
   3.506858443591165*^9, 3.506858488931209*^9}, {3.5068585246951647`*^9, 
   3.5068585308139687`*^9}, {3.50692666809375*^9, 3.5069266704375*^9}, 
   3.5069307579375*^9, 3.50693082284375*^9}],

Cell["\<\
As the function is not intrinsically periodic we use Piecewise to extend it.\
\>", "Text",
 CellChangeTimes->{{3.506858170041534*^9, 3.506858192511097*^9}, {
  3.5068582336528873`*^9, 3.506858254029193*^9}, {3.506926768828125*^9, 
  3.506926774859375*^9}, {3.506926809390625*^9, 3.506926867328125*^9}},
 FontFamily->"Times New Roman",
 FontSize->24,
 Background->GrayLevel[0.85]],

Cell[BoxData[
 RowBox[{
  RowBox[{"\[Rho]piece", "[", 
   RowBox[{"x_", ",", "y_"}], "]"}], "=", 
  RowBox[{"Piecewise", "[", 
   RowBox[{"{", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"\[Rho]", "[", 
       RowBox[{"x", ",", "y"}], "]"}], ",", 
      RowBox[{
       RowBox[{"(", 
        RowBox[{
         RowBox[{
          RowBox[{"-", "\[Lambda]x"}], "/", "2"}], "\[LessEqual]", "x", 
         "\[LessEqual]", 
         RowBox[{"\[Lambda]x", "/", "2"}]}], ")"}], " ", "&&", 
       "\[IndentingNewLine]", "                ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{
          RowBox[{"-", "\[Lambda]y"}], "/", "2"}], "\[LessEqual]", "y", 
         "\[LessEqual]", 
         RowBox[{"\[Lambda]y", "/", "2"}]}], ")"}]}]}], "    ", "}"}], "}"}], 
   "]"}]}]], "Input",
 FontSize->24],

Cell[BoxData[
 RowBox[{
  RowBox[{"\[Rho]piece", "[", 
   RowBox[{"x_", ",", "y_"}], "]"}], ":=", 
  RowBox[{
   RowBox[{"\[Rho]piece", "[", 
    RowBox[{
     RowBox[{"x", "-", "\[Lambda]x"}], ",", "y"}], "]"}], "/;", 
   RowBox[{"x", " ", ">", "   ", 
    RowBox[{"\[Lambda]x", "/", "2"}], "  "}]}]}]], "Input",
 FontSize->24],

Cell[BoxData[
 RowBox[{
  RowBox[{"\[Rho]piece", "[", 
   RowBox[{"x_", ",", "y_"}], "]"}], ":=", 
  RowBox[{
   RowBox[{"\[Rho]piece", "[", 
    RowBox[{
     RowBox[{"x", "+", "\[Lambda]x"}], ",", "y"}], "]"}], "/;", 
   RowBox[{"x", " ", "<", " ", 
    RowBox[{
     RowBox[{"-", "\[Lambda]x"}], "/", "2"}]}]}]}]], "Input",
 FontSize->24],

Cell[BoxData[
 RowBox[{
  RowBox[{"\[Rho]piece", "[", 
   RowBox[{"x_", ",", "y_"}], "]"}], ":=", 
  RowBox[{
   RowBox[{"\[Rho]piece", "[", 
    RowBox[{"x", ",", 
     RowBox[{"y", "-", "\[Lambda]y"}]}], "]"}], "/;", 
   RowBox[{"y", " ", ">", "   ", 
    RowBox[{"\[Lambda]y", "/", "2"}], "  "}]}]}]], "Input",
 FontSize->24],

Cell[BoxData[
 RowBox[{
  RowBox[{"\[Rho]piece", "[", 
   RowBox[{"x_", ",", "y_"}], "]"}], ":=", 
  RowBox[{
   RowBox[{"\[Rho]piece", "[", 
    RowBox[{"x", ",", 
     RowBox[{"y", "+", "\[Lambda]y"}]}], "]"}], "/;", 
   RowBox[{"y", " ", "<", " ", 
    RowBox[{
     RowBox[{"-", "\[Lambda]y"}], "/", "2"}]}]}]}]], "Input",
 FontSize->24],

Cell[BoxData[
 RowBox[{
  RowBox[{"\[Rho]uno", "=", 
   RowBox[{"Plot3D", "[", 
    RowBox[{
     RowBox[{"\[Rho]piece", "[", 
      RowBox[{"x", ",", "y"}], "]"}], ",", 
     RowBox[{"{", 
      RowBox[{"x", ",", 
       RowBox[{
        RowBox[{"-", "3"}], 
        FractionBox["\[Lambda]x", "2"]}], ",", 
       RowBox[{"3", 
        FractionBox["\[Lambda]x", "2"]}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"y", ",", 
       RowBox[{
        RowBox[{"-", "3"}], " ", 
        FractionBox["\[Lambda]y", "2"]}], ",", 
       RowBox[{"3", 
        FractionBox["\[Lambda]y", "2"]}]}], "}"}], ",", 
     RowBox[{"AxesLabel", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{"\"\<x\>\"", ",", "\"\<y\>\"", ",", "\"\<\[Rho](x,y)\>\""}], 
       "}"}]}], ",", 
     RowBox[{"PlotPoints", "\[Rule]", "50"}], ",", 
     RowBox[{"ImageSize", "\[Rule]", "500"}]}], "]"}]}], 
  "\[IndentingNewLine]"}]], "Input",
 CellChangeTimes->{3.431680851703125*^9},
 FontSize->24],

Cell[BoxData[
 RowBox[{
  RowBox[{"DensityPlot", "[", 
   RowBox[{
    RowBox[{"\[Rho]piece", "[", 
     RowBox[{"x", ",", "y"}], "]"}], ",", 
    RowBox[{"{", 
     RowBox[{"x", ",", 
      RowBox[{
       RowBox[{"-", 
        FractionBox[
         RowBox[{"3", "\[Lambda]x"}], "2"]}], "-", 
       RowBox[{"0.1", "*", "\[Lambda]x"}]}], ",", 
      RowBox[{
       FractionBox[
        RowBox[{"3", "\[Lambda]x"}], "2"], "+", 
       RowBox[{"0.1", "*", "\[Lambda]x"}]}]}], "}"}], ",", 
    RowBox[{"{", 
     RowBox[{"y", ",", 
      RowBox[{
       RowBox[{"-", 
        FractionBox[
         RowBox[{"3", "\[Lambda]y"}], "2"]}], "-", 
       RowBox[{"0.1", "*", "\[Lambda]y"}]}], ",", 
      RowBox[{
       FractionBox[
        RowBox[{"3", "\[Lambda]y"}], "2"], "+", 
       RowBox[{"0.1", "*", "\[Lambda]y"}]}]}], "}"}], ",", 
    RowBox[{"PlotLabel", "\[Rule]", "\"\<\[Rho](x,y) top view\>\""}]}], "]"}],
   "\[IndentingNewLine]"}]], "Input",
 CellChangeTimes->{{3.48057433596875*^9, 3.480574341609375*^9}, 
   3.480585905515625*^9, {3.5068585642131243`*^9, 3.506858585575338*^9}, {
   3.5068599890229673`*^9, 3.506859993113852*^9}, {3.506926884484375*^9, 
   3.506926907421875*^9}}]
}, Open  ]],

Cell[CellGroupData[{

Cell["Section II.A", "Text",
 CellChangeTimes->{{3.480337450140625*^9, 3.48033745403125*^9}, {
  3.506858615413578*^9, 3.506858654687529*^9}, {3.5068587174772*^9, 
  3.5068587179122353`*^9}, {3.506861393525679*^9, 3.506861395850875*^9}, {
  3.5068614865007753`*^9, 3.506861487054907*^9}, {3.50693004978125*^9, 
  3.506930051171875*^9}, {3.506930083171875*^9, 3.50693008509375*^9}},
 FontFamily->"Times New Roman",
 FontSize->24,
 Background->GrayLevel[0.85]],

Cell["\<\
 With the following expression we can calculate the  Fourier coefficients \
one-by-one.
Again, in the following, we  h \[LongLeftArrow] m,  k \[LongLeftArrow] n.\
\>", "Text",
 CellChangeTimes->{{3.506854537832323*^9, 3.5068545865961437`*^9}, 
   3.5068546736373568`*^9, {3.506854759123962*^9, 3.506854796157324*^9}, {
   3.506858886085376*^9, 3.506858894423806*^9}, {3.506866018175528*^9, 
   3.5068660303742027`*^9}, {3.506866091384695*^9, 3.5068661130472*^9}, {
   3.50693066034375*^9, 3.5069306684375*^9}},
 FontFamily->"Times New Roman",
 FontSize->24,
 Background->GrayLevel[0.85]],

Cell[BoxData[
 RowBox[{
  RowBox[{"coef\[Rho]", "[", 
   RowBox[{"m_", ",", "n_"}], "]"}], ":=", "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    FractionBox["1", 
     RowBox[{"\[Lambda]x", "*", "\[Lambda]y"}]], "*", 
    RowBox[{
     SubsuperscriptBox["\[Integral]", 
      RowBox[{"-", 
       FractionBox["\[Lambda]x", "2"]}], 
      RowBox[{
       FractionBox["\[Lambda]x", "2"], " "}]], 
     RowBox[{
      SubsuperscriptBox["\[Integral]", 
       RowBox[{"-", 
        FractionBox["\[Lambda]y", "2"]}], 
       FractionBox["\[Lambda]y", "2"]], " ", 
      RowBox[{
       RowBox[{"\[Rho]", "[", 
        RowBox[{"x", ",", "y"}], "]"}], "*", 
       RowBox[{"Exp", "[", 
        RowBox[{
         RowBox[{"-", "\[ImaginaryI]"}], " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{
            FractionBox[
             RowBox[{"2", " ", "\[Pi]", " ", "m"}], "\[Lambda]x"], " ", "x"}],
            " ", "+", " ", 
           RowBox[{
            FractionBox[
             RowBox[{"2", " ", "\[Pi]", " ", "n"}], "\[Lambda]y"], " ", 
            "y"}]}], ")"}]}], "]"}], 
       RowBox[{"\[DifferentialD]", "y"}], " ", 
       RowBox[{"\[DifferentialD]", "x"}]}]}]}]}], " ", "//", 
   "Chop"}]}]], "Input",
 CellChangeTimes->{{3.506853413608817*^9, 3.506853420386717*^9}, {
   3.50685346087473*^9, 3.506853512467503*^9}, 3.506853607316888*^9, {
   3.5068536598817263`*^9, 3.506853677239573*^9}, {3.506853737622998*^9, 
   3.5068537419545813`*^9}, {3.506853853965234*^9, 3.506853870822291*^9}, {
   3.506858862063613*^9, 3.506858864759335*^9}, {3.506927028953125*^9, 
   3.50692707534375*^9}, {3.50692718590625*^9, 3.50692719709375*^9}},
 FontSize->18],

Cell["It is useful for further checking", "Text",
 CellChangeTimes->{{3.506858910448209*^9, 3.506858929547999*^9}},
 FontFamily->"Times New Roman",
 FontSize->24,
 Background->GrayLevel[0.85]],

Cell[BoxData[
 RowBox[{
  StyleBox["coef\[Rho]00",
   FontColor->RGBColor[1, 0, 0]], "=", "\[IndentingNewLine]", 
  RowBox[{
   FractionBox["1", 
    RowBox[{"\[Lambda]x", "*", "\[Lambda]y"}]], "*", 
   RowBox[{
    SubsuperscriptBox["\[Integral]", 
     RowBox[{"-", 
      FractionBox["\[Lambda]x", "2"]}], 
     RowBox[{
      FractionBox["\[Lambda]x", "2"], " "}]], 
    RowBox[{
     SubsuperscriptBox["\[Integral]", 
      RowBox[{"-", 
       FractionBox["\[Lambda]y", "2"]}], 
      FractionBox["\[Lambda]y", "2"]], " ", 
     RowBox[{
      RowBox[{"\[Rho]", "[", 
       RowBox[{"x", ",", "y"}], "]"}], "*", 
      RowBox[{"Exp", "[", 
       RowBox[{
        RowBox[{"-", "\[ImaginaryI]"}], " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{
           FractionBox[
            RowBox[{"2", " ", "\[Pi]", " ", "0"}], "\[Lambda]x"], " ", "x"}], 
          " ", "+", " ", 
          RowBox[{
           FractionBox[
            RowBox[{"2", " ", "\[Pi]", " ", "0"}], "\[Lambda]y"], " ", 
           "y"}]}], ")"}]}], "]"}], 
      RowBox[{"\[DifferentialD]", "y"}], " ", 
      RowBox[{"\[DifferentialD]", "x", " "}]}]}]}]}]}]], "Input",
 CellChangeTimes->{{3.506853413608817*^9, 3.506853420386717*^9}, {
   3.50685346087473*^9, 3.506853512467503*^9}, 3.506853607316888*^9, {
   3.506853881062399*^9, 3.5068539526224203`*^9}, 3.5069270881875*^9, {
   3.506927301625*^9, 3.5069273025*^9}},
 FontSize->18],

Cell[BoxData[
 RowBox[{
  StyleBox["coef\[Rho]10",
   FontColor->RGBColor[1, 0, 0]], "=", "\[IndentingNewLine]", 
  RowBox[{
   FractionBox["1", 
    RowBox[{"\[Lambda]x", "*", "\[Lambda]y"}]], "*", 
   RowBox[{
    SubsuperscriptBox["\[Integral]", 
     RowBox[{"-", 
      FractionBox["\[Lambda]x", "2"]}], 
     RowBox[{
      FractionBox["\[Lambda]x", "2"], " "}]], 
    RowBox[{
     SubsuperscriptBox["\[Integral]", 
      RowBox[{"-", 
       FractionBox["\[Lambda]y", "2"]}], 
      FractionBox["\[Lambda]y", "2"]], " ", 
     RowBox[{
      RowBox[{"\[Rho]", "[", 
       RowBox[{"x", ",", "y"}], "]"}], "*", 
      RowBox[{"Exp", "[", 
       RowBox[{
        RowBox[{"-", "\[ImaginaryI]"}], " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{
           FractionBox[
            RowBox[{"2", " ", "\[Pi]", " ", "1"}], "\[Lambda]x"], " ", "x"}], 
          " ", "+", " ", 
          RowBox[{
           FractionBox[
            RowBox[{"2", " ", "\[Pi]", " ", "0"}], "\[Lambda]y"], " ", 
           "y"}]}], ")"}]}], "]"}], 
      RowBox[{"\[DifferentialD]", "y"}], " ", 
      RowBox[{"\[DifferentialD]", "x", " "}]}]}]}]}]}]], "Input",
 CellChangeTimes->{{3.506853413608817*^9, 3.506853420386717*^9}, {
   3.50685346087473*^9, 3.506853512467503*^9}, 3.506853607316888*^9, {
   3.506853881062399*^9, 3.506853972390997*^9}, 3.506927092109375*^9, 
   3.50692730721875*^9},
 FontSize->18],

Cell[BoxData[
 RowBox[{
  StyleBox["coef\[Rho]20",
   FontColor->RGBColor[1, 0, 0]], "=", "\[IndentingNewLine]", 
  RowBox[{
   FractionBox["1", 
    RowBox[{"\[Lambda]x", "*", "\[Lambda]y"}]], "*", 
   RowBox[{
    SubsuperscriptBox["\[Integral]", 
     RowBox[{"-", 
      FractionBox["\[Lambda]x", "2"]}], 
     RowBox[{
      FractionBox["\[Lambda]x", "2"], " "}]], 
    RowBox[{
     SubsuperscriptBox["\[Integral]", 
      RowBox[{"-", 
       FractionBox["\[Lambda]y", "2"]}], 
      FractionBox["\[Lambda]y", "2"]], " ", 
     RowBox[{
      RowBox[{"\[Rho]", "[", 
       RowBox[{"x", ",", "y"}], "]"}], "*", 
      RowBox[{"Exp", "[", 
       RowBox[{
        RowBox[{"-", "\[ImaginaryI]"}], " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{
           FractionBox[
            RowBox[{"2", " ", "\[Pi]", " ", "2"}], "\[Lambda]x"], " ", "x"}], 
          " ", "+", " ", 
          RowBox[{
           FractionBox[
            RowBox[{"2", " ", "\[Pi]", " ", "0"}], "\[Lambda]y"], " ", 
           "y"}]}], ")"}]}], "]"}], 
      RowBox[{"\[DifferentialD]", "y"}], " ", 
      RowBox[{"\[DifferentialD]", "x", " "}]}]}]}]}]}]], "Input",
 CellChangeTimes->{{3.506853413608817*^9, 3.506853420386717*^9}, {
   3.50685346087473*^9, 3.506853512467503*^9}, 3.506853607316888*^9, {
   3.506853881062399*^9, 3.5068539930009604`*^9}, {3.506854050740521*^9, 
   3.506854060952449*^9}, 3.5069270959375*^9, 3.50692731078125*^9},
 FontSize->18],

Cell[BoxData[
 RowBox[{
  StyleBox["coef\[Rho]62",
   FontColor->RGBColor[1, 0, 0]], "=", "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    FractionBox["1", 
     RowBox[{"\[Lambda]x", "*", "\[Lambda]y"}]], "*", 
    RowBox[{
     SubsuperscriptBox["\[Integral]", 
      RowBox[{"-", 
       FractionBox["\[Lambda]x", "2"]}], 
      RowBox[{
       FractionBox["\[Lambda]x", "2"], " "}]], 
     RowBox[{
      SubsuperscriptBox["\[Integral]", 
       RowBox[{"-", 
        FractionBox["\[Lambda]y", "2"]}], 
       FractionBox["\[Lambda]y", "2"]], " ", 
      RowBox[{
       RowBox[{"\[Rho]", "[", 
        RowBox[{"x", ",", "y"}], "]"}], "*", 
       RowBox[{"Exp", "[", 
        RowBox[{
         RowBox[{"-", "\[ImaginaryI]"}], " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{
            FractionBox[
             RowBox[{"2", " ", "\[Pi]", " ", "6"}], "\[Lambda]x"], " ", "x"}],
            " ", "+", " ", 
           RowBox[{
            FractionBox[
             RowBox[{"2", " ", "\[Pi]", " ", "2"}], "\[Lambda]y"], " ", 
            "y"}]}], ")"}]}], "]"}], 
       RowBox[{"\[DifferentialD]", "y"}], " ", 
       RowBox[{"\[DifferentialD]", "x"}]}]}]}]}], " ", "//", "N"}]}]], "Input",\

 CellChangeTimes->{{3.506853413608817*^9, 3.506853420386717*^9}, {
   3.50685346087473*^9, 3.506853512467503*^9}, 3.506853607316888*^9, {
   3.506853881062399*^9, 3.5068539930009604`*^9}, {3.506854050740521*^9, 
   3.506854060952449*^9}, 3.5069270959375*^9, {3.5069272763125*^9, 
   3.506927323390625*^9}},
 FontSize->18],

Cell["Now  BarChart when h= 6 and k = -6,-5,...+6", "Text",
 CellChangeTimes->{{3.506858976513879*^9, 3.506858983597492*^9}, {
  3.506859237242876*^9, 3.5068592856911497`*^9}},
 FontFamily->"Times New Roman",
 FontSize->24,
 Background->GrayLevel[0.85]],

Cell[BoxData[
 RowBox[{"Timing", "[", 
  RowBox[{"BarChart", "[", 
   RowBox[{
    RowBox[{"Table", "[", 
     RowBox[{
      RowBox[{"Re", "[", 
       RowBox[{"coef\[Rho]", "[", 
        RowBox[{"6", ",", "jj"}], "]"}], "]"}], ",", 
      RowBox[{"{", 
       RowBox[{"jj", ",", 
        RowBox[{"-", "6"}], ",", "6"}], "}"}]}], "]"}], ",", 
    RowBox[{"ImageSize", "\[Rule]", "500"}]}], "]"}], " ", "]"}]], "Input",
 CellChangeTimes->{
  3.506854111427039*^9, {3.5068543090943623`*^9, 3.506854316722907*^9}, {
   3.506854371438354*^9, 3.506854380597989*^9}, {3.506858993558634*^9, 
   3.506858995965232*^9}, {3.506927355625*^9, 3.506927368125*^9}, {
   3.50692741478125*^9, 3.506927493296875*^9}},
 FontSize->24],

Cell["\<\
We can find also a general expression for the Fourier coefficients.\
\>", "Text",
 CellChangeTimes->{{3.480574783203125*^9, 3.48057480971875*^9}, {
   3.506859305136689*^9, 3.506859332877553*^9}, {3.506859368976349*^9, 
   3.506859474573471*^9}, 3.506919854265625*^9, {3.50691998978125*^9, 
   3.50691999478125*^9}, 3.5069308675*^9},
 FontFamily->"Times New Roman",
 FontSize->24,
 Background->GrayLevel[0.85]],

Cell[BoxData[
 RowBox[{"Timing", "[", 
  RowBox[{
   RowBox[{"coef1mn\[Rho]", "[", 
    RowBox[{"m_", ",", "n_"}], "]"}], "=", 
   RowBox[{
    RowBox[{"Simplify", "[", 
     RowBox[{
      FractionBox["1", 
       RowBox[{"\[Lambda]x", " ", "\[Lambda]y"}]], 
      RowBox[{"Integrate", "[", 
       RowBox[{
        RowBox[{
         RowBox[{"\[Rho]", "[", 
          RowBox[{"x", ",", "y"}], "]"}], 
         RowBox[{"Exp", "[", 
          RowBox[{
           RowBox[{"-", "\[ImaginaryI]"}], " ", 
           FractionBox[
            RowBox[{"2", " ", "\[Pi]", " ", "m"}], "\[Lambda]x"], " ", "x"}], 
          "]"}], " ", 
         RowBox[{"Exp", "[", 
          RowBox[{
           RowBox[{"-", "\[ImaginaryI]"}], " ", 
           FractionBox[
            RowBox[{"2", " ", "\[Pi]", " ", "n"}], "\[Lambda]y"], " ", "y"}], 
          "]"}]}], ",", 
        RowBox[{"{", 
         RowBox[{"x", ",", 
          RowBox[{"-", 
           FractionBox["\[Lambda]x", "2"]}], ",", 
          FractionBox["\[Lambda]x", "2"]}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{"y", ",", 
          RowBox[{"-", 
           FractionBox["\[Lambda]y", "2"]}], ",", 
          FractionBox["\[Lambda]y", "2"]}], "}"}]}], "]"}]}], "]"}], "//", 
    "Chop"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.480337719296875*^9, 3.480337724421875*^9}, {
   3.480337799859375*^9, 3.48033780553125*^9}, {3.506779500343532*^9, 
   3.506779516425398*^9}, {3.50683572903125*^9, 3.506835772734375*^9}, {
   3.506844410671875*^9, 3.50684442384375*^9}, 3.506927584578125*^9}],

Cell["\<\
To construct a general view of the coefficients we have to define the numers \
of terms,
e.g., ntx4=4 and nty4=4\
\>", "Text",
 CellChangeTimes->{{3.480574783203125*^9, 3.48057480971875*^9}, {
   3.506859305136689*^9, 3.506859332877553*^9}, {3.506859368976349*^9, 
   3.506859474573471*^9}, 3.506859532665609*^9, {3.506859604900346*^9, 
   3.5068596839529133`*^9}, {3.506859769303937*^9, 3.506859790731352*^9}, {
   3.506930880625*^9, 3.5069309606875*^9}},
 FontFamily->"Times New Roman",
 FontSize->24,
 Background->GrayLevel[0.85]],

Cell[BoxData[
 RowBox[{
  RowBox[{"ntx4", "=", "4"}], ";"}]], "Input",
 CellChangeTimes->{{3.48057590903125*^9, 3.48057595640625*^9}, {
  3.480578082828125*^9, 3.480578083578125*^9}, {3.506838654765625*^9, 
  3.506838657359375*^9}, {3.50692804121875*^9, 3.5069280416875*^9}, {
  3.506930921765625*^9, 3.506930922265625*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"nty4", "=", "4"}], ";"}]], "Input",
 CellChangeTimes->{{3.48057590903125*^9, 3.48057596015625*^9}, {
   3.5068386608125*^9, 3.506838664546875*^9}, 3.5068597205293016`*^9, {
   3.5069280476875*^9, 3.50692804809375*^9}, {3.506930925859375*^9, 
   3.5069309259375*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"Timing", "[", 
   RowBox[{"Do", "[", 
    RowBox[{
     RowBox[{"Do", "[", 
      RowBox[{
       RowBox[{
        RowBox[{"coefmn\[Rho]tab", "[", 
         RowBox[{"m", ",", "n"}], "]"}], "=", 
        RowBox[{"N", "[", 
         RowBox[{"coef1mn\[Rho]", "[", 
          RowBox[{"m", ",", "n"}], "]"}], "]"}]}], ",", 
       RowBox[{"{", 
        RowBox[{"m", ",", 
         RowBox[{
          RowBox[{"-", "ntx4"}], "-", "1"}], ",", 
         RowBox[{"ntx4", "+", "1"}], ",", "1"}], "}"}]}], "]"}], ",", 
     RowBox[{"{", 
      RowBox[{"n", ",", 
       RowBox[{
        RowBox[{"-", "nty4"}], " ", "-", "1"}], ",", 
       RowBox[{"nty4", "+", "1"}], ",", "1"}], "}"}]}], "]"}], "]"}], 
  "  "}]], "Input",
 CellChangeTimes->{
  3.506830240171875*^9, {3.5068358901875*^9, 3.506835969375*^9}, {
   3.5068365601875*^9, 3.50683658525*^9}, {3.50683663303125*^9, 
   3.506836647765625*^9}, {3.50683676696875*^9, 3.506836795671875*^9}, {
   3.506837456375*^9, 3.50683749284375*^9}, {3.5068390136875*^9, 
   3.506839025625*^9}, {3.506859538058672*^9, 3.5068595400924263`*^9}, {
   3.5069276573125*^9, 3.506927667828125*^9}, {3.506927736234375*^9, 
   3.506927782265625*^9}, {3.506927838109375*^9, 3.506927877265625*^9}, {
   3.506930970328125*^9, 3.506930990203125*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"tabcoef\[Rho]", "=", 
   RowBox[{
    RowBox[{"Table", "[", 
     RowBox[{
      RowBox[{"Table", "[", 
       RowBox[{
        RowBox[{"coefmn\[Rho]tab", "[", 
         RowBox[{"m", ",", "n"}], "]"}], ",", 
        RowBox[{"{", 
         RowBox[{"m", ",", 
          RowBox[{
           RowBox[{"-", "ntx4"}], "-", "1"}], ",", 
          RowBox[{"ntx4", "+", "1"}], ",", "1"}], "}"}]}], "]"}], ",", 
      RowBox[{"{", 
       RowBox[{"n", ",", 
        RowBox[{
         RowBox[{"-", "nty4"}], " ", "-", "1"}], ",", 
        RowBox[{"nty4", "+", "1"}], ",", "1"}], "}"}]}], "]"}], "//", 
    "Chop"}]}], ";"}]], "Input",
 CellChangeTimes->{{3.5067755878888273`*^9, 3.506775587911757*^9}, {
   3.5067756310422173`*^9, 3.506775636444723*^9}, {3.5067766236405497`*^9, 
   3.5067766307929792`*^9}, {3.50683693915625*^9, 3.50683697946875*^9}, 
   3.5068370549375*^9, {3.50683904903125*^9, 3.50683907084375*^9}, {
   3.50683917209375*^9, 3.50683919328125*^9}, {3.506859554500267*^9, 
   3.506859560130862*^9}, {3.506927801671875*^9, 3.506927806453125*^9}, {
   3.506927900625*^9, 3.5069279025625*^9}, {3.506930978671875*^9, 
   3.506930997*^9}},
 FontSize->24],

Cell[BoxData[
 RowBox[{"tabcoef\[Rho]", "//", "MatrixForm"}]], "Input",
 CellChangeTimes->{{3.506837013546875*^9, 3.50683703409375*^9}, 
   3.5068595675644207`*^9, 3.5068619485926247`*^9}],

Cell[BoxData[
 RowBox[{"Date", "[", "]"}]], "Input",
 CellChangeTimes->{{3.480574883328125*^9, 3.4805748845625*^9}}],

Cell[BoxData[
 RowBox[{"ListPlot3D", "[", 
  RowBox[{"tabcoef\[Rho]", ",", 
   RowBox[{"PlotRange", "\[Rule]", "All"}], ",", 
   RowBox[{
   "PlotLabel", "\[Rule]", 
    "\"\<discrete view of coefmn\[Rho]tab[m,n]\>\""}]}], "]"}]], "Input",
 CellChangeTimes->{{3.480338125078125*^9, 3.480338130625*^9}, 
   3.506843882734375*^9, 3.506859573834304*^9, {3.506859815165773*^9, 
   3.506859842605032*^9}, {3.506928690421875*^9, 3.5069287285625*^9}}],

Cell[BoxData[
 RowBox[{"ListContourPlot", "[", 
  RowBox[{"tabcoef\[Rho]", ",", 
   RowBox[{
   "PlotLabel", "\[Rule]", "\"\<another view of coefmn\[Rho]tab[m,n]\>\""}]}],
   "]"}]], "Input",
 CellChangeTimes->{
  3.506843884625*^9, 3.506859579670528*^9, {3.506859861984846*^9, 
   3.50685987345465*^9}, {3.5069287360625*^9, 3.50692873871875*^9}}]
}, Open  ]],

Cell[CellGroupData[{

Cell["SectionII.B", "Text",
 CellChangeTimes->{{3.480337450140625*^9, 3.48033745403125*^9}, {
  3.506858615413578*^9, 3.506858654687529*^9}, {3.5068587174772*^9, 
  3.5068587179122353`*^9}, {3.506861393525679*^9, 3.506861395850875*^9}, {
  3.5068614865007753`*^9, 3.506861487054907*^9}, {3.506861557089506*^9, 
  3.506861557745035*^9}, {3.5069300555625*^9, 3.506930056296875*^9}, {
  3.5069300895*^9, 3.50693009159375*^9}},
 FontFamily->"Times New Roman",
 FontSize->24,
 Background->GrayLevel[0.85]],

Cell["It is wise to reconstruct the original", "Text",
 CellChangeTimes->{{3.506859907876388*^9, 3.506859947977003*^9}, {
  3.506866167393362*^9, 3.5068661816322947`*^9}},
 FontFamily->"Times New Roman",
 FontSize->24,
 Background->GrayLevel[0.85]],

Cell[BoxData[
 RowBox[{
  RowBox[{"S", "[", 
   RowBox[{"x_", ",", "y_", ",", "ntx_", ",", "nty_"}], "]"}], ":=", 
  RowBox[{
   RowBox[{
    UnderoverscriptBox["\[Sum]", 
     RowBox[{"m", "=", 
      RowBox[{"-", "ntx"}]}], "ntx"], 
    RowBox[{
     UnderoverscriptBox["\[Sum]", 
      RowBox[{"n", "=", 
       StyleBox[
        RowBox[{"-", "nty"}],
        FontColor->RGBColor[1, 0, 0]]}], "nty"], 
     RowBox[{
      RowBox[{"N", "[", 
       RowBox[{"coef1mn\[Rho]", "[", 
        RowBox[{"m", ",", "n"}], "]"}], "]"}], "*", 
      SuperscriptBox["\[ExponentialE]", 
       RowBox[{"I", "*", 
        RowBox[{"(", 
         StyleBox[
          RowBox[{
           RowBox[{
            FractionBox[
             RowBox[{"2", " ", "\[Pi]", " ", "m"}], "\[Lambda]x"], " ", "x"}],
            "+", 
           RowBox[{
            FractionBox[
             RowBox[{"2", " ", "\[Pi]", " ", "n"}], "\[Lambda]y"], " ", 
            "y"}]}],
          FontSize->24], ")"}]}]]}]}]}], " ", "//", "Chop"}]}]], "Input",
 CellChangeTimes->{{3.431321031421875*^9, 3.4313210425625*^9}, {
   3.500441560609375*^9, 3.500441595578125*^9}, {3.500443328765625*^9, 
   3.50044334603125*^9}, {3.5068385855625*^9, 3.506838626171875*^9}, {
   3.50683870196875*^9, 3.50683870434375*^9}, {3.506838765125*^9, 
   3.506838799234375*^9}, 3.506839273375*^9, {3.50684428521875*^9, 
   3.506844355421875*^9}, {3.50692876925*^9, 3.50692877015625*^9}, {
   3.506928803859375*^9, 3.5069288238125*^9}},
 FontSize->24],

Cell["We consider the partial sums when ntx=nty=2 and ntx=nty=4", "Text",
 CellChangeTimes->{{3.506860414073595*^9, 3.5068604579039183`*^9}, 
   3.506866220971305*^9, {3.506931061359375*^9, 3.506931066171875*^9}},
 FontFamily->"Times New Roman",
 FontSize->24,
 Background->GrayLevel[0.85]],

Cell[BoxData[
 RowBox[{
  RowBox[{"ntx2", "=", "2"}], ";"}]], "Input",
 CellChangeTimes->{{3.48057590903125*^9, 3.48057595640625*^9}, {
  3.480578082828125*^9, 3.480578083578125*^9}, {3.506838654765625*^9, 
  3.506838657359375*^9}, {3.506862089177499*^9, 3.506862093291448*^9}, {
  3.5069289415*^9, 3.506928955328125*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"nty2", "=", "2"}], ";"}]], "Input",
 CellChangeTimes->{{3.48057590903125*^9, 3.48057596015625*^9}, {
   3.5068386608125*^9, 3.506838664546875*^9}, 3.5068597205293016`*^9, {
   3.506862096474998*^9, 3.506862099636944*^9}, {3.50692896090625*^9, 
   3.506928964171875*^9}}],

Cell[BoxData[
 RowBox[{"Sumntx2", "=", 
  RowBox[{"S", "[", 
   RowBox[{"x", ",", "y", ",", "ntx2", ",", "nty2"}], "]"}]}]], "Input",
 CellChangeTimes->{
  3.48033838653125*^9, {3.506838722296875*^9, 3.50683872475*^9}, {
   3.506840016546875*^9, 3.506840052796875*^9}, {3.506860596902791*^9, 
   3.506860605224491*^9}, {3.5068620142061243`*^9, 3.506862017053617*^9}, {
   3.506862102498674*^9, 3.506862106452075*^9}, {3.506929011171875*^9, 
   3.50692904271875*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"ntx4", "=", "4"}], ";"}]], "Input",
 CellChangeTimes->{{3.48057590903125*^9, 3.48057595640625*^9}, {
  3.480578082828125*^9, 3.480578083578125*^9}, {3.506838654765625*^9, 
  3.506838657359375*^9}, {3.506862089177499*^9, 3.506862093291448*^9}, {
  3.5069289415*^9, 3.506928955328125*^9}, {3.5069289855625*^9, 
  3.50692899690625*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"nty4", "=", "4"}], ";"}]], "Input",
 CellChangeTimes->{{3.48057590903125*^9, 3.48057596015625*^9}, {
   3.5068386608125*^9, 3.506838664546875*^9}, 3.5068597205293016`*^9, {
   3.506862096474998*^9, 3.506862099636944*^9}, {3.50692896090625*^9, 
   3.50692899290625*^9}}],

Cell[BoxData[
 RowBox[{"Sumntx4", "=", 
  RowBox[{"S", "[", 
   RowBox[{"x", ",", "y", ",", "ntx4", ",", "nty4"}], "]"}]}]], "Input",
 CellChangeTimes->{{3.480338368734375*^9, 3.480338376859375*^9}, {
   3.50683929953125*^9, 3.50683931421875*^9}, {3.50684004434375*^9, 
   3.5068400564375*^9}, {3.506840179140625*^9, 3.506840179765625*^9}, {
   3.5068404640625*^9, 3.506840467453125*^9}, {3.506841040921875*^9, 
   3.50684104215625*^9}, {3.506841297546875*^9, 3.50684129821875*^9}, {
   3.506841491234375*^9, 3.50684149875*^9}, {3.50684216059375*^9, 
   3.506842164140625*^9}, {3.506860612926467*^9, 3.5068606164550877`*^9}, 
   3.506861138399109*^9, {3.50692900121875*^9, 3.506929004203125*^9}, {
   3.50692905134375*^9, 3.506929052140625*^9}}],

Cell[BoxData[
 RowBox[{"graSum2", "=", 
  RowBox[{"Plot3D", "[", 
   RowBox[{
    RowBox[{"Evaluate", "[", "Sumntx2", "]"}], ",", 
    RowBox[{"{", 
     RowBox[{"x", ",", 
      RowBox[{"-", 
       FractionBox["\[Lambda]x", "2"]}], ",", 
      FractionBox["\[Lambda]x", "2"]}], "}"}], ",", 
    RowBox[{"{", 
     RowBox[{"y", ",", 
      RowBox[{"-", 
       FractionBox["\[Lambda]y", "2"]}], ",", 
      FractionBox["\[Lambda]y", "2"]}], "}"}], ",", 
    RowBox[{"PlotLabel", "\[Rule]", "\"\<Partial sum with \!\(\*
StyleBox[\"ntx\",
FontColor->RGBColor[1, 0, 0]]\)\!\(\*
StyleBox[\"=\",
FontColor->RGBColor[1, 0, 0]]\)\!\(\*
StyleBox[\"nty\",
FontColor->RGBColor[1, 0, 0]]\)\!\(\*
StyleBox[\"=\",
FontColor->RGBColor[1, 0, 0]]\)\!\(\*
StyleBox[\"2\",
FontColor->RGBColor[1, 0, 0]]\) terms\>\""}]}], "]"}]}]], "Input",
 CellChangeTimes->{{3.480338398*^9, 3.480338413765625*^9}, {
   3.50683154534375*^9, 3.5068315755*^9}, {3.50683790234375*^9, 
   3.50683793021875*^9}, 3.50684008390625*^9, {3.506842193015625*^9, 
   3.506842200703125*^9}, {3.50686053576528*^9, 3.506860563915483*^9}, {
   3.506860637086513*^9, 3.506860669360257*^9}, {3.5069290623125*^9, 
   3.506929062765625*^9}, {3.5069291093125*^9, 3.50692912115625*^9}, {
   3.506931088890625*^9, 3.5069310898125*^9}}],

Cell[BoxData[
 RowBox[{"graSum4", "=", 
  RowBox[{"Plot3D", "[", 
   RowBox[{
    RowBox[{"Evaluate", "[", "Sumntx4", "]"}], ",", 
    RowBox[{"{", 
     RowBox[{"x", ",", 
      RowBox[{"-", 
       FractionBox["\[Lambda]x", "2"]}], ",", 
      FractionBox["\[Lambda]x", "2"]}], "}"}], ",", 
    RowBox[{"{", 
     RowBox[{"y", ",", 
      RowBox[{"-", 
       FractionBox["\[Lambda]y", "2"]}], ",", 
      FractionBox["\[Lambda]y", "2"]}], "}"}], ",", 
    RowBox[{"PlotLabel", "\[Rule]", "\"\<Partial sum with \!\(\*
StyleBox[\"ntx\",
FontColor->RGBColor[1, 0, 0]]\)\!\(\*
StyleBox[\"=\",
FontColor->RGBColor[1, 0, 0]]\)\!\(\*
StyleBox[\"nty\",
FontColor->RGBColor[1, 0, 0]]\)\!\(\*
StyleBox[\"=\",
FontColor->RGBColor[1, 0, 0]]\)\!\(\*
StyleBox[\"4\",
FontColor->RGBColor[1, 0, 0]]\) terms\>\""}]}], "]"}]}]], "Input",
 CellChangeTimes->{{3.480338398*^9, 3.480338413765625*^9}, {
   3.50683154534375*^9, 3.5068315755*^9}, {3.50683790234375*^9, 
   3.50683793021875*^9}, {3.5068379865625*^9, 3.5068379909375*^9}, 
   3.506840197046875*^9, {3.506842211171875*^9, 3.5068422206875*^9}, {
   3.506860642626095*^9, 3.506860657782949*^9}, {3.5068658433750677`*^9, 
   3.5068658480061502`*^9}, {3.5069291345625*^9, 3.506929142265625*^9}, {
   3.50693109578125*^9, 3.50693110165625*^9}}],

Cell[BoxData[
 RowBox[{"Timing", "[", 
  RowBox[{"graErrornt2", "=", 
   RowBox[{"Plot3D", "[", 
    RowBox[{
     RowBox[{"Evaluate", "[", 
      RowBox[{
       RowBox[{"\[Rho]", "[", 
        RowBox[{"x", ",", "y"}], "]"}], "-", "Sumntx2"}], "]"}], ",", 
     RowBox[{"{", 
      RowBox[{"x", ",", 
       RowBox[{"-", 
        FractionBox["\[Lambda]x", "2"]}], ",", 
       FractionBox["\[Lambda]x", "2"]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"y", ",", 
       RowBox[{"-", 
        FractionBox["\[Lambda]y", "2"]}], ",", 
       FractionBox["\[Lambda]y", "2"]}], "}"}], ",", 
     RowBox[{"PlotLabel", "\[Rule]", "\"\<\[Rho][x,y]-Sumntx2\>\""}]}], 
    "]"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.480338503078125*^9, 3.48033853475*^9}, {
   3.5068315895625*^9, 3.50683161496875*^9}, {3.506838014984375*^9, 
   3.50683813771875*^9}, {3.50683819265625*^9, 3.506838209421875*^9}, 
   3.50684013528125*^9, {3.506840848703125*^9, 3.506840866390625*^9}, {
   3.506860709139802*^9, 3.5068607169728107`*^9}, 3.5068607628142653`*^9, 
   3.5068608181765413`*^9, 3.506865295889846*^9, {3.506929156109375*^9, 
   3.506929180140625*^9}}],

Cell[BoxData[
 RowBox[{"Timing", "[", 
  RowBox[{"graErrornt4", "=", 
   RowBox[{"Plot3D", "[", 
    RowBox[{
     RowBox[{"Evaluate", "[", 
      RowBox[{
       RowBox[{"\[Rho]", "[", 
        RowBox[{"x", ",", "y"}], "]"}], "-", "Sumntx4"}], "]"}], ",", 
     "\[IndentingNewLine]", 
     RowBox[{"{", 
      RowBox[{"x", ",", 
       RowBox[{"-", 
        FractionBox["\[Lambda]x", "2"]}], ",", 
       FractionBox["\[Lambda]x", "2"]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"y", ",", 
       RowBox[{"-", 
        FractionBox["\[Lambda]y", "2"]}], ",", 
       FractionBox["\[Lambda]y", "2"]}], "}"}], ",", 
     RowBox[{"PlotPoints", "\[Rule]", "25"}], ",", 
     RowBox[{"AxesLabel", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{"\"\<x\>\"", ",", "\"\<y\>\"", ",", "\"\<err\>\""}], "}"}]}], 
     ",", 
     RowBox[{"ImageSize", "\[Rule]", "500"}], ",", "\[IndentingNewLine]", 
     RowBox[{
     "PlotLabel", "\[Rule]", "\"\<Evaluate[\[Rho][x,y]-Sumntx4]\>\""}], ",", 
     "\[IndentingNewLine]", 
     RowBox[{"AxesStyle", "\[Rule]", 
      RowBox[{"Directive", "[", 
       RowBox[{"Blue", ",", "20", ",", 
        RowBox[{"FontFamily", "\[Rule]", "\"\<Helvetica\>\""}]}], "]"}]}], 
     ",", 
     RowBox[{"ImageSize", "\[Rule]", "500"}]}], "]"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.480338503078125*^9, 3.48033853475*^9}, {
   3.5068315895625*^9, 3.50683161496875*^9}, {3.506838014984375*^9, 
   3.50683815946875*^9}, 3.5068401425*^9, {3.506840611625*^9, 
   3.5068408125*^9}, {3.506840885765625*^9, 3.506840976453125*^9}, {
   3.50684143809375*^9, 3.5068414520625*^9}, {3.50684195609375*^9, 
   3.506841973046875*^9}, 3.506842005390625*^9, {3.50684226315625*^9, 
   3.506842302078125*^9}, {3.50684357353125*^9, 3.506843576890625*^9}, {
   3.50684361421875*^9, 3.50684362009375*^9}, 3.506860726731629*^9, 
   3.506860762824346*^9, {3.506860824061234*^9, 3.5068608273085012`*^9}, {
   3.506862342690421*^9, 3.506862368908675*^9}, {3.506865321619494*^9, 
   3.5068653305835457`*^9}, {3.506865409149466*^9, 3.506865417441761*^9}, 
   3.506865472150667*^9, {3.506929207078125*^9, 3.506929250109375*^9}}],

Cell[BoxData[
 RowBox[{"graErrsectionnt2", "=", 
  RowBox[{"Plot", "[", 
   RowBox[{
    RowBox[{"Evaluate", "[", 
     RowBox[{
      RowBox[{"\[Rho]", "[", 
       RowBox[{
        RowBox[{
         RowBox[{"-", "\[Lambda]x"}], "/", "4"}], ",", "y"}], "]"}], "-", 
      RowBox[{"S", "[", 
       RowBox[{
        RowBox[{
         RowBox[{"-", "\[Lambda]x"}], "/", "4"}], ",", "y", ",", "ntx2", ",", 
        "nty2"}], "]"}]}], "]"}], ",", 
    RowBox[{"{", 
     RowBox[{"y", ",", 
      RowBox[{
       RowBox[{"-", "\[Lambda]x"}], "/", "2"}], ",", 
      RowBox[{"\[Lambda]y", "/", "2"}]}], "}"}], ",", 
    RowBox[{"PlotStyle", "\[Rule]", 
     RowBox[{"{", 
      RowBox[{"Hue", "[", "0.05", "]"}], "}"}]}], ",", 
    RowBox[{
    "PlotLabel", "\[Rule]", 
     "\"\<\[Rho][-\[Lambda]x/4,y]-S[-\[Lambda]x/4,y,ntx2,nty2\>\""}]}], 
   "]"}]}]], "Input",
 CellChangeTimes->{{3.480338553359375*^9, 3.480338579921875*^9}, {
   3.506839472796875*^9, 3.506839475046875*^9}, 3.506860762878305*^9, {
   3.5068611000210876`*^9, 3.506861108456558*^9}, {3.506862195302443*^9, 
   3.506862200967244*^9}, 3.5068655688364*^9, {3.506929288515625*^9, 
   3.5069293218125*^9}, {3.506929358671875*^9, 3.50692936828125*^9}, {
   3.506931150140625*^9, 3.50693115115625*^9}}],

Cell[BoxData[
 RowBox[{"graErrsectionnt4", "=", 
  RowBox[{"Plot", "[", 
   RowBox[{
    RowBox[{"Evaluate", "[", 
     RowBox[{
      RowBox[{"\[Rho]", "[", 
       RowBox[{
        RowBox[{
         RowBox[{"-", "\[Lambda]x"}], "/", "4"}], ",", "y"}], "]"}], "-", 
      RowBox[{"S", "[", 
       RowBox[{
        RowBox[{
         RowBox[{"-", "\[Lambda]x"}], "/", "4"}], ",", "y", ",", "ntx4", ",", 
        "nty4"}], "]"}]}], "]"}], ",", 
    RowBox[{"{", 
     RowBox[{"y", ",", 
      RowBox[{
       RowBox[{"-", "\[Lambda]x"}], "/", "2"}], ",", 
      RowBox[{"\[Lambda]y", "/", "2"}]}], "}"}], ",", "\[IndentingNewLine]", 
    RowBox[{"(*", 
     RowBox[{
      RowBox[{"PlotRange", "\[Rule]", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{
          RowBox[{"-", "1"}], " ", 
          SuperscriptBox["10", 
           RowBox[{"-", "16"}]]}], ",", " ", 
         RowBox[{"1", " ", 
          SuperscriptBox["10", 
           RowBox[{"-", "16"}]]}]}], "}"}]}], ","}], "*)"}], 
    RowBox[{"PlotStyle", "\[Rule]", 
     RowBox[{"{", 
      RowBox[{"Hue", "[", "0.05", "]"}], "}"}]}], ",", 
    RowBox[{
    "PlotLabel", "\[Rule]", 
     "\"\<\[Rho][-\[Lambda]x/4,y]-S[-\[Lambda]x/4,y,ntx4,nty4]\>\""}]}], 
   "]"}]}]], "Input",
 CellChangeTimes->{{3.480338553359375*^9, 3.480338579921875*^9}, {
   3.506839472796875*^9, 3.506839475046875*^9}, 3.506860762878305*^9, {
   3.506860995879436*^9, 3.506861051188295*^9}, {3.506861085789925*^9, 
   3.50686112179174*^9}, {3.506862248080908*^9, 3.506862312314608*^9}, 
   3.5068655916590643`*^9, {3.506865639909278*^9, 3.5068656887627077`*^9}, {
   3.506866609234321*^9, 3.506866612402614*^9}, {3.50692938809375*^9, 
   3.50692949140625*^9}, {3.5069311604375*^9, 3.506931165515625*^9}, {
   3.506931201328125*^9, 3.506931208890625*^9}, {3.5069314370625*^9, 
   3.506931452859375*^9}}]
}, Open  ]]
}, Open  ]]
},
CellGrouping->Manual,
WindowSize->{1904, 946},
WindowMargins->{{0, Automatic}, {Automatic, 0}},
FrontEndVersion->"8.0 for Microsoft Windows (64-bit) (February 23, 2011)",
StyleDefinitions->"Zosi-direi-buono.nb"
]
(* End of Notebook Content *)

(* Internal cache information *)
(*CellTagsOutline
CellTagsIndex->{}
*)
(*CellTagsIndex
CellTagsIndex->{}
*)
(*NotebookFileOutline
Notebook[{
Cell[545, 20, 643, 13, 87, "Text"],
Cell[1191, 35, 11052, 216, 977, "Text",
 CellGroupingRules->{GroupTogetherGrouping, 10001.}],
Cell[CellGroupData[{
Cell[12268, 255, 1360, 21, 71, "Text",
 CellGroupingRules->{GroupTogetherGrouping, 10000.}],
Cell[13631, 278, 4876, 118, 328, "Text",
 CellGroupingRules->{GroupTogetherGrouping, 10000.}],
Cell[CellGroupData[{
Cell[18532, 400, 1168, 19, 55, "Text",
 CellGroupingRules->{GroupTogetherGrouping, 10000.}],
Cell[19703, 421, 354, 8, 31, "Input"],
Cell[20060, 431, 1579, 31, 64, "Input",
 CellGroupingRules->{GroupTogetherGrouping, 10001.}],
Cell[21642, 464, 346, 10, 33, "Input"],
Cell[21991, 476, 115, 2, 31, "Input"],
Cell[22109, 480, 306, 8, 57, "Text"],
Cell[22418, 490, 674, 21, 49, "Input"],
Cell[23095, 513, 111, 3, 31, "Input"],
Cell[23209, 518, 399, 8, 52, "Input"],
Cell[23611, 528, 752, 19, 65, "Text"],
Cell[24366, 549, 722, 19, 47, "Input"],
Cell[25091, 570, 1802, 48, 112, "Input"],
Cell[26896, 620, 1039, 28, 68, "Input"]
}, Open  ]],
Cell[CellGroupData[{
Cell[27972, 653, 361, 7, 57, "Text"],
Cell[28336, 662, 324, 8, 57, "Text"],
Cell[28663, 672, 276, 7, 31, "Input"],
Cell[28942, 681, 488, 11, 87, "Text"],
Cell[29433, 694, 345, 7, 31, "Input"],
Cell[29781, 703, 273, 6, 57, "Text"],
Cell[30057, 711, 1693, 40, 97, "Input"]
}, Open  ]],
Cell[CellGroupData[{
Cell[31787, 756, 411, 8, 57, "Text"],
Cell[32201, 766, 542, 11, 87, "Text"],
Cell[32746, 779, 1414, 37, 93, "Input"],
Cell[34163, 818, 192, 4, 57, "Text"],
Cell[34358, 824, 1259, 35, 93, "Input"],
Cell[35620, 861, 1257, 35, 93, "Input"],
Cell[36880, 898, 1309, 36, 93, "Input"],
Cell[38192, 936, 253, 5, 57, "Text"],
Cell[38448, 943, 750, 20, 42, "Input"],
Cell[39201, 965, 571, 12, 87, "Text"],
Cell[39775, 979, 1335, 35, 49, "Input"],
Cell[41113, 1016, 401, 9, 57, "Text"],
Cell[41517, 1027, 388, 9, 31, "Input"],
Cell[41908, 1038, 288, 7, 31, "Input"],
Cell[42199, 1047, 472, 14, 33, "Input"],
Cell[42674, 1063, 1458, 40, 49, "Input"],
Cell[44135, 1105, 1558, 41, 49, "Input"],
Cell[45696, 1148, 501, 11, 87, "Text"],
Cell[46200, 1161, 232, 5, 31, "Input"],
Cell[46435, 1168, 206, 4, 31, "Input"],
Cell[46644, 1174, 1402, 37, 31, "Input"],
Cell[48049, 1213, 1012, 26, 42, "Input"],
Cell[49064, 1241, 188, 3, 31, "Input"],
Cell[49255, 1246, 116, 2, 31, "Input"],
Cell[49374, 1250, 352, 8, 31, "Input"],
Cell[49729, 1260, 308, 8, 31, "Input"]
}, Open  ]],
Cell[CellGroupData[{
Cell[50074, 1273, 458, 8, 57, "Text"],
Cell[50535, 1283, 248, 5, 57, "Text"],
Cell[50786, 1290, 1371, 38, 92, "Input"],
Cell[52160, 1330, 244, 5, 57, "Text"],
Cell[52407, 1337, 278, 5, 31, "Input"],
Cell[52688, 1344, 256, 5, 31, "Input"],
Cell[52947, 1351, 417, 8, 31, "Input"],
Cell[53367, 1361, 651, 11, 31, "Input"],
Cell[54021, 1374, 976, 24, 31, "Input"],
Cell[55000, 1400, 1026, 25, 31, "Input"],
Cell[56029, 1427, 924, 20, 31, "Input"],
Cell[56956, 1449, 342, 6, 57, "Text"],
Cell[57301, 1457, 1881, 39, 72, "Input"],
Cell[59185, 1498, 2069, 47, 55, "Input"],
Cell[61257, 1547, 1659, 34, 72, "Input"],
Cell[62919, 1583, 976, 22, 31, "Input"],
Cell[63898, 1607, 1277, 32, 33, "Input"],
Cell[65178, 1641, 985, 26, 31, "Input"],
Cell[66166, 1669, 1464, 39, 55, "Input"],
Cell[67633, 1710, 380, 7, 57, "Text"],
Cell[68016, 1719, 1651, 45, 55, "Input"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[69716, 1770, 1321, 20, 71, "Text",
 CellGroupingRules->{GroupTogetherGrouping, 10000.}],
Cell[71040, 1792, 4750, 116, 264, "Text",
 CellGroupingRules->{GroupTogetherGrouping, 10000.}],
Cell[CellGroupData[{
Cell[75815, 1912, 1168, 19, 55, "Text",
 CellGroupingRules->{GroupTogetherGrouping, 10000.}],
Cell[76986, 1933, 354, 8, 31, "Input"],
Cell[77343, 1943, 1579, 31, 64, "Input",
 CellGroupingRules->{GroupTogetherGrouping, 10001.}],
Cell[78925, 1976, 99, 1, 31, "Input"],
Cell[79027, 1979, 115, 2, 31, "Input"],
Cell[79145, 1983, 383, 8, 57, "Text"],
Cell[79531, 1993, 662, 20, 47, "Input"],
Cell[80196, 2015, 159, 4, 31, "Input"],
Cell[80358, 2021, 250, 7, 52, "Input"],
Cell[80611, 2030, 447, 9, 52, "Input"],
Cell[81061, 2041, 1806, 46, 112, "Input"],
Cell[82870, 2089, 389, 8, 57, "Text"],
Cell[83262, 2099, 806, 25, 77, "Input"],
Cell[84071, 2126, 328, 10, 42, "Input"],
Cell[84402, 2138, 341, 11, 42, "Input"],
Cell[84746, 2151, 328, 10, 42, "Input"],
Cell[85077, 2163, 341, 11, 42, "Input"],
Cell[85421, 2176, 966, 29, 107, "Input"],
Cell[86390, 2207, 1192, 33, 68, "Input"]
}, Open  ]],
Cell[CellGroupData[{
Cell[87619, 2245, 458, 8, 57, "Text"],
Cell[88080, 2255, 597, 12, 87, "Text"],
Cell[88680, 2269, 1675, 44, 100, "Input"],
Cell[90358, 2315, 192, 4, 57, "Text"],
Cell[90553, 2321, 1426, 40, 100, "Input"],
Cell[91982, 2363, 1409, 40, 100, "Input"],
Cell[93394, 2405, 1455, 40, 100, "Input"],
Cell[94852, 2447, 1540, 43, 100, "Input"],
Cell[96395, 2492, 253, 5, 57, "Text"],
Cell[96651, 2499, 716, 18, 42, "Input"],
Cell[97370, 2519, 420, 9, 57, "Text"],
Cell[97793, 2530, 1548, 41, 49, "Input"],
Cell[99344, 2573, 543, 12, 87, "Text"],
Cell[99890, 2587, 324, 6, 31, "Input"],
Cell[100217, 2595, 301, 6, 31, "Input"],
Cell[100521, 2603, 1303, 32, 31, "Input"],
Cell[101827, 2637, 1191, 29, 42, "Input"],
Cell[103021, 2668, 188, 3, 31, "Input"],
Cell[103212, 2673, 116, 2, 31, "Input"],
Cell[103331, 2677, 444, 9, 31, "Input"],
Cell[103778, 2688, 347, 8, 31, "Input"]
}, Open  ]],
Cell[CellGroupData[{
Cell[104162, 2701, 500, 9, 57, "Text"],
Cell[104665, 2712, 248, 5, 57, "Text"],
Cell[104916, 2719, 1490, 40, 92, "Input"],
Cell[106409, 2761, 290, 5, 57, "Text"],
Cell[106702, 2768, 322, 6, 31, "Input"],
Cell[107027, 2776, 305, 6, 31, "Input"],
Cell[107335, 2784, 466, 9, 31, "Input"],
Cell[107804, 2795, 368, 7, 31, "Input"],
Cell[108175, 2804, 304, 6, 31, "Input"],
Cell[108482, 2812, 745, 12, 31, "Input"],
Cell[109230, 2826, 1279, 32, 47, "Input"],
Cell[110512, 2860, 1282, 32, 47, "Input"],
Cell[111797, 2894, 1144, 27, 47, "Input"],
Cell[112944, 2923, 2126, 46, 121, "Input"],
Cell[115073, 2971, 1260, 32, 31, "Input"],
Cell[116336, 3005, 1845, 47, 55, "Input"]
}, Open  ]]
}, Open  ]]
}
]
*)

(* End of internal cache information *)
