(* Content-type: application/mathematica *)

(*** Wolfram Notebook File ***)
(* http://www.wolfram.com/nb *)

(* CreatedBy='Mathematica 7.0' *)

(*CacheID: 234*)
(* Internal cache information:
NotebookFileLineBreakTest
NotebookFileLineBreakTest
NotebookDataPosition[       145,          7]
NotebookDataLength[    560836,      10616]
NotebookOptionsPosition[    551970,      10313]
NotebookOutlinePosition[    552439,      10333]
CellTagsIndexPosition[    552396,      10330]
WindowFrame->Normal*)

(* Beginning of Notebook Content *)
Notebook[{
Cell["\<\
Evaluation time
\[CapitalDelta]t < 4 s   \
\>", "Text",
 CellChangeTimes->{{3.5613483031229563`*^9, 3.561348339745145*^9}, {
  3.56135098674468*^9, 3.561351023826701*^9}, {3.561351426355578*^9, 
  3.561351561050626*^9}, {3.561351658143539*^9, 3.561351701940361*^9}, {
  3.562308659027141*^9, 3.562308685577752*^9}, {3.5739849802054777`*^9, 
  3.573985010523902*^9}, {3.5739850441078873`*^9, 3.573985091187277*^9}, {
  3.5739852917493277`*^9, 3.573985301197431*^9}, {3.573985387415966*^9, 
  3.573985423188324*^9}, {3.573985799716304*^9, 3.573985871674148*^9}, {
  3.5739859027151823`*^9, 3.573985908625372*^9}, {3.573985970636365*^9, 
  3.573985971137138*^9}, {3.574514403882321*^9, 3.5745144157610006`*^9}},
 FontSize->24,
 FontColor->RGBColor[0, 0, 1],
 Background->RGBColor[1, 0.9, 0.8]],

Cell[TextData[{
 "This notebook is about some aspects of the numerical solution of an ODE , \
for example, \n                             \n                                \
   ",
 Cell[BoxData[
  FormBox[
   RowBox[{
    StyleBox["{",
     FontSize->45], " ", GridBox[{
      {
       RowBox[{
        RowBox[{
         RowBox[{"ODE", "           ", 
          RowBox[{"x", "'"}], 
          RowBox[{"(", "t", ")"}]}], "-", 
         RowBox[{"x", "(", "t", ")"}]}], "=", "0"}]},
      {
       RowBox[{"    ", 
        RowBox[{
         RowBox[{"IC", "      ", 
          RowBox[{"x", "[", "0", "]"}]}], "=", 
         RowBox[{
          RowBox[{"1", " ", "for", " ", "0"}], " ", "<", " ", "t", " ", "<", 
          " ", "t_fin", "  "}]}]}]}
     }]}], TraditionalForm]]],
 "(1)\n \n obtained  by means of the command NDSolve.\n \n Since we do not \
expect to give an exaustive treatment, we will just illustrate, \n even with \
this trivial example,  how it is possible\n to have at least an idea of the \
possibilities offered by the NDSolve command.\n For this purpose, we have to \
introduce two kinds of errors (Note 1):\n \n 1) The global error is here \
defined as\n              ",
 StyleBox[" ",
  FontSize->36],
 Cell[BoxData[
  FormBox[
   RowBox[{
    SubscriptBox["e", "i"], " "}], TraditionalForm]]],
 " =  ",
 StyleBox["x",
  FontSlant->"Italic"],
 "(",
 Cell[BoxData[
  FormBox[
   SubscriptBox["t", "i"], TraditionalForm]]],
 ")",
 Cell[BoxData[
  FormBox[
   RowBox[{" ", 
    RowBox[{"-", " ", 
     SubscriptBox["x", "i"]}]}], TraditionalForm]]],
 " where\n  - ",
 StyleBox["x",
  FontSlant->"Italic"],
 "(",
 Cell[BoxData[
  FormBox[
   SubscriptBox["t", "i"], TraditionalForm]]],
 ") is the",
 StyleBox[" true",
  FontSlant->"Italic"],
 " solution of the ODE at ",
 Cell[BoxData[
  FormBox[
   RowBox[{"t", " ", "=", " ", 
    SubscriptBox["t", "i"], " "}], TraditionalForm]]],
 " ",
 StyleBox[" ",
  FontSlant->"Italic"],
 " and\n -",
 Cell[BoxData[
  FormBox[
   RowBox[{"  ", 
    SubscriptBox["x", "i"]}], TraditionalForm]], "Input"],
 " is the numerical solution found, at the same  ",
 Cell[BoxData[
  FormBox[
   RowBox[{
    RowBox[{"t", " ", "=", " ", 
     SubscriptBox["t", "i"]}], ",", " "}], TraditionalForm]]],
 " by the built-in command NDSolve.\n  However, as  ",
 StyleBox["x",
  FontSlant->"Italic"],
 "(",
 Cell[BoxData[
  FormBox[
   SubscriptBox["t", "i"], TraditionalForm]]],
 ")  is at disposal only in those cases where the analytical solutions know,\n\
  it is useful to resort to the second kind of error\n   \n 2) The residual \
error is obtainable after substitution of the numerical solution, \n          \
 an interpolation function object (IFO, Note 2),  back into the original \
equation to see\n            how well it solves the ODE. Usually, we are \
satisfied when  the residual is \n            near to zero, but it is \
appropriate to recall what Mark Sofroniou (Wolfram) says\n            \n      \
      ",
 StyleBox["While the residual is related to the error you should not mistake \
it\n           for a direct measure of the error. A solution with small \
residual error\n           can have large error",
  FontSlant->"Italic"]
}], "Text",
 CellChangeTimes->{{3.432984958734375*^9, 3.4329849665625*^9}, {
   3.43332981478125*^9, 3.433329816109375*^9}, {3.442057656984375*^9, 
   3.44205774384375*^9}, 3.442058730484375*^9, {3.442059064375*^9, 
   3.442059098265625*^9}, {3.4420603753125*^9, 3.442060384109375*^9}, {
   3.442060422*^9, 3.4420605378125*^9}, {3.49519575603125*^9, 
   3.495195794484375*^9}, {3.495195828203125*^9, 3.495195907859375*^9}, {
   3.495195945171875*^9, 3.49519611775*^9}, {3.4951962355*^9, 
   3.495196298203125*^9}, {3.495196355078125*^9, 3.49519646371875*^9}, {
   3.4951965003125*^9, 3.495196647734375*^9}, {3.49519682521875*^9, 
   3.4951968799375*^9}, {3.495196951078125*^9, 3.49519695415625*^9}, {
   3.495199133890625*^9, 3.49519930815625*^9}, 3.49666944190625*^9, {
   3.496669540609375*^9, 3.49667000575*^9}, 3.49667007896875*^9, {
   3.49667011534375*^9, 3.496670218515625*^9}, {3.496670256015625*^9, 
   3.49667026009375*^9}, {3.496670337*^9, 3.4966703671875*^9}, {
   3.496670478*^9, 3.496670505890625*^9}, {3.496670547234375*^9, 
   3.496670574875*^9}, {3.496670608203125*^9, 3.496670631328125*^9}, {
   3.49672760571875*^9, 3.49672760803125*^9}, {3.496727644203125*^9, 
   3.496727685984375*^9}, {3.4967277201875*^9, 3.49672772178125*^9}, {
   3.49674708671875*^9, 3.496747096609375*^9}, {3.56128282309694*^9, 
   3.5612828308307047`*^9}, {3.561283878860196*^9, 3.5612839225077763`*^9}, {
   3.561283962100245*^9, 3.561283984169382*^9}, {3.561284020422007*^9, 
   3.561284166601224*^9}, {3.5612842611462383`*^9, 3.561284297399015*^9}, {
   3.561284332316331*^9, 3.5612844118409157`*^9}, {3.56128444384931*^9, 
   3.56128458932201*^9}, {3.5612846517560167`*^9, 3.5612847219715347`*^9}, {
   3.561284753686095*^9, 3.561284930446385*^9}, {3.5612849912225313`*^9, 
   3.561285085266478*^9}, 3.561285132195622*^9, {3.56128520264758*^9, 
   3.561285287930707*^9}, {3.561285436626279*^9, 3.561285514684123*^9}, {
   3.56128557569715*^9, 3.5612855887123547`*^9}, {3.561285685798307*^9, 
   3.561285778829077*^9}, {3.5612858719345284`*^9, 3.5612858756819887`*^9}, {
   3.561285961560574*^9, 3.56128597435222*^9}, 3.5612860123055887`*^9, {
   3.5612860817450867`*^9, 3.561286122301196*^9}, {3.561286165064357*^9, 
   3.561286165388467*^9}, {3.5612863146724577`*^9, 3.56128631963903*^9}, {
   3.561286374101522*^9, 3.561286393054981*^9}, {3.561286494618198*^9, 
   3.561286591316832*^9}, {3.5612867061554613`*^9, 3.561286800723712*^9}, {
   3.561286831828373*^9, 3.561286834367888*^9}, {3.561286886917225*^9, 
   3.5612869126834717`*^9}, {3.5612869582731256`*^9, 3.561286959092511*^9}, {
   3.561287139176734*^9, 3.5612871772803707`*^9}, 3.56135064500805*^9, 
   3.561351512300521*^9, {3.5745144454726996`*^9, 3.574514610241124*^9}},
 FontFamily->"Times New Roman",
 FontSize->24,
 FontColor->RGBColor[0, 0, 1],
 Background->RGBColor[1, 1, 0.85]],

Cell[TextData[{
 " Note 1. Any good book on the numerical evaluation of the ODE has some \
sections\n                 discussing the difference between the different \
kinds of errors;\n                 E.g.  M.J. Maron \
\[OpenCurlyDoubleQuote]Numerical Analysis Apractical Approach\
\[CloseCurlyDoubleQuote], 2nd ed, MacMillan Pub. Co, 1987\n",
 StyleBox["\n ",
  FontSlant->"Italic"],
 "Note 2. The numerical solution is representd by an interpolation function \
object, \n               that is, a function passing through the points \
chosen by the algorithm which\n               evaluates the unknown over the \
selected grid points.  \n               We recall that the IFO can be \
differentiated, integrated,  plotted, and so on.\n               In this nb \
we consider only the Default Options offered by NDSolve "
}], "Text",
 CellChangeTimes->{{3.432984958734375*^9, 3.4329849665625*^9}, {
   3.43332981478125*^9, 3.433329816109375*^9}, {3.442057656984375*^9, 
   3.44205774384375*^9}, 3.442058730484375*^9, {3.442059064375*^9, 
   3.442059098265625*^9}, {3.4420603753125*^9, 3.442060384109375*^9}, {
   3.442060422*^9, 3.4420605378125*^9}, {3.49519575603125*^9, 
   3.495195794484375*^9}, {3.495195828203125*^9, 3.495195907859375*^9}, {
   3.495195945171875*^9, 3.49519611775*^9}, {3.4951962355*^9, 
   3.495196298203125*^9}, {3.495196355078125*^9, 3.49519646371875*^9}, {
   3.4951965003125*^9, 3.495196647734375*^9}, {3.49519682521875*^9, 
   3.4951968799375*^9}, {3.495196951078125*^9, 3.49519695415625*^9}, {
   3.495199133890625*^9, 3.49519930815625*^9}, 3.49666944190625*^9, {
   3.496669540609375*^9, 3.49667000575*^9}, 3.49667007896875*^9, {
   3.49667011534375*^9, 3.496670218515625*^9}, {3.496670256015625*^9, 
   3.49667026009375*^9}, {3.496670337*^9, 3.4966703671875*^9}, {
   3.496670478*^9, 3.496670505890625*^9}, {3.496670547234375*^9, 
   3.496670574875*^9}, {3.496670608203125*^9, 3.496670631328125*^9}, {
   3.49672760571875*^9, 3.49672760803125*^9}, {3.496727644203125*^9, 
   3.496727685984375*^9}, {3.4967277201875*^9, 3.49672772178125*^9}, {
   3.49674708671875*^9, 3.496747096609375*^9}, {3.56128282309694*^9, 
   3.5612828308307047`*^9}, {3.561283878860196*^9, 3.5612839225077763`*^9}, {
   3.561283962100245*^9, 3.561283984169382*^9}, {3.561284020422007*^9, 
   3.561284166601224*^9}, {3.5612842611462383`*^9, 3.561284297399015*^9}, {
   3.561284332316331*^9, 3.5612844118409157`*^9}, {3.56128444384931*^9, 
   3.56128458932201*^9}, {3.5612846517560167`*^9, 3.5612847219715347`*^9}, {
   3.561284753686095*^9, 3.561284930446385*^9}, {3.5612849912225313`*^9, 
   3.561285085266478*^9}, 3.561285132195622*^9, {3.56128520264758*^9, 
   3.561285287930707*^9}, {3.561285436626279*^9, 3.561285514684123*^9}, {
   3.56128557569715*^9, 3.5612855887123547`*^9}, {3.561285685798307*^9, 
   3.561285778829077*^9}, {3.5612858719345284`*^9, 3.5612858756819887`*^9}, {
   3.561285961560574*^9, 3.56128597435222*^9}, 3.5612860123055887`*^9, {
   3.5612860817450867`*^9, 3.561286122301196*^9}, {3.561286165064357*^9, 
   3.561286165388467*^9}, {3.5612863146724577`*^9, 3.56128631963903*^9}, {
   3.561286374101522*^9, 3.561286393054981*^9}, {3.561286494618198*^9, 
   3.561286591316832*^9}, {3.5612867061554613`*^9, 3.561286800723712*^9}, {
   3.561286831828373*^9, 3.561286834367888*^9}, {3.561286886917225*^9, 
   3.5612869126834717`*^9}, {3.5612869582731256`*^9, 3.561286959092511*^9}, {
   3.561287139176734*^9, 3.5612871772803707`*^9}, 3.56135064500805*^9, {
   3.573985184168124*^9, 3.5739852827863693`*^9}, {3.574514615297413*^9, 
   3.57451461874561*^9}},
 FontFamily->"Times New Roman",
 FontSize->24,
 FontColor->RGBColor[0, 0, 1],
 Background->RGBColor[1, 1, 0.85]],

Cell[TextData[{
 "We consider seven parts:\n\n1) We calculate ",
 StyleBox["the symbolic solution (with DSolve) and ",
  FontFamily->"Utopia",
  FontSize->24],
 " \n     ",
 StyleBox["the numeric solution  (with NDSolve) ",
  FontFamily->"Utopia",
  FontSize->24],
 "of the system (1)\n2) We  extract the coordinates of the nodes (TimeNodes) \
hit by    \n     the numeric method and evaluate solsymb and solNDS on the \
same nodes\n3) To estimate the GlobalError, we examine the difference ",
 StyleBox[" between \n     the values calculated  by the numeric solution and \
the symbolic \n     solution on the same ",
  FontFamily->"Utopia",
  FontSize->24],
 "TimeNodes",
 StyleBox["\n4) ",
  FontFamily->"Utopia",
  FontSize->24],
 "To estimate the GlobalError, we examine the difference ",
 StyleBox[" between \n       the symbolic solution and the IFO representing \
the numerical solution\n5)   We examine the residual function obtained by \
substituting teh IFO into the system (1)\n",
  FontFamily->"Utopia",
  FontSize->24],
 "6)   We compare the GlobalError and the ResidualError only on the \
TimeNodes,\n      that means, the nodes hit by the numerical method\n 7)  \
Short digression on Hermite interpolation  \n  \n   Conclusion: The \
ResidualError is not a ",
 StyleBox["perfect",
  FontSlant->"Italic"],
 " indicator of the real error \n                         contained in the \
numerical solution but it can be considered \n                          a \
useful tool. \n                          \n                         We invite \
the reader to try the same procedures with more complicated functions and \
enjoy the results!"
}], "Text",
 CellChangeTimes->{{3.441959582546875*^9, 3.44195966165625*^9}, {
   3.442060616203125*^9, 3.44206062196875*^9}, {3.4420611343125*^9, 
   3.442061276953125*^9}, {3.442061320265625*^9, 3.442061394359375*^9}, {
   3.442061487515625*^9, 3.442061887515625*^9}, 3.442061923609375*^9, 
   3.44206238434375*^9, {3.44206255975*^9, 3.44206256028125*^9}, {
   3.442149009734375*^9, 3.442149012859375*^9}, {3.442149050359375*^9, 
   3.442149188640625*^9}, {3.442149226875*^9, 3.4421493121875*^9}, {
   3.442149342640625*^9, 3.442149399421875*^9}, {3.442149433609375*^9, 
   3.44214961746875*^9}, {3.442149678796875*^9, 3.442149714328125*^9}, {
   3.442154405328125*^9, 3.44215440609375*^9}, 3.442298685386031*^9, {
   3.49510363821875*^9, 3.495103649*^9}, {3.49510846128125*^9, 
   3.495108467421875*^9}, 3.495111457765625*^9, {3.49666306821875*^9, 
   3.4966631073125*^9}, {3.49666314753125*^9, 3.49666322784375*^9}, {
   3.496663282171875*^9, 3.4966634096875*^9}, {3.496663513421875*^9, 
   3.496663539984375*^9}, {3.496663651484375*^9, 3.49666368903125*^9}, {
   3.496663756046875*^9, 3.4966637888125*^9}, {3.496663831953125*^9, 
   3.4966638435625*^9}, {3.4966639441875*^9, 3.496664044375*^9}, {
   3.496664085875*^9, 3.496664135015625*^9}, {3.496664227453125*^9, 
   3.49666427475*^9}, {3.496664418171875*^9, 3.496664487015625*^9}, {
   3.496664542640625*^9, 3.49666459959375*^9}, {3.49666475696875*^9, 
   3.49666485115625*^9}, {3.496665516375*^9, 3.4966655215*^9}, {
   3.496665556359375*^9, 3.49666571553125*^9}, {3.4967464605*^9, 
   3.4967464618125*^9}, {3.496749313796875*^9, 3.496749317328125*^9}, {
   3.49683442459375*^9, 3.4968345115*^9}, {3.5612869989920607`*^9, 
   3.5612870402733917`*^9}, {3.56129697056164*^9, 3.561296988217889*^9}, {
   3.561298210351753*^9, 3.561298258341168*^9}, {3.561348920301907*^9, 
   3.561348920515768*^9}, {3.561351178083227*^9, 3.561351201577052*^9}, {
   3.574514692360821*^9, 3.5745147208734517`*^9}, 3.5745147722893925`*^9, {
   3.574514846688648*^9, 3.57451484724868*^9}, {3.5745151302018642`*^9, 
   3.57451519936982*^9}},
 FontSize->24,
 FontColor->RGBColor[0, 0, 1],
 Background->RGBColor[1, 1, 0.85]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", 
   RowBox[{"However", ",", " ", 
    RowBox[{
    "if", " ", "you", " ", "are", " ", "Impatient", " ", "and", " ", "you", 
     " ", "have", " ", "someway", " ", 
     StyleBox[
      RowBox[{"a", 
       StyleBox["lready",
        FontVariations->{"Underline"->True}]}]], 
     StyleBox[" ",
      FontVariations->{"Underline"->True}], 
     StyleBox["run",
      FontVariations->{"Underline"->True}], 
     StyleBox[" ",
      FontVariations->{"Underline"->True}], 
     StyleBox["this",
      FontVariations->{"Underline"->True}], 
     StyleBox[" ",
      FontVariations->{"Underline"->True}], 
     StyleBox["nb",
      FontVariations->{"Underline"->True}]}], 
    StyleBox[",",
     FontVariations->{"Underline"->True}], " ", 
    RowBox[{"you", " ", "can", " ", "click", " ", "this", " ", "cell"}]}], 
   " ", "*)"}], "\[IndentingNewLine]", 
  RowBox[{"Hyperlink", "[", "hyphyp", "]"}]}]], "Input",
 CellChangeTimes->{{3.561349979732888*^9, 3.561350019757031*^9}, {
  3.561350697829133*^9, 3.561350746264123*^9}, {3.5613508942216454`*^9, 
  3.561350962456707*^9}, {3.561370354190283*^9, 3.561370355172756*^9}}],

Cell[BoxData[
 TagBox[
  ButtonBox[
   PaneSelectorBox[{False->"hyphyp", True->
    StyleBox["hyphyp", "HyperlinkActive"]}, Dynamic[
     CurrentValue["MouseOver"]],
    BaseStyle->{"Hyperlink"},
    FrameMargins->0,
    ImageSize->Automatic],
   BaseStyle->"Hyperlink",
   ButtonData:>{$CellContext`hyphyp, None},
   ButtonNote->ButtonData],
  Annotation[#, $CellContext`hyphyp, "Hyperlink"]& ]], "Output",
 CellChangeTimes->{3.577697677977151*^9}]
}, Open  ]],

Cell[TextData[{
 "We considere the following  ODE with the initial condition IC\n\n\t\t\t",
 Cell[BoxData[
  FormBox[
   RowBox[{
    StyleBox["{",
     FontSize->45], " ", GridBox[{
      {
       RowBox[{
        RowBox[{
         RowBox[{"ODE", "   ", 
          RowBox[{"x", "'"}]}], "-", "x"}], "=", "0"}]},
      {
       RowBox[{
        RowBox[{"IC", "      ", 
         RowBox[{"x", "[", "0", "]"}]}], "=", "1.", "  "}]}
     }]}], TraditionalForm]]],
 "        (1)\t\n\nThe solution is  ",
 StyleBox[" ",
  FontFamily->"Times New Roman"],
 Cell[BoxData[
  RowBox[{
   RowBox[{"x", 
    RowBox[{"(", "t", ")"}]}], " ", "=", " ", 
   SuperscriptBox["\[ExponentialE]", "t"]}]],
  CellChangeTimes->{
   3.44195948865625*^9, 3.441959712359375*^9, 3.44196010528125*^9, 
    3.4419611048125*^9, 3.4419611419375*^9, {3.44196508165625*^9, 
    3.44196509034375*^9}, {3.441965139859375*^9, 3.441965145890625*^9}, 
    3.441965927140625*^9, 3.44197415546875*^9, 3.442063654859375*^9, 
    3.44206504321875*^9, 3.4420729784375*^9, 3.4420851091875*^9, 
    3.442095234078125*^9, {3.44210079153125*^9, 3.44210080328125*^9}, 
    3.44210188709375*^9, {3.442151937171875*^9, 3.44215195665625*^9}, 
    3.4421544799375*^9, 3.4421799611875*^9, 3.442182094140625*^9, 
    3.442299818117124*^9, 3.442300769908202*^9, 3.4423021008866043`*^9},
  FontFamily->"Times New Roman"]
}], "Text",
 CellChangeTimes->{{3.441959582546875*^9, 3.44195966165625*^9}, {
   3.442060616203125*^9, 3.44206062196875*^9}, {3.4420611343125*^9, 
   3.442061276953125*^9}, {3.442061320265625*^9, 3.442061394359375*^9}, {
   3.442061487515625*^9, 3.442061887515625*^9}, 3.442061923609375*^9, {
   3.442062088828125*^9, 3.44206213271875*^9}, {3.4420622845*^9, 
   3.442062318953125*^9}, {3.442062402703125*^9, 3.442062426421875*^9}, {
   3.44206247659375*^9, 3.44206260809375*^9}, {3.442100619625*^9, 
   3.442100707203125*^9}, {3.442149653421875*^9, 3.44214967221875*^9}, {
   3.442149720984375*^9, 3.442149721234375*^9}, {3.44215201878125*^9, 
   3.4421520224375*^9}, {3.4421543131875*^9, 3.442154313921875*^9}, {
   3.49510366065625*^9, 3.49510371525*^9}, {3.49666293459375*^9, 
   3.49666304296875*^9}, {3.49666312734375*^9, 3.496663140578125*^9}, 
   3.5745147393015056`*^9},
 FontSize->24,
 Background->GrayLevel[0.85]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"Clear", "[", "\"\<Global`*\>\"", "]"}], ";", 
  RowBox[{"Remove", "[", "\"\<Global`*\>\"", "]"}], ";", 
  RowBox[{"$Line", "=", "0", "  "}]}]], "Input",
 CellChangeTimes->{3.495103580875*^9},
 FontSize->24],

Cell[BoxData["0"], "Output",
 CellChangeTimes->{3.57769767825077*^9}]
}, Open  ]],

Cell[BoxData[
 RowBox[{
  RowBox[{"SetOptions", "[", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"Plot", ",", "ListPlot", ",", "Plot3D"}], "}"}], ",", 
    RowBox[{"ImageSize", "\[Rule]", "500"}], ",", 
    RowBox[{"LabelStyle", "\[Rule]", 
     RowBox[{"(", 
      RowBox[{"FontFamily", "\[Rule]", "\"\<Helvetica\>\""}], ")"}]}], ",", 
    RowBox[{"AxesStyle", "\[Rule]", 
     RowBox[{"Directive", "[", 
      RowBox[{"20", ",", 
       RowBox[{"Thickness", "[", "0.005", "]"}], ",", "Blue"}], "]"}]}]}], 
   "]"}], ";"}]], "Input",
 CellChangeTimes->{{3.431404133265625*^9, 3.431404152625*^9}, {
   3.431404184828125*^9, 3.43140419784375*^9}, {3.431404229828125*^9, 
   3.431404286*^9}, {3.431404358734375*^9, 3.431404362015625*^9}, 
   3.43140449659375*^9, {3.431404585328125*^9, 3.431404586390625*^9}, {
   3.431404647765625*^9, 3.431404694953125*^9}, {3.43140617875*^9, 
   3.4314062495625*^9}, {3.431406282875*^9, 3.4314063513125*^9}, {
   3.43140679328125*^9, 3.43140680225*^9}, {3.4314068341875*^9, 
   3.431406876078125*^9}, {3.43228594825*^9, 3.432285987546875*^9}, {
   3.441960481296875*^9, 3.441960483484375*^9}, 3.44205855490625*^9, {
   3.44205867675*^9, 3.442058682359375*^9}, 3.495103580875*^9},
 FontSize->24,
 Background->GrayLevel[0.85]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"tini", "=", "0"}], ";", " ", 
  RowBox[{"tfin", " ", "=", " ", "1"}]}]], "Input",
 FontSize->24],

Cell[BoxData["1"], "Output",
 CellChangeTimes->{3.5776976782841053`*^9}]
}, Open  ]],

Cell[BoxData[""], "Input",
 CellChangeTimes->{{3.5745148520569553`*^9, 3.5745148537940545`*^9}}],

Cell[CellGroupData[{

Cell["Part I", "Text",
 CellChangeTimes->{{3.4420619435625*^9, 3.4420619460625*^9}, {
  3.495108480859375*^9, 3.49510848184375*^9}, {3.495285762890625*^9, 
  3.495285793703125*^9}, {3.49528627184375*^9, 3.49528627628125*^9}, {
  3.574514859153361*^9, 3.574514860104415*^9}},
 FontSize->36,
 FontColor->RGBColor[0, 0, 1],
 Background->RGBColor[1, 0.9, 0.8]],

Cell[CellGroupData[{

Cell["We evaluate symbolically the solution (solsymb) of the ODE", "Text",
 CellChangeTimes->{{3.4420619435625*^9, 3.4420619460625*^9}, {
  3.495108480859375*^9, 3.49510848184375*^9}, {3.495285762890625*^9, 
  3.495285793703125*^9}, {3.49528627184375*^9, 3.49528627628125*^9}, {
  3.574515224057232*^9, 3.5745152276014347`*^9}},
 FontSize->24,
 Background->GrayLevel[0.85]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  StyleBox[
   RowBox[{"sol", 
    StyleBox["DS",
     FontColor->RGBColor[0, 0, 1]]}]], "=", 
  RowBox[{"DSolve", "[", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{
      RowBox[{
       RowBox[{
        RowBox[{
         RowBox[{"x", "'"}], "[", "t", "]"}], "-", 
        RowBox[{"x", "[", "t", "]"}]}], "\[Equal]", " ", "0"}], ",", 
      RowBox[{
       RowBox[{"x", "[", "0", "]"}], "\[Equal]", "1"}]}], "}"}], ",", "x", 
    ",", "t"}], "]"}]}]], "Input",
 CellChangeTimes->{
  3.442065042296875*^9, {3.442100765640625*^9, 3.44210077103125*^9}},
 FontSize->24],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"{", 
   RowBox[{"x", "\[Rule]", 
    RowBox[{"Function", "[", 
     RowBox[{
      RowBox[{"{", "t", "}"}], ",", 
      SuperscriptBox["\[ExponentialE]", "t"]}], "]"}]}], "}"}], 
  "}"}]], "Output",
 CellChangeTimes->{3.577697678368862*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"solsymb", "[", "t_", "]"}], "=", " ", 
  RowBox[{
   RowBox[{"x", "[", "t", "]"}], " ", "/.", " ", 
   RowBox[{"First", "[", 
    StyleBox[
     RowBox[{"sol", 
      StyleBox["DS",
       FontColor->RGBColor[0, 0, 1]]}]], "]"}]}]}]], "Input",
 CellChangeTimes->{{3.442064885734375*^9, 3.44206489003125*^9}, 
   3.4420650454375*^9, 3.495285363296875*^9},
 FontSize->24],

Cell[BoxData[
 SuperscriptBox["\[ExponentialE]", "t"]], "Output",
 CellChangeTimes->{3.57769767855602*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Plot", "[", 
  RowBox[{
   RowBox[{"solsymb", "[", "t", "]"}], ",", 
   StyleBox[
    RowBox[{"{", 
     RowBox[{"t", ",", "tini", ",", "tfin"}], "}"}],
    FontColor->GrayLevel[0]], 
   StyleBox[",",
    FontColor->GrayLevel[0]], 
   StyleBox[
    RowBox[{"PlotRange", "\[Rule]", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"tini", ",", "tfin"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"0", ",", "3"}], "}"}]}], "}"}]}],
    FontColor->GrayLevel[0]]}], "]"}]], "Input",
 CellChangeTimes->{
  3.441959714828125*^9, {3.442063648015625*^9, 3.44206364865625*^9}, {
   3.44206415028125*^9, 3.44206415140625*^9}, {3.4420649815625*^9, 
   3.442064987640625*^9}, {3.44207357215625*^9, 3.44207357578125*^9}, 
   3.44208707471875*^9, 3.49528536753125*^9},
 FontSize->24],

Cell[BoxData[
 GraphicsBox[{{}, {}, 
   {Hue[0.67, 0.6, 0.6], LineBox[CompressedData["
1:eJwVxXk4lHkAB/AZ5n1cOaaUHSWrRUo6hJLa70+1qaRCko14SiXbjaUe+zDO
XCtMkvtKxYM0g+TqQW1JjiiSuwnleIfMiMLu/vF5PlonL9mclmIwGFb/+f/9
p4dbnn62+9X48nWKwRCBtUv9ci/HCD41t3PNmSJsTktI5nN2I3bRtFuglAiW
r9sfpXCOwMs7cJMMJYK963RlLMcVzdsUJpXlRejeELoriuMJ75g4Q11VEdKX
HgoJ5wQh1s+n+rSeCFxZ/uowDg/Dumk+m6xFOOaQUSiayMan9osMuTwRFBa4
jhYrC5FwMKI2lzEBHevx4doIAayWy4TsOzoB70ZTJEyVIS43oJNdPAE1AbuH
yaxGjPdq7d+VJ1EysKuhaXsNYp5KvEw9JlHjnrLcYbQOZr0lJc7tkxDr7lDO
v/APDkt+yhOYfIXUTJ7Kcp168FMFjcbpX2Gy4FJiW9CA3e5OY1WsKTQEGTU+
X9sEZfknPPNzU9C8OTLzYLwZQmv/1PCOKYxM9/a83fgGZXdCSdBOMbK/lNcr
/d0KtTClu3WlYihp3KOFwjaE8y+usDOQIPJc8Zl07XeY+uBxyyRFAgnJE7r5
tYP37uVDRc40PA3rBMtqO3ApKmOLbPQ0egvqIlq0OpGYY+sXyv6G7+5tSWuu
fwCB/oPTvG/QN5eZP1PehbjRC0ZzKjOwyNQ6W6TWA4NXOlFdiTPw1nBe1e/Y
C35Y2rOdK2exbtROod2qD791aY5kZsxiibJItm62D8N6kxGqm7+DVZ1U+Ety
P8wDLX8kVn7HH0bl7+UsB7CQfO1159EfyNt3Mr1KMgDRz4ndwaIfEI+oqwzG
f4Rjaa74RcAcim0tpHm7hYh/1LY+V3sefnuD0wSDQhQZQDxUNQ+t7v0dWcGf
kNWpuEzdYQHbtgTxOIaDOD+y3W2EySCOK5tmmK2DCG3JFBvZMoi4PmrgMncI
6vIh0M1nkATWCU8b7WG82MN91y/FJEt6ijOl6oZR9dhcOukYk1B/cY+YXvmM
OWNuol8pkzAenCgcWPwFof2d+kK2FLmaWBi1uOYLVO/NPuv3kiKV+jdk2RdH
YLrqlNzqTinC3n91XYDSKG55FEgSTaVJl0Fz67WKUZRvUbLakSVNHqZCW3hi
DHw6LnpIhkWcCk3YGvNjsFjWKh95nkX8gzO4XbnjqECZ88wHFskf1khSOkCD
leOwTm0PRW6kBLv0HKQh6fesFVtQxNVmTKfAmsalN6lBbfsosqKi4qGVPY2+
OwbBsVYUCY8+/jzyJI0I21Q/FTuKuJncmZC/RuO6nLyTqitFVgWp7pXJoaF2
TLbNLIAi81t9Fdvv05BNXyPQDKLI+7GPb3LyaLADm6ukQyhy057vtKeIhoFi
lW1DGEUW1tp4BFfQWDrk7+scQ5GuluhU6VYaXldHG6LSKfI4ZPpU61saLpF6
9p6ZFOGZOa/J6qDhb6i76Hg2RSzvrhfs7KGxQd9LonefIk98Xr/kfqbhq/aq
4XkhReINjKOtR2nQ733zC4oocmUg+YgWTaORKJXF8ymid+B879MpGsZKvYfP
llKExWzLvjlNo25ep/tQGUX6is3cXWZp1N87zttaTpEK96wNG+doaDYF/qlV
SZHbmgrihQUa49syA+WrKfIvk9dWVA==
     "]]}},
  AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
  Axes->True,
  AxesLabel->{None, None},
  AxesOrigin->{0, 0},
  AxesStyle->Directive[20, 
    Thickness[0.005], 
    RGBColor[0, 0, 1]],
  ImageSize->500,
  LabelStyle->(FontFamily -> "Helvetica"),
  Method->{},
  PlotRange->{{0, 1}, {0, 3}},
  PlotRangeClipping->True,
  PlotRangePadding->{Automatic, Automatic}]], "Output",
 CellChangeTimes->{
  3.577697678625606*^9},ImageCache->GraphicsData["CompressedBitmap", "\<\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\
\>"]]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
 "We evaluate numerically the solution (solNDS) of the ODE\n      ( ",
 StyleBox["without  introducing any of the numerous Options of NDSolve)\n     \
 and use some of the tools  offered by ",
  FontColor->GrayLevel[0]],
 "InterpolatingFunctionAnatomy"
}], "Text",
 CellChangeTimes->{{3.442063124046875*^9, 3.44206312528125*^9}, {
   3.49510850378125*^9, 3.49510857546875*^9}, {3.495197200984375*^9, 
   3.495197246390625*^9}, {3.495285807359375*^9, 3.49528582221875*^9}, 
   3.495285997171875*^9, {3.495286281265625*^9, 3.495286285046875*^9}, {
   3.496834527765625*^9, 3.496834554671875*^9}, {3.561289543257484*^9, 
   3.561289589162808*^9}, {3.574515225698326*^9, 3.574515228649495*^9}},
 FontSize->24,
 Background->GrayLevel[0.85]],

Cell[BoxData[
 RowBox[{
  RowBox[{
  "Needs", "[", "\"\<DifferentialEquations`InterpolatingFunctionAnatomy`\>\"",
    "]"}], ";"}]], "Input",
 FontSize->24,
 CellID->408132437],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  StyleBox["solNDS",
   FontColor->RGBColor[1, 0, 0]], "=", 
  RowBox[{"x", " ", "/.", 
   RowBox[{"First", "[", 
    RowBox[{"NDSolve", "[", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{
        RowBox[{
         RowBox[{
          RowBox[{
           RowBox[{"x", "'"}], "[", "t", "]"}], "-", 
          RowBox[{"x", "[", "t", "]"}]}], "\[Equal]", "0"}], ",", 
        RowBox[{
         RowBox[{"x", "[", "0", "]"}], "\[Equal]", "1"}]}], "}"}], ",", "x", 
      ",", 
      RowBox[{"{", 
       RowBox[{"t", ",", "tini", ",", "tfin"}], " ", "}"}]}], "]"}], 
    "]"}]}]}]], "Input",
 CellChangeTimes->{
  3.442065051078125*^9, {3.442100775234375*^9, 3.442100780421875*^9}, {
   3.4951089606875*^9, 3.495108975015625*^9}},
 FontSize->24],

Cell[BoxData[
 TagBox[
  RowBox[{"InterpolatingFunction", "[", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"{", 
      RowBox[{"0.`", ",", "1.`"}], "}"}], "}"}], ",", "\<\"<>\"\>"}], "]"}],
  False,
  Editable->False]], "Output",
 CellChangeTimes->{3.577697678973868*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Plot", "[", 
  RowBox[{
   RowBox[{
    StyleBox["solNDS",
     FontColor->RGBColor[1, 0, 0]], "[", "t", "]"}], ",", 
   RowBox[{"{", 
    RowBox[{"t", ",", "tini", ",", "tfin"}], "}"}], ",", 
   StyleBox[
    RowBox[{"PlotRange", "\[Rule]", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"tini", ",", "tfin"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"0", ",", "3"}], "}"}]}], "}"}]}],
    FontColor->GrayLevel[0]]}], "]"}]], "Input",
 CellChangeTimes->{{3.441959759734375*^9, 3.4419597776875*^9}, {
  3.441960135109375*^9, 3.441960165265625*^9}, {3.44206395715625*^9, 
  3.4420639584375*^9}, {3.44206419675*^9, 3.442064197640625*^9}, {
  3.442065068421875*^9, 3.4420650700625*^9}, {3.4420870690625*^9, 
  3.44208707215625*^9}, {3.495109033578125*^9, 3.495109035765625*^9}},
 FontSize->24],

Cell[BoxData[
 GraphicsBox[{{}, {}, 
   {Hue[0.67, 0.6, 0.6], LineBox[CompressedData["
1:eJwVxXk4lHkAB/C53iXWMSU9k+RRWOnckpJtv7/oIUqWiE5WdMhuKp62lq0p
JBJZrESNY4vEJINkpPDYkiNRpMk4Zt28I8Y4Nnb3j8/zMfQ+5eLLYjAYjv/5
fwffvsbn/W7fbw64QDEYcnBsFgdIeeZw8pE83MaUY8PdpJQC3nZ0mu44eYUl
x866lsepPFdI9bTMVSg53H2UZXE8H9hm71doqcnxae1Vm2heIKJ1aAsTHTkE
C53CI3mhKIjgVPuaysFXLfjmGi8eVhGRId86y+GxL00oH83EzSI2Y16OHOpz
/IN2S4UwSxRWPmCMwth5pK8ySoQf7A3C7feO4ly9JZLGS1Ck39fGLRzFIhG3
ncksR6Ls3vL9Wp9R1GVT2/BdBa7orgmyPPsZFX6pevuGqpC/a6bQs+UzFCZb
tXJ/+gsdNS0PRBZjYE3laOsZ10Acx6/fKBiDxZxX0Z68WgR7tMueccZRG2pe
X23WAPbL+rBtJ8ZhEDs4lT3yButeJaZGto5jUCltf7fuLZ4vSUCotQKZA6U1
mjeaUMFPSKgqVkBT/z4tkzXDaolgodvqCVw/UXhUYPQeHXED8RapE5ggObLj
F1ugZqwu0OApEbi+SqRb2YozBporVWOUkOZVRTUatiH/deClq9xJzPg1315x
4SNUFSO3fOMnsXKbyuzRUgmGE/yMvmhPwS7d8Fj+onY8ic29IUmewjl9z2Wd
B6WQ8SRPrZdOY9WQm3qLYwemHKUt6WnTWKAlV62a7kCVr1WkzoYZcMpvC5en
dCLrTq0yuWwGJ81LP8zb2YWhXKqkbe8/yLH3Fjyb6IKNv2ZrmPwfKAYXa/ck
doNxqln+8vIXFO6xY8dvlyH6sYMk22gWF3eE3RX1yGDveSKo99ksDD85tGaE
/Y3ugA4Rb98ctmwKjeet74F6tu6Pg0wGObi0YYrZ1IOvf5OPme9hEEVNdFcA
vxfw38I1yWWQJM7hQBejPrhE2cZ2sphkQXthOquqDzU9KQ3JHkxChfBdLU/3
451y8PeLxUzCyD4s7Jo/gLzYoyYyLoucSRZGz68YQL9pUFxnEIuUrYxQ5f48
CPGvjZUmbSzCdTiz6rLmEDQPaNUlW7KJZPWbpvPiIRg0m+3emsEmj+7ASHZ4
GBWbBoN7VTjkkNCCqz87DI/OtJoofw65FJbGlzwYgXtI7cKpjxyS26d/W3MX
DeFYkeoiW4pEpIZ5te+m4XRfJFDYUcTHZdg4z5nGQ58X3s32FFkiFj9ydKfh
76XrG+dIkciYA9XXvWmU6y44ou1GkeMWt0bVztMIcA2x0/GhyLJQnR0q92j0
v7B5bXWZIrObgzVasmj4fqX30CCUIh+Gu9/ey6FhfDawmB1OkVj3gkO2+TTs
V4gda69RZM7M5WyYmEZ9Bfu8502KSBpj7rCbaERdulUXLaDIk3DlkaZ3NKQz
1h6B6RSJt/JckdFKo2xNlsaBTIrs/HONyLqdRu9S0aRpFkWe/lL3it9P41G3
xZtqIUUSV2+McR6iof5+WX5ePkVOd6W4GtI0btr1ihMLKGK6y1/6fJzGuLqq
27FiinCYzZmxSholsSc7nUoo0lFo5ec1TSN4sjBpcylFxH4Za9d9obFWMnDB
sIwifxioK+bmaLxs1ohQK6fIvyLNWVQ=
     "]]}},
  AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
  Axes->True,
  AxesLabel->{None, None},
  AxesOrigin->{0, 0},
  AxesStyle->Directive[20, 
    Thickness[0.005], 
    RGBColor[0, 0, 1]],
  ImageSize->500,
  LabelStyle->(FontFamily -> "Helvetica"),
  Method->{},
  PlotRange->{{0, 1}, {0, 3}},
  PlotRangeClipping->True,
  PlotRangePadding->{Automatic, Automatic}]], "Output",
 CellChangeTimes->{
  3.5776976790165243`*^9},ImageCache->GraphicsData["CompressedBitmap", "\<\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\
\>"]]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"TemporalDomain", "=", " ", 
  RowBox[{"InterpolatingFunctionDomain", "[", "solNDS", "]"}]}]], "Input",
 CellChangeTimes->{{3.49510877171875*^9, 3.495108772953125*^9}, {
  3.495108825265625*^9, 3.4951088274375*^9}, {3.49510886309375*^9, 
  3.495108866390625*^9}, {3.4951089250625*^9, 3.495108944625*^9}, {
  3.495109047234375*^9, 3.495109049828125*^9}, {3.49511156471875*^9, 
  3.495111577875*^9}},
 FontSize->24],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"{", 
   RowBox[{"0.`", ",", "1.`"}], "}"}], "}"}]], "Output",
 CellChangeTimes->{3.577697679103084*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"endTime", "=", " ", 
  RowBox[{
   RowBox[{
    StyleBox[
     RowBox[{"InterpolatingFunction", 
      StyleBox["Domain",
       FontColor->RGBColor[1, 0, 0]]}]], "[", "solNDS", "]"}], "[", 
   RowBox[{"[", 
    RowBox[{"1", ",", 
     RowBox[{"-", "1"}]}], "]"}], "]"}]}]], "Input",
 CellChangeTimes->{{3.49510907590625*^9, 3.495109118234375*^9}, {
  3.495111648078125*^9, 3.495111649234375*^9}},
 FontSize->24],

Cell[BoxData["1.`"], "Output",
 CellChangeTimes->{3.577697679131653*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  StyleBox[
   RowBox[{"InterpolatingFunction", 
    StyleBox["InterpolationOrder",
     FontColor->RGBColor[1, 0, 0]]}]], "[", "solNDS", "]"}]], "Input",
 CellChangeTimes->{3.49510912890625*^9},
 FontSize->24],

Cell[BoxData[
 RowBox[{"{", "3", "}"}]], "Output",
 CellChangeTimes->{3.577697679158638*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"numTimeNodes", " ", "=", " ", 
  RowBox[{
   RowBox[{"Map", "[", 
    RowBox[{"Length", ",", 
     RowBox[{
      StyleBox[
       RowBox[{"InterpolatingFunction", 
        StyleBox["Coordinates",
         FontColor->RGBColor[1, 0, 0]]}]], "[", "solNDS", "]"}]}], "]"}], "[", 
   RowBox[{"[", "1", "]"}], "]"}]}]], "Input",
 CellChangeTimes->{
  3.495109154296875*^9, {3.4951092309375*^9, 3.4951092768125*^9}, 
   3.4951115569375*^9},
 FontSize->24],

Cell[BoxData["25"], "Output",
 CellChangeTimes->{3.577697679215993*^9}]
}, Open  ]]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Part II", "Text",
 CellChangeTimes->{{3.4420619435625*^9, 3.4420619460625*^9}, {
   3.495108480859375*^9, 3.49510848184375*^9}, {3.495285762890625*^9, 
   3.495285793703125*^9}, {3.49528627184375*^9, 3.49528627628125*^9}, {
   3.574514859153361*^9, 3.574514860104415*^9}, 3.57451490371791*^9},
 FontSize->36,
 FontColor->RGBColor[0, 0, 1],
 Background->RGBColor[1, 0.9, 0.8]],

Cell[CellGroupData[{

Cell["\<\
To estimate the difference between  the symbolic and the numeric solution 
     we need to extract the coordinates of the nodes hit by  the numeric \
method 
     and evaluate solsymb and solNDS on the same nodes\
\>", "Text",
 CellChangeTimes->{{3.441959955203125*^9, 3.441959988515625*^9}, {
   3.44206396709375*^9, 3.44206396775*^9}, {3.44206435590625*^9, 
   3.4420644369375*^9}, {3.442064549234375*^9, 3.442064574015625*^9}, {
   3.44206466409375*^9, 3.44206467515625*^9}, {3.442064711296875*^9, 
   3.44206471734375*^9}, {3.44215441884375*^9, 3.442154421296875*^9}, {
   3.495108614015625*^9, 3.495108615125*^9}, {3.495110375234375*^9, 
   3.49511037740625*^9}, {3.495197288609375*^9, 3.49519739653125*^9}, {
   3.495285673125*^9, 3.495285680078125*^9}, 3.49528573853125*^9, {
   3.49528584253125*^9, 3.495285957703125*^9}, {3.495286075859375*^9, 
   3.4952861430625*^9}, {3.495286186375*^9, 3.4952862223125*^9}, {
   3.495286295125*^9, 3.49528633228125*^9}, 3.495286389578125*^9, {
   3.5745152508647656`*^9, 3.5745152511687827`*^9}},
 FontSize->24,
 Background->GrayLevel[0.85]],

Cell[CellGroupData[{

Cell["We extract the nodes hit by  NDSolve ", "Text",
 CellChangeTimes->{{3.441959955203125*^9, 3.441959988515625*^9}, {
   3.44206396709375*^9, 3.44206396775*^9}, {3.44206435590625*^9, 
   3.4420644369375*^9}, {3.442064549234375*^9, 3.442064574015625*^9}, {
   3.44206466409375*^9, 3.44206467515625*^9}, {3.442064711296875*^9, 
   3.44206471734375*^9}, {3.44215441884375*^9, 3.442154421296875*^9}, {
   3.495108614015625*^9, 3.495108615125*^9}, {3.495110375234375*^9, 
   3.49511037740625*^9}, 3.495197402734375*^9, {3.49528649334375*^9, 
   3.49528653159375*^9}, 3.49528671425*^9, 3.5745152574171405`*^9},
 FontSize->24,
 Background->GrayLevel[0.85]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"TimeNodes", " ", "=", " ", 
  RowBox[{
   RowBox[{
    StyleBox[
     RowBox[{"InterpolatingFunction", 
      StyleBox["Coordinates",
       FontColor->RGBColor[1, 0, 0]]}]], "[", "solNDS", "]"}], "//", 
   "First"}]}]], "Input",
 CellChangeTimes->{{3.495109361859375*^9, 3.495109395546875*^9}, {
   3.495109760984375*^9, 3.495109762734375*^9}, 3.495111458734375*^9},
 FontSize->24],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
  "0.`", ",", "0.00009181159895230448`", ",", "0.00018362319790460896`", ",", 
   "0.004699904079599348`", ",", "0.009216184961294088`", ",", 
   "0.013732465842988827`", ",", "0.027629545150928247`", ",", 
   "0.041526624458867664`", ",", "0.05542370376680709`", ",", 
   "0.06932078307474651`", ",", "0.09711494169062534`", ",", 
   "0.12490910030650419`", ",", "0.15270325892238304`", ",", 
   "0.18049741753826187`", ",", "0.2082915761541407`", ",", 
   "0.274464206202746`", ",", "0.3406368362513512`", ",", 
   "0.4068094662999565`", ",", "0.4729820963485618`", ",", 
   "0.539154726397167`", ",", "0.6053273564457723`", ",", 
   "0.7053273564457723`", ",", "0.8053273564457724`", ",", 
   "0.9026636782228861`", ",", "1.`"}], "}"}]], "Output",
 CellChangeTimes->{3.577697679270876*^9}]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["\<\
We extract the values (numsolOnNodes) of solNDS  on the nodes hit 
       by  NDSolve \
\>", "Text",
 CellChangeTimes->{{3.441959955203125*^9, 3.441959988515625*^9}, {
   3.44206396709375*^9, 3.44206396775*^9}, {3.44206435590625*^9, 
   3.4420644369375*^9}, {3.442064549234375*^9, 3.442064574015625*^9}, {
   3.44206466409375*^9, 3.44206467515625*^9}, {3.442064711296875*^9, 
   3.44206471734375*^9}, {3.44215441884375*^9, 3.442154421296875*^9}, {
   3.495108614015625*^9, 3.495108615125*^9}, {3.495110375234375*^9, 
   3.495110390765625*^9}, 3.495197405140625*^9, {3.495286548734375*^9, 
   3.495286589796875*^9}, 3.495286716875*^9, {3.49528679521875*^9, 
   3.495286801546875*^9}, {3.495423414609375*^9, 3.495423419375*^9}, {
   3.561289705686593*^9, 3.5612897058864193`*^9}, 3.5612904466227303`*^9, 
   3.574515259209243*^9},
 FontSize->24,
 Background->GrayLevel[0.85]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  StyleBox[
   RowBox[{
    StyleBox["numsol",
     FontColor->RGBColor[1, 0, 0]], 
    StyleBox["OnNodes",
     FontColor->GrayLevel[0]]}]], " ", "=", " ", 
  RowBox[{
   StyleBox[
    RowBox[{"InterpolatingFunction", 
     StyleBox["ValuesOnGrid",
      FontColor->RGBColor[1, 0, 0]]}]], "[", "solNDS", "]"}]}]], "Input",
 CellChangeTimes->{{3.495109299453125*^9, 3.495109329125*^9}, {
   3.495109421984375*^9, 3.49510942846875*^9}, 3.495111488984375*^9, 
   3.4951118013125*^9},
 FontSize->24],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
  "1.`", ",", "1.000091820029096`", ",", "1.0001836484891098`", ",", 
   "1.0047109821340385`", ",", "1.00925880876516`", ",", 
   "1.0138272211441395`", ",", "1.0280147777420905`", ",", 
   "1.0424009132948093`", ",", "1.0569883698396405`", ",", 
   "1.0717799646127624`", ",", "1.1019870327815013`", ",", 
   "1.1330454532161571`", ",", "1.1649792292162466`", ",", 
   "1.1978130274190366`", ",", "1.2315722140428649`", ",", 
   "1.315825488919433`", ",", "1.4058426014390661`", ",", 
   "1.5020178981701786`", ",", "1.6047726591931482`", ",", 
   "1.7145569903826074`", ",", "1.8318517932086347`", ",", 
   "2.0245093468382307`", ",", "2.2374288422878164`", ",", 
   "2.46616346263022`", ",", "2.718281861392969`"}], "}"}]], "Output",
 CellChangeTimes->{3.577697679287743*^9}]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[StyleBox["We calculate the values (symbsolOnNodes) of solsymb \
on the same node",
 Background->None]], "Text",
 CellChangeTimes->{{3.44206787890625*^9, 3.442067892984375*^9}, {
   3.4420679595*^9, 3.4420679813125*^9}, {3.44207210578125*^9, 
   3.442072158328125*^9}, {3.44207248221875*^9, 3.442072484296875*^9}, {
   3.4420736696875*^9, 3.442073675828125*^9}, {3.495286436109375*^9, 
   3.495286437375*^9}, {3.495286603890625*^9, 3.4952866434375*^9}, {
   3.49528681759375*^9, 3.49528682165625*^9}, 3.49542321865625*^9, {
   3.49666349775*^9, 3.49666349875*^9}, 3.5745152602173004`*^9},
 FontSize->24,
 Background->GrayLevel[0.85]],

Cell[CellGroupData[{

Cell[BoxData[
 StyleBox[
  RowBox[{" ", 
   RowBox[{
    StyleBox[
     RowBox[{
      StyleBox["symbsol",
       FontColor->RGBColor[0, 0, 1]], 
      StyleBox["OnNodes",
       FontColor->GrayLevel[0]]}]], 
    StyleBox[" ",
     FontColor->RGBColor[1, 0, 0]], "=", 
    RowBox[{"Map", "[", 
     RowBox[{"solsymb", ",", "TimeNodes"}], "]"}]}]}],
  FontSize->24]], "Input",
 CellChangeTimes->{{3.442068115359375*^9, 3.4420681323125*^9}, {
   3.442068187671875*^9, 3.442068187828125*^9}, 3.4420683945625*^9, 
   3.44206855365625*^9, {3.44206921278125*^9, 3.4420692448125*^9}, 
   3.442072173546875*^9, 3.49511151078125*^9, 3.495112104171875*^9, {
   3.495197716453125*^9, 3.495197719828125*^9}, {3.495197944515625*^9, 
   3.495197946171875*^9}, 3.495285368609375*^9, {3.5612899285099573`*^9, 
   3.561289938232676*^9}},
 FontSize->48],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
  "1.`", ",", "1.0000918158137662`", ",", "1.000183640057676`", ",", 
   "1.0047109659519013`", ",", "1.0092587847625591`", ",", 
   "1.0138271892507256`", ",", "1.0280147808115174`", ",", 
   "1.0424009148422984`", ",", "1.0569883697647773`", ",", 
   "1.0717799628821536`", ",", "1.1019870305941315`", ",", 
   "1.133045454901079`", ",", "1.164979230454139`", ",", 
   "1.1978130281701778`", ",", "1.231572214291671`", ",", 
   "1.3158254748359048`", ",", "1.4058425970765613`", ",", 
   "1.5020178933695176`", ",", "1.6047726514288712`", ",", 
   "1.7145569797419784`", ",", "1.831851779231441`", ",", "2.02450931263172`",
    ",", "2.237428815693897`", ",", "2.4661634358191593`", ",", 
   "2.718281828459045`"}], "}"}]], "Output",
 CellChangeTimes->{3.577697679316058*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Length", "[", "%", "]"}]], "Input",
 CellChangeTimes->{{3.442068150375*^9, 3.442068157328125*^9}},
 FontSize->24],

Cell[BoxData["25"], "Output",
 CellChangeTimes->{3.5776976793532763`*^9}]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
 StyleBox["Remarks on ",
  FontFamily->"Times New Roman"],
 "TimeNodes",
 StyleBox["  ",
  FontFamily->"Times New Roman"],
 Cell[BoxData[
  FormBox[
   SubscriptBox["t", "i"], TraditionalForm]]]
}], "Text",
 CellChangeTimes->{{3.441959955203125*^9, 3.441959988515625*^9}, {
   3.44206396709375*^9, 3.44206396775*^9}, {3.44206435590625*^9, 
   3.4420644369375*^9}, {3.442064549234375*^9, 3.442064574015625*^9}, {
   3.44206466409375*^9, 3.44206467515625*^9}, {3.442064711296875*^9, 
   3.44206471734375*^9}, {3.44215441884375*^9, 3.442154421296875*^9}, {
   3.495108614015625*^9, 3.495108615125*^9}, {3.495110375234375*^9, 
   3.49511037740625*^9}, {3.495197288609375*^9, 3.49519739653125*^9}, {
   3.495285673125*^9, 3.495285680078125*^9}, 3.49528573853125*^9, {
   3.49528584253125*^9, 3.495285957703125*^9}, {3.495286075859375*^9, 
   3.4952861430625*^9}, {3.495286186375*^9, 3.4952862223125*^9}, {
   3.495286295125*^9, 3.49528633228125*^9}, {3.495286389578125*^9, 
   3.495286397875*^9}, {3.495286442828125*^9, 3.4952864435*^9}, {
   3.495286727296875*^9, 3.49528672821875*^9}, {3.5612898690156307`*^9, 
   3.5612898793765917`*^9}, 3.574515261857394*^9},
 FontSize->24,
 Background->GrayLevel[0.85]],

Cell[TextData[{
 "When we observe the distribution of the abscissae of the Nodes (",
 Cell[BoxData[
  FormBox[
   SubscriptBox["t", "i"], TraditionalForm]]],
 ")\nwe see that the increment ",
 StyleBox["\[CapitalDelta]t",
  FontColor->RGBColor[1, 0.5, 0]],
 StyleBox[" ",
  FontColor->GrayLevel[0]],
 " is not constant;\n",
 StyleBox["n",
  FontColor->RGBColor[1, 0.5, 0]],
 " is the (ordinal cardinal) number (25) of time steps "
}], "Text",
 CellChangeTimes->{{3.44196020565625*^9, 3.441960209140625*^9}, {
   3.441960444578125*^9, 3.4419604470625*^9}, 3.442065268234375*^9, {
   3.44206533153125*^9, 3.442065339390625*^9}, {3.44206593065625*^9, 
   3.442066002359375*^9}, {3.442066047375*^9, 3.4420660479375*^9}, {
   3.4420665305625*^9, 3.4420665315625*^9}, {3.4420673055*^9, 
   3.4420673123125*^9}, {3.44206746953125*^9, 3.4420674756875*^9}, {
   3.442152383984375*^9, 3.442152385375*^9}, {3.442152419734375*^9, 
   3.44215248025*^9}, {3.442152556421875*^9, 3.44215259575*^9}, {
   3.442153564625*^9, 3.44215357153125*^9}, {3.442153618109375*^9, 
   3.442153618453125*^9}, 3.49511149440625*^9, {3.4952839759375*^9, 
   3.495284057109375*^9}, {3.49528419015625*^9, 3.495284231609375*^9}, {
   3.4952843364375*^9, 3.495284397203125*^9}, {3.496663459859375*^9, 
   3.49666346046875*^9}},
 FontSize->24,
 Background->GrayLevel[0.85]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"ListPlot", "[", 
   RowBox[{"TimeNodes", ",", 
    RowBox[{"PlotStyle", "\[Rule]", 
     RowBox[{"PointSize", "[", "0.015", "]"}]}], ",", " ", 
    "\[IndentingNewLine]", 
    RowBox[{"AxesLabel", "\[Rule]", 
     RowBox[{"{", 
      RowBox[{"\"\<\!\(\*
StyleBox[\"n\",
FontColor->RGBColor[1, 0.5, 0]]\)\>\"", ",", "\"\< \!\(\*
StyleBox[\"\[CapitalDelta]t\",
FontColor->RGBColor[1, 0.5, 0]]\)\>\""}], "}"}]}]}], "]"}], "  "}]], "Input",
 CellChangeTimes->{{3.441960038578125*^9, 3.44196003953125*^9}, 
   3.495111504703125*^9, {3.495284074796875*^9, 3.495284098421875*^9}, {
   3.495284139640625*^9, 3.49528414209375*^9}, {3.49528423434375*^9, 
   3.49528423440625*^9}, {3.49666346434375*^9, 3.496663464828125*^9}},
 FontSize->24],

Cell[BoxData[
 GraphicsBox[{{}, 
   {RGBColor[0.24720000000000014`, 0.24, 0.6], PointSize[0.015], 
    PointBox[CompressedData["
1:eJxTTMoPSmViYGCQBGIQDQEf7BlQgcPlimKneEEJqDgHlK8B5Qs4bLbgf2ri
UAzlizhcyGLNeH+/CcqXcHCzbI49It8D5cs4GOT5Jb/2mgPlKzjcm//W+5fT
UihfyWEph8mzuoQ1UL6KwzYL2wOM+zdC+WoONQubo9ru7IDyNRycuU594fq1
H8rXcmi17Dh+vPswlK/j8CJ3tUiX1HEoX8/Be9G5RJ+Vp6B8A4flfCmBlyZc
hPINHTTOPCj8d+YqlG/ksKozdpIW5y0o39hBx/3WpjDXe1C+iUNY0+rMgw4P
oXxTB/GHLyuvxz2G8s0cvERk13JNegblmzvUuQc8sD36Esq3cNinrPFh3qM3
UL6lAyweAIOQZjY=
     "]]}, {}},
  AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
  Axes->True,
  AxesLabel->{
    FormBox[
    "\"\\!\\(\\*\\nStyleBox[\\\"n\\\",\\nFontColor->RGBColor[1, 0.5, \
0]]\\)\"", TraditionalForm], 
    FormBox[
    "\" \\!\\(\\*\\nStyleBox[\\\"\[CapitalDelta]t\\\",\\nFontColor->RGBColor[\
1, 0.5, 0]]\\)\"", TraditionalForm]},
  AxesOrigin->{0, 0},
  AxesStyle->Directive[20, 
    Thickness[0.005], 
    RGBColor[0, 0, 1]],
  ImageSize->500,
  LabelStyle->(FontFamily -> "Helvetica"),
  Method->{},
  PlotRange->{{0, 25.}, {0, 1.}},
  PlotRangeClipping->True,
  PlotRangePadding->{{0.5, 0.5}, {0.02, 0.02}}]], "Output",
 CellChangeTimes->{
  3.577697679394348*^9},ImageCache->GraphicsData["CompressedBitmap", "\<\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\
\>"]]
}, Open  ]],

Cell[TextData[{
 "The plot of \[CapitalDelta]",
 Cell[BoxData[
  FormBox[
   SubscriptBox["t", "i"], TraditionalForm]]],
 " = ",
 Cell[BoxData[
  FormBox[
   SubscriptBox["t", 
    RowBox[{"i", "+", "1"}]], TraditionalForm]]],
 " - ",
 Cell[BoxData[
  FormBox[
   SubscriptBox["t", "i"], TraditionalForm]]],
 "  shows that they are Piecewise constant and not always monotone\n(although \
not particularly evident, in this case).\nObserve also that on the horizontal \
axis we have  their abscissae"
}], "Text",
 CellChangeTimes->{{3.442065304875*^9, 3.44206530534375*^9}, {
   3.442066008296875*^9, 3.44206601040625*^9}, {3.44206604471875*^9, 
   3.442066044921875*^9}, {3.442066307*^9, 3.44206638746875*^9}, {
   3.442066471125*^9, 3.442066508109375*^9}, {3.44206700596875*^9, 
   3.44206701925*^9}, {3.4420673786875*^9, 3.442067453640625*^9}, {
   3.442067503546875*^9, 3.442067513296875*^9}, {3.44206758809375*^9, 
   3.442067603046875*^9}, {3.442152616671875*^9, 3.44215261784375*^9}, {
   3.442153579921875*^9, 3.442153580390625*^9}, {3.442153801859375*^9, 
   3.442153804484375*^9}, {3.442155195828125*^9, 3.4421551963125*^9}, {
   3.495284535625*^9, 3.49528474978125*^9}, {3.495284800921875*^9, 
   3.495284862484375*^9}, 3.5612899958456163`*^9, 3.561290241395894*^9},
 FontSize->24,
 Background->GrayLevel[0.85]],

Cell["Therefore ...", "Text",
 CellChangeTimes->{{3.4420660126875*^9, 3.442066041625*^9}, {
  3.4420661958125*^9, 3.442066202890625*^9}, {3.442066517765625*^9, 
  3.44206653765625*^9}, {3.442066634953125*^9, 3.44206666803125*^9}, {
  3.44206671596875*^9, 3.44206673528125*^9}, {3.442066956296875*^9, 
  3.44206695671875*^9}, {3.44206763434375*^9, 3.442067652453125*^9}, {
  3.442067701296875*^9, 3.44206773134375*^9}, {3.442152635921875*^9, 
  3.44215266415625*^9}, {3.442153523265625*^9, 3.442153523796875*^9}, {
  3.442153877484375*^9, 3.442153917*^9}, {3.442153990734375*^9, 
  3.442153991421875*^9}, {3.44215520175*^9, 3.442155218625*^9}, {
  3.495284758*^9, 3.495284766078125*^9}, {3.495284871625*^9, 
  3.495284904078125*^9}},
 FontSize->24,
 Background->GrayLevel[0.85]],

Cell[BoxData[
 RowBox[{
  RowBox[{"finite$diff", " ", "=", " ", 
   RowBox[{"Table", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"TimeNodes", "[", 
        RowBox[{"[", "i", "]"}], "]"}], ",", 
       RowBox[{
        RowBox[{"TimeNodes", "[", 
         RowBox[{"[", 
          RowBox[{"i", "+", "1"}], "]"}], "]"}], "-", 
        RowBox[{"TimeNodes", "[", 
         RowBox[{"[", "i", "]"}], "]"}]}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"i", ",", "1", ",", 
       RowBox[{
        RowBox[{"Length", "[", "TimeNodes", "]"}], "-", "1"}]}], "}"}]}], 
    "]"}]}], ";"}]], "Input",
 CellChangeTimes->{
  3.441960513*^9, {3.4951115079375*^9, 3.495111509984375*^9}, 
   3.561290124983654*^9, 3.561290308183489*^9},
 FontSize->24],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Length", "[", "finite$diff", "]"}]], "Input",
 CellChangeTimes->{{3.441960347953125*^9, 3.44196037834375*^9}, {
   3.441960518671875*^9, 3.44196051928125*^9}, 3.561290126933793*^9},
 FontSize->24],

Cell[BoxData["24"], "Output",
 CellChangeTimes->{3.577697679439116*^9}]
}, Open  ]],

Cell[TextData[{
 StyleBox["Be careful!",
  FontSlant->"Italic"],
 " In this Plot we see only 21 points, as some are squeezed around the origin"
}], "Text",
 CellChangeTimes->{{3.44196032634375*^9, 3.441960330484375*^9}, {
   3.441960551234375*^9, 3.441960574203125*^9}, {3.442066031640625*^9, 
   3.442066034828125*^9}, {3.442153397890625*^9, 3.44215339821875*^9}, {
   3.44215343309375*^9, 3.442153493375*^9}, {3.442153870453125*^9, 
   3.4421538733125*^9}, 3.442155225328125*^9, {3.49528510971875*^9, 
   3.495285170171875*^9}, {3.561290169689958*^9, 3.561290177116951*^9}, {
   3.5745152695388336`*^9, 3.5745152717459598`*^9}},
 FontSize->24,
 Background->GrayLevel[0.85]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"ListPlot", "[", 
   RowBox[{"finite$diff", ",", 
    RowBox[{"PlotStyle", "\[Rule]", 
     RowBox[{"PointSize", "[", "0.015", "]"}]}], " ", ",", 
    RowBox[{"AxesLabel", "\[Rule]", 
     RowBox[{"{", 
      RowBox[{"\"\<\!\(\*
StyleBox[\"t\",
FontColor->RGBColor[1, 0.5, 0]]\)\>\"", ",", "\"\< \!\(\*
StyleBox[\"\[CapitalDelta]t\",
FontColor->RGBColor[1, 0.5, 0]]\)\>\""}], "}"}]}]}], "]"}], "    "}]], "Input",
 CellChangeTimes->{{3.44196053546875*^9, 3.441960535875*^9}, {
   3.4952849975625*^9, 3.495285002*^9}, 3.5612901314544983`*^9},
 FontSize->24],

Cell[BoxData[
 GraphicsBox[{{}, 
   {RGBColor[0.24720000000000014`, 0.24, 0.6], PointSize[0.015], 
    PointBox[CompressedData["
1:eJxTTMoPSmViYGCQAGIQDQOXK4qd4gUl7LHTGvZv5vx+tbK+yH6zBf9TE4di
+7dQ/oUs1oz395vg8m6WzbFH5HvspRZLZgqV9dgb5Pklv/aaYy8B5d+b/9b7
l9NSexkofymHybO6hDVw/jYL2wOM+zdC1c+xr1nYHNV2ZwdUfo69M9epL1y/
9sP5rZYdx493H4arf5G7WqRL6jic773oXKLPylP2bN8+NW74sMF+OV9K4KUJ
F+1ZoHyNMw8K/525as8B5a/qjJ2kxXkLztdxv7UpzPWePQOUH9a0OvOgw0O4
vPjDl5XX4x7bz5gJAjvtvURk13JNema/AMqvcw94YHv0pT3Do311HK932O9T
1vgw79EbewEoHwC0HbY5
     "]]}, {}},
  AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
  Axes->True,
  AxesLabel->{
    FormBox[
    "\"\\!\\(\\*\\nStyleBox[\\\"t\\\",\\nFontColor->RGBColor[1, 0.5, \
0]]\\)\"", TraditionalForm], 
    FormBox[
    "\" \\!\\(\\*\\nStyleBox[\\\"\[CapitalDelta]t\\\",\\nFontColor->RGBColor[\
1, 0.5, 0]]\\)\"", TraditionalForm]},
  AxesOrigin->{0, 0},
  AxesStyle->Directive[20, 
    Thickness[0.005], 
    RGBColor[0, 0, 1]],
  ImageSize->500,
  LabelStyle->(FontFamily -> "Helvetica"),
  Method->{},
  PlotRange->{{0, 0.9026636782228861}, {0, 0.10000000000000009`}},
  PlotRangeClipping->True,
  PlotRangePadding->{{0.018053273564457722`, 0.018053273564457722`}, {
   0.0020000000000000018`, 0.0020000000000000018`}}]], "Output",
 CellChangeTimes->{
  3.577697679511383*^9},ImageCache->GraphicsData["CompressedBitmap", "\<\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\
\>"]]
}, Open  ]]
}, Open  ]]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Part III", "Text",
 CellChangeTimes->{{3.4420619435625*^9, 3.4420619460625*^9}, {
  3.495108480859375*^9, 3.49510848184375*^9}, {3.495285762890625*^9, 
  3.495285793703125*^9}, {3.49528627184375*^9, 3.49528627628125*^9}, {
  3.574514859153361*^9, 3.574514860104415*^9}, {3.574514928113305*^9, 
  3.574514929217368*^9}},
 FontSize->36,
 FontColor->RGBColor[0, 0, 1],
 Background->RGBColor[1, 0.9, 0.8]],

Cell[CellGroupData[{

Cell[TextData[{
 "We evaluate the difference between numsolOnNodes  and symbsolOnNodes\n     \
to obtain wht we call  Global Error (on nodes) \n     The error is of a few \
parts per ",
 Cell[BoxData[
  FormBox[
   SuperscriptBox["10", 
    RowBox[{"-", "8"}]], TraditionalForm]]]
}], "Text",
 CellChangeTimes->{{3.44206941684375*^9, 3.442069526640625*^9}, 
   3.442069594109375*^9, {3.442069747109375*^9, 3.442069783640625*^9}, {
   3.442069833640625*^9, 3.4420698405*^9}, {3.442088213421875*^9, 
   3.44208821409375*^9}, {3.442089608390625*^9, 3.442089658171875*^9}, {
   3.49528193915625*^9, 3.49528195596875*^9}, {3.495286736515625*^9, 
   3.49528675934375*^9}, {3.495286836921875*^9, 3.49528695675*^9}, {
   3.495287062953125*^9, 3.495287066984375*^9}, {3.495422119640625*^9, 
   3.49542212121875*^9}, {3.4966658866875*^9, 3.496665888109375*^9}, 
   3.49674646296875*^9, 3.496800160703125*^9, {3.561290398873845*^9, 
   3.561290424183964*^9}, {3.561290471264151*^9, 3.561290472085348*^9}, 
   3.5745153054978905`*^9},
 FontSize->24,
 Background->GrayLevel[0.85]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  StyleBox["GlobalErrorOnNodes",
   FontColor->RGBColor[1, 0, 1]], "=", " ", 
  RowBox[{"(", 
   RowBox[{
    StyleBox[
     RowBox[{
      StyleBox["symbsol",
       FontColor->RGBColor[0, 0, 1]], 
      StyleBox["OnNodes",
       FontColor->GrayLevel[0]]}]], "-", 
    StyleBox[
     RowBox[{
      StyleBox["numsol",
       FontColor->RGBColor[1, 0, 0]], 
      StyleBox["OnNodes",
       FontColor->GrayLevel[0]]}]]}], 
   StyleBox[")",
    FontColor->RGBColor[1, 0, 0]]}]}]], "Input",
 CellChangeTimes->{{3.442069804375*^9, 3.442069823125*^9}, {
   3.442069874328125*^9, 3.442069883609375*^9}, 3.44207012475*^9, 
   3.49511205315625*^9, {3.495112085828125*^9, 3.495112091265625*^9}, {
   3.495112134125*^9, 3.495112159578125*^9}, {3.495197878828125*^9, 
   3.4951978824375*^9}, {3.495197916703125*^9, 3.495197918765625*^9}, 
   3.49519949678125*^9, 3.49528126609375*^9, 3.496746464046875*^9, {
   3.561271733278864*^9, 3.561271737750537*^9}, 3.561272349629354*^9, {
   3.561290530127079*^9, 3.561290558459846*^9}},
 FontSize->24],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"0.`", ",", 
   RowBox[{"-", "4.2153298629443725`*^-9"}], ",", 
   RowBox[{"-", "8.431433773381514`*^-9"}], ",", 
   RowBox[{"-", "1.6182137185793977`*^-8"}], ",", 
   RowBox[{"-", "2.4002600795824947`*^-8"}], ",", 
   RowBox[{"-", "3.1893413909855894`*^-8"}], ",", "3.0694269348430225`*^-9", 
   ",", "1.5474890258104779`*^-9", ",", 
   RowBox[{"-", "7.4863226728894`*^-11"}], ",", 
   RowBox[{"-", "1.7306087674029413`*^-9"}], ",", 
   RowBox[{"-", "2.1873698408114706`*^-9"}], ",", "1.6849219797165915`*^-9", 
   ",", "1.2378924552081116`*^-9", ",", "7.51141149279988`*^-10", ",", 
   "2.4880608684441086`*^-10", ",", 
   RowBox[{"-", "1.4083528121489053`*^-8"}], ",", 
   RowBox[{"-", "4.362504801846967`*^-9"}], ",", 
   RowBox[{"-", "4.800660979853433`*^-9"}], ",", 
   RowBox[{"-", "7.76427699911153`*^-9"}], ",", 
   RowBox[{"-", "1.064062904454488`*^-8"}], ",", 
   RowBox[{"-", "1.3977193624725714`*^-8"}], ",", 
   RowBox[{"-", "3.420651051300183`*^-8"}], ",", 
   RowBox[{"-", "2.6593919510986552`*^-8"}], ",", 
   RowBox[{"-", "2.681106048285642`*^-8"}], ",", 
   RowBox[{"-", "3.293392403236339`*^-8"}]}], "}"}]], "Output",
 CellChangeTimes->{3.5776976795432777`*^9}]
}, Open  ]],

Cell["\<\
We can plot the distribution of the Global Errors on the Nodes\
\>", "Text",
 CellChangeTimes->{{3.4420711055625*^9, 3.442071167671875*^9}, {
   3.442071236765625*^9, 3.442071290875*^9}, {3.44207133446875*^9, 
   3.442071357171875*^9}, {3.442071410546875*^9, 3.44207150603125*^9}, 
   3.442073642703125*^9, 3.495287137640625*^9, {3.4954221466875*^9, 
   3.49542218003125*^9}, 3.496746465015625*^9},
 FontSize->24,
 Background->GrayLevel[0.85]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  StyleBox["couplesGlobalErr",
   FontColor->RGBColor[1, 0, 1]], "=", " ", 
  RowBox[{"Transpose", "[", 
   RowBox[{"{", 
    RowBox[{"TimeNodes", ",", 
     StyleBox["GlobalErrorOnNodes",
      FontColor->RGBColor[1, 0, 1]]}], "}"}], "]"}]}]], "Input",
 CellChangeTimes->{
  3.441960932421875*^9, {3.442069966828125*^9, 3.442069989515625*^9}, {
   3.442070127140625*^9, 3.442070127828125*^9}, {3.44209703803125*^9, 
   3.442097053265625*^9}, 3.4951115133125*^9, 3.495112168875*^9, 
   3.495198293609375*^9, 3.49519836325*^9, 3.495199498734375*^9, 
   3.495281272984375*^9, 3.4953729181875*^9, {3.496746466015625*^9, 
   3.496746466765625*^9}, 3.561290826480085*^9, 3.56230883537571*^9},
 FontSize->24],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{"0.`", ",", "0.`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"0.00009181159895230448`", ",", 
     RowBox[{"-", "4.2153298629443725`*^-9"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"0.00018362319790460896`", ",", 
     RowBox[{"-", "8.431433773381514`*^-9"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"0.004699904079599348`", ",", 
     RowBox[{"-", "1.6182137185793977`*^-8"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"0.009216184961294088`", ",", 
     RowBox[{"-", "2.4002600795824947`*^-8"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"0.013732465842988827`", ",", 
     RowBox[{"-", "3.1893413909855894`*^-8"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"0.027629545150928247`", ",", "3.0694269348430225`*^-9"}], "}"}], 
   ",", 
   RowBox[{"{", 
    RowBox[{"0.041526624458867664`", ",", "1.5474890258104779`*^-9"}], "}"}], 
   ",", 
   RowBox[{"{", 
    RowBox[{"0.05542370376680709`", ",", 
     RowBox[{"-", "7.4863226728894`*^-11"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"0.06932078307474651`", ",", 
     RowBox[{"-", "1.7306087674029413`*^-9"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"0.09711494169062534`", ",", 
     RowBox[{"-", "2.1873698408114706`*^-9"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"0.12490910030650419`", ",", "1.6849219797165915`*^-9"}], "}"}], 
   ",", 
   RowBox[{"{", 
    RowBox[{"0.15270325892238304`", ",", "1.2378924552081116`*^-9"}], "}"}], 
   ",", 
   RowBox[{"{", 
    RowBox[{"0.18049741753826187`", ",", "7.51141149279988`*^-10"}], "}"}], 
   ",", 
   RowBox[{"{", 
    RowBox[{"0.2082915761541407`", ",", "2.4880608684441086`*^-10"}], "}"}], 
   ",", 
   RowBox[{"{", 
    RowBox[{"0.274464206202746`", ",", 
     RowBox[{"-", "1.4083528121489053`*^-8"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"0.3406368362513512`", ",", 
     RowBox[{"-", "4.362504801846967`*^-9"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"0.4068094662999565`", ",", 
     RowBox[{"-", "4.800660979853433`*^-9"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"0.4729820963485618`", ",", 
     RowBox[{"-", "7.76427699911153`*^-9"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"0.539154726397167`", ",", 
     RowBox[{"-", "1.064062904454488`*^-8"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"0.6053273564457723`", ",", 
     RowBox[{"-", "1.3977193624725714`*^-8"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"0.7053273564457723`", ",", 
     RowBox[{"-", "3.420651051300183`*^-8"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"0.8053273564457724`", ",", 
     RowBox[{"-", "2.6593919510986552`*^-8"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"0.9026636782228861`", ",", 
     RowBox[{"-", "2.681106048285642`*^-8"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"1.`", ",", 
     RowBox[{"-", "3.293392403236339`*^-8"}]}], "}"}]}], "}"}]], "Output",
 CellChangeTimes->{3.577697679600321*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  StyleBox["gra$GlobalErrorOnNodes",
   FontColor->RGBColor[1, 0, 1]], "=", 
  RowBox[{"ListPlot", "[", 
   RowBox[{
    StyleBox["couplesGlobalErr",
     FontColor->RGBColor[1, 0, 1]], 
    StyleBox[",",
     FontSize->16], "\[IndentingNewLine]", 
    RowBox[{"PlotRange", "\[Rule]", "All"}], ",", 
    RowBox[{"Joined", "\[Rule]", "True"}], ",", 
    RowBox[{"ImageSize", "\[Rule]", "600"}], ",", "\[IndentingNewLine]", 
    RowBox[{"Epilog", "\[Rule]", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"PointSize", "[", "0.015", "]"}], ",", 
       RowBox[{"RGBColor", "[", 
        RowBox[{"1", ",", "0", ",", "0"}], "]"}], ",", "\[IndentingNewLine]", 
       RowBox[{"Map", "[", 
        RowBox[{"Point", ",", 
         StyleBox["couplesGlobalErr",
          FontColor->RGBColor[1, 0, 1]]}], "]"}]}], "}"}]}], ",", 
    "\[IndentingNewLine]", 
    RowBox[{"PlotLabel", "->", "\"\<\!\(\*
StyleBox[\"GlobalErrorOnNodes\",
FontSize->18,
FontColor->RGBColor[1, 0, 1]]\)\!\(\*
StyleBox[\" \",
FontSize->18,
FontColor->RGBColor[1, 0, 0]]\)\!\(\*
StyleBox[\"=\",
FontSize->18,
FontColor->RGBColor[1, 0, 0]]\)\!\(\*
StyleBox[\" \",
FontSize->18,
FontColor->RGBColor[1, 0, 0]]\)\!\(\*SuperscriptBox[\(\[ExponentialE]\), \
\(\(t\)\(\\\ \)\)]\)\!\(\*
StyleBox[\" \",
FontSize->18,
FontColor->RGBColor[1, 0, 0]]\)\!\(\*
StyleBox[\"-\",
FontSize->18,
FontColor->RGBColor[1, 0, 0]]\)\!\(\*
StyleBox[\" \",
FontSize->18,
FontColor->RGBColor[1, 0, 0]]\)\!\(\*
StyleBox[\"numsol\",
FontSize->18,
FontColor->RGBColor[1, 0, 0]]\)\!\(\*
StyleBox[\"OnNodes\",
FontSize->18,
FontColor->GrayLevel[0]]\)\>\""}]}], "]"}]}]], "Input",
 CellChangeTimes->{
  3.44196163203125*^9, {3.44196206984375*^9, 3.44196207321875*^9}, {
   3.441962219796875*^9, 3.44196222246875*^9}, {3.441964388390625*^9, 
   3.441964413125*^9}, {3.441964480875*^9, 3.441964512796875*^9}, {
   3.441964582328125*^9, 3.441964613984375*^9}, {3.442097151609375*^9, 
   3.44209730259375*^9}, {3.442097364828125*^9, 3.4420974085625*^9}, {
   3.442097452734375*^9, 3.44209746390625*^9}, {3.4951983005625*^9, 
   3.49519830115625*^9}, {3.495198507546875*^9, 3.495198574375*^9}, {
   3.4951986106875*^9, 3.495198650953125*^9}, {3.495198704859375*^9, 
   3.495198712390625*^9}, 3.495199500359375*^9, 3.49528127353125*^9, {
   3.495281370046875*^9, 3.495281371375*^9}, 3.49528184559375*^9, 
   3.495282013703125*^9, {3.49537236553125*^9, 3.4953723671875*^9}, {
   3.495372928421875*^9, 3.49537292915625*^9}, 3.495422200109375*^9, {
   3.49542292134375*^9, 3.495423036390625*^9}, 3.49551541428125*^9, {
   3.4955155981875*^9, 3.49551562990625*^9}, {3.496746467375*^9, 
   3.496746468546875*^9}, {3.561271707097414*^9, 3.5612717132266607`*^9}, {
   3.561271802928584*^9, 3.561271813708804*^9}, {3.561271925030548*^9, 
   3.5612719574543467`*^9}, {3.561290659458837*^9, 3.561290669886795*^9}, {
   3.561290888928451*^9, 3.5612908975308228`*^9}, {3.561291008538294*^9, 
   3.5612910147406673`*^9}, 3.561291079418614*^9, {3.561291520531279*^9, 
   3.561291524640407*^9}, {3.561291576209609*^9, 3.561291587528001*^9}},
 FontSize->24],

Cell[BoxData[
 GraphicsBox[{{}, 
   {RGBColor[0.24720000000000014`, 0.24, 0.6], LineBox[CompressedData["
1:eJxTTMoPSmViYGCQBGIQjQ4uVxQ7xQtK2AOZD85KGe2D8DVA/AtW0k77Nlvw
PzVxKAbx18gkBO67kMWa8f5+E1j9iaOR+9wsm2OPyPeA+PtS5RP3GeT5Jb/2
mgPiH9gbq2V3b/5b719OS8H8t1Ol7JZymDyrS1gD4jNwTLmyd5uF7QHG/RtB
fAef3bL7ahY2R7Xd2QFWL3xKaZ8z16kvXL/2g/gNsZ9k7FotO44f7z4M1u/v
Imr3Ine1SJfUcbC89HlOO+9F5xJ9Vp4Cy3NLfrRdzpcSeGnCRRA/ocHOb5/G
mQeF/85cBfE/zN9jtG9VZ+wkLc5bYH7iPJN9Ou63NoW53gPxb5SscdgX1rQ6
86DDQxA/Y/9Nt33iD19WXo97DOIrcLP47fMSkV3LNekZiD/DLzZpX517wAPb
oy9B/B0ifTH79ilrfJj36A2Iv+LIyZh9kFD/AOIXpK9L3AcA8jOUWQ==
     "]]}, {}},
  AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
  Axes->True,
  AxesLabel->{None, None},
  AxesOrigin->{0., 0.},
  AxesStyle->Directive[20, 
    Thickness[0.005], 
    RGBColor[0, 0, 1]],
  Epilog->{
    PointSize[0.015], 
    RGBColor[1, 0, 0], {
     PointBox[{0., 0.}], 
     PointBox[{0.00009181159895230448, -4.2153298629443725`*^-9}], 
     PointBox[{0.00018362319790460896`, -8.431433773381514*^-9}], 
     PointBox[{0.004699904079599348, -1.6182137185793977`*^-8}], 
     PointBox[{0.009216184961294088, -2.4002600795824947`*^-8}], 
     PointBox[{0.013732465842988827`, -3.1893413909855894`*^-8}], 
     PointBox[{0.027629545150928247`, 3.0694269348430225`*^-9}], 
     PointBox[{0.041526624458867664`, 1.5474890258104779`*^-9}], 
     PointBox[{0.05542370376680709, -7.4863226728894*^-11}], 
     PointBox[{0.06932078307474651, -1.7306087674029413`*^-9}], 
     PointBox[{0.09711494169062534, -2.1873698408114706`*^-9}], 
     PointBox[{0.12490910030650419`, 1.6849219797165915`*^-9}], 
     PointBox[{0.15270325892238304`, 1.2378924552081116`*^-9}], 
     PointBox[{0.18049741753826187`, 7.51141149279988*^-10}], 
     PointBox[{0.2082915761541407, 2.4880608684441086`*^-10}], 
     PointBox[{0.274464206202746, -1.4083528121489053`*^-8}], 
     PointBox[{0.3406368362513512, -4.362504801846967*^-9}], 
     PointBox[{0.4068094662999565, -4.800660979853433*^-9}], 
     PointBox[{0.4729820963485618, -7.76427699911153*^-9}], 
     PointBox[{0.539154726397167, -1.064062904454488*^-8}], 
     PointBox[{0.6053273564457723, -1.3977193624725714`*^-8}], 
     PointBox[{0.7053273564457723, -3.420651051300183*^-8}], 
     PointBox[{0.8053273564457724, -2.6593919510986552`*^-8}], 
     PointBox[{0.9026636782228861, -2.681106048285642*^-8}], 
     PointBox[{1., -3.293392403236339*^-8}]}},
  ImageSize->600,
  LabelStyle->(FontFamily -> "Helvetica"),
  Method->{},
  PlotLabel->FormBox[
   "\"\\!\\(\\*\\nStyleBox[\\\"GlobalErrorOnNodes\\\",\\nFontSize->18,\\\
nFontColor->RGBColor[1, 0, 1]]\\)\\!\\(\\*\\nStyleBox[\\\" \
\\\",\\nFontSize->18,\\nFontColor->RGBColor[1, 0, 0]]\\)\\!\\(\\*\\nStyleBox[\
\\\"=\\\",\\nFontSize->18,\\nFontColor->RGBColor[1, 0, \
0]]\\)\\!\\(\\*\\nStyleBox[\\\" \
\\\",\\nFontSize->18,\\nFontColor->RGBColor[1, 0, \
0]]\\)\\!\\(\\*SuperscriptBox[\\(\[ExponentialE]\\), \\(\\(t\\)\\(\\\\ \
\\)\\)]\\)\\!\\(\\*\\nStyleBox[\\\" \
\\\",\\nFontSize->18,\\nFontColor->RGBColor[1, 0, 0]]\\)\\!\\(\\*\\nStyleBox[\
\\\"-\\\",\\nFontSize->18,\\nFontColor->RGBColor[1, 0, \
0]]\\)\\!\\(\\*\\nStyleBox[\\\" \
\\\",\\nFontSize->18,\\nFontColor->RGBColor[1, 0, 0]]\\)\\!\\(\\*\\nStyleBox[\
\\\"numsol\\\",\\nFontSize->18,\\nFontColor->RGBColor[1, 0, \
0]]\\)\\!\\(\\*\\nStyleBox[\\\"OnNodes\\\",\\nFontSize->18,\\nFontColor->\
GrayLevel[0]]\\)\"", TraditionalForm],
  PlotRangeClipping->True]], "Output",
 CellChangeTimes->{
  3.577697679665921*^9},ImageCache->GraphicsData["CompressedBitmap", "\<\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\
\>"]]
}, Open  ]],

Cell[CellGroupData[{

Cell["\<\
We evaluate the relative Global error on the Nodes 
(not very different from gra$GlobalErrorOnNodes)
We drop the first point (in cases it is  zero)\
\>", "Text",
 CellChangeTimes->{{3.442071687046875*^9, 3.442071706953125*^9}, {
  3.495423135109375*^9, 3.4954231975625*^9}, {3.5612914357747726`*^9, 
  3.5612914419256268`*^9}, {3.561291477480262*^9, 3.561291509863324*^9}, {
  3.5612916137398987`*^9, 3.561291654615952*^9}},
 FontSize->24,
 Background->GrayLevel[0.85]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"RelativeGlobalError", "=", 
  RowBox[{
   RowBox[{"Drop", "[", 
    RowBox[{
     StyleBox["GlobalErrorOnNodes",
      FontColor->RGBColor[1, 0, 1]], ",", "1"}], "]"}], "/", 
   RowBox[{"Drop", "[", 
    RowBox[{
     StyleBox[
      RowBox[{
       StyleBox["symb",
        FontColor->RGBColor[0, 0, 1]], 
       StyleBox["solOnNodes",
        FontColor->RGBColor[1, 0, 0]]}]], 
     StyleBox[" ",
      FontColor->RGBColor[1, 0, 0]], ",", "1"}], "]"}]}]}]], "Input",
 CellChangeTimes->{{3.442071722453125*^9, 3.442071737984375*^9}, 
   3.442072003140625*^9, {3.495112475828125*^9, 3.495112513546875*^9}, 
   3.495199533390625*^9, 3.495281277015625*^9, 3.496746475109375*^9, {
   3.561291395558374*^9, 3.5612913971965857`*^9}},
 FontSize->24],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"-", "4.214942864535287`*^-9"}], ",", 
   RowBox[{"-", "8.429885708683769`*^-9"}], ",", 
   RowBox[{"-", "1.6106261137960613`*^-8"}], ",", 
   RowBox[{"-", "2.3782404630217673`*^-8"}], ",", 
   RowBox[{"-", "3.1458432214100404`*^-8"}], ",", "2.985780936359698`*^-9", 
   ",", "1.484543042678155`*^-9", ",", 
   RowBox[{"-", "7.082691623707657`*^-11"}], ",", 
   RowBox[{"-", "1.6147052821822799`*^-9"}], ",", 
   RowBox[{"-", "1.9849324720565535`*^-9"}], ",", "1.4870735965872563`*^-9", 
   ",", "1.0625875748235864`*^-9", ",", "6.270938215018902`*^-10", ",", 
   "2.020231407928521`*^-10", ",", 
   RowBox[{"-", "1.0703188523725302`*^-8"}], ",", 
   RowBox[{"-", "3.1031246392154865`*^-9"}], ",", 
   RowBox[{"-", "3.196141005407052`*^-9"}], ",", 
   RowBox[{"-", "4.838241100506235`*^-9"}], ",", 
   RowBox[{"-", "6.206051574994128`*^-9"}], ",", 
   RowBox[{"-", "7.630089826694323`*^-9"}], ",", 
   RowBox[{"-", "1.6896198155065913`*^-8"}], ",", 
   RowBox[{"-", "1.1885928760928622`*^-8"}], ",", 
   RowBox[{"-", "1.0871566779981422`*^-8"}], ",", 
   RowBox[{"-", "1.2115713568608579`*^-8"}]}], "}"}]], "Output",
 CellChangeTimes->{3.5776976803118877`*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"ListPlot", "[", 
   RowBox[{
    StyleBox["RelativeGlobalError",
     FontColor->RGBColor[1, 0, 1]], ",", 
    RowBox[{"PlotStyle", "\[Rule]", 
     RowBox[{"PointSize", "[", "0.015", "]"}]}]}], " ", "]"}], 
  "                                           "}]], "Input",
 CellChangeTimes->{{3.441961399453125*^9, 3.441961400109375*^9}, {
   3.442071888953125*^9, 3.442071891078125*^9}, 3.44207238921875*^9, 
   3.495112526296875*^9, {3.561291406841029*^9, 3.561291408437997*^9}},
 FontSize->24],

Cell[BoxData[
 GraphicsBox[{{}, 
   {RGBColor[0.24720000000000014`, 0.24, 0.6], PointSize[0.015], 
    PointBox[CompressedData["
1:eJxTTMoPSmViYGCQAGIQDQEf7JlTLn9MkDLaBxVwYI8WB/KdoHwOh+NCi+Mc
vQOhfAGHzwdbPzl2RkL5Ig7ntxjqz32cAOVLOMQlGNmeXappB+HLOEw4NOu+
WKMklK/gIL8/zJuh4vJeCF/JYX3H7baevdJQ/SoOr+zal7zkUYTy1Rx8BWTY
LHpg+jUcpm5KcvB3FILytRxCZ0of+NnNCuXrOHC3P13Hd+S1LYSv57Dl5bF7
yn/coOYZOETeYbh/fbkWlG/oIF0uk5dcog3lGzn8+yB8dvNxEyjf2GGJxg+L
BcutoHwTh+8Ws9auT3KA8k0dznrfsUtRCYLyzRyuzNh6KLrNE8o3d1jjfpph
a4Q7lG/hIGj/XGI9i9c+AHG4aPg=
     "]]}, {}},
  AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
  Axes->True,
  AxesLabel->{None, None},
  AxesOrigin->{0, 0.},
  AxesStyle->Directive[20, 
    Thickness[0.005], 
    RGBColor[0, 0, 1]],
  ImageSize->500,
  LabelStyle->(FontFamily -> "Helvetica"),
  Method->{},
  PlotRange->{{0, 24.}, {-3.1458432214100404`*^-8, 2.985780936359698*^-9}},
  PlotRangeClipping->True,
  PlotRangePadding->{{0.48, 0.48}, {6.888842630092021*^-10, 
   6.888842630092021*^-10}}]], "Output",
 CellChangeTimes->{
  3.577697680383156*^9},ImageCache->GraphicsData["CompressedBitmap", "\<\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\
\>"]]
}, Open  ]]
}, Open  ]]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Part IV", "Text",
 CellChangeTimes->{{3.4420619435625*^9, 3.4420619460625*^9}, {
  3.495108480859375*^9, 3.49510848184375*^9}, {3.495285762890625*^9, 
  3.495285793703125*^9}, {3.49528627184375*^9, 3.49528627628125*^9}, {
  3.574514859153361*^9, 3.574514860104415*^9}, {3.574514944825261*^9, 
  3.5745149458253183`*^9}},
 FontSize->36,
 FontColor->RGBColor[0, 0, 1],
 Background->RGBColor[1, 0.9, 0.8]],

Cell[CellGroupData[{

Cell[TextData[{
 "Still one step before examining directly the Residual punction\n    Now we \
compare - on the  ",
 StyleBox["entire Domain",
  FontWeight->"Bold"],
 " - the symbolic  solution and the IFO ",
 StyleBox["  ",
  FontWeight->"Bold"],
 "  "
}], "Text",
 CellChangeTimes->{{3.44208810684375*^9, 3.442088135015625*^9}, {
   3.442088245765625*^9, 3.4420883806875*^9}, {3.44208841290625*^9, 
   3.442088436875*^9}, {3.442089669109375*^9, 3.442089673796875*^9}, 
   3.44209036175*^9, {3.4421000129375*^9, 3.4421000394375*^9}, {
   3.495199332921875*^9, 3.49519934853125*^9}, {3.49537297840625*^9, 
   3.495373112453125*^9}, {3.495423225921875*^9, 3.495423234578125*^9}, {
   3.496664348359375*^9, 3.496664356625*^9}, {3.496664624828125*^9, 
   3.496664660609375*^9}, {3.561291808819169*^9, 3.561291813805765*^9}, {
   3.5612923515164948`*^9, 3.5612923824343567`*^9}, {3.561292439176154*^9, 
   3.561292440456601*^9}, {3.561294003688833*^9, 3.5612940071212473`*^9}, {
   3.561295256854271*^9, 3.561295298686286*^9}, 3.5745154654900413`*^9},
 FontSize->24,
 Background->GrayLevel[0.85]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{
   StyleBox["GlobalErrorOnDomain",
    FontColor->RGBColor[1, 0, 1]], "[", "t_", "]"}], " ", "=", 
  RowBox[{
   RowBox[{"solsymb", "[", "t", "]"}], "-", 
   RowBox[{
    StyleBox["solNDS",
     FontColor->RGBColor[1, 0, 0]], "[", "t", "]"}]}]}]], "Input",
 CellChangeTimes->{{3.442081513875*^9, 3.44208155765625*^9}, {
   3.495112587296875*^9, 3.495112589375*^9}, 3.49519964109375*^9, 
   3.495285369296875*^9, 3.495372769421875*^9, 3.5612732751410217`*^9, {
   3.562308886756784*^9, 3.562308888060438*^9}, {3.562309042654132*^9, 
   3.562309043354*^9}},
 FontSize->24],

Cell[BoxData[
 RowBox[{
  SuperscriptBox["\[ExponentialE]", "t"], "-", 
  RowBox[{
   TagBox[
    RowBox[{"InterpolatingFunction", "[", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{"{", 
        RowBox[{"0.`", ",", "1.`"}], "}"}], "}"}], ",", "\<\"<>\"\>"}], "]"}],
    False,
    Editable->False], "[", "t", "]"}]}]], "Output",
 CellChangeTimes->{3.57769768041835*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 StyleBox[
  RowBox[{"gra$GlobalErrorOnDomain", "=", " ", 
   RowBox[{"Plot", "[", 
    RowBox[{
     RowBox[{"GlobalErrorOnDomain", "[", "t", "]"}], ",", 
     RowBox[{"{", 
      RowBox[{"t", ",", "tini", ",", "tfin"}], "}"}]}], "]"}]}],
  FontColor->RGBColor[1, 0, 1]]], "Input",
 CellChangeTimes->{{3.562309062924403*^9, 3.562309091528368*^9}, {
  3.562309129260788*^9, 3.562309132126886*^9}},
 FontSize->18],

Cell[BoxData[
 GraphicsBox[{{}, {}, 
   {Hue[0.67, 0.6, 0.6], LineBox[CompressedData["
1:eJws13lYTV8XB/BKaJKkUimNmiWJklpuozTQPCrN83hLMqRBEjKT0EQhiRKl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     "]]}},
  AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
  Axes->True,
  AxesLabel->{None, None},
  AxesOrigin->{0, 0},
  AxesStyle->Directive[20, 
    Thickness[0.005], 
    RGBColor[0, 0, 1]],
  ImageSize->500,
  LabelStyle->(FontFamily -> "Helvetica"),
  Method->{},
  PlotRange->{{0, 1}, {-3.4203156307199833`*^-8, 5.754738672258952*^-7}},
  PlotRangeClipping->True,
  PlotRangePadding->{
    Scaled[0.02], 
    Scaled[0.02]}]], "Output",
 CellChangeTimes->{
  3.577697680473812*^9},ImageCache->GraphicsData["CompressedBitmap", "\<\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\
\>"]]
}, Open  ]],

Cell[TextData[{
 "    The maximum difference (blue curve) here amounts to several parts per  ",
 Cell[BoxData[
  FormBox[
   SuperscriptBox["10", 
    RowBox[{"-", "7"}]], TraditionalForm]]],
 ", that is,\n    an order of magnitude higher with respect to \
gra$GlobalErrorOnNodes,\n    Most  of the error visible in \
gra$GlobalErrorOnDomain, \n    where we have added, in the following graph \
the red dots appearing in gra$GlobalErrorOnNodes,\n     is due to \
interpolation error."
}], "Text",
 CellChangeTimes->{{3.44208810684375*^9, 3.442088135015625*^9}, {
   3.442088245765625*^9, 3.4420883806875*^9}, {3.44208841290625*^9, 
   3.442088436875*^9}, {3.442089669109375*^9, 3.442089673796875*^9}, 
   3.44209036175*^9, {3.4421000129375*^9, 3.4421000394375*^9}, {
   3.495199332921875*^9, 3.49519934853125*^9}, {3.49537297840625*^9, 
   3.495373112453125*^9}, {3.495423225921875*^9, 3.495423234578125*^9}, {
   3.496664348359375*^9, 3.496664356625*^9}, {3.496664624828125*^9, 
   3.496664660609375*^9}, {3.561291808819169*^9, 3.561291813805765*^9}, {
   3.5612923515164948`*^9, 3.5612923824343567`*^9}, {3.5612924316454067`*^9, 
   3.561292434500086*^9}, {3.5612924660464973`*^9, 3.5612924887152653`*^9}, {
   3.561292547611281*^9, 3.561292599841251*^9}, {3.561292634227234*^9, 
   3.561292672512847*^9}, {3.561292844064221*^9, 3.561292939340177*^9}, {
   3.5612930584818707`*^9, 3.5612930664274387`*^9}, {3.561293336012689*^9, 
   3.56129333870411*^9}, {3.562309724038978*^9, 3.5623097353218927`*^9}},
 FontSize->24,
 Background->GrayLevel[0.85]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Show", "[", 
  RowBox[{
   RowBox[{"ListPlot", "[", 
    RowBox[{
     StyleBox["couplesGlobalErr",
      FontColor->RGBColor[1, 0, 1]], 
     StyleBox[",",
      FontSize->16], "\[IndentingNewLine]", 
     RowBox[{"PlotRange", "\[Rule]", "All"}], ",", 
     RowBox[{"Joined", "\[Rule]", "True"}], ",", 
     RowBox[{"ImageSize", "\[Rule]", "600"}], ",", "\[IndentingNewLine]", 
     RowBox[{"PlotLabel", "->", "\"\<\!\(\*
StyleBox[\"GlobalErrorOnNodes\",
FontSize->18,
FontColor->RGBColor[1, 0, 0]]\)\!\(\*
StyleBox[\" \",
FontSize->18,
FontColor->RGBColor[1, 0, 0]]\)\!\(\*
StyleBox[\"and\",
FontSize->18,
FontColor->GrayLevel[0]]\)\!\(\*
StyleBox[\" \",
FontSize->18,
FontColor->RGBColor[1, 0, 0]]\)\!\(\*
StyleBox[\"GlobalErrorOnDomain\",
FontSize->18,
FontColor->RGBColor[0, 0, 1]]\)\>\""}], ",", "\[IndentingNewLine]", 
     RowBox[{"Epilog", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"PointSize", "[", "0.015", "]"}], ",", 
        RowBox[{"RGBColor", "[", 
         RowBox[{"1", ",", "0", ",", "0"}], "]"}], ",", "\[IndentingNewLine]", 
        RowBox[{"Map", "[", 
         RowBox[{"Point", ",", 
          StyleBox["couplesGlobalErr",
           FontColor->RGBColor[1, 0, 1]]}], "]"}]}], "}"}]}]}], "]"}], ",", 
   StyleBox["\[IndentingNewLine]",
    FontSize->16], 
   StyleBox["     ",
    FontSize->16], 
   StyleBox["gra$GlobalErrorOnDomain",
    FontColor->RGBColor[1, 0, 1]]}], 
  StyleBox["]",
   FontColor->RGBColor[1, 0, 1]]}]], "Input",
 CellChangeTimes->{
  3.44196616728125*^9, {3.442081721578125*^9, 3.442081746109375*^9}, 
   3.442081836078125*^9, {3.44229969106015*^9, 3.4422997618665047`*^9}, {
   3.4422998417080393`*^9, 3.4422999164942904`*^9}, {3.4423008777110453`*^9, 
   3.442300914691793*^9}, {3.442301994419495*^9, 3.442302013591947*^9}, {
   3.49519829784375*^9, 3.495198298515625*^9}, {3.495198365875*^9, 
   3.49519836634375*^9}, 3.4951996714375*^9, {3.49519976475*^9, 
   3.495199766125*^9}, {3.49519986484375*^9, 3.495199867140625*^9}, {
   3.49520059715625*^9, 3.49520059896875*^9}, {3.495200632734375*^9, 
   3.495200695265625*^9}, {3.495200766015625*^9, 3.495200771046875*^9}, 
   3.4952812779375*^9, 3.495281870515625*^9, {3.49528212528125*^9, 
   3.495282128109375*^9}, {3.4953727750625*^9, 3.49537277628125*^9}, {
   3.49537293165625*^9, 3.495372932453125*^9}, {3.49542331103125*^9, 
   3.495423360875*^9}, {3.4967464759375*^9, 3.496746477140625*^9}, {
   3.561272414820829*^9, 3.561272465568396*^9}, {3.561272535188488*^9, 
   3.5612725791713257`*^9}, {3.5612732920707073`*^9, 3.5612732952936897`*^9}, 
   3.561291783659618*^9, 3.561292698031069*^9, {3.5612927394355507`*^9, 
   3.561292758773952*^9}, {3.56230890342636*^9, 3.5623089141876173`*^9}},
 FontSize->24],

Cell[BoxData[
 GraphicsBox[{{{}, 
    {RGBColor[0.24720000000000014`, 0.24, 0.6], LineBox[CompressedData["
1:eJxTTMoPSmViYGCQBGIQjQ4uVxQ7xQtK2AOZD85KGe2D8DVA/AtW0k77Nlvw
PzVxKAbx18gkBO67kMWa8f5+E1j9iaOR+9wsm2OPyPeA+PtS5RP3GeT5Jb/2
mgPiH9gbq2V3b/5b719OS8H8t1Ol7JZymDyrS1gD4jNwTLmyd5uF7QHG/RtB
fAef3bL7ahY2R7Xd2QFWL3xKaZ8z16kvXL/2g/gNsZ9k7FotO44f7z4M1u/v
Imr3Ine1SJfUcbC89HlOO+9F5xJ9Vp4Cy3NLfrRdzpcSeGnCRRA/ocHOb5/G
mQeF/85cBfE/zN9jtG9VZ+wkLc5bYH7iPJN9Ou63NoW53gPxb5SscdgX1rQ6
86DDQxA/Y/9Nt33iD19WXo97DOIrcLP47fMSkV3LNekZiD/DLzZpX517wAPb
oy9B/B0ifTH79ilrfJj36A2Iv+LIyZh9kFD/AOIXpK9L3AcA8jOUWQ==
      "]]}, {}}, {{}, {}, 
    {Hue[0.67, 0.6, 0.6], LineBox[CompressedData["
1:eJws13lYTV8XB/BKaJKkUimNmiWJklpuozTQPCrN83hLMqRBEjKT0EQhiRKl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      "]]}}},
  AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
  Axes->True,
  AxesLabel->{None, None},
  AxesOrigin->{0., 0.},
  AxesStyle->Directive[20, 
    Thickness[0.005], 
    RGBColor[0, 0, 1]],
  Epilog->{
    PointSize[0.015], 
    RGBColor[1, 0, 0], {
     PointBox[{0., 0.}], 
     PointBox[{0.00009181159895230448, -4.2153298629443725`*^-9}], 
     PointBox[{0.00018362319790460896`, -8.431433773381514*^-9}], 
     PointBox[{0.004699904079599348, -1.6182137185793977`*^-8}], 
     PointBox[{0.009216184961294088, -2.4002600795824947`*^-8}], 
     PointBox[{0.013732465842988827`, -3.1893413909855894`*^-8}], 
     PointBox[{0.027629545150928247`, 3.0694269348430225`*^-9}], 
     PointBox[{0.041526624458867664`, 1.5474890258104779`*^-9}], 
     PointBox[{0.05542370376680709, -7.4863226728894*^-11}], 
     PointBox[{0.06932078307474651, -1.7306087674029413`*^-9}], 
     PointBox[{0.09711494169062534, -2.1873698408114706`*^-9}], 
     PointBox[{0.12490910030650419`, 1.6849219797165915`*^-9}], 
     PointBox[{0.15270325892238304`, 1.2378924552081116`*^-9}], 
     PointBox[{0.18049741753826187`, 7.51141149279988*^-10}], 
     PointBox[{0.2082915761541407, 2.4880608684441086`*^-10}], 
     PointBox[{0.274464206202746, -1.4083528121489053`*^-8}], 
     PointBox[{0.3406368362513512, -4.362504801846967*^-9}], 
     PointBox[{0.4068094662999565, -4.800660979853433*^-9}], 
     PointBox[{0.4729820963485618, -7.76427699911153*^-9}], 
     PointBox[{0.539154726397167, -1.064062904454488*^-8}], 
     PointBox[{0.6053273564457723, -1.3977193624725714`*^-8}], 
     PointBox[{0.7053273564457723, -3.420651051300183*^-8}], 
     PointBox[{0.8053273564457724, -2.6593919510986552`*^-8}], 
     PointBox[{0.9026636782228861, -2.681106048285642*^-8}], 
     PointBox[{1., -3.293392403236339*^-8}]}},
  ImageSize->600,
  LabelStyle->(FontFamily -> "Helvetica"),
  Method->{},
  PlotLabel->FormBox[
   "\"\\!\\(\\*\\nStyleBox[\\\"GlobalErrorOnNodes\\\",\\nFontSize->18,\\\
nFontColor->RGBColor[1, 0, 0]]\\)\\!\\(\\*\\nStyleBox[\\\" \
\\\",\\nFontSize->18,\\nFontColor->RGBColor[1, 0, 0]]\\)\\!\\(\\*\\nStyleBox[\
\\\"and\\\",\\nFontSize->18,\\nFontColor->GrayLevel[0]]\\)\\!\\(\\*\\\
nStyleBox[\\\" \\\",\\nFontSize->18,\\nFontColor->RGBColor[1, 0, 0]]\\)\\!\\(\
\\*\\nStyleBox[\\\"GlobalErrorOnDomain\\\",\\nFontSize->18,\\nFontColor->\
RGBColor[0, 0, 1]]\\)\"", TraditionalForm],
  PlotRangeClipping->True]], "Output",
 CellChangeTimes->{
  3.577697680513335*^9},ImageCache->GraphicsData["CompressedBitmap", "\<\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\
\>"]]
}, Open  ]],

Cell["\<\
For example, at numerical level, we observe that the value of the blue curve 
when t\[Rule](TimeNodes[[21]]), corresponding to the red spot are equal, 
in fact,  pointblue  = pointred,...\
\>", "Text",
 CellChangeTimes->{{3.44208810684375*^9, 3.442088135015625*^9}, {
   3.442088245765625*^9, 3.4420883806875*^9}, {3.44208841290625*^9, 
   3.442088436875*^9}, {3.442089669109375*^9, 3.442089673796875*^9}, 
   3.44209036175*^9, {3.4421000129375*^9, 3.4421000394375*^9}, {
   3.495199332921875*^9, 3.49519934853125*^9}, {3.49537297840625*^9, 
   3.495373112453125*^9}, {3.495423225921875*^9, 3.495423234578125*^9}, {
   3.496664348359375*^9, 3.496664356625*^9}, {3.496664624828125*^9, 
   3.496664660609375*^9}, {3.561291808819169*^9, 3.561291813805765*^9}, {
   3.5612923515164948`*^9, 3.5612923824343567`*^9}, {3.5612924316454067`*^9, 
   3.561292434500086*^9}, {3.5612924660464973`*^9, 3.5612924887152653`*^9}, {
   3.561292547611281*^9, 3.561292599841251*^9}, {3.561292634227234*^9, 
   3.561292672512847*^9}, {3.561292844064221*^9, 3.561292939340177*^9}, {
   3.5612930584818707`*^9, 3.5612930664274387`*^9}, {3.561293283437543*^9, 
   3.561293399157381*^9}, {3.561293556413988*^9, 3.561293656561858*^9}, {
   3.561293694130718*^9, 3.561293708988505*^9}, {3.562309201825165*^9, 
   3.56230923147756*^9}},
 FontSize->24,
 Background->GrayLevel[0.85]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  StyleBox["pointblue",
   FontColor->RGBColor[0, 0, 1]], 
  StyleBox[" ",
   FontColor->GrayLevel[0]], 
  StyleBox["=",
   FontColor->RGBColor[1, 0, 1]], 
  StyleBox[" ",
   FontColor->RGBColor[1, 0, 1]], 
  RowBox[{
   RowBox[{
    StyleBox["GlobalErrorOnDomain",
     FontColor->RGBColor[1, 0, 1]], "[", "t", "]"}], "  ", "/.", " ", 
   RowBox[{"t", "\[Rule]", 
    RowBox[{"(", 
     RowBox[{"TimeNodes", "[", 
      RowBox[{"[", "21", "]"}], "]"}], ")"}]}]}]}]], "Input",
 CellChangeTimes->{{3.56129342285572*^9, 3.561293441245575*^9}, {
  3.561293517856161*^9, 3.561293519120549*^9}},
 FontSize->18],

Cell[BoxData[
 RowBox[{"-", "1.3977193624725714`*^-8"}]], "Output",
 CellChangeTimes->{3.577697680557135*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  StyleBox["pointred",
   FontColor->RGBColor[1, 0, 0]], 
  StyleBox[" ",
   FontColor->RGBColor[1, 0, 1]], 
  StyleBox["=",
   FontColor->RGBColor[1, 0, 1]], 
  StyleBox[
   RowBox[{"GlobalErrorOnNodes", "[", 
    RowBox[{"[", "21", "]"}], "]"}],
   FontColor->RGBColor[1, 0, 1]]}]], "Input",
 CellChangeTimes->{{3.561293500600174*^9, 3.561293512798266*^9}},
 FontSize->18],

Cell[BoxData[
 RowBox[{"-", "1.3977193624725714`*^-8"}]], "Output",
 CellChangeTimes->{3.577697680586103*^9}]
}, Open  ]],

Cell["\<\
... but, when  t\[Rule](TimeNodes[[21]]+0.05), we have \
\>", "Text",
 CellChangeTimes->{{3.44208810684375*^9, 3.442088135015625*^9}, {
   3.442088245765625*^9, 3.4420883806875*^9}, {3.44208841290625*^9, 
   3.442088436875*^9}, {3.442089669109375*^9, 3.442089673796875*^9}, 
   3.44209036175*^9, {3.4421000129375*^9, 3.4421000394375*^9}, {
   3.495199332921875*^9, 3.49519934853125*^9}, {3.49537297840625*^9, 
   3.495373112453125*^9}, {3.495423225921875*^9, 3.495423234578125*^9}, {
   3.496664348359375*^9, 3.496664356625*^9}, {3.496664624828125*^9, 
   3.496664660609375*^9}, {3.561291808819169*^9, 3.561291813805765*^9}, {
   3.5612923515164948`*^9, 3.5612923824343567`*^9}, {3.5612924316454067`*^9, 
   3.561292434500086*^9}, {3.5612924660464973`*^9, 3.5612924887152653`*^9}, {
   3.561292547611281*^9, 3.561292599841251*^9}, {3.561292634227234*^9, 
   3.561292672512847*^9}, {3.561292844064221*^9, 3.561292939340177*^9}, {
   3.5612930584818707`*^9, 3.5612930664274387`*^9}, {3.561293283437543*^9, 
   3.561293399157381*^9}, {3.561293556413988*^9, 3.561293656561858*^9}, {
   3.561293689121221*^9, 3.5612937152298326`*^9}, 3.561293787828197*^9, {
   3.562309235136279*^9, 3.562309243235322*^9}, {3.574515386121502*^9, 
   3.5745153875295825`*^9}},
 FontSize->24,
 Background->GrayLevel[0.85]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"pointblue605", "=", 
  RowBox[{
   RowBox[{
    StyleBox["GlobalErrorOnDomain",
     FontColor->RGBColor[1, 0, 1]], "[", "t", "]"}], " ", "/.", " ", 
   RowBox[{"t", "\[Rule]", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"TimeNodes", "[", 
       RowBox[{"[", "21", "]"}], "]"}], "+", "0.05"}], ")"}]}]}]}]], "Input",
 CellChangeTimes->{{3.561293762359744*^9, 3.561293774295834*^9}, 
   3.5623095475454197`*^9, {3.562309804110806*^9, 3.5623098220843363`*^9}, {
   3.562309876186084*^9, 3.562309878789918*^9}},
 FontSize->18],

Cell[BoxData["4.776846378451438`*^-7"], "Output",
 CellChangeTimes->{3.5776976806177387`*^9}]
}, Open  ]],

Cell[TextData[{
 "whereas, from gra$GlobalErrorOnNodes, we get a value near",
 StyleBox[" to ",
  FontFamily->"Times New Roman"],
 Cell[BoxData[
  RowBox[{
   RowBox[{"-", "2."}], "\[Times]", 
   SuperscriptBox["10", 
    RowBox[{"-", "8"}]]}]],
  CellChangeTimes->{3.49542438165625*^9, 3.495424419796875*^9},
  FontFamily->"Times New Roman"],
 "."
}], "Text",
 CellChangeTimes->{{3.44208810684375*^9, 3.442088135015625*^9}, {
   3.442088245765625*^9, 3.4420883806875*^9}, {3.44208841290625*^9, 
   3.442088436875*^9}, {3.442089669109375*^9, 3.442089673796875*^9}, 
   3.44209036175*^9, {3.4421000129375*^9, 3.4421000394375*^9}, {
   3.495199332921875*^9, 3.49519934853125*^9}, {3.49537297840625*^9, 
   3.495373112453125*^9}, {3.495423225921875*^9, 3.495423234578125*^9}, {
   3.496664348359375*^9, 3.496664356625*^9}, {3.496664624828125*^9, 
   3.496664660609375*^9}, {3.561291808819169*^9, 3.561291813805765*^9}, {
   3.5612923515164948`*^9, 3.5612923824343567`*^9}, {3.5612924316454067`*^9, 
   3.561292434500086*^9}, {3.5612924660464973`*^9, 3.5612924887152653`*^9}, {
   3.561292547611281*^9, 3.561292599841251*^9}, {3.561292634227234*^9, 
   3.561292672512847*^9}, {3.561292844064221*^9, 3.561292939340177*^9}, {
   3.5612930584818707`*^9, 3.5612930664274387`*^9}, {3.561293283437543*^9, 
   3.561293399157381*^9}, {3.561293556413988*^9, 3.561293656561858*^9}, {
   3.561293689121221*^9, 3.5612937152298326`*^9}, {3.561293787828197*^9, 
   3.561293839021963*^9}, {3.561293875290812*^9, 3.561293940043146*^9}, {
   3.561294058737421*^9, 3.561294063332678*^9}, 3.5745153998742886`*^9},
 FontSize->24,
 Background->GrayLevel[0.85]]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Part V", "Text",
 CellChangeTimes->{{3.4420619435625*^9, 3.4420619460625*^9}, {
  3.495108480859375*^9, 3.49510848184375*^9}, {3.495285762890625*^9, 
  3.495285793703125*^9}, {3.49528627184375*^9, 3.49528627628125*^9}, {
  3.574514859153361*^9, 3.574514860104415*^9}, {3.574514959369093*^9, 
  3.574514961105192*^9}},
 FontSize->36,
 FontColor->RGBColor[0, 0, 1],
 Background->RGBColor[1, 0.9, 0.8]],

Cell[CellGroupData[{

Cell["\<\
To obtain  the residual function we introduce the numerical solution (IFO)
    into the original ODE \
\>", "Text",
 CellChangeTimes->{{3.44207339471875*^9, 3.4420734050625*^9}, {
   3.44207345690625*^9, 3.44207347240625*^9}, 3.442073723109375*^9, 
   3.495282611171875*^9, {3.495512351765625*^9, 3.4955124408125*^9}, {
   3.49551251203125*^9, 3.495512558640625*^9}, {3.496029353125*^9, 
   3.496029354078125*^9}, {3.49666470890625*^9, 3.496664745640625*^9}, {
   3.496664865125*^9, 3.4966648658125*^9}, {3.49666588228125*^9, 
   3.49666588290625*^9}, {3.496748114296875*^9, 3.49674811528125*^9}, {
   3.5612945572551117`*^9, 3.561294565424412*^9}, {3.561295367110045*^9, 
   3.561295392578741*^9}, {3.574515409257825*^9, 3.5745154093688316`*^9}},
 FontSize->24,
 FontColor->GrayLevel[0],
 Background->GrayLevel[0.85]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"soln", "=", 
  RowBox[{"NDSolve", "[", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{
      RowBox[{
       RowBox[{
        SuperscriptBox["x", "\[Prime]",
         MultilineFunction->None], "[", "t", "]"}], "==", 
       RowBox[{"x", "[", "t", "]"}]}], ",", 
      RowBox[{
       RowBox[{"x", "[", "0", "]"}], "==", "1"}]}], "}"}], ",", "x", ",", 
    RowBox[{"{", 
     RowBox[{"t", ",", "0", ",", "1"}], "}"}]}], "]"}]}]], "Input",
 FontSize->24],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"{", 
   RowBox[{"x", "\[Rule]", 
    TagBox[
     RowBox[{"InterpolatingFunction", "[", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"{", 
         RowBox[{"0.`", ",", "1.`"}], "}"}], "}"}], ",", "\<\"<>\"\>"}], "]"}],
     False,
     Editable->False]}], "}"}], "}"}]], "Output",
 CellChangeTimes->{3.577697680641178*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{
   StyleBox["Residual",
    FontColor->RGBColor[0, 1, 0]], "[", "t_", "]"}], "=", " ", 
  RowBox[{"Evaluate", "[", 
   RowBox[{
    RowBox[{
     RowBox[{
      RowBox[{"x", "'"}], "[", "t", "]"}], "-", 
     RowBox[{"x", "[", "t", "]"}]}], " ", "/.", " ", 
    RowBox[{"First", "[", "soln", "]"}]}], "]"}]}]], "Input",
 CellChangeTimes->{
  3.442072583828125*^9, 3.4420726575625*^9, {3.44207275725*^9, 
   3.442072759046875*^9}, {3.49511315684375*^9, 3.49511316046875*^9}, {
   3.495113224703125*^9, 3.4951132303125*^9}, {3.495113285828125*^9, 
   3.495113291484375*^9}, {3.49511340346875*^9, 3.49511341653125*^9}, 
   3.495282611734375*^9, {3.49551389653125*^9, 3.49551390346875*^9}, {
   3.495513957796875*^9, 3.49551395915625*^9}, 3.4967465493125*^9},
 FontSize->24],

Cell[BoxData[
 RowBox[{
  RowBox[{"-", 
   RowBox[{
    TagBox[
     RowBox[{"InterpolatingFunction", "[", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"{", 
         RowBox[{"0.`", ",", "1.`"}], "}"}], "}"}], ",", "\<\"<>\"\>"}], "]"}],
     False,
     Editable->False], "[", "t", "]"}]}], "+", 
  RowBox[{
   TagBox[
    RowBox[{"InterpolatingFunction", "[", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{"{", 
        RowBox[{"0.`", ",", "1.`"}], "}"}], "}"}], ",", "\<\"<>\"\>"}], "]"}],
    False,
    Editable->False], "[", "t", "]"}]}]], "Output",
 CellChangeTimes->{3.577697680649472*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  StyleBox["gra$Residual",
   FontColor->RGBColor[0, 1, 0]], " ", "=", 
  RowBox[{"Plot", "[", 
   RowBox[{
    RowBox[{
     StyleBox["Residual",
      FontColor->RGBColor[0, 1, 0]], "[", "t", "]"}], ",", 
    RowBox[{"{", 
     RowBox[{"t", ",", "tini", ",", "tfin"}], " ", "}"}], ",", 
    "\[IndentingNewLine]", " ", 
    RowBox[{"Epilog", "\[Rule]", 
     RowBox[{"{", 
      RowBox[{"Text", "[", 
       RowBox[{"\"\<\!\(\*
StyleBox[\"ResidualOnDomain\",
FontSize->18,
FontWeight->\"Plain\",
FontColor->RGBColor[0, 0, 1]]\)\>\"", ",", 
        RowBox[{"{", 
         RowBox[{"0.4", ",", 
          RowBox[{"1.", "*", 
           SuperscriptBox["10", 
            RowBox[{"-", "5"}]]}]}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{"0", ",", 
          RowBox[{"-", "1"}]}], "}"}]}], "]"}], "}"}]}]}], 
   "\[IndentingNewLine]", "]"}]}]], "Input",
 CellChangeTimes->{
  3.4419614244375*^9, {3.4419640730625*^9, 3.441964116375*^9}, {
   3.441964203484375*^9, 3.441964221734375*^9}, {3.442073052421875*^9, 
   3.4420731095*^9}, {3.442073143984375*^9, 3.442073153484375*^9}, {
   3.44207318525*^9, 3.4420731965*^9}, 3.442073775265625*^9, 
   3.442073817125*^9, {3.442096611484375*^9, 3.442096616375*^9}, 
   3.4952818811875*^9, {3.495282612375*^9, 3.495282613671875*^9}, {
   3.49528295471875*^9, 3.495282957453125*^9}, {3.495513914046875*^9, 
   3.4955139174375*^9}, {3.495513963390625*^9, 3.495513976421875*^9}, {
   3.496746550609375*^9, 3.496746553609375*^9}, {3.5612951752790623`*^9, 
   3.561295177958907*^9}},
 FontSize->24],

Cell[BoxData[
 GraphicsBox[{{}, {}, 
   {Hue[0.67, 0.6, 0.6], LineBox[CompressedData["
1:eJwk13c81d8bAHC0FElIiBKS+kqUInGykxEZoSE7StmyXevaW0YhIZmF7HFc
+7rXuCErIZmFaIrGzzm/v+r9ep7znOc853Pdzz1sbq9rxUBHR3eekY4O/atu
Nf+atGAANv+7a+a+A9iqxOMwwS15gY6OdC5RPB6cfpKS9opbedOZbENhxWCa
V8j/gfBlFBeqsKkCGt1DZenc+psumfR/AIFQJN+zf4eMN50ynrfWBH6rWySb
CZtsmusm26cW8DFooNUsyWzT83f/sLUBQ8ufDfHclpumY7rj0AZalXiqWtKs
N20kY7SlDYgLypV8O2SL4usd1BaQxmCafyT77qYnL9V0NgHGqYCsq8L3Ny2u
b7TeAGon+7pb9B02zX9GoasSOOhYqt9IckS+d42tCAiTvrd/G3JC9dqmQqPA
u5MhSlHcLpuW398tmgESn3CRjlx33bQDt4hpKVDfUyAL09w2zdqinlED6PzO
11wdf7BpnafdAiRQudx15vMhD3S+LubCZmBnYlIWYua56eH3U7dbgUDPZzH+
bC80jylt4zYwLOdfWD3tjfbr0fNrA9HFbCJXhH03vZazPNIKVPhychZu+6F5
W/PbtgDf9kesTfoEtB/7gmgTMPb9cDnqOzLNIE69HkieFY0yTvJH57num1MO
9iy7UI9IBWyaYHeqNxd8fNaw88sQMt2irLc5aLu5XQ26B6L7Y+iezgGZ+7SJ
4dxBaH4PU6ZeAa/u5Nartcix7Idr68DV4EkGwevBqN+/fr9JQELumMLnDeS1
54+0WwDzd0e/ujQiMtF0sBXMFdU2hMiFbFrt8evYNtBsueW33jgybXrJtw2k
82rK8PuFbjrPoiKzFbgPJLovHgpD/ewX+dEM9CLfVVaTkPnpVf1IQExZ+HuQ
WTg6z4WD7rVg5+/7p68wRGzadG67cRmYflXlyJeNTPgaofgUNN6lK1lQikTn
/VTm7QIfCV5arphGlq+Ol30M3d7GiQYER6Hn53Ht0Tx4JWH0zmXhaGQ7Hs5S
KKohmM/TgcxqSz9YARm32M3N3o5B9Z5W6dVCp5uj8cZbY9H9OJnHQHir5m9p
oz6yTUaCchPU3Cf4+sgz5JIXD/lboIzjxZWI78ix3JS3rVCk++6eLypxm2aM
VnJrh/uOxYoZJSHr1HGsdECG4HItOIucqaNzqROuTA7bCUnFo37+MAZQ4Ljs
n4jwEGSy/ZVHVEhNOVy4MoTMaCQb3wWrv6lQrookoM+X5ZhtN8zVubNQ746c
qaJ8uAcmFkUzCnYi6+QTq3ugP+Oro2Hciej+L1Se7IXHL8aFljkgh55oj+yF
fcH2C287kHVeXGnthV6tWurbDj1E/cQ6DPZCoS2ihWJuyGpPZVp6YZfCLmaj
buTYko7wXuhKmLfzF0ratHvkyRO98GBje3eBF/aW8IIe2P4nR2ygD1l8epmh
B9rLBsb8OZa8aZE/rme7IZeX2YqwP/Ikr5RKFyTVXLiiM4y9V/0kFdqu8ZV5
nExB8yho/9YJ2aR+s2UTkVkrWx+SYa3rqHPXO2Q1hhtsHdCivHrgu2QqmpdJ
zp02yPw16cyhSGRyckVGC6yQcE1S+4DM5fv8RRM0cdD76SjzCNVrFDzTCF8u
7alpnUdeeWyyuxIaiS5zL194jOIrgiylkO5ul+f+ZGTCTYmY5zA/v+Ct/DIy
aaB0LgXqzofK3lFJQ88TV7WeMdwQvp2ekIbNGseoBHKsVP7Wf8XuypjTB5o5
grdm1dORV9QPmoLvU/SkPVnYzFb1ViDj8CT/uV/Y05/U7gJVU+hvrpOB3HP1
lgNIeeepVPEX+1RUnitQ4DXOGTd4gvyhRMIdfLwmtY2xGNuQ5ZknOLjoYVF8
IhP5PZu8H3BiWmBXNMZmVS4lgPbjRq2DQciEOtsyf8Cj3uFytwTH/5zICgD2
tmeP0I1hmyj7BYLW0GdvEnc8Rfl3TNWCAFceB/HYaWS6ojO/g4BdR+BZaIJd
/CA1GJBmv8zqhuP8nyMHiYBju3nyXAU2J2sEEdgeeX3R+z3OT+geIwKoLL/G
ujsLxX+1sYUANsuXec+ksfuK/gsB1oEHjWUssfPOCIeAuqyonb0x2Ns56EMA
a/PvGos6ZLoHG7VEYPn+7p21WRwPfKJLBNV0b3mi2LJRvPJVezBg5lenHgbY
jz/tCwamF2q8Km2xa9dBEKgwERHVeIidmSgfCHb5Jo9NkLDf2HEHAJP07VEu
i9gzZ8kEUFbvKreTKwf5lWayL9g+Nr2UroTt+U7ZC1zb0Ms4ZY8tGZL0ALzk
abnc8Qj7Z0mYM9gqc+rf9XbsvECp+8DI+OnLlVXsVoVES/D5rf6uLJ5nyN60
KgNANGG00lPCJgTxsgHe93WNW+2waRzVauCVhT1PZSK2JiXSEKjPCrjebvh/
fq2BGZi0GezlmsWurRuyBiz35YK9pHKRF7ReO4BnKysToqbY/c6OzkDWOUdm
PBS76AaDG7jjzrQiP4rNP73kCeg3oPoXhufI584p+4AUH6dn2f9hy8IAP9AW
MHJtuw8ywWtqyB/c2BZVUfUMO/lvVwD4EiLPatuDfWShNBCE7fp2h+cndltM
cBDgj3reRj2Uh+rtn1QNBlV7rvP7qCETqju+BYPL8SxeYo44riEZTQQzHM1v
JlJx/B775vPknewqHteM3ajrFwLYeY5FKH7C+ZMTAyGgIG1s5it7PrJ93t5Q
IH8oVv6ZLDKB6ZFkKBh6qvT4qhW2QZZsKLgv9PP7jmicv/hCJBRsfV6gU1P5
//XFP0PA42MmhXcmsH0i8kLAqaK923kZC5CrzsqEgE6xNtNucey6tEIiMC11
r/M1xj5euBEMfpwW5RQPwM7SPhYMoionHN4XYLc8OB0EhM4lUOP7kQkn9nIH
gto6VWHl3zhO2DniD66AdcJ3oUIUN77sRADzpOK3uVrIdOWPOnyAn5LZWSM3
bKV5I0/A2c4Rt/MJdrppkhsoUiN/qu3AZpjwcQJKVC9VuxVsSx8eOzCqdfIp
H3cR8kBFkDlwoE1t9ChgF5230wE79JKuEu5gkz4kHAEZby6VSiRgO4Qe0ARn
jP4wfajDFl24aQy6RkusE6f/n8+rZQ5+Tezn/XmmGDlN/do9EGtOdcszwVbW
NnUEwjO+r41DsDX6trkA/Y8zxPphbLLEIQ/wyS71/T36F8jGFdFeIOCzpuyh
49hnJ+d8QMm3V6v+Xthb5Y76g4sPbmuezkEmMJP/CwDjv3ieT3fh+GA3fyBw
8e6hT/qOfUx6WxBg+ud/4+LBl/jv+8pQEEixNTQRVUUm5GolBgOhAVHTvfex
TyfLEUEpYDD/8RDnX+zoIwKQP2TxtgHHK4d0QwCVvdiKNIPjV5vrQ4DohaZX
fdtLkDcIe0KB07dCyTYeZILnbvVQUJOfVFElhuP5ZndDAd0t/7MFitjXHziF
AlUOu6q0qzjfWs0kFER2XpWOuYPjT3pOhIJ+X4Uaf1/s0S2TIYBHUlTGJR57
6b1zCDBd4KyzzsXrC83niSA3g17WuBb7k58sESzpLdZr9OD8gNP2wUBy55Ac
mMJWfOAXBDxhExT/gb1FxS4QkJyLLgjuKsWf9yTJALDjWDJp38FSPF+rIQK4
PO6vwHgKW8j4uS9ITLBrXlfBVurU8QKjaoZKS8bYZXvyH4DDfxVaJ+5hH+B/
4QxsXomq9PljXx6ruw9e2Oxvb32I/XfUzgqc71/syG/AJrzU4wQBoUNqaa+x
yVONepAs19wZPYPtXVthAQ3ykqnOu8uQe5WynWDazQBN68PYfRtBbnCK7V63
0Rns/GA2TyhCNryscQn7ym8tH2jvo9grdxOZYNnAS4CVp07oiDvi+K7ou/7w
99z+1wLB2Mk+iQFQMZ1Bd18qdlRqSiAM013q21GMffezexCk7RjWWydhl0ae
DYacDc0DiwPY4759wfCGU7HBxDzez7lfiwizj6YMvv6N4yvJ+UT4cSzAsJX1
FYr3j8wSoXj8veFKIeyM3O0h0O2ikXG+NDaNaVcIbPitOPpY8xX+PuD8QoRb
y05cjzbFtnnTSITqt7nGCC44v1vfhQhjebfcdA7F8UdZrEQ49HrpnVUajmt2
PQyGB0OGTYxKsC0ntgZDS9mWCfVWbIsFkyBYsFpsKjeM3fEzJxCu5qa8P7mI
zco1HAClbwSaC9CVo/qNhr/8oe/e+x84OJAJeq07/SGTt9LMr/M4rl++5gN1
JcSsF7WxR2WbvGDKLNfcuAW2SISDBzxyZXm+JQL70EyEC+Txuyhz+ym2eFuL
I2QtzozYVYUteox2D64z6oldmcLuCqA3hzRSlfO4dAVytQ27OmhbZm3zv4xd
csneGNTy3uE8Yok9HztrDp6589bcjcGW1hK0B57i/n/XZrCdPsl7AXuTUe20
DWyXpH8+wDJy8+VqbyUyl60eAWjPzygRZZEJn/n6AoAy54WHx3RxfCFoPRDI
KKfMdt3GVhrYGwxOOq1KOfjg/I1XnEQglKkexp6Ava9rRwjg7skerczDjmv9
EAJYfv/+7xrE6++r5G9+nx2/6vOnH8eLf1wNA78MX/ZkLuC4DuFTGFgOZuRX
/ofjBuFW4Zu/38wc5ziq8P3Ut4SDkfe1zeHHsaMbt0aAnj0cHGLyyASSzNEI
0CJ3z+q1AY5fGzwWAarvtle63MVxYxmmCPAi9RAjl///67FQwkF2h7txXRJ2
1IZlOEj5/rrApAjnN+eNhoFowf9+0zdjm8JjYSDwSpDWsyHs29M6ocDd712G
2hL2UPPlEHCv+OzKJ4Zq5DJ6ASIwfxujEMOFTLem1hkEjHYuxJ8Sw/E8eaVA
oCWlOP1GCbs1NtofKFo9PuNhjPMfN+v5AemEb0Ree+yQ8qNe4EST1nBjEPbl
i5vfpwKfc49ZPMJepaQ5gv18dF7bS7AnDzraAGYN4678NmzphMfGgMGjjE/r
LTYdMYoB/Mxlsl9Zwe7y22EGFwcsSQnba5CPhPc6wCkGuFeKF9ubOc0ddpk4
lPtcxI4UNguEzZGd2w7fxE6ixBJhVa2AYasTMsFHnxgGi+a98m6HYlcKK0XC
LM43v3ZlYFdkk6NhsrKYxotX2D84I2NhpFNI2pVOZNJCQmocDMicXPo2juNL
HlHx8EHPuQsp37BlPW0SIItYxUwnYy3KD91yKBHmRIlHbvAiE8Z2NCVCmaXC
UyckkOUv7td+CF9rHh0xUUGmG2nqfAhtirL8Yo1xfmayRBL8y3RQuPkezn8h
EpIEE++mdn31x2bdRk2C/1E5nI8k4fVD9X+SYPPxWG7DArz/3slDydAonIkU
CnG93r8SyXB5gWhd24fz+fMlk2HwJYbdi7M4n81eJBny5vu84tvA8arJ3cmw
jPGXsfaeOrQfb/RMElSzcaHzF0Sm091RkgQnOj7nlknV4edv7F4SdDt6V2ta
A+fbpR9Kgswhs1/3meJ8h9G2hzBr1uzRRRdkkr+g2UN4TvWdvEcojpcyfkmE
tGdGcwVpOL6bxyMRWm8biBorwfVz534kwIRWyuiFERyn/hyOh8eFVP0dl/B+
btdAPCQFNh3Npq9H8cc1aXFwSbHaZftxZPn4YtVYeLHpGUu3Zz3+PF2H4XCc
/3DF32hkOl476TDoQki7Lp6NbeZWHAKfXkjIS6Bii/yKDIIbDQTFa7wNyNxu
Ad4wnu/3fIQ4tpKslQcU8XkQ06CMLb6m7QYNZO+P8d/DvqKr6gBf1l53m2vA
jjUe1IOqPEO83H3/d0S1Ihzz0G1Rn8Wmm2vYDpxGum2917HnQ18og53nLrG+
YIH481vtqwcyU1orJwSwaRqCN8DZtQs390ph0/3lMwddhnVblDSw1acnrIBF
1dkCl1vYmsO6tmCds0wn1xk73NjJDsS6nfg5FIIdMHfOHggP5qXvTMOeIvQ5
gIYzQsrnS7BnEoYcgf7DJx/tWrFjF/OdwMdvPHEZw9jZ6hedAUE/SYq2iD15
r9gZ7C/fO05P34i8m3PUGdyI3NCf5sT++rPdGWRZzlDbRbE939xxBnOyvYr5
ithnXzc7AdF9NTURRtg1u7scgdNSlvj9+9jxxYEOoKot8rlOEHZBbvc98Dvd
7eDpR9jHlWZsgaKb6cN9JdhkVzUrEHpZnXmtDVtzx4dboFtYMnD0LfaARYUe
YPvHt16/ik068UUKFH0KrO7dQkJ2z6nQgj1Da19JLNhli6vmcLXl3skybuzf
2TH3IEfJ1J1sIewfUpuDPptmmJt4EruWa787NA7teh8sg91oyecNvV0U+B6o
YPsz1/vBDNNKIxsd7HN0Xv6wSfO/ROPryAQi11wAnJbO7FW3xrbsEAyC24/s
Y5J1xGYJPhUMj+0NVz3hjdc3dXIQoeafv/4HQ3C8ancXEd5fcG7YE4/jJzqN
Q2Dcm/k1unQcN3FpDIHlTTclvzzH8ZCQvyFwsLjP/kMZjk95coXCX6kXCwca
sIvaWUIhL7F+to2M8wU+TIVA4CQhUNWP7aOWFALNTHJv5o3j/PX7x0NgkPqB
1NQF7MGeTCLMPRs7EP4NW2NyPRh2Cmxj9f6H1ycfkAmGiyyeGvd2NeHnZe1W
EGTZWCaa7MNOX7kXCCXmLJq1+Zvw3ztPqwDo1qh17tRZHG88up8AUwubXQQV
sOdc83xgfbJUCYcmtkIgvRekdzh89KcZdg7HDVcYyf+doz4K2w3uMocvmO/o
FKdgr4gIGcLXa+MRGdnYRv+4lCHnazKDfw22DtVaBzz1T1tRmcHO3qLiCFrv
7RWVWsEWqvRyAbPGxNsiG9iynjkPgOgph/Fde5vx96kryQdcPjjD/fsAdvHM
VQJw3HXNYEkYO6aa5A8qp5S6emWb8ffVt9tBYFDNfzXqIo6nvE3b/H39AnJq
6mL/q28kAs59v8/vuonzhc70hgApr3Nm5Ns4vnWyMxQYvXcjEp1wPMn4RRhw
v1heqOyDPSjntfk+UrxKYwjF+SSRk5vvM+wnf5DicVyjkhwBhj3sDvil47hL
gGokWJvIl5fLw5Y89jwScKnOWW2UYQerLkQC6SKhiJoGbHM3pihgxGZe8oCM
67XqM0cBd/cnb870Yz/3+RgJUsbH1r++w94WlRMJapR5+MvmsYcOnosEowWG
Kg5fsbl7cyPAOuvDO2J//1/v3GI44HnQF7PI2ILcv74jHMi821NRwN6C7//F
Wii4pqQ1anMQe/vK5u9Tz/zwf8LHsA/e0COCR3vIQjOnsQOja4NAres29WyA
650UXA0Ao28V7c0u4Thf5XcCWFcgJB7Sx45sj/IBPHkNNe9MsDWj2t3BeZaN
8ce22HZr8Zt/D12kt15zwW72m7wLvEddj3H5YRPu378F6nNXnBMTsRNToR4c
YxZL1X2CfbxSxwr+droLWQuwvwWN20PekbwPPeXYL6Q7XKDchVnGqEbsXu7T
HtDkmaCYBgX7Z9MZH+jLZKa38w320+22BJjhmOHeMYE9c3dbAIRDb9ODP2IP
+joGwnE57hal79j+xS+C4N/sq/P0dK3482kFN38P7UrcTdqFTJDhzCJC4PD6
lO8+HLcSvR4CTQZZjGT5cZzA+SkE+spq+qwfx/FURb1QmJEVllV9BhsefBgK
Gxk7Otzkcf4GV1konLy/dUlSA9v0SWEopHujwPbVAOevHwoMhfzn/aRKTbHf
MMqEQvmn9Tfs72LTkV+HQNMd6/4n3LDDqBohkHBP6vknAq7n7b/5ezKz36Ur
PwJ73nAxGJLOla3eTsIerd8XDCeffOYUfvr//Q8eDYJ020/IThdih3w8HAgV
+p4TTZuwVzxHCNBceqbwYBfe79HZU34wIEPg9dgg9raGGG/YfCf9gPEiti7T
qht8tXD3rskP7GZ5MReYYyNTZ0HXhlw6a+gIg62Hrt3nwM5K/WoN1cz3PgqU
xTbdMykCzr2fWAhV/b+1jmuD46YvzkXrYCsrsd0AzCYaIymW2E6ZHndAr3Ew
14tI7F2ceh6ANKxn8yoJm3BF2huUGApUV2di3/rF5AfiDRoNW8qxqVkyASBw
IOo5GSIT2gQCA4GL3o2f3WQcj5eEQeDqlV9Jw2PYF2w3f59dpHXMvpvF+cvn
2EOBtHbS2Q8rOL57jTkMiPRYEufXsQM8v4YBbq3Tg0tb25HPpLSFg11d9MJf
WbB3iwRsft7Vaa5rXMiEVTqRSPCpM6PtjwCOU35VRIIxtXv7tpzA9l04HgW6
O85bMUphf8sNjgJQdVfFbgVs9p1tUeBF2/BWdg3s1tm5KPBE+bk+lwH2IudS
FIhtcc3hu4X3c3HojwIEReVvArY4rkRJjQKOTWzKIs7Y8hsgCpjLv0844YOt
O9oUCfQaX344FYJtBg5HAmXge1o6Dlv/7/UIINmgGSj3GNdnW3UIB0dkD/Qr
PsMOWDIJA5x1CwJqL3F+FEUoFGyXqXbSqsHmutVEBD+ric26LdjMAaeDwbyU
AZtRN16vvcszEIxUCprfHMLu7EnwB5QzX0rN3+P8Fs1/vqC2nERv8wn7X6+7
Jyg8HXPl3ndsjjdxriCt7OZTp3/YfTvVHECkhOjqg50deD/pU1bg/snO2AA+
7JJb3bLw1ovkyZCj2Bzsx02gzglr8SgJ7B9pTbZQoUiSEH8eew9nnyM89d8W
WrIKthM0dYOCBa8PpWtjPzwe4wk5jmXaZxlj2zbc8oVb8+43PrfA/mz3kQC/
C8vtKb6HTHB2dA+AYEqxI9wd22r/z0BITFfzswnE9tZQDoY9RpelVKOxTyWY
ESEnh/5nwVTsrS46m3+veo2f0+fg+ved2UJhbvitWxMvcPwjZ34oXFax2t9Q
g+PfP+wLg2fp7/Y+asVmMr0WBn3rHULce3H+c1b3MNj+wO3C1VEcV/VyCIMs
p71/np7BcfMjKmHQcNn/5d4VbPfEn6EwMz/k9ud1nL/1clgonLeMOtS9jYzi
/kMbIVCcP2GogJWMv08qN/t1f5sSE3oA+4JDGBGSkjIuWgtjPwh/HgwZdXP+
KUng9THhRUFQZ3dB1WFZHN/6IzUQppJf2v9TxdbRdQyAU4EVR99dwfkrQpL+
8PiFuonaGzhOmu3wg7UV7dpuTtjnTx/2hAyOXTv0fbDb1vgfQHXRvkaJUOye
99td4NusdyeX0rEtEwXuwt8x3/ZYdmLTiZVOyylrrHcoDGA78AtogsjtdIRD
E9jir/9eB3w+TCuj37A9l9/dBdbSe/Oq/2H/e3XDEbz4ymmatKsTuaCz0QWA
OwK0K/zYb/uNvQDxiEjoyf+wHcvCfUHP5An53WeRCYy3+gjAxPBcCVkDx9W4
WgNBLtsFm9yr2CTSkWCw3K3MH2SG3bPgSgR+yjqxFx7g9XXP34YC8j8DNb4A
HM+RWA4DrHXX6TYicfyU8EI4MHIzqx5OxvGlf5QIkClx26EyC/vqufhIML9o
J5JYjP1VUy4KiOc5TTpWY1+soGy+H1m4p2i34HqDi9LRgHTQV+dED7bwfWI0
YBwNZGQawa59VRoNdB6GkeY/YO+XrokGKTox7u3L2CTXx9HgPdND8ZxfuP75
uavR4HjHo3n/rRQU37XjYxRwCsjMvLUHu0xbLwrUyuUayfFgV5+PiwQMvwpZ
DxxBpnuqkhUBDnQrfr1wEscvXU0NB5JPR95YnsPx8mrrMKDp6lAdpoT97+TO
UGB1acfjF1o4X9nPjwh8+TJ8+g1xPMuWHASSViVN18ywJcumAsDLNqoinx3O
5+TtJgByqvkRRTccpw4w+4D3937tuE3A9ibxuG++j8V+jAjHdvNvcgLsnEe7
SxKxF8//sQWiHxtevsnAJjuA60AF6sev52ETJOh3ApP4Ty6HXmFb8EX7Qzfr
AEPlBrz/4rWEOBgjwy1j24FMsqjkfQTzWEp4o19jx32QeApJU6r/yt4iZz5O
lXwGv4S7tP7+jOOto8NFkOkW0/PD68grP4PlSqDQ6aww1a3UTfPff/u3FF59
23s5lgvZlPGDbgW0f2ktUSGArHNqfqYShgb+YR8VRS5Ro9lWw5r//hsRVECW
V/2sXAf7/jXVqWkgE057pNXDj/1GGfcMkElckTMNkNebaFFli9ff9RAmwTM6
fKpjzrj+264KErwsVC5C74s83CUFmqBf1/sl9Xhk9/PPZZphSqY7zT4NOfT8
mxfNsMRlz6vEXNxvyz3eFjjFK+c+Xoss4iAx3QI3VvqvbWlDZuUiglbI0XZH
TqQXOUUrJb4Vnkil59caQRbv855shar3UhicPiDb3FYTaYO3FE7OJC3h/Xr2
3GmD7vvaO+p+4vzOuWdtMHbhRsEkfdemaVwzb9tgfsPXyG3M2L68zO2wOS7c
/jgncl591tl2OGp1WFebH3k4IfJ6O/x6rlrS5Th227JnO2Rm0d6fKonMyjGe
2A6PTM38agDY8vb57RBUeo9NqSGLM1VVt0PDcPbGHXrIa2cpze3QwaTgqehN
5Mmgho52GHZKIejKbWSjymebzto+bO3miPeLTN7Mrx29f+mxF3bn8816/S+2
iZKCcf9inzb3WwxIY5mJwfv5uCW1w62Gp1d3PkImuJn4tkO+/yj9YjnI/GNV
Zu3w7D/TSr0XyCn2yfLtUFOLFKBSjeOZIwfaocXjQ9pSzcg2Aj++tEHPBd8D
x7qwg+jaN+cpNT7HM4gsrc/8sA3mBsuVM08ikw6dMG2D9f1phL8LeB6ubkfb
4IL9de6pP9jfaQWtkA7WzvTv6N509fmdt1shJzNPWdteZGnl6kOtUDFvWD3/
CHJKH5nYAtMmDbwdtJCN7g2daIZlYhVq5obImeoLvU2Q7M2xT98MmWzMYt8E
v3P1F0u54voqkzmbz+sVnYm/acim1VHvGyB9s7pi1CJybLjbmUrIxVrA4vcD
x7MMxCqgmMnOtw50PWge412C5fDaeoezPgdypgT/tjJYfkrl2QFZZLpSRY1C
aJ19gbEgApmQy0UfD7uCJHvaj/eiefAo5xQBmT1UhrgzyPITJ4++BHmpZlLX
5ZH519X7S0Dgi+jMzwbIOpWZmq+AzPC8E5c/Mo0l8XA1yDP3ez4Vgcz6wFu7
BnAu7RsrSsL1LNk8a8EqvZKKQhGOb/i21oO8/9L33xlCzjzplEgCnJWnNSWn
kCe5zA40gSB5CuHvIjL5y/iTJlBSsOFyiZ6G+o0RfNoM5j6rxrzYjmxkUs3X
Ag6eic9nZ8ZxSffkFhDRKDL+jhOZkXVfQCto3uqypsiL7M5P+tIK1i41suUd
Rh7WPmXaBqwHDC46iSITBBgl2kE691OzIQlk09fnEtvBgMmil6wUsnRlz9d2
oLgQULJdEVnnHHzeATzEeih3L+L9PsxudIASZ+4Zmiby2giLJhnMVVv+O6OL
9xPkSyGDg39fcj82RHZoX5sgAwOljdN0N5EzO0IFO0FkqOplK3Nk/hPl5p2g
uTvOhnIbueS3WXon+MX2LuDkPRyX9ejvBOJGIumJTri/1cmtFGCd7lz16wEy
+TBBggLSp+BrEx/k2H45YwoYOLprsSUA989M700BTPcMth8LRZ5/XZJKAYpl
mfzRUcisxyXLKMDj5yeZr/F4PY9TGwWUyEoZGKXg/fKv9FPAnH+AfUM63u9t
zVsKONjRHSaQjddXx41TgAEzd05IHjJNibQZj7xiCReL8TyCRDfXtyS9HL7y
Cu9PaGilgPW3618qq3G+3LUSCpA4rLqbF+L7blp4SAE21nFH/Vtw/3v1XCng
SeGYwiwZ2ea0z2UKGFw5ekOjB9/3Ce3DFLD7rLNbST+y2raSpU6g7AVj943g
eZOIrzqBF2lnoec4jlvVOnWCsm0GbRMfkLl+SfzXCebVMyeUF5Cr/QfGyOBQ
7Kdf+cv4vreFhZABNPPLL/uKTFeRJkEGJqfZjevW8Lx6fd50gLRBmeouhtfo
PNyGuzrA+bye2292IBuVCz9uB6Me5vvHmZEZY5yOtAMuvnC3z5zImaMnhNtA
1TKf8NoBZNNKl7RWcJVU+obuMPLK81mmVvDQYkSS7T9k+az1N81A8sy9aR5x
5OF9LuLNYGA7faLgGZzv0hHYBNgKRL5KXsD7Uws4SKDUqz5LThmZ7rpQDgQ6
Wjq6qpfw/k+3sjaAmJUHpYZ6yDpmhrU1QKyZyczUCJm1xH2tCvQkPGG1vYlM
EN15tBIwS3XYe97G5zV+o18GChmvHwq0w+snG/VKgProck+EIzLJbzmoCIT6
cIqle+H97+q/ywbbWq0WG2OwQ4/b3QI5D389Jifi+uKl6QSofDtK43UqXm9D
sYqHAbsqCqay8Xwky95lwcNjatc+5SFPvnvl8xySisd2fivG53kRu14I/+ps
td1WjfNdDqiWwXSBFC6WBjyf1UGdcij77T8yZzNybGKxeiX0StY7KtKFzzNq
zFwL195lzahPYpedtSbB5JdnH+rNILsHmh5vgmf9Kco3PiKLuLfNNkFXoS/Z
974hpyQlq7VAjh/Bem6/kKuFxJdbYHkH9xa/v7i/J9ciW+GXOwrmsYx96PMk
VF/WBuNk3+xN3Y1smnDwfDsUZ7FtesqGHFtlW98Oeyd+OxTsRw5VenW2A94v
jeV/xYtMWGAt6IC7A4VodYeRM6+ncJJhkX61X6swMr/mLW8y/PRzYvyNOPKk
A4NkJ6y8HdOsfhbvL5cV2QkJQyC38TzeT6LuXSfUuLgcJqmAbLRsc5QCOavS
7+WrIrNydthS4HthrSsHNZFp6qs5FFiU9Fsy4QruR2zLCAU+2F7ExWiILGLB
tZ0KFd2u//a+gfcL1xSlwt2zuyZXzZAdLtZpUOGwQW2L9W2cf55gSYXZbbbP
39rh+juq3Kjw/hnuCB0nfH5trwAqPPeMfL/tAbJO+XwIFW7d564r44PMNcyz
6d6go2dfBiCv3DhBoMJH3wa5hUJxvenzzlRoZUn8kxKF+9lrbkqF4gNn3u9O
wPHguotUuKE00xqQgtdPWRyjwvZXiXk/0/E8qW7bqDBOUDnSLhvZZnLPGAXe
SPhq/z4PebhVvZgChbdk6119ge+TR8mDAleddKWor5DpAjnkKbB+iv6AfA3e
P3OUngKJuqV/yyFy3r5S2Al5T7G2Z3Qir0X+OdYJ55425rP34vvoLxgmw7K9
9lGhA3i/tcEAMlRb7dZ3mkB2t+WhdEB2Mx/puWnklDWb2x1wnCbKe+Mjvv/l
HLoO6FIS8UHlO55Xqt7RdvjE/pITN1M/Ok9anForvDOxZhDNiqzGd4XcAiW1
885t4USO3fdWuQVSxHbQL/Ejk7/WSzbDH0utMaSzyJkXvGcaYdNNF+czssjy
wi+qIIzsFjQsUEAmHDgZ3AAFigMOJmoisypusNVBLTv54tvmyLTPHf8qYM7H
OgpLNDJ/Nm96LryfrC14JwHXe7d7MRtKKX/wakvpx38vH0k/hZT0XSe8s3H9
43opyXBVxzhmoRqZrpy49yYEVT/0Wj9gB3C/yAGMluFFhxZwvXUb/eegj/Xg
Nq9lvF9iwo98YHVHpVLiF46/HRJ9CSL5ErmesAyg+SkPFpSDkUCJdx7nkPld
Ag5CkCXeduYNQJaPoJNuBHbvjKLFlZFDO9mFSYBOinBh7jIyIbdXoglQPrCn
KOojx1YovWoCCbHPV9KNkdfysiWagfDHnqf6lv83FGoBK0nm6y9tcf5dldQW
UKv0Q5fJHtfz1d7VCrTS+bY2eyDn0Qe/bwWc6qU3+PyQaUe9L7aByR/KFe5B
yKa7ovPbgIuOnfXJGGSSQ6pZOwB//sHwRNxvgUlVO9hRkLB/NhWZzDzI2AFo
V486KDzB651mDDrAoy115LQcZIdKp4wOYFly+fBaPvLKK4upDiB2c8pD7yXy
sErGYTJY2+nW96IcWfwi4w0yaKrc+d+uWny++JA4Mgi3SA+0akSW3srQTAb6
rBJjpFa83vXm0ub7VEOrJC8F5zf7sW9+X9saRT3oxedvvyy5+X3OuTjTN4B9
vUR78/u+xQ+IjeL8G+FWm+8DDuzJYRPI88+aXTsBC9/zz9PT+L72XiB0Avmr
ge8+LCDb1LUGdQKnmFvUqWV8382HN51DPl/z/iue7xd5304wSM/1fHIN97dv
t3MnYDz/LXHiD17/02HzfU7GhRYwzvAGfV7NDTU7gV1xkcO7HcjVhwvFO0HG
bKjJGDOyO53hnk5AO2Sl+XYvcl6nyjwZMBgryIxyIkurmdeRgWQ8n8jIAWS1
i8mhZGBN/bVvmB+ZHNerTQYpWwe3DB1BJn35zkoGFLmy1TfHkUXOfKdu3kfJ
ne5+SeTY8GMnO4Dpgmpd3zm8/2nJoXYQLyCY/xogryw0u7eD1uv/kmhK2O4k
9nbwI/FtUK8azi/cn9cGRHqqnHq0cD3NV2fawLUdiabdurjfo771rQB6aMpS
b+B+KzQrNp/fMpHjFDPc398jR1uAwOJWrk5r3H/xSFwzIJo0fG13wHEbrytN
oDo59X2bK57Hrgu5JPCR5trb6on382adawRaSmKFzUHIdLuLl+uBr/eu1KYw
ZB1z8+t1oKRilkiKRmY97VFdAzhEnpjDFFw/47BSJVA189JpSEcusTJxKAfu
jwxBfRZeT6cXVQbGmFl5aotw/h6X/4oBi+rijppSZH7Fl/T5QN6P/L2qEsep
2ytzQM4q4XUFCVvE3j4Z2A2uhpYOIBOCttyLhRl7etxKRnCcciflEaSpFVi+
HMf9j/rKZkHJOnP54nnkzEy5F5u/574BsaIlbHZJrhKYcuIAb+EXZHGXSxfL
4O8n/T/zfuP7aTrmUAnFRl7OPKcfRJ/PS9p3qqEpW2R/7nZkksBxvVrYGqT8
MocVeeVf+WoDjLStsM4UQhb5GHa6GX6ULw5lOo5M56X3pxle5HpW4HYS2b2F
3NACGToSlzVlcD2O44Jt0DQjkrX6At7voza5DULXoFOCKsisex9atkMPIRe3
X9rI8p9WAjrg4MbdFEsDXO+uwjYylOy3qO29hmw0KORHhvEF18dkTHE/bNUr
ZLjir/f3mRWy2jaua53wsrEG/967OJ5kVtcJC8WVFL0dkLkKSzkokJHxvOWc
K7LD8SPWFGg9cYqo64Vcsj78kgJbK4/nNRCQGRk+rlKgQLQARYSIvCbsuvk+
QrDiWUyIQB7WTr5Fhe9k2Vj+xeJ5WNyLoEIZjl3id5JwXJWjhApTPtHrvnmM
XP0+r5sKfzT/cpZ/ivN51KapUP/R6sPCXNzfIMs3KixzXKjiLELW+c39hwr3
XHo/4l+K5+VM/EeFdvwjG4uVuF9+xw0qpPyk8RnVI2d++rFChSK95AstTcj8
tZKTVEjMJZmJdSDnOV3spMJpn+rA1C7klA2NIipUMCh5trUPWfr8rTAqzBDN
67AfwvtxZWy+7/zekrkwOob7cT9yigqvvU1mUp1CtlFk+0uB1WUxJ0rnkGk3
/Fs33//CQ7R5l/D9F8cEU6CzmZ9jyBe8/4FrChQoxmpfcfMP8vxcUn4njJyz
HiIzDKHnjU3paif8CE1+nWZEdvh28C8ZPrt3WW4XO7Kay8gFMmRQUb3lyoVs
OrE60gFNeYH/JB+yzaNi+w7ISz3RVimCXJ0aEN0OPbOOzB0WQyYXvNnfDoc8
+HZGnUaWfnYhvQ3Gi+zWsgDIk5+paa1wJ3FxYI8+sjvLZ8fN9xX5wmkbP+SS
HboH6mB9zqfHD4KQ+cdvT9XAAEZRPWIYMqGx91k1ZKEVNWUnIItnXRGohMK3
XmSMP8f5cwo/S+BVn1IjfRoyyf31XArkfb+6x+INsrwN1SEBTimf6nAcxfX+
PFqKgPeZX52JmUamY3g9exsSH5ezUdbw+v5r6/Ggoqaq68LhYTSPeSjyEnjy
rQVeFkaetFibKwHy/tLnb/6HrX7rXBnoUqvJ9zyDzPpvdKAcTA/VEisuIWfS
Wy/UgILzG3Ktl5Fji9WF64DDk/Pf+/SQxa8E36oHv63rLVZuIusQ5Nsh4PjR
IP+fE3LehTcvm8Co8d+f5x4g01x3yzWDzAbwUs0bmT+vvKMZiAY38lkTkR3o
vwy0AGWOpvXMR8gpIUldbWCXO33ZyyfIjJnliu2A9lbBFuYgr5UHV7SDG9nN
Q29fIKsNTMV2AIEdW2I+vkIuGb/wqwPM31FS/VWNXD2zepMMXE61lnO24PoL
Pw50AmtJ/sw4Mp5X8i3vTmB01juCuQf3w7ZzuBOoSw+7hfTjebm8EaOA8zKS
5gwjyMPDuQQKEJWN1fIZRyYY3eqmgINgUXrtA+5v93sOKmCVVxNyXsD12FkM
qYBBMWfP8jKOB5ATqOCbEt2GzTdcz+0LhQpmVG7MfviF57Pz/m8qGLxY/drk
H/KKHp9IFyBf4mgY2TqCnkfHKa0uUKvhkKe/C5ns9eReFyjS6kro3YMsHnU2
pAtkaIv4qe9DzmsMe9QFYq4E3WnjQXY44fW8CxD0Jg3k+XF8ZbG4CzgZyCrU
HcH1BZs2bWmYInr2P+S1iZHcLnDV+Nv+UnFkI3nu1C6gdl1ni+hZ5GoTs6Au
cO5m0XLueWQdg0SbLnD8FuPoYQVkfpCo0gV4zSzb0lTx/qeVDnQBFgtSyX5N
XE87cIEK6Kx40+KvINMVnS2hgi/W7iG7DZEJFhfsqeCDzYBT6A1k1lg/YSoY
uCNussUcmaYx8oYC2u0iL/neRp4sEfOhgOr785K/7JBtRsx4KaDAQZnfxQk5
dkL/VSdIc8pk+vwA9/NuQaETRLn8/mHrgyy/xEAmA183o6npAGSuYwEqZODg
Xt59KxRZpPBSbQcw92StGY3C9aLOC3cAfW+7HIMEXO/jubB2IEUQ8tLIwPW8
p09vvv8EEKzbs/F8Z/S9WgFP0NgVhXxkksS1mhbwNyRRRKoc1x8r5GoGK2Er
7GU1yKH36881gfcRmv9EG7E1P+qQQGvM1kEBCq6fp9lcDyrjTJvSe5FXLFZf
1YK8hPoirjd4/qHvY6tBRLJLIMsknt/bcqZyoPtkWnz9O3Jmu8yfbKD8VJ7X
dQP3c1eTNR2cyU7bsUI3iubvOkSNA1zP9cdnmJDp7A5uc4cTL1ojXh9Gnnz6
SaYA0pa2Lp46imza4ur5EpJEVTQTRXE+5YlqGcwsaGM2lEIW/y6zvwrGLmy7
Vy2L6x/+aFID/UVUu7kVkWlrx+PqoHlue9SYJq7npVfZCHVnti/L6SJzMY4O
kKCS0MXLTwyRY/dqtjZBoawOFnNzXF9jOagFcrzfYd9yG3vl2tVWuI1frVfo
HjJZjuFgG5xNJ8fMPcD713vEtsPBMcYVNR9kG3Pi+Q7YceCSTkEArv9I9V0H
rL4WVsIUiqz2ZNiVDPNSO1nvRSEzFl7b1glThnc69sQjS699jOiEYfvVX59M
wfs3Pd9JgXceUuK+ZCGLlBz6RIHXBnZ90ctDXlHfr02FGuwauhXF+Hwa5QVU
KKsbUcb5CvsTx18qFI2jsrlX4/2tDC91QV4ak/NIA57vt9TILsi8R7NfpgW5
+vV6Rxf8rRV5Oo2M70c6ZaMLLkV2JfzpRiZZxB7thuNU5m8m/XjekfSa3bBn
l5Y+aRjZYXmnbTeEl6LKD4/j+i0dvt3wRWg3R+AHbBXjqG6Y0bHbdXoe7/di
LLEbxmy//EZlGTlFxuFhNySoRJ95/hXPR/BUTDd0COp5yPgLzzdLPqAbmraw
/LD9i8z/teZ+N7zCoH2VuuUtWq9dr98NFRViKkV3Ikt/sZLshqcIvZzRLMg2
+97s7oYCjXsefGZHdv969H0XZP+rPaTDjTzf7v2iC26Vi5UqO4jMSll17YLf
vGjJ7ELIOlLPpLrgdC3rmssxZK5LFV+p8M0vHaNBMeThc/Kb86988Jor9Rxy
7NMLO6gwt3KvxzpAdohaKabA5O9XRq4rI5MVHmpToLtzX+pBbZy/dCqoE9qU
sa376eO4sc3+Tmi8qnvtvTEyv/uuXDKUse/nybFELinfXdkBN+4MPD7miWwU
a5LTBvXP3owT88P5a0uH2mAR/SzxdBAyrUg3pRWapPx0lIvG8xD569cCm9p4
1K5k4f0fRZ5ogiH8Zt/cKTj/M71YNWQfXNIk84yh+4sjTHlAu6duit2HsPNO
jirDVrt/Un1C2LcOvXQBblv2Co6JIcuLXaLFghFxyV+fFZFJfkS6HPAkwvPZ
/rvIDhLOBhVg7eqWx7wOyJlX91RWAh2ByNjDrsiTnV3s1YChJt3rPz9kgtJc
Wy2wmiVduZCA6x+S/dcI/lPY8de6DjlWrKa7FZQUFB4dJiHzL9263QYkOXSu
XGrH+X3EP21Adi4l57/XyIxfhg52AJKOXE/aIHJKekt+B1Cpff9z9xiud6VM
nAwuRx3XWJnFLj9wqhP0/ehxMVtEDh0wLOoEhqbOGX2ryNXj3AIUYHq6frX8
N3ZC2T8KmE4zPSDM8A49by/Vb1OB7fZtKsk7kHWSP3VSgdOIVooHG7JIMcWv
C/xQ/NL0cT8yvyalrwt4FSV9us6HzJhqwN8N6DjP7+sWQDbS1LLpBkF+EwCI
IIcejC/oBowLgTYvTyCzkrfOdYMoXZF4/tPINvREvh7AVt9VFyeN44E/tHpA
0hHHGQaA49uk3HsAT8y+PS5KyGvyImk94MlajfSMGu5vuaCmBwiZm5hfvYz3
a3tC6wF5VIbIDj1kB7+5yR4geuZ5hbQxrjdg/rEHlGRoTOSbIK94f1nsAZKM
K4wHLHH/Eg/me0CNY+KpSFtk+YLXYz0AvJW+8ec+7i9zqrMHNCu/C77vgixN
DX/ZA1Rf+L+c8MCeLojqAZT9wiM6fsiEbEHLHnDZn8LQHITd9OZUD+j/eF/0
dDgy+cfTX93ASJ/9ak4McsmGTXU3GGuo8tv3EJkUymTfDUyP3sgnPsL9X73D
1w1mYun6fz7B98Fn3dIF7qzn/LZ5hs/7cMK0CyxbXBIeLcD1HlR937zP7iVt
jRJkU+8efyr4eTbeo74Cme7Gtm2b7yu73nZlkJAnowxWOkGQs9+PPe34fq+I
G3WCne8E+f2peF604koyYCuxc7YYxPcxz27YAZK496YPvMVebUhpBwcCK9pV
3iPnpUbR2oDQ1b/cIovImbn8Aq0grzFLKXUVed772fkWcOLYxXu7fuL8/j71
ZnD2dwxpkX4cnXc6/xIJXMw6fLt0PzIroS6iCkimsAi38yLzpx6XqwD80RvT
o4eRTeXej5aBdY835ltFkQm/ysoLQfGVMBNDeWQ608OHQsCji258dirYk+bs
JyBRzmKMoI7z2xj+hELTY3LXCvRxvRODf55CdvpVgz82eL+QhapXkO7nOw62
+8iZ9HPilXBxkdIv7Iw8+XTLw2rYPpxzRccHOXbZ+VADfNUTx2oVgLxyW1K1
EWa2+vZ6hCDn0dyKSNCjxEgrOw6Z62fc02ZonavCXJ2EbDRHjGqBummnqF2P
kUu2zti3QtFQ5ks/nuF+Ey5xtUNu3187mAqRU+4Sx9vhdpfZ9kMlOF8u9XEH
nLhFUr5UiyyfXrxOhl0GxVtMGpGl42bSOmG1xqNmp1ZkHU3TsxT4TCHEP6QT
mUR/roMC46Vc5NN6kOenwze/3/1OmP0r6cfnEXHs3fz9LngZtg3j/ul3XOyC
KntEZD9PITOef8G3+X23bd/GlnlktS0/vLvhwQ36Wq4l3J/otYFuyLS67H7i
C57nx++CPXBt9q2U4k/cr8P03R44M0b+cfU3nu+KfFEP7OurqLhLP4H+nj0R
numBkJzlQtiOzFpSwtkLC2HM6YdMyOIG6/K9MKXc+0s+K7JO80HLXhhUYFsK
9yGTjp8j9ELHzKsO/Ty4XpPlw15okqR0cv4QskNtfXYv1IgUX/4thCyvdqOw
F0oH8BXvPY5smmFS1AuF3HfZCZ9E5loZz+2Fe+//PH5eEjnTYe1RL/xrMb2g
fQ5ZTa89tBd+NH6dZwlwPaqFQy8c0oa3PZSQh5kWr/TCVpVC4Wg1ZCM1zxO9
sPR8ykyWFvLaq2NbemGGRHBOlS62/77+Hhh+1MmiyxDvN2OU3gMf8N0SeH8D
WZptj3kPNNcRvzpmhkybeybQAy8H0ocPWU/g70+e8W4ovJC92u2A5zO1RbUb
svG6Hul0RSZ0FX7pgn8uqxq3euLzsqQ86oID5fOk2iDkUL6cMSokzdV8qwjD
/Yv+dKPCQp4IkdJofB9c35mpMIBwIvZ5Cj7/diNRChTXdLqVWIT7mwg5T4a8
fkoJMaXI5Dv/KjrgjjKOjvBK5NjRZdEOOL6/SsyfhDz58TFrO4z8sPHn3gA+
793fpS1w3jM47eJvfL7ikNl6+PHqfzZP6SbR/iqeAXXQdIWd4dAW5JW2WJ5a
qCE4c4aHEZku6seFKigQFpLOyoZMuiNvVQpp+l12f45gj6TxPISiiwZMQ1rI
4pYOkq9Atb5mY7gOMuHgEK0cKDUoOgM9XF/s3J1KcC365NtnRsi08IX4GhAm
vrPQxQJZvr6vvBFwpP4zEbFGlh79nkICmfQ/2MZskPll1vWbQHXflKfSfWSH
prnWZjDrUq/O5oH7KW8itAGnd2V/27zw+n0eR9vBH5X8Mg9fZK74LEo74Nif
xPM+ENn0D3kbGWT6RfYkEpHXPILSyUB0PiBALQzZ6ORJiU6gVGP/8WU0cp5p
rwYF9By2zrCI+/88Avso4Fr4Dd39iXh9Z7b+5vfJ9Uu1vqnIw9m56l3gb8uF
+6fS8HmLLsIuECZ6VmA2A5/naJ9oN8j8IxCulYP7ieRf7wai1tyA/jk+37Zs
ox5Q1bPnS3k+ng9zZGkPUJTanmtThOc5V7u1F/Q8+W3M+xLZfYJFtxdcY/y6
m1aK70/mdmovmHVYaAosx/2D7NHezfeXCVepKjwfnte7aOCPwuCxTzW4funh
IzQQWtD1LqMeeXHHaVka4GBvidNtxP03fdOmgUyvGpXtzcguAVdNaUB0+uWv
mlbc/9LFezRQrZlbfK8Dny+32o0GlCrSzA5TkJV1UrxpoIcvYd+bLmTNmEFf
GrhGDOsM7UXu2m7hQwOzy34+sn04fu2EOw04GrpJrAwg65w4Yk8DvxvtZrKH
kO0EZcw3+xWxSDUcRRaZvH5ls984Yy2md8gcOzw3+3/yS5u+cQKf/3yQIA0c
N1etcJrCz+fhO9tpoJIiays8g6xWfZbSCxRPn+YbncPzObjHrxd0Pz72Ouoj
8mSd7H+9wGgrf7DCEj7vcEZPD5i24zz3/TMyuZbDtgc4vGFeyvuC+ynw2bzP
33Jbnt74jvdfqg7oBux7Vhhb1/F8ogQfdIG+hvCQS3/w81amuEQF8XZHtvf+
w/cZ9vUaFbBRrm0Z3foe9bP8hJcC+ty/+9/ageygae3QCeKPxtLN7EQO/aNX
t/n+Edz25zMLsukvmbMdoO+0qbfrXuQSjn9W7SB+an19nR15XpAQ2Qb2youv
beNGFmm83NACWDcefTkgiNdn3rnaCGj5ZxyfHkGWn1450ABijWifhUWQxRMv
dteCPZXbliROIPN7xn2pACyODnMXpfB648jAXNBziMm6+xyOgz+NmSC659m0
riwyabv704dgt+jb9zcVkOl+5zDdgcxzKmPOGjjuM2FaALseTl77pfX//GGW
Ehip7DXiq4Oc+Th3sAwyZZUMhhkgs64ZC1ZDio6GwR4jPB+rkrxaGP5vpj/x
GrLOXR2uBrjr5oHXT27h86jmvSVBClOl9hFzZLJw3NcmGF6r01NgiWzjwUrf
AndyEakVtng/HuU/rZDczq9+3g7PS1ZisQ2GutaRSfeRY12FX7dDxv6VNqoz
nvebRz5kSPaPUL7ihvfv1VXphKHiwi2D7sgpxKAtFLgj+jrpvQ++j/52Cyps
l/0BbhOQh2VZt3dB4qfYhsUAvN9OlSddcPul9tqfITjfcaqyG7b/ND3nE47v
433gmR5IzN2oYohCrjYOKOyBqgZJZ0NjkCeV17l64batEhW74/F9MDP6bn6f
llFPJyQir3GRRze//82sy7iS8f3dKdxPg8qs9BIZqchB+vNyNLi18fFLwTTc
/z8RUxoclVVWm8jAzyfdCIEGX9YuTj56iu/T8E8aDQZJP/S4moP75c4rp8Fr
lXJsbM+RB0w+ddCguORsQXc+cv35kUEa3F4WrRRWhOfZHvieBsdOSo0pv0SW
3PdnjgZLiydc6MqQc+QMP9Ig8b/Q3fXlyF0GOfM0eCNfPPdBFY47/5iiwVNH
R8DpWmTG4lsjNMj4zH9ouR6fd/8XKg2OCxx3KGjE56U01tLgq8w+RutmZNHR
0Wc0GHrQ6+nhNmTNmwZRNGiSJijzrgPP11bBkQYlebr6UijIRvtKr9DgzhSX
u/rdyLxulWKb9ffxbWWlIX97asFIg+UJbWnUPuS8mw8bemH43vtnQt4gq1lt
WPRC0xjOHsVhXJ/It7UXMkXc/lfzDj+P7cKneuAkI2uK6yR+vmWvkrphJbFa
XOIDzvfqU+uG5gE7zfPmcf1tipe6YLVHYWvSV/z8sH9hosDon3o3dX/gz9MT
b4dO+L+O6zweqi8KALhKWVIhIRRRQioVpegmSbIlFBWSJD/Zt1RkCakkSUJl
TxtCSJabLVSWsSbZ92XMzJsZiaSf8/78fu595557zr0z7130mp9eNUueV1Mv
Si1e7WawNWSBvA8jh2/V4Ev29DsePAOwvo96YRUWNNtzwkgSrOFQvFCCx1p/
jq6UJp1506wYlxoHB9RsBmeXpL79iO0N23KQApiSqHysAOOjV4W2q4CTpArS
s/AV5eIfPHpgDmFqnwsuo7RlFBqQZhydsUfrnBj+l43AAeXpnsHo04stsp9P
kX6w2jkWrRWJdA+wBkvRo0+9QcWztitnvMD8WSKDRYg/xr/nhQ+5vrfpvRJ0
aXd8jukNcr7YxZ0YrbnSaJYbQObLz8wrQxe79qc53QOHafpSKlGhj+lViQhy
f8UykVVo1ToX3W+RZLyTKfqf0QeDNIZcDLiQ8bS4Gq38tPrgUBLYNbHC6Quy
PifP/ygV/Crblv8ryp85Mng4nYzHX5f1FZ1XunYn8S35fPOFnm8or+6RhWEW
Gb9cz6UO8fyXtfNvNll/Efc/deh98mDb2QJyfPUkZwPiRguveD6S+avPBjYg
y05R38JisM940WwD4lprKC1cDu743tjRiCze2U9XVYLrjOmSFJSjd6vWoxqs
vjzciILOBRc6N30DszvKXlFQtlTL4YAGsE7ZXgoFLS+dEtrZBDby92Mv/n+f
4R7rbiHrPXtrXRN6Ny1dHN4Ojubfv6cJcUYdjFD7AR56dc+gCZ3ZYX5h4ieY
84WDbRPK+uquHNcDnh+tutqEll2+z6XTD+4zvXO7CZkve9X5a5CsX0P6oyaU
mViR+WIE7KjK96wJLVXvDjAdByt6vUpqQmYdMybLqOCxyw7JTSjDU3BrLg2c
x9JIaEJLBLbPWRPg2D9iT5rQ6cxj9WvY4Gc2o/ea0NvjNkn4F7hq5WPfJqSs
uAkdmgWbtwY7NCG8uu/npz9kfqjCtAkdIxKuaSyAPe0PqTUhSoulSDnHIPwe
O9M2LO63QCL/8DLSTuXzFDQQ+9O4Yjk4MujNdwq6ciOeockN9vz2NIuC2JZn
Iip5wVTb24EU5Kchqqi1CizheH6xPytkvn+pWgMWWlgnTkGRy2MuHxUEc7ge
qGxE68dMl1cLgfucGo41opSva1O1RcBSSnWVDUgxs1mjZj24gyGyrwEhdyPf
2o3gpNMKy+pRjekaseObyHxdP56rQ0b7Gj58kQGLum19+w3ZzOuxvsqB+QV3
7fiKJnt4H+ptA7vKPr7wBXmWf9lRtx0st/K/e7Xodugxh/rdZLwdRHk14v9v
BbehCpixmOBnFK/3+UXDPjJf/UlKFcrgP9LfqA7m3n/tQwWixCPzZm2wdeC7
NSXojN/faePj4ACV5KCPaOB8yaMWPXL83/feAsTefKCx1QhslL7XPAf5cc06
njIh53f0DGegFRMfeNtPkfP3bKSlo8g671enzcEa2iW1SWj9OxXt72fJerIf
TUSjlIfsQTNL0sXl8f5I0fN9YMd5Mt76O//u4PzT7pJnbMh4Ih2X0zHav6v0
hy2YEtG55D2uEWecPXuZrA/P7OsibLSQ9bvzP7Ie1MPC5dimUlG5y5nMlzVq
XYsnX0w2WbiRz9ODJ75hz7A3Lt0eZP8olAuN+LaB3NseH/D83C++FpzxXUa6
P4jsh9fnMz+wStHApwsh4GC+X+2dGD9Lthy4DY5u9NbrwpQLknGD4eR6Ki/E
evH0pBj/SAw4hjNLfgBHPx+teRYHdj98qWUA7zmR52/yDDzxSMdnELvlGtDL
ksl4Mx/fD2F+W7GXV9PAFcfO6Q7jd+tGrXa8JOuz7UTXMJ7yCWh4mgEO33aK
OYLDFQxCjd+R5y/0uvco3ta1HvHkkuePJfprFP936H2m9wdwgv/o6BgeXj4S
frICPNbcETOBgz/kanF/Bpdta52ZwDL/+c/jGvDcw8emk/hCnaijYj25f86H
S6iY4+awzGAjuO5Ez0kqTtyZ+zOuGewgK5pAxd1RenpcHeR9ZF1VmMK+WqLL
cCdYUD7HYQqL/xoq8uwGd13+mz6Fi17muG/rA9ucsOudwmfO3FQYGCDPu//0
Whr+zas3EDsMzojJ06LhJyUi8SfGwHYqmW40vNd56OSKSXDz3Fg8DbdJ5vCU
ToGdQ93KaNizya/cgwEuuGo0QMNrb+leU2CR8Z0fcNBxrrLIrv5pMOJRFafj
kyODY09+g33GTHbTMeNJdpLhH7K/b6lH6fjBcT/z5QtgTWLlaTre8ec4fwnH
EPy/nym2oeP6DOFa92Vg+2BORzp2tBr0l18BjuIn3Oh4JX/2vj5ucMPzu550
/Kbclx6zEhzxrdODjo97HH9psBp8ev+kCx2PbRY+zykATgr9bE/Ht9sHhIvX
gseMPazoWDbsXYObMPjNwQUjOv683zdUbj3YdsRFg45tJ3VQrzg4ktqkSMfL
nq/79XgjOIO+XZiOUwwHMvU3gfc+uD9Pw4c53l1athn8ymGul4b7cm5sKJIF
B2+6uVhP/4s6ba7yYGQinUDDpdX9Wj07wLovmEY0bOGTNR+9CxzNuVuWhv/I
38jTUwbnWhT+nsL77wtt/rgfbOFV9ngKd6D+ny7q4AHPU9ZT+Coj85HsIbDi
pJncFM43ObYsWgu8tOhbNhWH6RWGSBwDByQ886JiiyPy3C+Ok/HSjVSpeOme
lasKDMEVLoEfJrGhYKNwhzl4t3D/8wm8iVcjzvocmZ9muvEEZi/JER+3BLvv
ur98Aj8loqTmbMj56b2XxvEY5bSChBM4RdRdYAwX19ZkpLmQ/QuRKhzFEWWq
O7e7k/0z3Wk5ipWzxZTRVbCD3f2UERz4oOegdSDYNUxWfBiLGdqdTHtM9ksx
/Ws/njr6vUUxFsy7YsW5flx2UOd0fjxYw//IRB+2265wrjqRnJ/kvbwPv+ej
2Y69BnfF7jrfhfW/efkoYrKflvrvW7G/Tkhi3gjY+lNQdw5utrK3UBonzw+l
OvYt3uyltz5jEtx3RcozFX9NFniUygBzxKZuu4aF/jwPjZoj13/oE5CJXmUW
OLmuHob/qwudyTVorjJOgcoP7tBQSf+CDDp9Ry+vBeuIGb/+hpgrjlw4LwqW
Kz33thGpWzeaGkqD2VeK6lsQRXBMTXEvmDNkJuwnkpb/9vulKtiIrnu9C3kd
ysqXUQP7Wqx16EZijp47xTXAXRq1Wr3I9jOHDK8uWDEhyr0f/b66nnfMEqwv
bzMwhHQj5qsvWoObVx7SG0bP03pv9dqAa937coeRZtOLv+2XwWWGJjdHULjC
buKzG3hHlcLyMbSpW7cjNQQs26hYN4HuVqi9OxUGVqor2TyJmC8VQ7nugdtf
GdyYRBXuq5WvRJLPn9SXpiIF83+8Gx6Bf2m9dKeiRwcZ/Q2PweH23WVUZMvd
/GD3U3K/D/JPT6G6qQq7oefg6CKthCmk0vL+YEwSGf/SncEptCLh8eTsC3BQ
+KrLNOR8K7Ti7SuyfkoHXtDQd/urcZZvwbmpv/po6NWeM8fKs8FVerNGdMS/
Xnejx3uw5ivFEDq6tnBgenMBWGLL1wI6GhjcVtdeCD57unaYjnS/SKSGFYN5
xlbzMFBu1qrrBzB486O+DQwkFr1gRC0Dh3ib7mKgoGv0rQmV4N1dl44w0KRV
38KJatKr+U0ZyFSrqW3JF/Cd04YXGahEviLj/Tcw+ifuxkCb17y/dakBbGbs
6cdA4ezUsyJN4M444zAGYv+I3vWlBVwvmfuQgSw/hXDfaAer7IiIY6DqNO9e
xR9gsTUDiQy04+7lgp6fYH++12kMFONifj+yB+zo2vOSgf6ZHrfV7AePB/u9
ZiD7AwfU2IPg348CF02R3CaYPgJOHB1enK+6XGLcbBw89uXFYrykCb4yHirZ
n+CSxfW4KX9jimlgJ5sti/m45dOcnAhwUcbPSAbqjO/VkmSDizM7QxlIM4Ai
3vQLfO3dhhsM9OZSOTNoFjz/J9GJgQT1cr8oz4O1uy2sGOi6UmrSyALY+vkJ
AwYaXBd9NXbJCJyfUI8DDKT/J9hQlxMsMVC5hYHy+ry2zK8A18yprWEgiWq7
+UwecIFy1hQdhbw1aznPR3rdpo90RIvUeSOwBvxMsSaAjk577w+sFAC7rnqi
RUf4nIK5lxBYW/82Jx3JHhbfuVUELOsXUUZDMyv/dt2VAO9eXqJIQ9bE1Ht1
SbBncGPXFKpt77lL2wRmHG0Nm0KxyWWqxlvBVb33WqmI43bOGk4FsGrfNk8q
+s8xZSRfESzo8WQNFR3YFxy9fjdYMent/knUbrN+73Nl8G/afOME8ojI+i61
DzxGC7aZQBnDHWJy6mAdOzHfcbQxenvyXm1wNi04YBQVfarQLNIh9xuUPzOC
zCbNhg7qgV896HUYQZGaQVuPGoH5ri05OoyWEu2ZJmfBbK30mgGUIOF44rsF
OM2ybsMAUtNZQpw9D7b9kOXSjzwTtynb2IL5o+6s6EMjBgFFrs7gvkO3/v1Y
vC/rLNiuZP6zI5c6kOSLN3+veoClqnUq25H5fKuGvw/Yx+KLTQv69ka+5n4Q
2W+mjF0tsm/H9gIhYGtvj8QqxLnUlPfxbXAA+vq5DKEzNw2ehYM1TGVzc1A2
V0vLmxjSu1JvZWP9PfZeO+LASY+mdn/E41Z/hXOfgpXEOLrKsHTB1rMfk8j+
O2tLf8HRtr59NW9IJ78514qVIgWC9DLJftqOKrfj+uJ0mcZ3ZD4RGzg78Iq1
TXbteWQ++GPwT+xTvmVqCJP1SzrK3Y+Fpooi7MvJfrkV1PfjHFEjJWolWDT5
csQAnnC57sGqJftBz1gyhC02Ns4uaSHrsyU7ewSvXu+eX9wGrnM0sxrF5WvX
uXl1kPlfL1oxhmV5zo2NdYMpHL3HxnHHsoXUlD6wKVdB3zi+u5B03mIQvJnm
4TmB6ayR9sYxsP7VxvBJnEK7E3VnkswvPUiAik3HFQ2P0Mj+Nh17SMWFPe6f
C1jgsF17gqaww491ga6/yP2ynVlTeENrobrCLPl83eh5Gg76svD++QJ53jqK
FehYuSrZxWzJKJznOMU7dDyKtbYJcILL7iwfpGP9vLspwTzgkrv3tRh4IWu7
FeIDsxMKHBg4+zVl/e/VYE/z1xEMvC5R+OEVIXCMzhIKA9fGfdTfIgLuOuo2
xcDXoy24e9eDC7zKuAms+OBfZawE2FWNvYnAPXdS/I0lwVZzAvsJHBl8VI1P
Gty+TtKQwEf8x3593gzeTEhdIPCva/dy/beCE+gS7gR+5bnDeb8Cub6naCCB
z7o0ybMUyXiDohEEXuXgOZyxE6ydKBNH4DJbkWS73eCklSiFwO7niyykVMD4
ntNrAm8+aynauQ/8O+hDFoHbTTlaHx0Ax5puyiVw2InUBwYHyXpczH5PYDVd
bT0uDXI9IYdF07TGV5RrgmW/mOQQOOlQeMX1o2S+w+6ZBDY+sPOmsg5Yor7u
JYE5VZr303TBjAG7JAIX7PSafmkAdrir/YTA/ymI5lwwAvfIuoUTWGJLsaO4
CRlPnOpP4AZJK7m2U+D5byVuBA4QWzIUYQ7WeTq2WK8969ISdc6BO6ieRgQe
WXPs3FIr8JzM5YMEjuWdEC6xBi9Nq5IjsO7y+81eF8GalChBAv/9tzNipx2Y
j+/7HAPbTHstT70CDj30vZqBhRii5RbO4M6/z98wcM1Esa+wG3jBnBHOwIp9
S9h3vMG8HgYGDDz99f6AayC5f1mOG3TctbLNfv4Wef40S3fRcYW+BP12KDke
qjZCw5ENb/4k3AMrxSXo0LBCc41Q/WOwajybRcX8a9c8NY8F88dkx1HxjMnp
TUPxYM5xj4NUXNU2tP1PIjg4Y4//JLb6seSY/Buwvcl96jjWEjten5cBLsy5
dmscbzsXaaLxjuz3k/ei4/h310ZrszzyvgjuQWM4qk/tWggGyzme9h7B1aNe
b/ubyfX+/UwZwBlypbuc2sD6GaXSA/jRf5yFv7+DqYevJfdj68moqjXdZD4o
+WkfnqO96z44CuYwMOXqxjt/ja+J/0Puby7OtBXHclp5Gm8eg9/PDYLsJLxw
UUSlSRbMccP74QNsW0mZPiFPOu+/ChukFHTkqsEOcv6m+wapqPaf3HUdVbCU
ZmZ5MZqZY/kjfTB/TX1TI7I4m6lRagi2f1PC2YQqPtotUT8Jjv2eKtmMInx+
BO0/TVrD1rgVyf7CIcrW4N+GPa870Gnizj0FT7BygeSdPlRidET/tTc4+m3+
yn4knT3PJ3cNHLzS6H4/ojm7RGy5Cab+dr0/gEKopg+lwsDZvL4BQyhvVPKJ
8DNwrcANhTEkduyH2eMEcMCDq3FjKCA9SlQoGay0k71iHOlfWh4vkA7WqdDv
HkdDAxPP+LLB6oWPvCeRrmaa5b1ccFj1645JlJ1suZE3n4zX/FeVinytKYlc
RWDVJsSmorU9+SlLq8BdE+qmNBTB5+f3oRrcutYwi4Z41bTMHb+Q+Uv+W05H
S2ObV7U3kOMZwll0dLM6buxuE1hrrf0CHc2xrSsPtYJXR4vIMhDzJN3n9Q+w
gtCcCwM5BxSYWHWBM3xpUQw0keW3Y20veGlKWB4D9a/kG/IdAvdwx7EYyOJA
C941Ct5dyilAoA77+LiRcXK+0JLtBKJ8ljthRAcXRMRYE0ifTZdfzgQ7btni
Q6Ba6Q+cRWyyPlo7IwikdfJmr/MMOCbtXQqBPvkfLZKZAw/8S8on0IEsvscd
8+CgNQvVBCroanG5/w88El7eTqDdK5/qai4dPwTfryNDBMrab7NlhhMcVWBH
EEjBXp4jgwuc1XZwnkDpMYxOa16wgo7dciaS/vwhf90qsHdNJx8TPWfdjPy6
BvybL0aQiUSlta/4C4JFm6OEmSjaaJW28jqwBuWbKBPx+7dKjYuA28vU1jNR
eObTP8/FwFqW3SJMxN1l0268AfzL6q0QEwXzKuRwSYGN/JPWMBHHfuJeiTQY
X/3AzUQ3LhfauW0Bpy+Z/EegX4/9D8vKkfm1q0wTyL1KW+KnAjjyXdQYgWjM
VTMPtoOtted/EMhhU1uTlhIZ39TpC4FGTjzLmN0Nro3qKyCQzc2Lt7NUwErF
Rov17slQsLmoCmaEFt4j0JmfhLqoGtj1naAHgVp5PorUHwRL0c6YE8hINYAZ
qAG2mg9TI5DO49WvJo+CVZ3u/GGgqsq2oCQd8CtNow4G0mA+szylB9avH89l
oH0ntq39ZATuGfW/sPh95cec8jABx0y4qSx+v2R8rJU7DVYM28TFQLI8Ojej
zoG5WTrH6Chl35ozx6zI9QI6u2hoo137nnlrsMXqUicaEq60Hb9kB6b81g2c
Qsv9Ak33u4HtH9s4T6I8gjr7yQP8TEJ+dALZ2pknanuD+U2izk2gqhM7J0xu
kM/7KewbR8HS3f7OIWT+TwMLR5DyE50t07fBm52cVo2goZV5X2/cJetl+MFy
GGlN31135wG5Hl2TMYg4a1XfpsaBC28c7+pDeeppRgrPwGVxKiv7kG3Oml/Z
CeAOQ2+HHlQVP6KBU8E+t/rYneiWU3R7RyaYI3Tzwxa0dC1jyeoK8vy1H6pM
R7m3z72MriLH1zsrBiGb+Wp98RrSE4nuz3DF8PMncnXgpIbWgI84qFBv+5F2
8rysMljbgHdv/9D8pYPsb/SsSBMeSJb2MfoJDotRE2/BmvdmKyz7yPz3dnB8
x0usXpr7TJD9XRmq24OzmwUXFqhgPs9dS/qw9bGbqSF0sPr6we99uEzpFC2K
DS4ZyfcawAHLlgVnLpDnLVnacxgr+TjLKy+ZgN/rn3u2juA+6o+GomXgV9ym
bSNYoz17fS032FV8VHoMc7y2ejcgCN6870LwBK6mfndOXAfm/OEvMYnDlU7u
sBAFZ1cqvJvEIoVHMts2kONpp6qouOtPiWOUFJg7d0p7Cqcc2qt4QgYcvl+z
agrvqJF7WysHLhk2ekfDbN4Uh5Bt4DJpmQ10XGQorqC5A/ybZyCEjo+2r3pd
vAfcsWzbZgbmFbtt77MXrPNU4CQDUyw55FT2g+WSQm8wsMUwMz0LgVN4lb8w
sLS8o92Vw2A7Xx8qA485Dm+R0wLPe1xcReCsbKvhIW2w58zcNgJ7sL+nJR8H
T/Ad1SGwqupJWyt9sHvRMRsCL9z4KiN+gqzPCp7rBK76dGTw+0mw2K+IBwS+
u6w0JdoUbBvZu/j+aXRsr81JM3L8J0cegYXvvdu0+iz4dNfvCgJ3Ncj1f7UA
K8XXNxI4RTAl6fZ5cJFYSCeB7U+LW2vZgFfbbhkk8I74aMkll8CavnnjBGZ3
r+otvQx2/k+VRuCPm24nXHcAp+36wCDwzUscVvucwAudewkCa72+toHtAo65
UkonMO8UsyvbHXxz3IhKYIqS4zMnL3DD2ZkRAsd4Dp9T8AEnfC7oJbBFoZX4
6HWy30qP2wksPf+9M9UPLJwU+43AY4dOxlsHkPUTr8GL9b319cyGW+Bnr2Wz
CexZc2R9ZwhY/URpIoEPrCztiAkDDwk+vE/gf4Z7Y03ugTPmXl5brG/UOzP+
CPK88nHbLta3XU6kPhLMMPygv1hPK/EY7Rgw9hVfv1jP5OhTy+LIfnl2zTNw
yvCqdWVPyf3kcfYy8HYnjuj9yeDWrakJDMzMvmbyKxWcZbfFl4EL2UzB9+ng
0BVbzRlYy3f4oWIGmX9g2crF81dmdXI8C8zXXFtNx5RlHfzpOeDYR4c86Pjc
va8PJD+Q901yopKG3ePf3ResIM9LdvDRKfxhPv52RRXY/IV3PxXPW4UGuteQ
8XVW36Di2zKWXs114KQ9Fi8n8bMMXsuo7+T9bM0ZHsef8SVFwSkwewVaNoJ5
N52UraCDA9gDN4ex0S11KXcmWb/Zwd9DuPPYWqHmGbDi8NaxQUyjlP15uHQS
7t+1X3n9WHRQ/JuAKPhVqZFMJ7Y8yvW5XAwcUFzP6MApL5nYbQM4u9il5DtW
dPyS2yQNpsz4Gbbhw9Pe8Q+3g5Moh60p2IGr+T+BI+Cyww77P+LSbWHcAs5g
/lxZkTq0t1WkPsoV7Hr8P5cGlO378qGQB9goY9aGglLqq8VEfcBKI2kFzSjM
Zfl2ySAyv8/XjL4j4/dBJ7fHgPUTpjf2oW/nBIXfxZLxntW/7kNanCmdSk/B
4Xape/rRvlPlF5WTwIpnZbQGkMTMPy+1N2S+iW5mQ2j0gF/8cQyOfrnj0Biy
HuQ7/60MbNsTnj+GOu89kzGoJPNpNFUYR3VdxRlGtWCtzvnVEyj35hw2awb3
eb+pnETbtt699aMVLGdlokhFaY3rdc59Bzv+En9ERU+k9jdZdZH1VRk9O4V8
K64OXhoBqzfYNNPQtAPXq9ExsNDGFdvoyHntE8f/JsHUdf6BdHTBtmDakQGO
8R1Zy0CdfNpFNCa5Xk6NGgOZ5rfddJ0G39wXaMNA2iumuTznyPw/OGQwUFlW
cN30PFkvl4eNDLTfTOjh1X/g3TN+BAMpvtojdoOTCv9vrMe7CPTCqLJnfgWY
tqXwBIE2zhqn3uQBS6TfdySQgK67YtBqMB+fxuL7TlL5mpUHBMDYT7yUQEr7
M8eJtWD1B2cW3yc/ZevWvhYGO55lTxHIUG4s/cJ68I7Z4WVM1J0YErJeghwP
kVt8/3MUkbFt2gjmXl+gwER/Iso072wCj9SHqTHR3RVWmw5vJvMrjddlovU3
//z7LUvmv2zEjIleTcf2ZMuDV3ywvchEqk57S+0VwQMsficmqhlqeSq1E3y9
ZciTiU5buF3v2AXOdem8zkQjLavPRCqDnQcmbzKRl17GPp194JijawOZiLPy
uDDHAXL/73UX/ejAKPuDOjhPK9x/8f03N7jF5RDYU6j5BhPlyEvnbtUE71YX
9mYijeRPkb1a4OY2Y2cmahS1dHlyDHzgT6AtE1lFzhmc0AXrVj83ZyIaV6wi
lwGYapS0uF8/f5WVn06AOfNvHWAivpnmcW9jsA+fphwTPXN2rd1xCizn1raW
ibaNrHo5Ygaem9/3l0BFlm9DEs6C279cXHy/P96mY3vaEpxEGC++33boj2iu
tib7F/Hv7eL7stomjpuXwL73rzkQKOQ97lGxB0/IqGkTSGibRemUA9n/mBRJ
Au0Re3Ld0pVc/5reNwaqeKh8Zp0H+K5E4HMGMuZp3lfvBR5adtSJgVx/802r
3wALrrBezkD/XN60sP3Atq9PP6WjiNFjuRkB4MLnnbJ0lNEe5CIRCm49e2MH
DY3n/R7/Ewmuo7QtTCIfxZja94/AHZTwS5OIO23PyysxYK3q5uoJJPvI2fbn
U7Je1l0+48jGbainKB2sOv80bgQRY4Gl7q/J/p0MaBlGAdaSzxQyyHwOPOYa
Roknzp6JzyHrEbPJahB1bae0XCsBGx1hh/aixEkBv2WfwGPUAyXdyOa1iez9
cnDZvdKRn2h883efpGqwa5e8eAf6Jd6zoYYCzrbk/deIin5I1hi1gKUoMh+/
Ib8nF1w728j5s4EWNYhz7XDFVCc4IGO4pAQJ8FIvCw2T5k/5m4pba7YLJIyS
9yET783DsSEuRVsnyHg6D9Qw3riExadGByv9fdxeixV/z+ZcmCXvm/WliDZM
z1c7N/mHtObVwu8418OP02sBrLHjSvsPvJ/OYRa2bAry/WZA68baI1zzWavA
9iZbawcwT9rxF6r8YNf3fZmDuO7CPcMKQfAY7r0/hE26Vye3iYDNt/1QH8HC
T410z4uBu/LHVo7iTvMo1pgEmOOQfdsotm5dpz2/Caya1G82jjdHmdFDNoOp
yQz+CTx6Ii52zVaw9XRc1QR2/iYxKa0ILhkaFqfiGxUykcf3kvlsu3ePhlHA
pf0tqmDbJY/F6HgpejlgoUaON95Po+OwjwoqrhrgAJNiUwbWv+rYM6sJ5p06
GMXAa1Sybt86Ct6raFDPwDHZuzpjdMErPsuqE/iMs8ctKQOw+/s/LgSWUMxX
fHMCLOrmnkzg1Jeq/qWm4NhbZ/8S2O7SdbljZmB1p/atTKwgU9JEOQPOOMFj
xMTZCYc2D1mBg+RexzEx6zqL68IFsNJHvyIm3mv2crL7Ill/beUfTOyz51zj
WTuwRl3TNBMXr1nz/rs9+Kv2OX4WXpisiDG9AhbObZNjYY1a7+tNTuR8Xu1D
LHwrTcHK0BVsrJdjwsLVAT2Hv7mT8d0k7FiY2zJqi44XONIn3JuF9fZr83y+
Ch6yWBHCwhHr5qiHr5P1FHvwkIUpRCYF+4KNMrc9Y+G1DRfy1PzBUQL9aSx8
+s262MJAsP6RvLcsHBv65YZKMBkfvclm4Z82fudzQ8He/2res/DGQ7uO7LwD
Xh0kmM/C1uLDshn3wA4VEXksnDoTyysfAU4rOZzLwiMt+rQXkeA6R6UsFpbL
5miWfgRmN5x/xcJXwvPyEx+DlXtbk1g4y94+TiIWnBAX/YSFGVoSfnHxYK25
1HAW3rOJYi38nOzXX64AFvb+e0vrUSI4PuGzGwsX/tgnx58Cduzsv8DCf/In
V95PA1MyLhixMIpKpPO8BDcL6B5k4QBnk5bQ1+C7y5MW+7Fia3F8QBbY5s6r
OSY+vszl5t9s8r4JXOpn4vBeaZvr78HzoqnVTCwQe1fesxDMjP4QzsSmnmgV
UQSuWBLrxMQxRkyGUyl4oHuVARNL8JwtvFxB5tdaz8XE54dXPRuqIuONbFr8
3kgpL/e/UAPecUaylMBbr8sfO1cHrtJXcCLw7snfbYbtYMZSPszAXjUZH791
gIvS9j5YfJ9OtX6u8xNcFrr7PAMftKi11ewjPXNxho516p+wVCbAfNcKDGnY
8t1egQ0LYN+Tl59O4IKzv1dTOGiLDpvPF5jAq1cU8d1aBo7M+B0yjsssDnKP
c4OleO7bj2FpXq1/eWvBOrtPi4zgEduTU/ry5PMqEbL92FnM8YuvKdhapDnq
C67+vL1mpxk426i4thpLutGrBs6AlfSb5ysxpca9TOc8Od//TVkJ3u117YOQ
AzggmLs5Fs80hr7I8AeXDXy6VokCQpIDu96AzZeaZPWiVVe5dC9kgmOLznn2
oXh7J8GRd2BHl4f8/ei93v5Ueh4Zf6L76AAaEWiqWvoJLOf/I2UI6SVwcMu3
gD0Jgw3jqOOBHSWzjRwP7XkxjmwD62J3d4CTBOsVJ9BN21h59W7wfE68yiTK
VlDSOzEKlrBt3zWFhD+cj/D6Aw7f1X+JgVJffT4995esT3hGPAMpxW+T9Oeg
w/ndZNrAQMf9Zt6FLQffPC6zm0DtzpY+q7jBEsEaNgSysa7UiOIFm+tseUgg
3yMPmp6uAauXKk0SiEdlOk5KEPxqnYEwE8XInrN5IQTWPCahwUTveLaystaD
Q0PwAyYaaMRCFTLgjU8DN7KQS/nmbm1ZMB5PRSw0n3v3xTc5cEr2CUsWCktj
OBltA2dV+l9noXUxp/e2bQeX/doRw0Ipt0sWziiBKzaYZ7PQjmvSNT27wdF8
v2pZSMeCZja2D7z74Y1pFmo1MJVyOgCubjDnYaMLh4rGCHVwgUyMOBvRlKRy
vA+Bhy7uUGSj69Kh1/4cJp+/KKHGRlxC1MMBWuCw6bM6bBS93Jh3+TFyfdqQ
CRtJzXxovnMc/FU635KNMsc2PF2tDw64VH2JjcKeh1j3GIJpkTmObGRrPLUl
6ySYT9bGjY00uE5N+pmCfzEpHmwkUVKSbWAGLvn8a9G/XTd7bzgLvu5Ytzi/
ZUu42pQFWDtf14mNsjpZHKXnwarODnZsdPfBuepwG7Ddpc2L+dhpVd6zuASm
2rudZCPNWYWTivbgLm3dI2y0MStKeN4BbFz/cjcbzdrM/fzmBLb6GiTJRq0i
NslPXcHSfK2L9cuu+2J3xQOcYR1NsFB44C5FNW+wWExJOwvZ740jeK+R+79+
9CMLaU1yfOi8Af79c2scC0km2fu+uQmOCbPwZqE5U8rh64FgV8MuIxZq51Hl
0g0mz9efRDkWysWJdetvg3Wskv4yUYQHV9T4HXK+VnsjEx3tbpe484A8Ly2f
rzCRVBQaMI8CM0XdVJhoXjv9pdxj8nyLqcwTKC/ba3dtPNgzbCKAQJGXumee
PAe3PqxHBLoidrT0chLY/UHGLANJBwvpcKWT44mH7RhoQdV31fdX4CrDcREG
+jE12Jz+lszXtC+cjiLN3ltq55D359DfPTTkyCcuI5wH1n9L95tCOuVBY8MF
YKV+u3Iq+qdg7BFSAs4Wf6M8iTp7P6qe+gROMj9jO4EKojctbK4Aa1FM7o8j
5wVGWFUN2L6P8XUUdTU9SFjWAlaOU2UNosLQmYstbWBGWdbkAIpWOy+f2kHm
z/m3qx/pvdiRp9lDrpdKMelFRT71XwLHwfyKDe1tKGa7yoOTVLCPvbBxC3Ib
eGa6iU6eryQ5TEFy+o69ZWxw32cXSjXiXNKaFjkDNir9pVeO+vLVHKznyP53
nTb6gEocUncq/QVzyJ589BI9kVw5/e8faY65GyvR/3IhHJ4=
     "]]}},
  AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
  Axes->True,
  AxesLabel->{None, None},
  AxesOrigin->{0, 0},
  AxesStyle->Directive[20, 
    Thickness[0.005], 
    RGBColor[0, 0, 1]],
  Epilog->{
    InsetBox[
     FormBox[
     "\"\\!\\(\\*\\nStyleBox[\\\"ResidualOnDomain\\\",\\nFontSize->18,\\\
nFontWeight->\\\"Plain\\\",\\nFontColor->RGBColor[0, 0, 1]]\\)\"", 
      TraditionalForm], {0.4, 0.00001}, {0, -1}]},
  ImageSize->500,
  LabelStyle->(FontFamily -> "Helvetica"),
  Method->{},
  PlotRange->{{0, 1}, {-0.000018794358882967543`, 0.0000195054857234922}},
  PlotRangeClipping->True,
  PlotRangePadding->{
    Scaled[0.02], 
    Scaled[0.02]}]], "Output",
 CellChangeTimes->{
  3.577697680722088*^9},ImageCache->GraphicsData["CompressedBitmap", "\<\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\
\>"]],

Cell["\<\
The values, e.g., when  t->TimeNodes[[21]] and  \
t\[Rule](TimeNodes[[21]]+0.025) are
significantly different and this is due to interpolation error\
\>", "Text",
 CellChangeTimes->{{3.44207339471875*^9, 3.4420734050625*^9}, {
   3.44207345690625*^9, 3.44207347240625*^9}, 3.442073723109375*^9, 
   3.495282611171875*^9, {3.495512351765625*^9, 3.4955124408125*^9}, {
   3.49551251203125*^9, 3.495512558640625*^9}, {3.496029353125*^9, 
   3.496029354078125*^9}, {3.49666470890625*^9, 3.496664745640625*^9}, {
   3.496664865125*^9, 3.4966648658125*^9}, {3.49666588228125*^9, 
   3.49666588290625*^9}, {3.496748114296875*^9, 3.49674811528125*^9}, {
   3.5612943381167727`*^9, 3.561294350382249*^9}, {3.561294587054325*^9, 
   3.5612946478105288`*^9}},
 FontSize->24,
 FontColor->GrayLevel[0],
 Background->GrayLevel[0.85]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"respoint1", "=", " ", 
  RowBox[{
   RowBox[{
    StyleBox["Residual",
     FontColor->RGBColor[0, 1, 0]], "[", "t", "]"}], "  ", "/.", "  ", 
   RowBox[{"t", "->", 
    RowBox[{"TimeNodes", "[", 
     RowBox[{"[", "21", "]"}], "]"}]}]}]}]], "Input",
 CellChangeTimes->{{3.495282959453125*^9, 3.495282959484375*^9}, {
  3.56126947935096*^9, 3.5612695282454567`*^9}, {3.561294276142832*^9, 
  3.561294291584056*^9}},
 FontSize->16],

Cell[BoxData[
 RowBox[{"-", "1.0034684194693`*^-9"}]], "Output",
 CellChangeTimes->{3.57769768076327*^9}]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"respoint6025", "=", " ", 
  RowBox[{
   RowBox[{
    StyleBox["Residual",
     FontColor->RGBColor[0, 1, 0]], "[", "t", "]"}], "  ", "/.", "  ", 
   RowBox[{"t", "\[Rule]", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"TimeNodes", "[", 
       RowBox[{"[", "21", "]"}], "]"}], "+", "0.025"}], ")"}]}]}]}]], "Input",
 CellChangeTimes->{{3.495282959453125*^9, 3.495282959484375*^9}, {
   3.56126947935096*^9, 3.5612695282454567`*^9}, {3.561269573327582*^9, 
   3.5612695838875647`*^9}, 3.561274662037977*^9, {3.561294297283977*^9, 
   3.5612943036124496`*^9}},
 FontSize->16],

Cell[BoxData[
 RowBox[{"-", "0.000014543875551220609`"}]], "Output",
 CellChangeTimes->{3.577697680788988*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
 StyleBox["It is interesting also to examine the behaviour of the function ",
  Background->None],
 "Residual[t]\nonly on the TimeNodes.",
 StyleBox["\nThe  range, between ",
  FontColor->GrayLevel[0],
  Background->None],
 Cell[BoxData[
  FormBox[
   RowBox[{
    RowBox[{"-", "8.3"}], "\[Times]", 
    SuperscriptBox["10", 
     RowBox[{"-", "9"}]]}], TraditionalForm]],
  Background->None],
 StyleBox[" e ",
  Background->None],
 Cell[BoxData[
  FormBox[
   RowBox[{"6", "\[Times]", 
    SuperscriptBox["10", 
     RowBox[{"-", "9"}]]}], TraditionalForm]],
  Background->None],
 ", is lower by about a factor ten"
}], "Text",
 CellChangeTimes->{
  3.441961594359375*^9, {3.4420967468125*^9, 3.4420967743125*^9}, {
   3.442096862265625*^9, 3.442096863140625*^9}, 3.49528291065625*^9, {
   3.495512720734375*^9, 3.495512784421875*^9}, {3.49551328978125*^9, 
   3.49551329046875*^9}, {3.49551332646875*^9, 3.495513349203125*^9}, {
   3.49551338009375*^9, 3.4955134728125*^9}, {3.496664985125*^9, 
   3.496664986359375*^9}, {3.49666523675*^9, 3.496665238671875*^9}, {
   3.4966652726875*^9, 3.49666531146875*^9}, {3.496748221703125*^9, 
   3.496748233921875*^9}, {3.4967483845625*^9, 3.49674838928125*^9}, 
   3.561273323864769*^9, {3.561290952465419*^9, 3.5612909535322437`*^9}, 
   3.561291786835256*^9, 3.561294812273067*^9, {3.561294849797824*^9, 
   3.561294940192629*^9}, {3.561295473016642*^9, 3.5612955135089483`*^9}, {
   3.5612955685568666`*^9, 3.561295576675688*^9}},
 FontSize->24,
 FontColor->GrayLevel[0],
 Background->GrayLevel[0.85]],

Cell[BoxData[
 StyleBox[
  RowBox[{
   RowBox[{
    StyleBox["ResidualErrorOnNodes",
     FontColor->RGBColor[0, 1, 0]], "=", 
    RowBox[{"Residual", " ", "/@", " ", "TimeNodes"}]}], ";"}],
  FontSize->24]], "Input",
 CellChangeTimes->{{3.442096887859375*^9, 3.442096916453125*^9}, 
   3.495111518*^9, {3.495282911359375*^9, 3.495282912375*^9}, 
   3.495283061609375*^9, 3.495512795359375*^9, {3.495513986421875*^9, 
   3.495513988*^9}, {3.496746589828125*^9, 3.496746590390625*^9}, 
   3.5612950361443367`*^9, 3.5612951451566353`*^9},
 FontSize->96],

Cell[BoxData[
 StyleBox[
  RowBox[{
   RowBox[{"couplesResidualError", "=", " ", 
    RowBox[{"Transpose", "[", 
     RowBox[{"{", 
      RowBox[{"TimeNodes", ",", 
       StyleBox["ResidualErrorOnNodes",
        FontColor->RGBColor[0, 1, 0]]}], "}"}], "]"}]}], ";"}],
  FontSize->24]], "Input",
 CellChangeTimes->{
  3.441961619796875*^9, {3.4420970919375*^9, 3.442097109078125*^9}, 
   3.49511151859375*^9, 3.495198299828125*^9, 3.495282915203125*^9, 
   3.49528306825*^9, 3.495283161125*^9, 3.49551279878125*^9, {
   3.495513992109375*^9, 3.495513993671875*^9}, {3.49551412428125*^9, 
   3.49551412671875*^9}, 3.496746591234375*^9, 3.5612950396122513`*^9, 
   3.5612951471383333`*^9},
 FontSize->36],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  StyleBox["Gra$ResidualErrorOnNodes",
   FontColor->RGBColor[0, 1, 0]], "=", 
  RowBox[{"ListPlot", "[", 
   RowBox[{
    StyleBox["couplesResidualError",
     FontColor->RGBColor[0, 1, 0]], ",", "\[IndentingNewLine]", 
    RowBox[{"PlotRange", "\[Rule]", "All"}], ",", 
    RowBox[{"Joined", "\[Rule]", "True"}], ",", "\[IndentingNewLine]", 
    RowBox[{"Epilog", "\[Rule]", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"PointSize", "[", "0.015", "]"}], ",", 
       RowBox[{"RGBColor", "[", 
        RowBox[{"0", ",", "1", ",", "0"}], "]"}], ",", 
       RowBox[{"Map", "[", 
        RowBox[{"Point", ",", 
         StyleBox["couplesResidualError",
          FontColor->RGBColor[0, 1, 0]]}], "]"}], 
       StyleBox[",",
        FontSize->16], 
       RowBox[{"Text", "[", 
        RowBox[{"\"\<\!\(\*
StyleBox[\"Residuals\",
FontSize->18,
FontWeight->\"Plain\",
FontColor->RGBColor[0, 1, 0]]\)\!\(\*
StyleBox[\" \",
FontSize->18,
FontWeight->\"Plain\",
FontColor->RGBColor[0, 1, 0]]\)\!\(\*
StyleBox[\"on\",
FontSize->18,
FontWeight->\"Plain\",
FontColor->RGBColor[0, 1, 0]]\)\!\(\*
StyleBox[\" \",
FontSize->18,
FontWeight->\"Plain\",
FontColor->RGBColor[0, 1, 0]]\)\!\(\*
StyleBox[\"nodes\",
FontSize->18,
FontWeight->\"Plain\",
FontColor->RGBColor[0, 1, 0]]\)\>\"", ",", 
         RowBox[{"{", 
          RowBox[{"0.4", ",", 
           RowBox[{"4.", "*", 
            SuperscriptBox["10", 
             RowBox[{"-", "9"}]]}]}], "}"}], ",", 
         RowBox[{"{", 
          RowBox[{
           RowBox[{"-", "0.1"}], ",", 
           RowBox[{"-", "1"}]}], "}"}]}], "]"}]}], "}"}]}]}], " ", 
   "\[IndentingNewLine]", "]"}]}]], "Input",
 CellChangeTimes->{
  3.44196163203125*^9, {3.44196206984375*^9, 3.44196207321875*^9}, {
   3.441962219796875*^9, 3.44196222246875*^9}, {3.441964388390625*^9, 
   3.441964413125*^9}, {3.441964480875*^9, 3.441964512796875*^9}, {
   3.441964582328125*^9, 3.441964613984375*^9}, {3.442097151609375*^9, 
   3.44209730259375*^9}, {3.442097364828125*^9, 3.4420974085625*^9}, {
   3.442097452734375*^9, 3.44209746390625*^9}, {3.4951983005625*^9, 
   3.49519830115625*^9}, 3.495281891875*^9, {3.49528291625*^9, 
   3.49528291725*^9}, 3.495283069359375*^9, {3.495283165046875*^9, 
   3.495283166203125*^9}, {3.4952831980625*^9, 3.495283214375*^9}, {
   3.495514068390625*^9, 3.49551406996875*^9}, {3.495514132984375*^9, 
   3.495514143796875*^9}, {3.496746592078125*^9, 3.496746594796875*^9}, {
   3.561294960009885*^9, 3.561294964085278*^9}},
 FontSize->24],

Cell[BoxData[
 GraphicsBox[{{}, 
   {RGBColor[0.24720000000000014`, 0.24, 0.6], LineBox[CompressedData["
1:eJxTTMoPSmViYGCQBGIQjQ4uVxQ7xQtK2IM5Ntl7IXwNCN8qe+9mC/6nJg7F
YL7FjDN7L2SxZry/3wTmX1hxZ6+bZXPsEfkeMJ/n1J29Bnl+ya+95oD4B/jW
CO27N/+t9y+npSB+w9tJAnZLOUye1SWsAav/IXhz7zYL2wOM+zeC+R23bu6t
Wdgc1XZnB1i9ZQHPPmeuU1+4fu0Hy+/N+W7batlx/Hj3YTD/9JNvti9yV4t0
SR0H849sv7zXe9G5RJ+Vp8D8F2uu7F3OlxJ4acJFEN9By1N1n8aZB4X/zlwF
8R/cslbbt6ozdpIW5y2wex92atnpuN/aFOZ6D6x/4tFve8OaVmcedHgI1q8Y
ILhP/OHLyutxj8HyvraC+7xEZNdyTXoGMY/fal+de8AD26MvQfyA2M+O+/Yp
a3yY9+gNiK/ge8/CDhLqH8D6WTm57ACxAJHr
     "]]}, {}},
  AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
  Axes->True,
  AxesLabel->{None, None},
  AxesOrigin->{0., 0.},
  AxesStyle->Directive[20, 
    Thickness[0.005], 
    RGBColor[0, 0, 1]],
  Epilog->{
    PointSize[0.015], 
    RGBColor[0, 1, 0], {
     PointBox[{0., 0.}], 
     PointBox[{0.00009181159895230448, -7.740474927686591*^-13}], 
     PointBox[{0.00018362319790460896`, -7.738254481637341*^-13}], 
     PointBox[{0.004699904079599348, -5.201328256987381*^-11}], 
     PointBox[{0.009216184961294088, -1.04262376510178*^-10}], 
     PointBox[{0.013732465842988827`, -1.0473466538485354`*^-10}], 
     PointBox[{0.027629545150928247`, -1.0868592692503398`*^-9}], 
     PointBox[{0.041526624458867664`, 9.647300736048692*^-10}], 
     PointBox[{0.05542370376680709, -9.120482147295661*^-11}], 
     PointBox[{0.06932078307474651, -9.405498602177431*^-11}], 
     PointBox[{0.09711494169062534, -8.276657137429311*^-10}], 
     PointBox[{0.12490910030650419`, 3.408751059197357*^-10}], 
     PointBox[{0.15270325892238304`, 3.3314750957913475`*^-10}], 
     PointBox[{0.18049741753826187`, -7.173306393326584*^-11}], 
     PointBox[{0.2082915761541407, -7.521672173993466*^-11}], 
     PointBox[{0.274464206202746, -2.4779933660568076`*^-9}], 
     PointBox[{0.3406368362513512, -2.588355973998091*^-9}], 
     PointBox[{0.4068094662999565, 3.0894997671282454`*^-9}], 
     PointBox[{0.4729820963485618, -3.3137248500736405`*^-10}], 
     PointBox[{0.539154726397167, -1.0077496614968595`*^-9}], 
     PointBox[{0.6053273564457723, -1.0034684194693*^-9}], 
     PointBox[{0.7053273564457723, -6.068016755733652*^-9}], 
     PointBox[{0.8053273564457724, -8.358919334483517*^-9}], 
     PointBox[{0.9026636782228861, 5.790117274528939*^-9}], 
     PointBox[{1., 7.577249938606201*^-10}]}, 
    InsetBox[
     FormBox[
     "\"\\!\\(\\*\\nStyleBox[\\\"Residuals\\\",\\nFontSize->18,\\nFontWeight->\
\\\"Plain\\\",\\nFontColor->RGBColor[0, 1, 0]]\\)\\!\\(\\*\\nStyleBox[\\\" \\\
\",\\nFontSize->18,\\nFontWeight->\\\"Plain\\\",\\nFontColor->RGBColor[0, 1, \
0]]\\)\\!\\(\\*\\nStyleBox[\\\"on\\\",\\nFontSize->18,\\nFontWeight->\\\"\
Plain\\\",\\nFontColor->RGBColor[0, 1, 0]]\\)\\!\\(\\*\\nStyleBox[\\\" \
\\\",\\nFontSize->18,\\nFontWeight->\\\"Plain\\\",\\nFontColor->RGBColor[0, \
1, 0]]\\)\\!\\(\\*\\nStyleBox[\\\"nodes\\\",\\nFontSize->18,\\nFontWeight->\\\
\"Plain\\\",\\nFontColor->RGBColor[0, 1, 0]]\\)\"", TraditionalForm], {0.4, 
     4.*^-9}, {-0.1, -1}]},
  ImageSize->500,
  LabelStyle->(FontFamily -> "Helvetica"),
  Method->{},
  PlotRangeClipping->True]], "Output",
 CellChangeTimes->{
  3.57769768085463*^9},ImageCache->GraphicsData["CompressedBitmap", "\<\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\
\>"]]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
 "The ",
 StyleBox["compression",
  FontSlant->"Italic"],
 " of the values,clearly shown here, induces a little reflection ..."
}], "Text",
 CellChangeTimes->{
  3.441961709234375*^9, {3.4419617824375*^9, 3.441961783015625*^9}, {
   3.44196579340625*^9, 3.441965855296875*^9}, 3.442097569515625*^9, {
   3.442097609921875*^9, 3.4420976901875*^9}, {3.442098287046875*^9, 
   3.44209835059375*^9}, {3.4420984299375*^9, 3.44209846421875*^9}, {
   3.44209850975*^9, 3.4420985634375*^9}, {3.442098593890625*^9, 
   3.44209860825*^9}, {3.442098643890625*^9, 3.442098647890625*^9}, {
   3.442098803*^9, 3.442098850578125*^9}, {3.442098912765625*^9, 
   3.4420989371875*^9}, 3.44209901884375*^9, 3.442099049453125*^9, {
   3.44209910971875*^9, 3.442099128515625*^9}, 3.44209922421875*^9, {
   3.4421002471875*^9, 3.442100271203125*^9}, {3.442157720359375*^9, 
   3.442157720359375*^9}, {3.49551305659375*^9, 3.49551314809375*^9}, 
   3.495513286265625*^9, {3.495513492671875*^9, 3.49551349534375*^9}, {
   3.49551352540625*^9, 3.495513581703125*^9}, {3.5612956018920593`*^9, 
   3.56129565764437*^9}},
 FontSize->24,
 Background->GrayLevel[0.85]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Show", "[", "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{"ListPlot", "[", 
    RowBox[{
     StyleBox["couplesResidualError",
      FontColor->RGBColor[0, 1, 0]], ",", "\[IndentingNewLine]", 
     RowBox[{"PlotRange", "\[Rule]", "All"}], ",", 
     RowBox[{"Joined", "\[Rule]", "True"}], ",", "\[IndentingNewLine]", 
     RowBox[{"Epilog", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"PointSize", "[", "0.015", "]"}], ",", 
        RowBox[{"RGBColor", "[", 
         RowBox[{"0", ",", "1", ",", "0"}], "]"}], ",", 
        RowBox[{"Map", "[", 
         RowBox[{"Point", ",", 
          StyleBox["couplesResidualError",
           FontColor->RGBColor[0, 1, 0]]}], "]"}]}], "}"}]}]}], 
    "\[IndentingNewLine]", "]"}], ",", "\[IndentingNewLine]", 
   StyleBox[
    RowBox[{"gra$", 
     StyleBox["Residual",
      FontColor->RGBColor[0, 1, 0]]}]]}], "\[IndentingNewLine]", 
  "]"}]], "Input",
 CellChangeTimes->{{3.442097751625*^9, 3.442097760546875*^9}, {3.442097802*^9,
    3.44209783196875*^9}, {3.442097894078125*^9, 3.442097912609375*^9}, {
   3.442098038359375*^9, 3.4420980613125*^9}, {3.49519830175*^9, 
   3.49519830234375*^9}, 3.495281897515625*^9, {3.49528316853125*^9, 
   3.495283169609375*^9}, {3.495283565609375*^9, 3.49528356628125*^9}, {
   3.49551416509375*^9, 3.495514222640625*^9}, 3.49674660853125*^9, {
   3.56129518698149*^9, 3.561295190609332*^9}},
 FontSize->24],

Cell[BoxData[
 GraphicsBox[{{{}, 
    {RGBColor[0.24720000000000014`, 0.24, 0.6], LineBox[CompressedData["
1:eJxTTMoPSmViYGCQBGIQjQ4uVxQ7xQtK2IM5Ntl7IXwNCN8qe+9mC/6nJg7F
YL7FjDN7L2SxZry/3wTmX1hxZ6+bZXPsEfkeMJ/n1J29Bnl+ya+95oD4B/jW
CO27N/+t9y+npSB+w9tJAnZLOUye1SWsAav/IXhz7zYL2wOM+zeC+R23bu6t
Wdgc1XZnB1i9ZQHPPmeuU1+4fu0Hy+/N+W7batlx/Hj3YTD/9JNvti9yV4t0
SR0H849sv7zXe9G5RJ+Vp8D8F2uu7F3OlxJ4acJFEN9By1N1n8aZB4X/zlwF
8R/cslbbt6ozdpIW5y2wex92atnpuN/aFOZ6D6x/4tFve8OaVmcedHgI1q8Y
ILhP/OHLyutxj8HyvraC+7xEZNdyTXoGMY/fal+de8AD26MvQfyA2M+O+/Yp
a3yY9+gNiK/ge8/CDhLqH8D6WTm57ACxAJHr
      "]]}, {}}, {{}, {}, 
    {Hue[0.67, 0.6, 0.6], LineBox[CompressedData["
1:eJwk13c81d8bAHC0FElIiBKS+kqUInGykxEZoSE7StmyXevaW0YhIZmF7HFc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      "]]}}},
  AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
  Axes->True,
  AxesLabel->{None, None},
  AxesOrigin->{0., 0.},
  AxesStyle->Directive[20, 
    Thickness[0.005], 
    RGBColor[0, 0, 1]],
  Epilog->{
    PointSize[0.015], 
    RGBColor[0, 1, 0], {
     PointBox[{0., 0.}], 
     PointBox[{0.00009181159895230448, -7.740474927686591*^-13}], 
     PointBox[{0.00018362319790460896`, -7.738254481637341*^-13}], 
     PointBox[{0.004699904079599348, -5.201328256987381*^-11}], 
     PointBox[{0.009216184961294088, -1.04262376510178*^-10}], 
     PointBox[{0.013732465842988827`, -1.0473466538485354`*^-10}], 
     PointBox[{0.027629545150928247`, -1.0868592692503398`*^-9}], 
     PointBox[{0.041526624458867664`, 9.647300736048692*^-10}], 
     PointBox[{0.05542370376680709, -9.120482147295661*^-11}], 
     PointBox[{0.06932078307474651, -9.405498602177431*^-11}], 
     PointBox[{0.09711494169062534, -8.276657137429311*^-10}], 
     PointBox[{0.12490910030650419`, 3.408751059197357*^-10}], 
     PointBox[{0.15270325892238304`, 3.3314750957913475`*^-10}], 
     PointBox[{0.18049741753826187`, -7.173306393326584*^-11}], 
     PointBox[{0.2082915761541407, -7.521672173993466*^-11}], 
     PointBox[{0.274464206202746, -2.4779933660568076`*^-9}], 
     PointBox[{0.3406368362513512, -2.588355973998091*^-9}], 
     PointBox[{0.4068094662999565, 3.0894997671282454`*^-9}], 
     PointBox[{0.4729820963485618, -3.3137248500736405`*^-10}], 
     PointBox[{0.539154726397167, -1.0077496614968595`*^-9}], 
     PointBox[{0.6053273564457723, -1.0034684194693*^-9}], 
     PointBox[{0.7053273564457723, -6.068016755733652*^-9}], 
     PointBox[{0.8053273564457724, -8.358919334483517*^-9}], 
     PointBox[{0.9026636782228861, 5.790117274528939*^-9}], 
     PointBox[{1., 7.577249938606201*^-10}]}},
  ImageSize->500,
  LabelStyle->(FontFamily -> "Helvetica"),
  Method->{},
  PlotRangeClipping->True]], "Output",
 CellChangeTimes->{
  3.577697680889749*^9},ImageCache->GraphicsData["CompressedBitmap", "\<\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\
\>"]]
}, Open  ]]
}, Open  ]]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Part VI", "Text",
 CellChangeTimes->{{3.4420619435625*^9, 3.4420619460625*^9}, {
  3.495108480859375*^9, 3.49510848184375*^9}, {3.495285762890625*^9, 
  3.495285793703125*^9}, {3.49528627184375*^9, 3.49528627628125*^9}, {
  3.574514859153361*^9, 3.574514860104415*^9}, {3.5745149766890836`*^9, 
  3.5745149778251486`*^9}},
 FontSize->36,
 FontColor->RGBColor[0, 0, 1],
 Background->RGBColor[1, 0.9, 0.8]],

Cell[CellGroupData[{

Cell[TextData[{
 "Finally, the following Graph  illustrates the distribution of  \n \
GlobalError and of  ResidualError. We can conclude\n that the Residual \
function on the Nodes is not a good indicator\n of the ",
 StyleBox["true ",
  FontSlant->"Italic"],
 "error, confirming the warning indicated by  Wolfram experts.\n However, \
even though  one has to carefully examine the behaviour of the IFO\n on the \
entire domain, and not only on the TimeNodes, the Residual function\n is a \
valuable tool."
}], "Text",
 CellChangeTimes->{{3.441974677375*^9, 3.441974679421875*^9}, {3.442099289*^9,
    3.442099448640625*^9}, {3.442099523390625*^9, 3.442099560453125*^9}, {
   3.442099820171875*^9, 3.442099844734375*^9}, {3.44210027746875*^9, 
   3.44210028125*^9}, {3.495513617171875*^9, 3.495513743734375*^9}, {
   3.495513788375*^9, 3.49551383215625*^9}, {3.495514263578125*^9, 
   3.495514288078125*^9}, 3.4955143389375*^9, 3.495514429078125*^9, {
   3.4955144661875*^9, 3.495514555890625*^9}, {3.495514588515625*^9, 
   3.495514591546875*^9}, {3.495514654625*^9, 3.49551471384375*^9}, {
   3.496665741265625*^9, 3.49666586775*^9}, {3.496748334578125*^9, 
   3.496748338375*^9}, {3.561295661622114*^9, 3.561295879354619*^9}, {
   3.561296153478772*^9, 3.561296199953438*^9}, {3.561350116246757*^9, 
   3.5613501631960583`*^9}, {3.5613511135395813`*^9, 3.561351144523131*^9}, {
   3.5745154901634526`*^9, 3.574515505201313*^9}},
 FontSize->24,
 Background->GrayLevel[0.85]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  StyleBox[" ",
   Background->RGBColor[1, 1, 0]], 
  RowBox[{
   StyleBox["hyphyp",
    Background->RGBColor[1, 1, 0]], 
   StyleBox["=",
    Background->RGBColor[1, 1, 0]], 
   RowBox[{"Show", "[", 
    RowBox[{
     StyleBox["gra$GlobalErrorOnNodes",
      FontColor->RGBColor[1, 0, 1]], ",", 
     StyleBox[
      RowBox[{"Gra$", 
       StyleBox["ResidualErrorOnNodes",
        FontColor->RGBColor[0, 1, 0]]}]], ",", 
     RowBox[{"Epilog", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"PointSize", "[", "0.015", "]"}], ",", 
        RowBox[{"RGBColor", "[", 
         RowBox[{"1", ",", "0", ",", "0"}], "]"}], ",", 
        RowBox[{"Map", "[", 
         RowBox[{"Point", ",", "couplesGlobalErr"}], "]"}], 
        StyleBox[" ",
         FontSize->18], 
        StyleBox[",",
         FontSize->18], 
        RowBox[{"Text", "[", 
         RowBox[{"\"\<\!\(\*
StyleBox[\"\[CapitalDelta]\",
FontSize->18,
FontColor->RGBColor[1, 0, 0]]\)\!\(\*
StyleBox[\"  \",
FontSize->18,
FontColor->RGBColor[1, 0, 0]]\)\!\(\*
StyleBox[\"Global\",
FontSize->18,
FontColor->RGBColor[1, 0, 0]]\)\!\(\*
StyleBox[\" \",
FontSize->18,
FontColor->RGBColor[1, 0, 0]]\)\!\(\*
StyleBox[\"error\",
FontSize->18,
FontColor->RGBColor[1, 0, 0]]\)\>\"", ",", 
          RowBox[{"{", 
           RowBox[{"0.66", ",", 
            RowBox[{
             RowBox[{"-", "2.5"}], "*", 
             SuperscriptBox["10", 
              RowBox[{"-", "8"}]]}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"0", ",", 
            RowBox[{"-", "1"}]}], "}"}]}], "]"}], ",", "\[IndentingNewLine]", 
        RowBox[{"PointSize", "[", "0.015", "]"}], ",", 
        RowBox[{"RGBColor", "[", 
         RowBox[{"0", ",", "1", ",", "0"}], "]"}], ",", "\[IndentingNewLine]", 
        RowBox[{"Map", "[", 
         RowBox[{"Point", ",", "couplesResidualError"}], "]"}], ",", 
        StyleBox["\[IndentingNewLine]",
         FontSize->16], 
        RowBox[{"Text", "[", 
         RowBox[{"\"\<\!\(\*
StyleBox[\"\[CapitalDelta]\",
FontSize->18,
FontColor->RGBColor[0, 1, 0]]\)\!\(\*
StyleBox[\"  \",
FontSize->18,
FontColor->RGBColor[0, 1, 0]]\)\!\(\*
StyleBox[\"Residual\",
FontSize->18,
FontColor->RGBColor[0, 1, 0]]\)\!\(\*
StyleBox[\" \",
FontSize->18,
FontColor->RGBColor[0, 1, 0]]\)\!\(\*
StyleBox[\"error\",
FontSize->18,
FontColor->RGBColor[0, 1, 0]]\)\>\"", ",", 
          RowBox[{"{", 
           RowBox[{"0.66", ",", 
            RowBox[{"2.", "*", 
             SuperscriptBox["10", 
              RowBox[{"-", "9"}]]}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"0", ",", 
            RowBox[{"-", "1"}]}], "}"}]}], "]"}]}], "}"}]}]}], 
    "\[IndentingNewLine]", "]"}]}]}]], "Input",
 CellChangeTimes->{
  3.44196616428125*^9, {3.4420996166875*^9, 3.442099654890625*^9}, {
   3.4420997593125*^9, 3.44209979509375*^9}, {3.442099870859375*^9, 
   3.442099906484375*^9}, {3.495198304125*^9, 3.495198304671875*^9}, 
   3.4951983668125*^9, {3.49528190625*^9, 3.495281910140625*^9}, 
   3.4952820166875*^9, 3.495283070328125*^9, 3.495283173953125*^9, {
   3.495283668453125*^9, 3.495283669078125*^9}, {3.495283767125*^9, 
   3.49528378671875*^9}, 3.49537293475*^9, 3.495514813890625*^9, {
   3.49551499546875*^9, 3.495514997125*^9}, {3.495515029578125*^9, 
   3.49551503125*^9}, {3.496746610984375*^9, 3.496746612015625*^9}, {
   3.496748345828125*^9, 3.496748349109375*^9}, {3.4967485021875*^9, 
   3.49674850353125*^9}, {3.496748609734375*^9, 3.4967486148125*^9}, {
   3.561290955160486*^9, 3.5612909721628113`*^9}, {3.561294973851232*^9, 
   3.561294988700889*^9}, 3.561348705699731*^9, {3.561349910029133*^9, 
   3.561349913237624*^9}},
 FontSize->24],

Cell[BoxData[
 GraphicsBox[{{{}, 
    {RGBColor[0.24720000000000014`, 0.24, 0.6], LineBox[CompressedData["
1:eJxTTMoPSmViYGCQBGIQjQ4uVxQ7xQtK2AOZD85KGe2D8DVA/AtW0k77Nlvw
PzVxKAbx18gkBO67kMWa8f5+E1j9iaOR+9wsm2OPyPeA+PtS5RP3GeT5Jb/2
mgPiH9gbq2V3b/5b719OS8H8t1Ol7JZymDyrS1gD4jNwTLmyd5uF7QHG/RtB
fAef3bL7ahY2R7Xd2QFWL3xKaZ8z16kvXL/2g/gNsZ9k7FotO44f7z4M1u/v
Imr3Ine1SJfUcbC89HlOO+9F5xJ9Vp4Cy3NLfrRdzpcSeGnCRRA/ocHOb5/G
mQeF/85cBfE/zN9jtG9VZ+wkLc5bYH7iPJN9Ou63NoW53gPxb5SscdgX1rQ6
86DDQxA/Y/9Nt33iD19WXo97DOIrcLP47fMSkV3LNekZiD/DLzZpX517wAPb
oy9B/B0ifTH79ilrfJj36A2Iv+LIyZh9kFD/AOIXpK9L3AcA8jOUWQ==
      "]]}, {}}, {{}, 
    {RGBColor[0.24720000000000014`, 0.24, 0.6], LineBox[CompressedData["
1:eJxTTMoPSmViYGCQBGIQjQ4uVxQ7xQtK2IM5Ntl7IXwNCN8qe+9mC/6nJg7F
YL7FjDN7L2SxZry/3wTmX1hxZ6+bZXPsEfkeMJ/n1J29Bnl+ya+95oD4B/jW
CO27N/+t9y+npSB+w9tJAnZLOUye1SWsAav/IXhz7zYL2wOM+zeC+R23bu6t
Wdgc1XZnB1i9ZQHPPmeuU1+4fu0Hy+/N+W7batlx/Hj3YTD/9JNvti9yV4t0
SR0H849sv7zXe9G5RJ+Vp8D8F2uu7F3OlxJ4acJFEN9By1N1n8aZB4X/zlwF
8R/cslbbt6ozdpIW5y2wex92atnpuN/aFOZ6D6x/4tFve8OaVmcedHgI1q8Y
ILhP/OHLyutxj8HyvraC+7xEZNdyTXoGMY/fal+de8AD26MvQfyA2M+O+/Yp
a3yY9+gNiK/ge8/CDhLqH8D6WTm57ACxAJHr
      "]]}, {}}},
  AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
  Axes->True,
  AxesLabel->{None, None},
  AxesOrigin->{0., 0.},
  AxesStyle->Directive[20, 
    Thickness[0.005], 
    RGBColor[0, 0, 1]],
  Epilog->{
    PointSize[0.015], 
    RGBColor[1, 0, 0], {
     PointBox[{0., 0.}], 
     PointBox[{0.00009181159895230448, -4.2153298629443725`*^-9}], 
     PointBox[{0.00018362319790460896`, -8.431433773381514*^-9}], 
     PointBox[{0.004699904079599348, -1.6182137185793977`*^-8}], 
     PointBox[{0.009216184961294088, -2.4002600795824947`*^-8}], 
     PointBox[{0.013732465842988827`, -3.1893413909855894`*^-8}], 
     PointBox[{0.027629545150928247`, 3.0694269348430225`*^-9}], 
     PointBox[{0.041526624458867664`, 1.5474890258104779`*^-9}], 
     PointBox[{0.05542370376680709, -7.4863226728894*^-11}], 
     PointBox[{0.06932078307474651, -1.7306087674029413`*^-9}], 
     PointBox[{0.09711494169062534, -2.1873698408114706`*^-9}], 
     PointBox[{0.12490910030650419`, 1.6849219797165915`*^-9}], 
     PointBox[{0.15270325892238304`, 1.2378924552081116`*^-9}], 
     PointBox[{0.18049741753826187`, 7.51141149279988*^-10}], 
     PointBox[{0.2082915761541407, 2.4880608684441086`*^-10}], 
     PointBox[{0.274464206202746, -1.4083528121489053`*^-8}], 
     PointBox[{0.3406368362513512, -4.362504801846967*^-9}], 
     PointBox[{0.4068094662999565, -4.800660979853433*^-9}], 
     PointBox[{0.4729820963485618, -7.76427699911153*^-9}], 
     PointBox[{0.539154726397167, -1.064062904454488*^-8}], 
     PointBox[{0.6053273564457723, -1.3977193624725714`*^-8}], 
     PointBox[{0.7053273564457723, -3.420651051300183*^-8}], 
     PointBox[{0.8053273564457724, -2.6593919510986552`*^-8}], 
     PointBox[{0.9026636782228861, -2.681106048285642*^-8}], 
     PointBox[{1., -3.293392403236339*^-8}]}, 
    InsetBox[
     FormBox[
     "\"\\!\\(\\*\\nStyleBox[\\\"\[CapitalDelta]\\\",\\nFontSize->18,\\\
nFontColor->RGBColor[1, 0, 0]]\\)\\!\\(\\*\\nStyleBox[\\\"  \
\\\",\\nFontSize->18,\\nFontColor->RGBColor[1, 0, 0]]\\)\\!\\(\\*\\nStyleBox[\
\\\"Global\\\",\\nFontSize->18,\\nFontColor->RGBColor[1, 0, \
0]]\\)\\!\\(\\*\\nStyleBox[\\\" \
\\\",\\nFontSize->18,\\nFontColor->RGBColor[1, 0, 0]]\\)\\!\\(\\*\\nStyleBox[\
\\\"error\\\",\\nFontSize->18,\\nFontColor->RGBColor[1, 0, 0]]\\)\"", 
      TraditionalForm], {0.66, -2.5*^-8}, {0, -1}], 
    PointSize[0.015], 
    RGBColor[0, 1, 0], {
     PointBox[{0., 0.}], 
     PointBox[{0.00009181159895230448, -7.740474927686591*^-13}], 
     PointBox[{0.00018362319790460896`, -7.738254481637341*^-13}], 
     PointBox[{0.004699904079599348, -5.201328256987381*^-11}], 
     PointBox[{0.009216184961294088, -1.04262376510178*^-10}], 
     PointBox[{0.013732465842988827`, -1.0473466538485354`*^-10}], 
     PointBox[{0.027629545150928247`, -1.0868592692503398`*^-9}], 
     PointBox[{0.041526624458867664`, 9.647300736048692*^-10}], 
     PointBox[{0.05542370376680709, -9.120482147295661*^-11}], 
     PointBox[{0.06932078307474651, -9.405498602177431*^-11}], 
     PointBox[{0.09711494169062534, -8.276657137429311*^-10}], 
     PointBox[{0.12490910030650419`, 3.408751059197357*^-10}], 
     PointBox[{0.15270325892238304`, 3.3314750957913475`*^-10}], 
     PointBox[{0.18049741753826187`, -7.173306393326584*^-11}], 
     PointBox[{0.2082915761541407, -7.521672173993466*^-11}], 
     PointBox[{0.274464206202746, -2.4779933660568076`*^-9}], 
     PointBox[{0.3406368362513512, -2.588355973998091*^-9}], 
     PointBox[{0.4068094662999565, 3.0894997671282454`*^-9}], 
     PointBox[{0.4729820963485618, -3.3137248500736405`*^-10}], 
     PointBox[{0.539154726397167, -1.0077496614968595`*^-9}], 
     PointBox[{0.6053273564457723, -1.0034684194693*^-9}], 
     PointBox[{0.7053273564457723, -6.068016755733652*^-9}], 
     PointBox[{0.8053273564457724, -8.358919334483517*^-9}], 
     PointBox[{0.9026636782228861, 5.790117274528939*^-9}], 
     PointBox[{1., 7.577249938606201*^-10}]}, 
    InsetBox[
     FormBox[
     "\"\\!\\(\\*\\nStyleBox[\\\"\[CapitalDelta]\\\",\\nFontSize->18,\\\
nFontColor->RGBColor[0, 1, 0]]\\)\\!\\(\\*\\nStyleBox[\\\"  \
\\\",\\nFontSize->18,\\nFontColor->RGBColor[0, 1, 0]]\\)\\!\\(\\*\\nStyleBox[\
\\\"Residual\\\",\\nFontSize->18,\\nFontColor->RGBColor[0, 1, 0]]\\)\\!\\(\\*\
\\nStyleBox[\\\" \\\",\\nFontSize->18,\\nFontColor->RGBColor[0, 1, \
0]]\\)\\!\\(\\*\\nStyleBox[\\\"error\\\",\\nFontSize->18,\\nFontColor->\
RGBColor[0, 1, 0]]\\)\"", TraditionalForm], {0.66, 2.*^-9}, {0, -1}]},
  ImageSize->600,
  LabelStyle->(FontFamily -> "Helvetica"),
  Method->{},
  PlotLabel->FormBox[
   "\"\\!\\(\\*\\nStyleBox[\\\"GlobalErrorOnNodes\\\",\\nFontSize->18,\\\
nFontColor->RGBColor[1, 0, 1]]\\)\\!\\(\\*\\nStyleBox[\\\" \
\\\",\\nFontSize->18,\\nFontColor->RGBColor[1, 0, 0]]\\)\\!\\(\\*\\nStyleBox[\
\\\"=\\\",\\nFontSize->18,\\nFontColor->RGBColor[1, 0, \
0]]\\)\\!\\(\\*\\nStyleBox[\\\" \
\\\",\\nFontSize->18,\\nFontColor->RGBColor[1, 0, \
0]]\\)\\!\\(\\*SuperscriptBox[\\(\[ExponentialE]\\), \\(\\(t\\)\\(\\\\ \
\\)\\)]\\)\\!\\(\\*\\nStyleBox[\\\" \
\\\",\\nFontSize->18,\\nFontColor->RGBColor[1, 0, 0]]\\)\\!\\(\\*\\nStyleBox[\
\\\"-\\\",\\nFontSize->18,\\nFontColor->RGBColor[1, 0, \
0]]\\)\\!\\(\\*\\nStyleBox[\\\" \
\\\",\\nFontSize->18,\\nFontColor->RGBColor[1, 0, 0]]\\)\\!\\(\\*\\nStyleBox[\
\\\"numsol\\\",\\nFontSize->18,\\nFontColor->RGBColor[1, 0, \
0]]\\)\\!\\(\\*\\nStyleBox[\\\"OnNodes\\\",\\nFontSize->18,\\nFontColor->\
GrayLevel[0]]\\)\"", TraditionalForm],
  PlotRangeClipping->True]], "Output",
 CellChangeTimes->{
  3.577697680941061*^9},ImageCache->GraphicsData["CompressedBitmap", "\<\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\
\>"]]
}, Open  ]]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Part VII", "Text",
 CellChangeTimes->{{3.4420619435625*^9, 3.4420619460625*^9}, {
  3.495108480859375*^9, 3.49510848184375*^9}, {3.495285762890625*^9, 
  3.495285793703125*^9}, {3.49528627184375*^9, 3.49528627628125*^9}, {
  3.574514859153361*^9, 3.574514860104415*^9}, {3.5745149904888725`*^9, 
  3.574514992584993*^9}},
 FontSize->36,
 FontColor->RGBColor[0, 0, 1],
 Background->RGBColor[1, 0.9, 0.8]],

Cell[CellGroupData[{

Cell[TextData[{
 "This part consists of a shor digression... plus two checks...\n\n   The \
following  shows that the IFO contains also the first derivatives\n   of the \
solution of teh ODE on the TimeNodes; in other words, NDSolve performs an  \n \
   interpolation",
 StyleBox[" \[AGrave] la Hermite, ",
  FontSlant->"Italic"],
 "equivalent to \n\n",
 Cell[BoxData[
  RowBox[{
   ButtonBox["Interpolation",
    BaseStyle->"Link",
    ButtonData->"paclet:ref/Interpolation"], "[", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        SubscriptBox[
         StyleBox["x", "TI"], 
         StyleBox["1", "TR"]], "}"}], ",", 
       SubscriptBox[
        StyleBox["y", "TI"], 
        StyleBox["1", "TR"]], ",", 
       SubscriptBox[
        StyleBox[
         RowBox[{"y", "'"}], "TI"], 
        StyleBox["1", "TR"]]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        SubscriptBox[
         StyleBox["x", "TI"], "2"], "}"}], ",", 
       SubscriptBox[
        StyleBox["y", "TI"], "2"], ",", 
       SubscriptBox[
        StyleBox[
         RowBox[{"y", "'"}], "TI"], "2"]}], "}"}], ",", 
     StyleBox["\[Ellipsis]", "TR"]}], "}"}], "]"}]], "InlineFormula"],
 ") \n"
}], "Text",
 CellChangeTimes->{{3.44196595746875*^9, 3.44196596009375*^9}, {
   3.44196609815625*^9, 3.4419661488125*^9}, {3.441974200375*^9, 
   3.441974210453125*^9}, {3.441974295046875*^9, 3.441974310953125*^9}, {
   3.441974345875*^9, 3.441974653*^9}, {3.441979008332594*^9, 
   3.4419790190967293`*^9}, {3.44208976115625*^9, 3.4420899933125*^9}, {
   3.4420903913125*^9, 3.442090450140625*^9}, {3.442090486984375*^9, 
   3.4420905391875*^9}, {3.442090587953125*^9, 3.442090647046875*^9}, {
   3.44209073928125*^9, 3.442090927640625*^9}, {3.44209098921875*^9, 
   3.44209103275*^9}, {3.4420910679375*^9, 3.442091114640625*^9}, {
   3.442091214703125*^9, 3.44209129325*^9}, {3.442091385671875*^9, 
   3.442091602859375*^9}, {3.442091635515625*^9, 3.44209166903125*^9}, {
   3.4420917439375*^9, 3.44209183696875*^9}, {3.4420918740625*^9, 
   3.442091933109375*^9}, {3.442091969421875*^9, 3.44209204984375*^9}, {
   3.44209243234375*^9, 3.44209243340625*^9}, {3.4420932424375*^9, 
   3.442093319953125*^9}, {3.442095443265625*^9, 3.4420955011875*^9}, {
   3.442095655265625*^9, 3.442095845234375*^9}, {3.442095889171875*^9, 
   3.4420961198125*^9}, 3.44210031803125*^9, {3.495111514796875*^9, 
   3.4951115155625*^9}, {3.495112806125*^9, 3.495112808390625*^9}, {
   3.495114069625*^9, 3.49511409396875*^9}, {3.495282497265625*^9, 
   3.495282501328125*^9}, {3.495512316953125*^9, 3.49551232109375*^9}, {
   3.495512485078125*^9, 3.4955124958125*^9}, {3.4967484274375*^9, 
   3.496748447109375*^9}, {3.56129632718645*^9, 3.561296343204586*^9}, {
   3.561296647574409*^9, 3.561296659778904*^9}, {3.561297691646077*^9, 
   3.561297883522846*^9}, {3.5612979416309347`*^9, 3.561297942989006*^9}, {
   3.561348491295784*^9, 3.5613485267250423`*^9}, {3.561351209659326*^9, 
   3.561351210493394*^9}, {3.56135125768546*^9, 3.561351285454668*^9}, {
   3.574515519364123*^9, 3.5745155462326593`*^9}},
 FontSize->24,
 Background->GrayLevel[0.85]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"derOnTimeNodes", "=", 
  RowBox[{"Table", "[", 
   RowBox[{
    RowBox[{"solNDS", "[", 
     RowBox[{"[", 
      RowBox[{"4", ",", "3", ",", "i"}], "]"}], "]"}], ",", 
    RowBox[{"{", 
     RowBox[{"i", ",", "2", ",", "50", ",", "2"}], "}"}]}], "]"}]}]], "Input",
 CellChangeTimes->{{3.561297179465206*^9, 3.561297253201758*^9}, {
  3.561297294514649*^9, 3.5612972954368563`*^9}, {3.561297347702697*^9, 
  3.561297413219369*^9}, {3.5612974656762953`*^9, 3.561297466488941*^9}, {
  3.561297603757675*^9, 3.561297610094159*^9}, {3.561348551203958*^9, 
  3.561348563389862*^9}},
 FontSize->18],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
  "1.`", ",", "1.000091820028322`", ",", "1.000183648488336`", ",", 
   "1.0047109820820253`", ",", "1.0092588086608976`", ",", 
   "1.0138272210394048`", ",", "1.0280147766552312`", ",", 
   "1.0424009142595394`", ",", "1.0569883697484357`", ",", 
   "1.0717799645187074`", ",", "1.1019870319538356`", ",", 
   "1.1330454535570322`", ",", "1.1649792295493941`", ",", 
   "1.1978130273473035`", ",", "1.2315722139676482`", ",", 
   "1.3158254864414396`", ",", "1.4058425988507102`", ",", 
   "1.5020179012596784`", ",", "1.6047726588617757`", ",", 
   "1.7145569893748578`", ",", "1.8318517922051663`", ",", 
   "2.024509340770214`", ",", "2.237428833928897`", ",", "2.466163468420337`",
    ",", "2.718281862150694`"}], "}"}]], "Output",
 CellChangeTimes->{3.577697680974111*^9}]
}, Open  ]],

Cell["First simple check ...", "Text",
 CellChangeTimes->{{3.44196595746875*^9, 3.44196596009375*^9}, {
   3.44196609815625*^9, 3.4419661488125*^9}, {3.441974200375*^9, 
   3.441974210453125*^9}, {3.441974295046875*^9, 3.441974310953125*^9}, {
   3.441974345875*^9, 3.441974653*^9}, {3.441979008332594*^9, 
   3.4419790190967293`*^9}, {3.44208976115625*^9, 3.4420899933125*^9}, {
   3.4420903913125*^9, 3.442090450140625*^9}, {3.442090486984375*^9, 
   3.4420905391875*^9}, {3.442090587953125*^9, 3.442090647046875*^9}, {
   3.44209073928125*^9, 3.442090927640625*^9}, {3.44209098921875*^9, 
   3.44209103275*^9}, {3.4420910679375*^9, 3.442091114640625*^9}, {
   3.442091214703125*^9, 3.44209129325*^9}, {3.442091385671875*^9, 
   3.442091602859375*^9}, {3.442091635515625*^9, 3.44209166903125*^9}, {
   3.4420917439375*^9, 3.44209183696875*^9}, {3.4420918740625*^9, 
   3.442091933109375*^9}, {3.442091969421875*^9, 3.44209204984375*^9}, {
   3.44209243234375*^9, 3.44209243340625*^9}, {3.4420932424375*^9, 
   3.442093319953125*^9}, {3.442095443265625*^9, 3.4420955011875*^9}, {
   3.442095655265625*^9, 3.442095845234375*^9}, {3.442095889171875*^9, 
   3.4420961198125*^9}, 3.44210031803125*^9, {3.495111514796875*^9, 
   3.4951115155625*^9}, {3.495112806125*^9, 3.495112808390625*^9}, {
   3.495114069625*^9, 3.49511409396875*^9}, {3.495282497265625*^9, 
   3.495282501328125*^9}, {3.495512316953125*^9, 3.49551232109375*^9}, {
   3.495512485078125*^9, 3.4955124958125*^9}, {3.4967484274375*^9, 
   3.496748447109375*^9}, {3.56129632718645*^9, 3.561296343204586*^9}, {
   3.561296647574409*^9, 3.561296659778904*^9}, {3.561297691646077*^9, 
   3.56129792106236*^9}, {3.574515552185*^9, 3.574515557201287*^9}},
 FontSize->24,
 Background->GrayLevel[0.85]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{
   StyleBox["DsolNDS",
    FontColor->RGBColor[1, 0, 0]], "[", "t_", "]"}], "=", 
  RowBox[{"D", "[", 
   RowBox[{
    RowBox[{
     StyleBox["solNDS",
      FontColor->RGBColor[1, 0, 0]], "[", "t", "]"}], ",", "t"}], 
   "]"}]}]], "Input",
 CellChangeTimes->{{3.442093392453125*^9, 3.44209349578125*^9}, {
  3.495112728453125*^9, 3.495112739*^9}},
 FontSize->24],

Cell[BoxData[
 RowBox[{
  TagBox[
   RowBox[{"InterpolatingFunction", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"{", 
       RowBox[{"0.`", ",", "1.`"}], "}"}], "}"}], ",", "\<\"<>\"\>"}], "]"}],
   False,
   Editable->False], "[", "t", "]"}]], "Output",
 CellChangeTimes->{3.577697681008341*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  StyleBox["DsolNDSOnNodes",
   FontColor->RGBColor[1, 0, 0]], 
  StyleBox[" ",
   FontColor->RGBColor[1, 0, 0]], "=", 
  RowBox[{"Map", "[", 
   RowBox[{
    StyleBox["DsolNDS",
     FontColor->RGBColor[1, 0, 0]], ",", " ", "TimeNodes"}], "]"}]}]], "Input",
 CellChangeTimes->{{3.44209355475*^9, 3.44209356546875*^9}, 
   3.49511151621875*^9, {3.49511274909375*^9, 3.4951127753125*^9}, 
   3.561296350639676*^9, 3.561296762667254*^9},
 FontSize->24],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
  "1.`", ",", "1.000091820028322`", ",", "1.000183648488336`", ",", 
   "1.0047109820820253`", ",", "1.0092588086608976`", ",", 
   "1.0138272210394048`", ",", "1.0280147766552312`", ",", 
   "1.0424009142595394`", ",", "1.0569883697484357`", ",", 
   "1.0717799645187074`", ",", "1.1019870319538356`", ",", 
   "1.1330454535570322`", ",", "1.1649792295493941`", ",", 
   "1.1978130273473035`", ",", "1.2315722139676482`", ",", 
   "1.3158254864414396`", ",", "1.4058425988507102`", ",", 
   "1.5020179012596784`", ",", "1.6047726588617757`", ",", 
   "1.7145569893748578`", ",", "1.8318517922051663`", ",", 
   "2.024509340770214`", ",", "2.237428833928897`", ",", "2.466163468420337`",
    ",", "2.718281862150694`"}], "}"}]], "Output",
 CellChangeTimes->{3.577697681038617*^9}]
}, Open  ]],

Cell[BoxData[
 RowBox[{
  RowBox[{"couplesHermite", "=", 
   RowBox[{"Table", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"TimeNodes", "[", 
         RowBox[{"[", "i", "]"}], "]"}], "}"}], ",", 
       RowBox[{
        StyleBox["numsolOnNodes",
         FontColor->RGBColor[1, 0, 0]], 
        StyleBox["  ",
         FontColor->RGBColor[1, 0, 0]], "[", 
        RowBox[{"[", "i", "]"}], "]"}], ",", 
       RowBox[{"derOnTimeNodes", "[", 
        RowBox[{"[", "i", "]"}], "]"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"i", ",", "1", ",", 
       RowBox[{"Length", "[", "TimeNodes", "]"}]}], "}"}]}], "]"}]}], 
  ";"}]], "Input",
 CellChangeTimes->{{3.442094173390625*^9, 3.44209417359375*^9}, {
   3.442094235265625*^9, 3.442094284640625*^9}, {3.4420943514375*^9, 
   3.442094379296875*^9}, {3.442094412*^9, 3.442094456859375*^9}, {
   3.442094548046875*^9, 3.4420945845625*^9}, 3.44209465490625*^9, {
   3.442094716046875*^9, 3.442094729390625*^9}, 3.442096182015625*^9, {
   3.49511151678125*^9, 3.49511151734375*^9}, {3.495112859609375*^9, 
   3.49511287259375*^9}, 3.495112968515625*^9, {3.561296353573278*^9, 
   3.561296372889037*^9}, {3.561296480692415*^9, 3.5612964914602747`*^9}, {
   3.561297486494081*^9, 3.56129748670623*^9}, {3.561297657605492*^9, 
   3.561297661489443*^9}, 3.561348586596077*^9},
 FontSize->24],

Cell[CellGroupData[{

Cell[BoxData[
 StyleBox[
  RowBox[{
   StyleBox["interpolHermite",
    FontColor->RGBColor[0.6, 0.4, 0.2]], "=", 
   RowBox[{"Interpolation", "[", "couplesHermite", "]"}]}],
  FontSize->24]], "Input",
 CellChangeTimes->{{3.442094686796875*^9, 3.442094691546875*^9}, {
   3.44209619896875*^9, 3.44209620159375*^9}, {3.44218218725*^9, 
   3.442182194171875*^9}, {3.442182266015625*^9, 3.442182289375*^9}, {
   3.442182334875*^9, 3.442182337359375*^9}, 3.5612963822689037`*^9, {
   3.561296499967198*^9, 3.561296512755769*^9}},
 FontSize->216],

Cell[BoxData[
 TagBox[
  RowBox[{"InterpolatingFunction", "[", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"{", 
      RowBox[{"0.`", ",", "1.`"}], "}"}], "}"}], ",", "\<\"<>\"\>"}], "]"}],
  False,
  Editable->False]], "Output",
 CellChangeTimes->{3.577697681089271*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 StyleBox[
  RowBox[{"Plot", "[", 
   RowBox[{
    RowBox[{
     StyleBox["interpolHermite",
      FontColor->RGBColor[0.6, 0.4, 0.2]], "[", "t", "]"}], ",", 
    RowBox[{"{", 
     RowBox[{"t", ",", "tini", ",", "tfin"}], "}"}], ",", 
    StyleBox[
     RowBox[{"PlotRange", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{"tini", ",", "tfin"}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{"0", ",", "3"}], "}"}]}], "}"}]}],
     FontColor->GrayLevel[0]]}], "]"}],
  FontSize->24]], "Input",
 CellChangeTimes->{
  3.44209474746875*^9, 3.44209621421875*^9, {3.44209640834375*^9, 
   3.44209641034375*^9}, {3.442101450078125*^9, 3.442101453734375*^9}, 
   3.5612965231843224`*^9},
 FontSize->96],

Cell[BoxData[
 GraphicsBox[{{}, {}, 
   {Hue[0.67, 0.6, 0.6], LineBox[CompressedData["
1:eJwVxXk4lHkAB/C53iXWMSU9k+RRWOnckpJtv7/oIUqWiE5WdMhuKp62lq0p
JBJZrESNY4vEJINkpPDYkiNRpMk4Zt28I8Y4Nnb3j8/zMfQ+5eLLYjAYjv/5
fwffvsbn/W7fbw64QDEYcnBsFgdIeeZw8pE83MaUY8PdpJQC3nZ0mu44eYUl
x866lsepPFdI9bTMVSg53H2UZXE8H9hm71doqcnxae1Vm2heIKJ1aAsTHTkE
C53CI3mhKIjgVPuaysFXLfjmGi8eVhGRId86y+GxL00oH83EzSI2Y16OHOpz
/IN2S4UwSxRWPmCMwth5pK8ySoQf7A3C7feO4ly9JZLGS1Ck39fGLRzFIhG3
ncksR6Ls3vL9Wp9R1GVT2/BdBa7orgmyPPsZFX6pevuGqpC/a6bQs+UzFCZb
tXJ/+gsdNS0PRBZjYE3laOsZ10Acx6/fKBiDxZxX0Z68WgR7tMueccZRG2pe
X23WAPbL+rBtJ8ZhEDs4lT3yButeJaZGto5jUCltf7fuLZ4vSUCotQKZA6U1
mjeaUMFPSKgqVkBT/z4tkzXDaolgodvqCVw/UXhUYPQeHXED8RapE5ggObLj
F1ugZqwu0OApEbi+SqRb2YozBporVWOUkOZVRTUatiH/deClq9xJzPg1315x
4SNUFSO3fOMnsXKbyuzRUgmGE/yMvmhPwS7d8Fj+onY8ic29IUmewjl9z2Wd
B6WQ8SRPrZdOY9WQm3qLYwemHKUt6WnTWKAlV62a7kCVr1WkzoYZcMpvC5en
dCLrTq0yuWwGJ81LP8zb2YWhXKqkbe8/yLH3Fjyb6IKNv2ZrmPwfKAYXa/ck
doNxqln+8vIXFO6xY8dvlyH6sYMk22gWF3eE3RX1yGDveSKo99ksDD85tGaE
/Y3ugA4Rb98ctmwKjeet74F6tu6Pg0wGObi0YYrZ1IOvf5OPme9hEEVNdFcA
vxfw38I1yWWQJM7hQBejPrhE2cZ2sphkQXthOquqDzU9KQ3JHkxChfBdLU/3
451y8PeLxUzCyD4s7Jo/gLzYoyYyLoucSRZGz68YQL9pUFxnEIuUrYxQ5f48
CPGvjZUmbSzCdTiz6rLmEDQPaNUlW7KJZPWbpvPiIRg0m+3emsEmj+7ASHZ4
GBWbBoN7VTjkkNCCqz87DI/OtJoofw65FJbGlzwYgXtI7cKpjxyS26d/W3MX
DeFYkeoiW4pEpIZ5te+m4XRfJFDYUcTHZdg4z5nGQ58X3s32FFkiFj9ydKfh
76XrG+dIkciYA9XXvWmU6y44ou1GkeMWt0bVztMIcA2x0/GhyLJQnR0q92j0
v7B5bXWZIrObgzVasmj4fqX30CCUIh+Gu9/ey6FhfDawmB1OkVj3gkO2+TTs
V4gda69RZM7M5WyYmEZ9Bfu8502KSBpj7rCbaERdulUXLaDIk3DlkaZ3NKQz
1h6B6RSJt/JckdFKo2xNlsaBTIrs/HONyLqdRu9S0aRpFkWe/lL3it9P41G3
xZtqIUUSV2+McR6iof5+WX5ePkVOd6W4GtI0btr1ihMLKGK6y1/6fJzGuLqq
27FiinCYzZmxSholsSc7nUoo0lFo5ec1TSN4sjBpcylFxH4Za9d9obFWMnDB
sIwifxioK+bmaLxs1ohQK6fIvyLNWVQ=
     "]]}},
  AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
  Axes->True,
  AxesLabel->{None, None},
  AxesOrigin->{0, 0},
  AxesStyle->Directive[20, 
    Thickness[0.005], 
    RGBColor[0, 0, 1]],
  ImageSize->500,
  LabelStyle->(FontFamily -> "Helvetica"),
  Method->{},
  PlotRange->{{0, 1}, {0, 3}},
  PlotRangeClipping->True,
  PlotRangePadding->{Automatic, Automatic}]], "Output",
 CellChangeTimes->{
  3.5776976811248302`*^9},ImageCache->GraphicsData["CompressedBitmap", "\<\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\
\>"]]
}, Open  ]],

Cell["Another check ... the second ...", "Text",
 CellChangeTimes->CompressedData["
1:eJwtyrFLAmEcxvE3GwL19luEBF0EI4SWiuDMsyBwkDbBobKuqWuIbEheTFCH
5kqClDMVIa7+hyaHsIYIisIIqiOnHDTiyPf3NLx8eL6/17uyFU85GGOe4RMy
Zupj558KY6PbUM3CUgG6d11CHkvDThY+50g2W4RlU3hadbaloZq8eitR97/N
k4GRCGmFSB6Zhi9z6OsqdmYJduLom0ns3g52fR/KBzCTx335EN6foDcM7CkT
JlpQv8G9cgftR3j2DsNf+Gd8w2Affcahkq4QDP4bOyK5XYZaM0q9dkXyj2tY
f4L+V9x/bGyvvED72EPycR/sTsDB7yIp28Kqb89tFCyldtGShNrlZPehYin6
xhr5B1tCx1s=
  "],
 FontSize->24,
 Background->GrayLevel[0.85]],

Cell[CellGroupData[{

Cell[BoxData[
 StyleBox[
  RowBox[{"Plot", "[", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{
      RowBox[{
       RowBox[{"solsymb", "[", "t", "]"}], "-", 
       RowBox[{
        StyleBox["interpolHermite",
         FontColor->RGBColor[0.6, 0.4, 0.2]], "[", "t", "]"}]}], ",", 
      RowBox[{
       RowBox[{"solsymb", "[", "t", "]"}], "-", 
       RowBox[{
        StyleBox["solNDS",
         FontColor->RGBColor[1, 0, 0]], "[", "t", "]"}]}]}], "}"}], ",", 
    RowBox[{"{", 
     RowBox[{"t", ",", "tini", ",", "tfin"}], "}"}], ",", 
    RowBox[{"PlotRange", " ", "\[Rule]", " ", "All"}]}], "]"}],
  FontSize->24]], "Input",
 CellChangeTimes->{{3.442094855796875*^9, 3.4420948730625*^9}, {
   3.442095019734375*^9, 3.442095048671875*^9}, {3.442095101671875*^9, 
   3.44209510396875*^9}, 3.44209625653125*^9, {3.44210146509375*^9, 
   3.44210146578125*^9}, {3.4421823104375*^9, 3.44218232725*^9}, {
   3.495113046328125*^9, 3.4951130485*^9}, {3.49528537309375*^9, 
   3.4952853745*^9}, 3.56129655181417*^9},
 FontSize->96],

Cell[BoxData[
 GraphicsBox[{{}, {}, 
   {Hue[0.67, 0.6, 0.6], LineBox[CompressedData["
1:eJws13lYTV8XB/BKaJKkUimNmiWJklpuozTQPCrN83hLMqRBEjKT0EQhiRKl
wd0ukn5pkohKklQIIVPCW2u//vF8nu/aa699zumee+V8o+wDuDg4OPJnc3BM
/28ZMPKI/dYJOPBf4y1uE8nolxI6a6ZQLbjYmCzPz865LmE67YSBDGMyKKWY
skVp/bTF91qZEKuWropcCcdp2yp4mhLFTOnz/2Tcpl3QfsWMTFr6nfRR8pq2
a9mStcTF/wfrqIT/tMtjt1uSehPJm/dyAqedfUjVmmgpGJaPy4RMO3jdAxuS
w+V9aXFh2LS1akw3EJ6B1HPOSpHTbp+wsCW1/R0t9xyjp62xr82WRNv6W27M
ipl2o4imHVFif2sY72JOW7Foox15sXSPyQGJOJxHINKOHM8XZy/22Izrr1+1
I5ZzSwxITvy0HZuk7AlH0uoa574t0252LbcnVR+bV3yS2Trtn/4+DiTcy6ti
j8+2aReNKzsS+dZPmrKF26fdLzDpSA5eEVaxU9o57YyRUmdiJl1U9DYoadpC
17e6kJ0Np4XuOCbjeUV0XInbztfrD3xDFwh2uhKdlRoH3LJSps1daOdG5n6M
e7hYNxXn7yhyI+/Os3i/dKFv5Nx3I/c9Z1mQhF3Tll31yo0UiG5I3yeRNu00
RS13sr3lZL1zLdo2tcSdOO/u51Lw2I3Xx9bCgywzVDX69Bs9to9zIxH4FpNU
l5OO8y5t3UiGS2tZewz3TNtA74Inues/Y9KhD518NsWL5EpZ68smZeD1C3Dd
RBI6jyeMyuyddj3M8yYOmS+qqtno4s9h3kTTVOlbms++aeesrfYmvJORy+24
9k87y+CLNxm8fjNGuhANzaI+5HYYR/lbk8xpGzvL+JDTCus+Vg6ic+LFfEh8
zxGN1N0Hph09k8OH2B3rDl2vdBDPU9zrTTSsFC5JPkB/mXXFm/DMCB8eCjo0
bZ77Md6E6dl91I37MN6PDHVvsqnm77XbjmiO0cpNxFpU4dHi8+hmf85NRD9m
7dj+b+jGe/peRFT1sKZr1pFphzvs2Ei4dt+wIUNoHuE9HmSs/1m4ou7RabM7
0tzJw2y5y2Nd6B1RXq4khee68l6J49O23n3FgaitPZJREY32Bzd70rE76m3P
A/RIOacdUZyhcVkz/gTaOM+aNBvxCbi2UJ/6uI5sTh4JT1HMwudPwmwtafhT
pNnZgRZfMc+YRBnsOvRH9SQ+r6sl1xDx7T5jSilooaO6+iTkp3TF1qXZ6Oe/
tYiw7qRwYTqafdBLldRu7o5tfoEuCDWWI343qju/6ZzC3G/TfCLwNWuFTCaa
Y13WN1blss1ZFq+pD6z5Y+gV7fAjRv/0tBkbioVhVtky1zNH0MnC+6Wg7MPc
mvoRNLslSh5cNT5KfFxzBve73rAYOMKaty04ifbmABW4dKmkh/GR5sn/qYL9
SIZBqFkOeranGvxWCso9loNmaE65KMDs762vaG8hJzWwLlLYNGSZi/vrmKnB
twFO9txzaO+LS9QgT65fdtUvdP8OQTUw9yYpvrZ5WN82rAqf8nIG9l+kvlOj
CtkvtplU/kWzt6epgpGUW1GfUz7207RQhXfuujN5rlALzVSFpma+6+JcBTif
d50KLBrd6ndlCbVfmAow+d/ON3ZD9weIqkCDmmv90zQ0u65GGaJCVi7m6EVz
PP6iBPUZ558cn30WvSlDCcSLRdJVl6OTH0soAXvoy5D9PjTbTXsxCPuXFZ/X
O4efH4UWChC4a5Gbvj/am7dZHurOHeBtO4QueLZBHvxfhYX+HEJzbPWQg2qO
HskDwoXY7/agLAjIWj6UA3SBe4wsVHqpaFidKKT3f6kM8O082fuSjWZkBi4C
r9xZB+JG6fqPJdJQcWuzIa94ETr9rxTM6h38kGuCZqzwkwL33w552lHo5Lfd
C6FM8t76B6epC4IWAre+9j+PBlofyL8QXN3Olo19RnM4NUrCpx5HvnOS5zF3
OCcJ6V48AQ4m6ORPJyRB6lXdbe5wNHvLIUm47hclWXUczcHaJgmWQ/Kbg1i0
vs1FEvqDn7aJD9H6JiVJ2PJ+r1qT4AWsfzIsAYKRhru366LZMmck4PzY2EsN
b5oPMSTAILZIvy8DzYh+Lg6Pv7mcOHSNem6AOIQm8I8xumm97OAC4PxNLL9w
XcR+fC4LIDuReb5QHc1hTMTgfupz91mJ6OSTYaKwceaBypvnad5RIQJf9jCE
QlppfmRsPsgeuHj/oUwxeoO9MOw4uVnryF00B2/GHJgvqbrf+D3NLxXzQ0lO
75uv8y9hbnePF7rOmpxxDqB+8nEmaJfOmyXFU0KvV/Wk4X+a971btKizRH4Z
el9LqNvpRh2395vhgaqX0a9KqH9e/GCouOrYw6OPqd+FDBvW1pkrmU5SS+5/
ZWgHE8nfFC+jg5c+MxxhX+m5YEM9Ft1smGTis9I1ntpbo9JQrEHkCG8+df+X
QlapReP72gfUyfPuskwebjcPH6Mujm5mddssPSstUYouGHvEim4f+N1qRL1D
pJM12yHLOTmUeux0Jyvvybpry45RC6x9wlrh+of/dd3/8+dPWc3d5YHHB6nD
7Z+zfD3975jNuYIuvdrL+vVygdSPFdQi8f2sw74P44u9qFtnvGYpvdn5yG0P
9cG/b1isIG0N/nJqHv+3LMd3b9JvPaM+uuwD6334qVcRnFfRYhVjrNRP1gYy
atQw+YVVPn79c8p26kMLf7LWbgmyXl5EnTo6wer7JXlxsJl64M0fFv+/lI1r
F5Wh/1PgItkhLl4a5tQ7m2cQxU4N73mR1Oa7ZhK41OXXw6J+JcJLai5lVd7U
LEfbWAsRjk0pK0uM0cm+RvOIuUj4zRxnNMNypTB5vNOoJmUn9fKFIuSDw+gt
q1bqw+ULiA5vlyEMUJfsEifbyB2i9Z32b7GWIOzY0jUKfNfQR/gkyWzVk2zR
RWh2Wp0kWd+XYsSjTa3utZAcPxZ+d8IMnfxvbCHptnAx+eBGHcmUInJ/jepf
RqAZff1SJPi6hllHCl1frC9NrgYvaKg/QfNFO6XJuDTX2puXqNMuSZPVj0cf
XGJRi9VJk9SMLoucR9QPr0mTRsO7/x18Qy18SJoIfi21TPlF569wlCZOxScf
xs6pwDyIW5rkeKZaB8qh2a/zpciAcESL6wrqVhUpotLost5qHZqjoWAhiUo0
bjP0RCd78C4kVdpLbLViaD9xf0kyObzgkfxuWr+tQoLstf/QMfsK9eel4qR9
9jOHCTatb/VZQMRYdztHO+l+/ZlipFA5++mjSVpf/1iEsCaNu89YX0fzm88j
3BVLPA56Uwf6CRHLIPHe5Dh0svmsuaTr0YcXATnU6mf4yaI9z7xcy6m1x3mJ
v8G9l5b11LpuPOTzhexXS0dpv0M2M4nexl2+8hw3MH/6cgbZOS/ytYjIDfr3
kcZF6htc/WerUAev5iT8O0ze/FpNrTabg9gv0wwc3UD9uP0PK3tIfLjPj9qT
/ZvVd2ZG8KMt1N19v1iL7T6O3NtPPUPzJ0syaa1+0Flq9yPfWUJXCvbz3aQ+
vewba2bPr94rzdT2QuOsCR4HTbsB6ueaX1ljK0uTxn9Qrzv4hfXGf+ajk3Mq
0WlLv7C6j3rJr1ag1pr/hdXOvhnbp0fNWvWFdf+j0P2U9dQehV9YtVKhYov9
qbltv7LKLe8FNW6lTlgzzjqfIFUTdohaP+Yb6/SFzXxzz1MfH/zOOtzZ6lFR
S52d/ZO1m0vlilM7tWTmBGubVsrfn2+oq1iTrCiv7g05v6lb1f+x/DOnvmzM
q0KbveMg7rWZXwaUqN+5c5ENI29M0g3QyWVDM4ip2JoTqvbU9pkzib5p9lBz
EK2PsZxNFAss984/Rs3Px08kWgu7q4qpl/HMIYKTk+ruhFpdfC755VLWWvAW
zXhaMY+0zhUR0WTcxP4HDcTIPcOIgEdOaHa4/wJSHdZQFRdG3bJfnBQ+SHCr
y6L16x9Lkuxvj0q8Sqn9pz4fDiqoT3LeRTPezZImCUkv8iw+UB+RkCERV1aO
veeqxnoJXlni23PI6JA42rtwpyxx5X17VFsTzYgblSU2usaDT0zQBUft5Ihx
wJkVW93o+j+lckTv2Hi6VBRa9sofObLkjs2z22k0P2IsT+Q/XVD1O03z49vk
yQJpju2zytH9WUXyRMDKrfnSferY2/KEa2uFtE0P3f/vf/LkxwX+qLEx2s+R
LU9GO/3Zx2bVYL/MfHkywEXm6UqhkyeD5UmX1gK/7mXUP6XlSbNX9I3EtTX0
8+y2HLmb+d9MOU80u3qDHLlZK+9Sz6T+0ypLSke2Fwdl0Po2kCXnxJ784suj
rmLIkJOmmlZXr9P6Q2+lSSZzT47df2iOkG1SZEvrqjXZ4zRv3ChBBDUr3/zH
U4vr49sWkKIDWpm/pdDsCB0x8sha+bmXGc0P9ggT9YcisYuz0Bwdh2eTu2qH
JVxK0MlCn2YQ13387AxC8xELDrJ7Hdec0SFq5pfPrJcPPl2o0K1D32h9Yxiv
HGYzaEWtNfbZUGDP0FdRb2rBlz8NV5m/YGzNQCeHac2A9vOuwyU51CfjZ0Hg
zM4DveW0XucSLxyrb+pe85zmcq1zQU3RPCXmA80/ec0D9q47yoWctzCPbhKG
D8bVcbPU0AzTbaKQdm75Qj1Asy+wxECSq+xOiD2tb/6yANbeOS/Yso3W/9WS
hD5Zucq/B2m+edVCiEvO8dAqpPlubSng61/A5XuT5v8WSsPZNceKjz2k+Z1v
0qCXL7jh/kvq67cXQevfvd++f6X+b6sM+HvNzFHhYeH8nMKy8JuVbOwuhZbV
2SQLR6UnR/Zr0XxvkSyoJG45xDJFM4QGZIH0flnxyZXW9y+QAyeDyF7ZCHSB
iLkcjJ55m2qfgk5uC5eD1N/+qmkn6Hq9TDkQ9+hvq7yEZm8vkoOyWo/4YRa6
v7lSDswlu6QkOmi9P1sOerfa37McovMk18sB83lLyI4Jut7vrhzwrlondFWQ
4H5utXJQkF1f9VIezSgvlYOVP9d4ztOlZp2Sg2aXuhkmVuj+7hQ58Lu5siRu
E3VIgBxMiFXYXoil9e2mcnA4fsmPrj1o9lZZOWCtUDRdXY4u8G2VBccT+e/C
62l91llZeDcueSTvGc2/MWVhwY15fZyct/HzZtPU9d6Y+dtxUAydPFYrA+f8
3zxs0EBzWNjLwLBBm/ElY5p7ji4CDdGamv2u1F37FgHzwzmtyEjqiKWL4Ob9
zIu2adRDPdIwmRu/aPlpNFv8qDQYx3ufEC2nfu8gDRnrLQV+3qf1TgrS0KKk
s6u7h+6/kUsahP9JT9z6TOtFv0pB6ftd1W0z2GiJCSlo7fr5lS2I5nghKw2f
70UsrZCg+dsAaRApHwgtVEQzHjdIw8oclwvHl6KTDYwWgVtG86vd+jR/1rEI
dsQZSW8xow6Zej7zvKtcg23Rsj4SsnDHWv24mwfN/XbKwqBeQZtlIN3v+jtZ
mLVYlN8ghuaOnnJg/edvyqI9dL5rdvIQ+TaWNfcouuDkI3k48mTkJ0cu2lve
UQGeXumIel2B7m/3VAQfrwuexX00nxGpBGmWC0+dekv3M/+gBBdWHu7cN07r
nUKUYVRwm1UE3x08X6qTCgj+/pjuJYou2FuvAsuG/e5ukEX3L9VUhfjbNqu0
V1KnfVKFU5fvxikYoRme5mpw66RuuYg1mkMlSw36dpW+n+mClj3Ypwac0XLK
P3xoPUNGHRQ3ZvmOhNP9f7iog7kFf97zLWh2XIY6hOgkP29KpU4uV4dM2W8i
tw5Qj7apw1WBUNsr2WjvI0Pq8Ohn3/68QjrfhnF1GB90eHDoKt1v3i91EHvU
yJVSQ/drmMpXsQyBWU/rg4fVYeOliq1+bbTfr3Z12HlCudKxm65PuaYOZ1Ny
xsze0P3n7VWH+oh5Grpj9Hz1U/MPuaUHqfymeY20OvCa/z4nMesu5lI9aqCh
Hd3HNw+dLHVYDdYveiMxuZB63EANYvjcnT4oUb95pQpVAybNbQZotpGoKjy1
SPl8YC11/AUV+H6ViFnbozlclqmA7vZVPo1B6IKyFcpQPX/pd/ZRtHfmzMXw
bGv4wqRcOs/VaEX4+fISw7CY5hHPFUCvVHF/DYuut7ogDzWmkrIVI9RvGLLQ
XeJiFv0VzVjpKgMTQidCNf/SeVJXLAL9F3MrS+bfw7ySXwrcTWy6gxdRr+JZ
CNsu7funpHqP/v0JS8LpuY2Kb5aj2SeWSEDt5pmWhUAd5C4O3T3GUT7rqAPO
LIAJo+TjMo7UFV+m3kfFrJoXXrR/sq8YrBb83XcmhPaf+0EUNsbpcbvHoZOv
HheFHd2bVcWTaD3xEIUcxvX1T/dSl5qKwq0LY7HHj1Nn2opCr4DmKft8uj58
hyhMMsOIUAnNu++LgtTz4tetN+g8O9TEwHDNEM+B2zTnLRYDr/MKmlZN1GYG
C2Anv48D7xNaz/1mAeTF5CU8eEn7qxeIA+nqyd39js5fGiYBfYYS90y+0TzD
TBL+FjqPcHLUY79H6gsBoh9p7xRFc+iLScNtngcP4hlo7yfZstAfyf1Bxwot
O7hIDjieGAl/daJ50tT7i3H21saoMHR/1mV58J49kbIknvarV1eA5Ajdi++T
af3LYgVgr6r4HJRF85MnFaE//5OY0llqOZ7FwDFricHgZTrf5tjFIBse6nOu
ivaXfr4YjDoupnvfQSeX6imBr96by4uaqWuPKEFqnvyj3qe0fuS1Epzj9v5+
+hXdv19TGe6G5i50G6X97ZjKcP1tWJjXd7p+WYkyFAXr1/lx3MdcuEcZjg/z
8IfwoQvquVVgd2CXe6QIzWWVVSD+zfmS2EXoZE5jFQj0j5tIUKH1VlOfhy6v
jS13aqM5hr1VwMJ33uldBuj+O/4qsOrVy7cZ5mh2+1Su5n111UFb2n/O1PqF
L3fsPeZO+28xUgEBL6vn2f50vYiSCvzplVDNi6T9P3OpwEePkYTCBGrpZ8rQ
113VWJyKli0/rwxtbrvFr2bS/EGYMrCfOQRfz6L7p6kpQ7mLfHV1AZ1/3oAS
nH06NpuU0Pqco0pw1Om2y70bdD5XAyXY1XngYiOh8yW/XAxxDht/tDSivR13
LAZnu19Zz3rpvAuLFGFt+4OhF0O0f+lSRdDbkLXy9RjN5asUQMJm+dMP3A2Y
61fKQ69FhOiMJWjZG3tkoeXB6gAeXXRy63sZIOZ8lXOMqMXvL4J804uO4k5o
9l2mFPgyXh1bkkjz9z0LwOF22WvtPWiO02wxMIWdy/WO0Fy7VBQWGyx8bHye
5tx580Gs7q28RRmaYXVRGGbpVzNtamj9KdY8+FGdftf+Hs2PDQjBiK6TsGsL
Xf92gRA8r1Lw9eyi9VeIIDSt+HLN9xW1xeY5UHuDzRn8ntrSRQAuLz9kF/GN
mhnMDzkVnmeZ/2i/k6V8kLlM4/MW3gfo88p8kFg+wUicj04ufMELkUv/O5wq
TfOwDl7YdPVk/x5l6pMz+MB2SaDWgWW03iKcD4xKdZKPrqb5Lh5+0Faf0X7S
jOa+nfygUPJIJncDtWSzAIioFkSdc6P139/PAe7iyNsX/ahdtObCNyXDuVci
qHsthQAGjB/sS6BeKz0P0nMtkoJ3oRnjf+eBmIjjJ4VTtP/w8HxYyRnWdroe
zd4uKQ47b0XvSWij9Z1aEtCwJX6NczftV7dWElw+ppTNG6OeFyMFCT3ZhzIW
NuLzY2QmC+ysvLWBSmgONpEFHvuifybL0N56y+XAdk7JTTkDdP/ic3JwqrEs
6p85zQX45WFgV6XyCzu07JYIeVBbU/eydiPNJxrlgTnBPpkd1EifH2kFqK1s
2BDPpPvfC1EArpjm2Y6J1O5XFcBSo+P2soxG+r54pwBHh7u2zD1G99+8SBF6
zr1Y+iGXesc6RVD0ej3cVIxmHwxThHCJt/nF12m/lDRFuNH50SWd0P2XH1eE
yUPjc/3/o+fdf1oRTK0mHhh10nnjpz5vM2dxJMu8pOf5sE8ROu/M1PvzltZ/
jFME6UT+se5xul+ykyIE6s0rrv5H80oNRbj6Vcw7i+8/zM9NKEx9f5ASjxNF
e4feVgAIlW+3k0UzdLYrQPpilYyl6jRfpqkArf1LGHNWojnOPJMHsZzlP98x
aF6xTR68XFaVN1rR9XdE5OGC8JrgC87oAomLcvCxxVQ2zYdaVFsOkkxtD6/Z
QufZv1wWGv85WUin0v6NTjIgVOfB8TuT9tNbtQgKlgVFV51DJ+8ZWAjsRTtt
l7TSvPWlGPB0T/0VPKfrv0+9721P7GWPvKb9Ry1E4BX/Ca2iXzTfe30ecP26
LLRwcRP2+72bFxa2GH9dsxTNkeozG3TOPn/iv4o6xWEmWG+Ort5rQuudNs2A
gHWzz1y1oY7L4ISd0nmJj11ofXfRP8OszzreP32o21MmDcvuPzSWDqe2Kftl
2HjKd7FxPPXsFT8MX0X8mh2UTD0s+c1wwujwu/37qHlCvhrOF1NuKT9OfUv5
i6HGO1bZk7z/z7fps6EZcTw6UUw9V+KzodfR93Ey16nVNn8xjA9MdTFlUb84
/93wkL6EfsgDas+sP4bFguVSBx9Rv8qeAewB838VPdRXrvFOfR6+eNX1Bs0o
3i0EX/bF1U9+ou5oEQH+TfwX5SbQbJtSCVBcfm6vOfdDvD5yUjJgOHtVeJgg
mr00Ux6ce9rWHxannt+6GKLKApdVylPb26lCxq4/87s10AV75y+BGnX15wpG
aNnq89rQ8e9OnYUVzQ36dODdY9e8CCc0R9YyXZDake53MwRdbqJoACtspc17
Y+l6rzsA6xVvqHDuRD8Lr2VAUvOrD5ZH0e12B0xgQMowoa8WHc15bh1cYn3N
nCnQjOul9zvAyn/eVQ5X0YcV/nqDtQ071awarXM/wgf8zshs0L2Ljr/a6wOH
dfuGJZ+iGbOqfeFtlIfEwB/01SJff+AgtW8ez27BevcmfxATkKy4Pw8dTLQC
wLj4meWlxWgVq18BkNPvtCPaBt15fksQVGhWWvi6oMd/dARB4w4RUUcf9N14
jWD4Jv74iu5mdAP7eTAIBGlvU01CL4peEgLylUfMF+5FB4okhcB6O9uXf3Po
fjxSoeCfX3Z57AK6HoJCYfsHwYSBcnS2XnkoFO9tEWqoR1tarA4DzruWxgdG
0c1XdMJBXKhEMOk7OvxReDhoevH2RHO04udl4LlwcJ94EOsogq6+PzMCoi2U
GeaL0NZJyyNgT1a6gJ4KWnC/VwTc0DY7v9AAnZdYGgFNyUUxc8zRBS5tEdDf
OgP+bUDrhX6KgO9Sfnyf3dAfywQiYU7Y3acDfugKBeVIUKyRK+yMQLezIRL0
Z6dENWxBj6c6RIKtU//q6hS0RmBAJAQWruEp2Y8eDYyLhB2f8zrPnEBzpyZH
wrE1fwsO5KOLbuyNhJIDnhFJl9Bek4cigd1za1XMdbSay7FIeKoqNcuPhXa9
N+XRLds7HB/Q86w5EglcDd155o/QUg/3R4KEiH6YXg+aEbArErR8T+mqvUG/
m5MQCeblP2dIfULb3g+JhI1/Xdrn/EILZ7pGAtP6Zs4/rja8v36mkZBxWizk
swB6wmpJJOSPbF7xWgzNsJgfCVUrn3A+kUUvcv8eAc1pOq0NamjxtKcRoD/3
IdeRFeiV18sjoPiUj64HA629c08EiCn+DFtshW566x4Bu64eLPjkhDb4rRYB
Y3qLn9R4o+2rf4SD17063rQw9EblO+Gg/2yEKZ6C1tO1DIdi36SLA/vRFsO8
4SD2QbS3NAvdG9QQBp85TcyMStFP/64Ig2L13AWhXWj3grEQEKtabq0zgO4e
PRkCaYym5L+jNPc2CIHykt9x6zjb8fp/3hEM+2+r9L0QQzvb9gXCXe64n8ZS
6Fn+0YHwc91t4WI5tNoCjkAI7HRay9RAi58Tn/r7fZtaPssYXe2o5QdbNVub
wtai3UOv+UJ5rMSbdmv0WI2WLyz6WyZxxgVt76XmA7+EX6QujUDLbhf3gnID
XSfXbLS1OcMJhlNSo1i5aA4fWUdY9KBlr3whukiJwwEy7fzJ6BX0+PnbthAc
eEQ55R6tL9tnATKH3/+69BGdLLZsCRCfpEsVX2len7EYvJbPd6v7SfMbPxZC
zlP96mauR5iPbnvGEpfeF/9JjPrNWQ1y86O00s+FaG+1M8uIM/vaEw45tGx0
mw454fdcR1gdXfDgsz7RWRExKKlFfe6FIemcxXlcYQV65KALgwiXqHzVWYNO
WPbPmFzbfuucoSl67IOBKbG1sbU3X0f3Uw0zI2OLBjk3rEcnW+01J4fGtlxz
cUBb1GatJZp3+X28Xem83UctSOuxfKEQT3TwnMR1JCJgOTvGF3240tGSCOg+
iNoWhH62TMKKXObxkNkVjhbq/8+KWHZ/bN0fg7aVCrQmby+n7jwej+Yx+mBN
MhLFNHO3o8UvetkQ5Q0lL84n0/Oer7EhDbJw4OputNbRPzYk8Msjg5v70MVs
1fVkZn3A6O1DaMYuw/Wk6MSvM43Hqb/qriemQQesHp2i/S6Kryev9eR+P8+j
86/vtyGpfJUlA4VovTOHbIhcr4X7+2K6fo2yDWFf6eUdv4LOeHfRmmxKiq6Z
rEC7Wglbk7+23CEzq+n1EQyyIrny2eKCLNq/74IlMRhXbxS7S/sFdKwjvfdv
b5F5QM9v+c6CbD/poKzSTO+X9qe1RDJk+KnWI3q/6l+Zk1r97emrntL7cfau
Gfn54twby356v4idCTlZtvKEwxt6vQ04jcnKlCbTje/ofklnGWSz4pfCiHE6
z/aI1eRLqJHvYZ4OzN2El5AjBk/mnZqD7hdTVyJagiF3zgrTfEJ7EYm8dlj2
uhSao5eznfX+x8u+J1po2fwNmlAVdOiu5Up0gULickjuggu3V6OFNrzSBbGb
uRGXzNHiB4MZYBzvMbljI+03P2sdnB5/KqGYgR78ou0MAf7pf7IPoK1FvF1A
q3PFqznH0CM+ma7QcP148Y9cdNGeV+7wmWmv+/A6Wit4yyaw+NziyHyJNrcT
8of5Pol6w4Poc+1H/aGvXUNq4zu064r5ARBXvv+12Tf0F+c5gZAftY4pwf8Y
3/c3BoMg9OVPp4NCaG4Rx2DQ2VC8aoYY2ruaHQxNmrM5P8ii1fYdCYHvH+oP
sVei/x6YGwZ3PONiVxigS6yCwiCzRcGlxAjd0VEXBvJXUhcdt0YL8HuEwwcp
bS5ee7R10flwqM589SbRBR3eNRoONuGMK0G+aMmB6AgQ7/10uDcIve/ClQgY
sMqPs4tAZ/cNRcCVuvWuDUy0RqpUJCSo/129OgFdv3d9JJicuSJTnoiO/7gj
EgT5PWcs3oUeuXQxEp5vExg+lYHeWNUaCUXv6poED9LzCH6JhMiTGxRCj9F+
8vOiQNf09fb72eiBHI0o4Pgc3ymbh27aahoFTbl8S3YUUle5RsFxy7zdXcVo
YhcSBV4/lvVpX0ULrYuPApWi+ysPXkffOJMUBZ9t3Q69rUYrrdsdBbV/RodN
CZ3fbk8UpJUkMwruoaFyKl/vInLqdyM6b3NyFIhzF392bkVbHN8SBQPlqy0r
HqO3zQ+LgsuebefmPEdPfnOPgjg+v9/BfWjFNWujAG5+d6h/Te/fl6VRwOO/
r1TmLTpOVDQKOoQWzdz+ET2r9Hsk5LCueT79Ss9zqzMSAkLNqpb9QhdYlUWC
5oLnggf+0ufJJz0Sft4LDxqZ0TltJrd7JGRKHxfPF0QLCv+IAOcm5ZiJ+eiK
A+wIkNlS95+TBLqvOj0CKtoHtgko0npz3gjYkRj/OEgVfZx1PxzM1fg07mmi
z81NCofnu5a92LoKHRg3EgbntO6veAJo7rPZYRD+wvWglin6b49ZGHDoJq8Z
Xo/urjoZCkrvWs86+qO9bkiGwFiW70RZCJqDuzIYak2+2/NHocUHrYPBJlea
++5WtPnZzUEQZxseuPQQOnTNlQCAP//IvuPoXlgZALNLji0YOoW2jmP5w+kZ
dY05RejwvgY/uFPFq85Xi+7waPQBQemLnwYH0Qae+h7AcN714vVbdH2moTsw
D216OPCRznOC4QZPOcUv9v9E3+BY6wJ5QxlevQJPpt2s7OEA7TIB1j3z0Jm/
fe2By81Iv1sM7bgp3A4CH/4SfSaLjt7NuwE0y0NbHuugOXTOrwXvt+Z1HavQ
jcI9ZnBUXuHSI0AHjy4whe/He9LaLNDs3GIGqLTeZLbaoIU4fxuC++zj3i32
aO+RKn0gW60NHm5Et0eE6MBYhYpakw9ay9B3GciPcov/F0jr5V5rQLoX62tD
NFo2u1wOqk+eenV/M5rB2SgO79o3t9Vvo/MeWDkHbEw0L99No448+Zm1cwff
qTt7qdf68JHyyqF09kHquu2iZODj3bjbx9DJWsbSREQl35dkU6eukSfmPttt
Wbl0/6ysxSThtAvcOkfPe79QhZQ8Xq5RdxHdn+ivTnoFhCRrS+n8Ck+XEEHz
0dk112gu8n0pYSQ1frtZhR7r7NcizOqi11V16HKJqe9TRZ+TH1Wy0YcTVbTJ
UzXP2zfu0/Oe26NNePxXXbneROsX39Qm+rmiZyraaC5ZqU3Cn37OuNZJz7dr
pzbJm9saX/6c7u8uok3aLUr8y/rQBaIJywhXarr91df0/itc1iI6db6MKyO0
34DnUhI4DpqlH+j6Nt4lJHvJQqnLX+j6no1qpCnwB2/JD5o3uSmTyfzHP4on
6fXzmKFINJ+XvbnI+RTrTTfKEm/hzMcXZqEZka3ipD7NtKxICM1R/XGS9Z0l
m1soSt0x/7Whyo/Jfeck0ckac3khM6QysECRWl5VDt4xrmTwq1GbbFGGteLn
S+KX0vXXeDSB68Hxj9b6aHby+ArYqhgX/2sDOjv/qDE8/R2W7e+Ero45aQo6
j/1q29zRY1IXzWEsxeHv+QC07NJBSwh8qZ1uvx2tNeeVHdRXqRWzktHRMNMB
5A/KN6mk0/OqazjCCwNhwX+H0RY/k53B8fTnE5cvoA93GHqAkVP5ee4OdJGU
ry/kaRQ/iOpCH9320xcmZxS87e5FP/15wA+qKw4tuTZM5+up9AdNoahKzz/o
uJnfAyFzOLCrkatr2rfUUoPgHfH6tZwHrbNfIBjOR6w35JuPzs5aGAJSD5fc
r1JByyvLhsG2c4uH5TTRJTFnwqBrqzTvgeXoZ3oi4XBUZY6NH6Bd3/4Jh7F/
3FGtJmjLksgIWN81eXjVOrTkyd4I4E0f7ZzriGaUTL0vAj0Hv29zQwteEYmC
ep1e8SEvdNHxqfdl8uuHG2+FoIeDxaOhr/beTuUotHOaaTSsPlpXcDQOvf1r
ZDR8Z1weDE5C77tGouFW0fszW9LQsumvoiGVR8MhfS86tI0rBgTbS+8UHkPf
vMKIgc7lHxIqstEL9D1j4PTJJVp3ctEfVBNiQGnT1by+i+g1iy/FwOjdj04f
StHfVG/HQIXS0jmT19CH0h7HQMK+qHq+m2gj7aEYgI9l2yVuoeO0fsQAt/2Y
tsoddPuOWUxoqtR6t7IBrSsqwoTDEjFnzR6iG37IMME58ZqrYzv6qbwaE6Re
fZ7r9wQ9cVybCQOm2g9iutGcNquYUFzM3Jn8Ev1zHTAhUuD6ikOD9P7uN2KC
TvTX0dy3aC4hEyZMPF5eVPoR7fDMmAls3TiPuq/ouYMMJqSfuSHc9BMdstyQ
Cdb/xv979ofO36DLBGG/FSnDXM+m/TFPiwnPGjbrfZ+NvnRLmQl5alWfuOeg
FeSkmeB/8PuF+cLomy1CTFD7stJLfgGao56LCWNOW0SXSaE7Zn6Ngcqam81r
5NAGJ17FwDbpn7vWK6Ez4lpjgJGit9pTHW14oSYGZr1J+BKmhZZdUhgDzRY1
l7atQC8R2B8DR0t/ee/VR+eZx8SAq5C+ePYa9NuXTjEw2FWbXrkOPQckY6Bk
9W/D+vXoP3wT0RCdv/pbhwN6zPxZNEwG3vIb80QXLTocDSLfWQx1JvpnbU8U
dLv9/bFqC9rbd1cUFLCgzGIHehRUokBj923pwHT00MOQSDAVuTNRcBpdQlrC
gS+Bs6IsH216wjsc2nuMQkgRWkzscxhsLLzb1XMV3erGHwZx2vU3xO6hJ3qU
QiBQR7bgSCN63DUvGFxX7tgv0Iq+2zA/GFbr6/hyPUdr9/0MBC7jorkfP6Jv
cZb5wyG7tND7ks+nvfFR0yZIduh3Ysiik02PeQHTycCobjE6YZuHJzi7jS+4
poW+5TjqDlI+/vdzzNHVIuLOUBJtKhvHRHvrs9ZBDrOA/9MWdPC9w2vhQNzk
95BEtIpWpBlEJ9xo2ZSBFi9eZwS+24Rqug+g2YFHARx3hBc5HaP9zC7rg26y
4narPLTQCa3loJKaHNhQiO73ZiwFybReO6NL1O2bVODvnuMqujfoeb4+E4Ox
vWPzK2rQHBEpM+HVfut/GrepZQ8+YNUf4n4q34RmjP8nSqqOeN/JbaN2tpYh
xcdulYo/ofN08SuS0yfEs4910/0ChFXI/pNxuwT7af3yKnWy41R75N436IIj
XzVJ5BkNd+73NPd/rUW8czPMksbQtnxi2sQ+f1Br4hvNO+cuJ6ZnGVKbf6PH
nrQuJysKc2aPcXSjpe10iNL5n19CZ6ELKo/rEPGLjn1v+NHR9id1CN+l8v+8
56HLC5x1yGSJQGWPGPqwTudy8rE0uMBZCp0sLrycvLxav/+RHF1vJzz1feID
96i2MlpL4YUWYWuYWR/XQDMK+jVJedju0m/L0ByBZ9RJQcl9ARddauOPyuTw
25kR1Qbo/ie9CiRFxbxFwpiuj3myiPheaDjQa03r3ZtmEvs3sz4a2lMnD2Qb
miiuXZ/vQucjCbNB8dwDQV9fmpuEy8NQbuOh4S00nxWmC097ecYsEun8w+ar
4cHCdbYlqfS8YmvWQPGp/4QiDqCDF942gdATTUe+nKO+lW4NHzKbj/1poeed
2ewCfQ8Fxr0eo8ezeNyglc/Gkf0MnVlo7g5XM1pEdr2m1//L/Y0QndZ6gucX
OmvvoDeMb28/OV+xBz/fAh8FwGCt0M84VfTAptBAePLL1vWpJnroLWcQVG15
JH5qFbp4lUYwJMR2nFq0Aa1VGRoKwRXCE0mO6AuS30LB7bO9+ys39NiKxDDQ
j3osWeSPLtVID4ffoZ1nVLeho48nRILjSs8jmknoq/ZDkVDKOZS+PA1dkmA3
9fs2+0eM4UH01r650XDTLznI+Bh6i5dRNAgt5fVcm43mj4uJhjv3JS3szqEt
TVuiQfJIoaHzRXT155/RwNyosdyjFM2QVIgBxa+GiwKq0A/rmTGQSBrmh9ah
E1Znx8DTvRt4o9joU2K3YmCPrM94QhN6ydDfGOh///ZtYht65aOp943eTebL
1E70izmrmXAk9Xfnnudo7mxnJryzSWvK7EM/CotmgonEHPaR1+jc3RlMyBk8
UZk1gp49kMeE8bJFl898QA8nXmeCzfaLBQVf0A7ODUy4YK6Vdf4HOj+4iwl/
59XsL5lEb6wYYoLLC6OUMs7eabstG2dCeXFT/I1Z6MLX/5jAG+cQXsOPTn3A
Gwu+a3p9iBB6R8+8WKjlC3C5J4p2XSQeC/OffrBulESLHpKKhfCz8cYtMuhv
GjKxUB/+T7dDER33Y8rSehlLulTR1h8XxUL8jHkKvZro+HlT69taT4m/Wo5W
9lkQCyqn5QWH9NCPXwjFQnLA5RnvDdHqGTyx8FxL59cnY7S0z18maE/e+ji+
Fv0k5AsT9j0wG/xljSaFg0x4fbT1+V87dIrQEyYYeLm0zXBBc1bcY8IJ1f56
no1on33lTPg4Hlw7xwfNnXOGCfn7t51fEIb+b3M4E346zzgjFY0eMLFngq18
5mG5zWgNl5VM4KrJ3a6ehH7j8SsGPNKUYrTS0AZOz2LgxoaywBV70QcLK2Mg
YIhtt+YYOscuLAbItXVrTbPRS+pMYkAsscNgXS464MDU94PG+YPKDhfRcqn3
okHdaPbfwDr0BecZ0VBecln5GRsNe7KiQEfE1m5dA7pVSiEKDIazi9Qfobsf
aEfC+gNqVmND6EYvzXBgPrfJ3ir8YtqzWkuC4LvxlzvvFqADW4WCYHtp1nsP
afQNgc2BkJb0EkAFbVqnFwBZi2PecAFabUO5L9TEHNfODEFbc026A/TobfwT
ib5VddUN7pq+2B0Zh1Y083WFpgVKz22T0J0rW5ygl3UzSfQE2rakzha8lTde
Sj+Ndr03uR7eHOZ4/CMf7W2x1xo++q1T6i5BW2yrXQscfD3NeWy6vkzRENJi
k77PbUAfTm7SA94XCrIpD+n6/H06IFweHuv3FM2xg60CWRLzcjt70P2CX2Rh
4a7KBrNXaPaDJmFQdP4roTKKTl6ZNoMU3z5ncuozdYfyArJEdW0E3w/af8kP
OVJx9H3W9km07LrZKmTl5CH2KGcffh6dZS8htQE67zxno20fHFpGoO3Z/DYB
NIeWkA65q5doyBBGe5duWknWnpMLurYAXe66Q4/oZAsqNUjRfqfM9Inswd+D
3XK03u7lajInbaTwkxI6+t1aQzKx9Ykvtwa64L9EIMNRd+UklqHHNiStIZ0B
Zf1LVqLFIxYzCNsjJ994NTrZO4pBrtjt9XJhUJfmMMjptfHS4Wa0fmspg6Qb
+vUmW6LZh3IZJHa57ZkTG+i876fWe6saupc4oqvDFRnERkZN4rYbWujVljVE
X3TBs8detP/5SCBK/NwnR/zQ/c81Dcl8zs9Of4KpNWpXE44fL0SEI+l51wnr
k9HRpsdKsXT/J3p65PnAzaOrE+j1jVu6kjQ8K7KzTaTX696P5eR66xGhgFR6
fTYeW0YK6ne2bd2Dlr08W5NsLXe1KTxC53F4LE8CL5gJVGfR+xORIUHsc7Qf
Np+hbi3lJRoZAuu+n6eW9hWAl5vYputq6f4e+7Sh2enKDK/bdF7Xwyuh2ur0
XWY9Wqu6TB+O6sYxclrRI8dOG4HZXBWDTwPohBunLeEyObT8BP/LaRdl/XaG
LdKb5F9tROe9TA8AX1st514ftP4GmUBYv4tzX1cg+ntKVSAovS383BKNPv2w
Pwg6b4ywa9PQ1ebyocAerhmv3IvmVrgaCpcl96tcO4hu59YLg9TkJYcvZqPj
dpmFg5Y1c9PxUrSBtlkkSCWZHDt0DR05SSJhdoXIg31VaA7NlVHQt+CmZgob
3cQQjIYmywzfHffRf9hm0VCZ6Ja1pQlt8nh7NGS+/v0nohMtf+h1NCSItSwL
eY4eUhWNAb91eQH+fej5q8xiQL+M0eI+Qs9zqmDq9/XAPE7nD2jHvocxME/0
tY7dF/T5xG8xMLJtd87aSXRg5dTv1XfO6sFnOfrxehkHM8F7bD6XzAz0DtH9
zKnvB5NncmaiF6uUMsFK4c0KSR60d/zDqd+3t1raTvKhe36PMGGlc1WI6Bx0
6g3uWJDfuydXSBhtVb4yFrLlo3UPiqB3jVrHguAt10f8C9Di631iIc3JKGyv
BHplR2ws/PqoOnO2FHptfFosRGYI56ctQo/rHouFQbnfelxyaFXRglhwr3vd
kaSAnitwORbaHZvD/yxGCy68EQvmH2/M2q6CfsSoi4Vbe3ILfqqh1+xgx4K2
XLp+/BI6X/O9WLhYG9n5dSl6xrL7sSDl6BIZo40OuVQfC0c/rOH5pIM+veJu
LPDsUTkXrou+84QVCztl5xm8W4U23XczFsZrfj0JMkA/dCiLhVCHgag3gDZc
fj4W+kebeP2M0HdVT8WCU/r1wn4TNFtvfyw0yeQYepmjX/psjwVGTVpXjwWa
52JILFTZR8S4WaG9+JxjQWPUib/LBm19kBEL1Y7Wt/fZohMUlWPBhGUcCw50
vgP8sdC6eJXyFyc6f/MHJrgfXNpz3hXtOtzChKHviw+5eaDbXl1mAnOTlMkc
L3r97uxhwl4t3stxfugVZquYIHLqn5dKILrsmyATCji/C/cGo/kLB2KgumNg
m0kkWkooLQaG4m5ZCm+l14O3fOr77IuKv/e3o3tj46Phj9mliq076fO2cHU0
iCzIkny1C116YmcUmNREvSs7SH04OAIK/sjvsylCN82qCgaNQAngvIjuFhUN
hputc7/cuETvnzIzCFrzJ92kytDHW5QC4Y/RU9X3NWiuokQ/cE/f+19GG/pn
9j8PGPqYlGjQgfYvznWHGJf4ZWOd6PrlBm6QoeJ3yqUbrTNnhzNUNRmEKL1B
jxgJ2cH8uWM89RNohnb4auhg7duz7g/68P7JlXA0fPGstn/o6LFz2iDc5D6j
m/sVvs9SIxWhI+FbyqbZaI5L+eJwVPkwxxtedHJ9AScI777/55MgtVmEKOlY
7r1j8zxqkRE5cnRgYmJiPlr271MVMo+h9XOmBNr26tjU79GPTfH7F9L+Qb9X
kMO5Ad+EFlE/69MjQr9Pf1moQF2uCqT90oqYs4vRrr/MGeSwa/snJRX0YXtf
I2I7OyyyVA2tJRpoTOZWzfywbAk6O9rOhLT6F4TdXIrmOapgSg7OX/3OQJvO
W9RjStbffRJ8Vwc91p5gRgRjoofX6tJ6mDAjrTL8gS2r0N5Cm8zJwdbzg/YG
1KEXzMn6RIbfM0AzwtvMyRyNnleeRuh+tefmpLl7s/drE7SQ311zkrlX6GWw
OTpj635zYq132fOjBZ3XZYU5ERg26421otdrkG1Gmk/0u/+yQRdzLzUjmabb
n++0RUefSTYl1l9FXbkd0Hp7q0wI/7nyp3ud6PlKHxmTJlsrp7mu6IRXHUZk
3783j4+7oy246hiEz3Pho/xNdN7/0g1IE3/VhsW+9DwFTavIvlrb1hJ/+nx8
HVhJeMXTH1aGoNvTT2qRxgZZy9XhtP5DhBrJ2FzXyI6kTvdVIDyPx+4/jKX3
U/gNJ2lM2W9qF0898HXCMENL6d7TBDpv3ogYzD7owX6VSOdxWa8Bs9Y11P7Y
g2bfk2QA9+0zZQo5aP+jv+2g28DU4mUePf8Zfwcoqx3tP30W3ezR7gjuVYbC
whfROjuuusC1Ky/jOCro8/R0myd45Sjov3iA3vkm1R90JJs7spvQ8WzdAODN
jgtzbEELrnkfADeO3c952IHOO2YTBPz7g/7VvEBr3/odAv08Qtmb+9FP28+G
QlV6tday1+i+zWZh4JvK61s8Qv0tLRyqt16uz/qKNj39KhIO/nDwtP9O/35+
RUeB3+bJb3N+oXtn/okCwRgb5d1/0ZJ+u6Nh8OO32wzOgWkvWdwQDbXhea6T
M9C1gjOnfi8Ff9oby4v+o5E49X4fOim/VADNa1MVA0L+jLp3gmjdsA8xcGvT
kVEfEXTHDicmHH2xarf0AvQFr3QmBHkMSD+XQPsvrGSCsMvyDbYy6LxZArEw
0tkzzC+PPqSkEwss+7TkB4poJ273qfdbu4bELmX02VOJsRC8/sk1UEPv7s+L
BWhOtJzQQG95PPW+m2+p9LpyKdo6onuq/4PW7THaaKNL47FAzLaILFmB/pwq
EAfH78lcGdFFe3yXi4MQo0azIn10/z+dOIDb0X2bDNFmOWZxIGIosWUhA13e
6BAH72rvzO0yRl9K3RQHbL3Q4qNmaOnG4DjIqhI2Wm+Bdj8ZFQdhOnXPea3Q
8z/FTtW3PymttqH9H26OA9GIsaQgW3SA2ZRDefkdxBzQVp7MOLh9frHSfSd6
/+ZHTM1jzPgV64o+FRQwNX+fe7O8B3qnh0cckG2b8x95ohXH1sfB/AWHmcne
aC1lRhwEXy8xW+qHPse1NA5YG+6L9wWgn6YtjAPh0ZfvM4PR6eUz4yAoY4Ks
DkM3ZHyY+v6iKHr0XQR61rzHsTDvztKAU9FoEZuqWKj75c//YzP65OfNsSCU
ldR3PgEd52cfCwHap685bke/O6MRC3PD2lwqktERW7qZ4D/7nZrPLvRdpatM
qCnk/js3HW1SmcQEv95VRRH70Y6ZUkyoTnDcInUQPW9wOAbmiEZZPjyMtl91
LQZu2hSNqWShq/4axgD/bUHDwQL0tl+MaPD2UBU6Vkivx86JKKj8YfLa6AI6
/mxUFGzS2ro3/zLanMc2Eq6fff3EvYrOP3M0DDzSqiMfPURP7CgOhMvrfAvI
d/SNDk1n0NGQgzW/0DyLHjsCEezvuf0bfas3wQHaH3suuMPxGv+e+/+zhXFP
t4P3+NB6L0XWQiJDXMN0Ds137jaFWQpd/9XPRVeP/jECiRHHmQ0iaEbZPH0A
pu2OxkVoDtIiBQ8c50quk0MnJ9bMBFvd1pv/KdBcqXiC5Ttp9bVJhfZ/raVI
3vfxHbFSR3tvN9EgcXf+02xeQutP82mTPelrQ1u0af1Y3CoiFDKLZ/0KtK3T
VwNy2ur++VZddPbhqd+3CpppJhv00SqbWEakVMjkVZsB7b+OYUJWfOVMsl2D
/pl0xZSQJ2ypR0Z03mXc5mRtdVKtnSk93z6TtaT9NLh2mKNdb4RaELfEP9/s
19H6roR1ZGDTrWOPrWh/iQhLEma8fZnjero+19yKjCvqt3Xa0vVp3NYkcfav
cCcHdPCH89Zk1rubfE+d6Pm+qdqQw83xxc6u6P7KQzZEomyFeZc7mr32qQ05
d2T8tYsnNXvShmjEXU95tgn9LPSvDal0Zsq4+aLFrattCKxaxnruT6+nhYIN
ebBwzN09iO7XybAmtn+v/uwOoffXT9iKPO+PyPIIR48EnVpHfO9p6PRGohM2
dK0l78+/f7QxBi20p8WMxGWURL2IpfMmJJqQv6Ehc7zi6X4HRhhkj43K5b4E
dLm9rAER0hq22LQd3e77fgU5LXxh6GUirZcM1SSlXQryr1Kpxxofs1bUDtz2
2U3NHS4DJOes58Aeen2vbteCdh+ZU68z6Xl/7zMCN9O+lf6H6PkUdpvDgFJu
5+ARej7TSiv49l5SaCgLHS3n5gDHc4cf5Jyiz8OfRGdYvuFGkkMOWiD5thvE
VNh8Yp9FR+ZZesOHhOTWM6Vorhu1QZCpZpNuX0afv9M3QkC9VwJ4K9AG5TVh
ELLm+pX4m+jSN6+j4M3MoUy7u2gZHpc4SLtZYcpzH+2bvH0zKIQkTZIHaP8F
RfHg0ywertGCrhjl2AovjlpZzX6G/uUymAhPZK7xsj5MO3nUSiwN4h4l3okd
Q9tY306D+bsst6p9Rc/kDdkNdkOvR07+RBeGkHRoKRVrZM4YnO5XfC1yL9xf
tSNdRQJNHJ4chEqHtTOOm06bwZV87jhkWFXvllo77WSSMXocNpqo8pxfh3nl
3xUngGs5/5yq9Zh/k3pwAtYLt4k9c8U8/sirLJDjY5zy9kDrMJVOwjjntYVv
PXG/8JOhJ+HM56OyE76Yu+eMnYSRdmc1qYhps9/O/ZoNdY0PSouiML94bNkp
OMjWW7qEifmEbtQp0CmX1IEtmA8+Gj4FKYf6DL1TsP+enpbT4LhnA3tkF+bL
x7nPgEoS2zgmHR0juPoMtEaeW5u6H/sdX1V0BiTXB9oVncDzuAmE5sAHs67H
GtnY70NHdg6wDS2cK09j/efkhhwIXKLm0ZCPecWeRbmwavGZF+vPYd7ebZEL
AtIC3l1FmCvxMXPhusBH/5FLuL/wV3YupHNvGo4uxfzSxaFccJ9sC/l1lV4/
Tf484Bi9Fsl3A/vtu2SbB9YPNydoEHSbREseyNwbmrjBxvV3FN7mwZdal0TD
e+iTn2bkw6mSVanrG9HQsCIfws+VcHc1oYdbrPOBcXrhnk0tuJ/iEd98GNr7
Z390B57/tem+fKhJiRT81Yn1Pdo5+ZC59eXhlC60fVdpPmyKsZ3P1431Ostu
5YN2yJ0TR3uxX+qapnyY6aMtvvAl1m/g7MqHZ66Fpwtf4fx3Ng/kQ6mtiLTG
IK4XzRnNhySL3fk3hrD+dOy3fOjwCt6o9Rb7fX82mQ+Km60kSt+jbyVyFsCW
/ZpPlT9Ou8D1w4wCaDo771jhGFqubmYBSFWPb5D5Ou3+z0OzCiCqtUvgzDfs
fyV6dgHcHaz9T+wn5mtcpyzyOzf96MS0vQtyp+oD56WYCP7BvIUx1a9G2Z9j
3z+ct91oaj8BWMuayfVm+jw1BRwF4OWoti2FG21RN5EP5aFzdP/MQgd9/pIP
M1LGvibwTptDffBtPjiffFw+zj/t5L/HXuZD8ZWqiGhBzH04O/Nh4t4ptVGh
aTNeazzIB5vuHcNB8zFXXVCTDwVjm4pei+L6YfalfPgyy8Rnkzjmw2qn8sFU
WmlRjySay3lPPpxcztvjLI39FpvE5YOBd5vjenmc71iQZT4cjK+Y16SI/UTO
Ls+HV5knWs2UcT3v2YX5kF7jYWH4v5brO57q/4sDOFGkISNJRSRZSSIZnSRJ
yMreRCRZKQoZWaGMbBf3c29DoiSl+U6S8dVQShpKkpFKVDTQ7zqf35/Px+uc
836/P/fzuPd9lbE+9nd/CXQ+hpnXVXDeY+sHJaDUJ12vvhbrZSIvlkCb8ICO
8nqsX6cRUgIyCq2/zm7A3Pw/yxI4sOnClRU6uJ68mmoJSPiHrlmih/X5sYPF
4HWfa4WAMc4XsTcrhquvP7xLMMX+zTdli2H2aCOD2xxz0Rl/GHBB8rjY7504
74gBxYBfYYsFBlzQ6z72FIHxiYnGXe44v6uyqgiKT707+s4T8yuBUUWg/+T0
ZIcPzl8wJFLE+b5XG7kfjPMjFmsUgnSXcSc7AfMgR5N8SKnXuWiTjPN8r/Dm
w+hZ5US+VMz3Sd7Og/qQ+ep7M7B/sapSHnjxP01XK8L11L5O5EDZOodtd6uw
vnNO5ElQSfG5+vY15u/Ya9IgN9D+eMZbzO/FH0mFf9bbvfTfY35B92EKtEkp
cX5R0QUH/Y5B8JWv+/aNoCW4zyRCTfeBlROz+qatmL42FpY27p6onI0O8UyM
gYTzdu1uc6fN1RF0LRpsD2rF3hNCz4gSi4LxOZNvUpaiS/+MhIG2Znz2YjV0
/OwCf+jwXLy+WB3NuBnhB/tPXHixXBOtWrvbFyo+dkrI66Kb79h6gWT2amq9
ITrcydwBbtyp179hhG6LKLcBuyG73o0maH7ZJVaQoR+3aqsFnetGG8KMkY7K
nY5orvGkhaRkqb/5C2e0e+pfVaJjxD3i6IZe/lFBl4SWKql7eqFjZhcbkQWt
dc8/7kZ/U0vdQSrHbML27KHz5VKWpG9HzI2gAHr92oM2JO7QQucfQfQ85/12
ROp0+WTYfvS1EnMHcqttU+nfA3R/o4ATsZ94phcdju5efMqZ/Fzl1zMjAj3Q
JeFKsnb+O5oYhc6wDXAjKtHZKwVi6Of1wcydtJYrNB2PQztrPnMnvh3EVygB
/abJ0IPwzrAWyElCi6uf8SDU6sHz4inoTolRDwIOR3Yw0tBGEoqe5FW8yLBU
Or2fxzs8SVhVWQY7E53d6exJRN9sVFuVja4wtfUkVXzt7eW59OdlpuVJTNf5
HlApQJfpz/Ikg66TYtVF9PPJvO1BElOyrmmU0Ga5eRCZq6scrzPR8l2f3Ql5
f+uvLhutd87bnTjNsyquO00/z5fZbuTXhn4wKEPbL9Z0Jdlekd1N5fT5uqqd
iWqGUJxJJT3/C78TeXjzzIrHF9HJC7QdiF+/zn2ranTdvG12ZJbIk90dNfT7
dU7VhrBgN79jLdri7LgV2eT391zXdfr5tzAsSPjdlV96CZo5wb+NiH65ccL3
Lr0/yczN5JK4herne7R5ajXJp8DD+7830++f8v3ujc6Sj39zt6OrNFeawPzF
IVduPqf3uy3GEu6KLAw+0Em/b36pNiA322lgoIs+b86YCwx/7+t4PEDXC/P6
QlzL1OXiKbTya7GDoN5ABdpx909bpSggDPqJgZIQL1rZ+79wMK1JYcXPRodb
Ho+AhaVimXtF0YklxTFQFqoSoKWIblFNSgTHwCcK35XRy/WNkmCeX+jHijXo
332zkyHE7Ybzcg10ce6JY6BjbGjCp4f+vL0oDR5Juco/t5l2zB8z+0z4+d/x
nqBY9JdHK/PgzZznvhNHsX7m3jDO95/p0uGkRMz1LZrzIONR+d+SVMwd3vnk
g+LTJtGHOZgPhxYXwAIRwSL7fPRJMlAA4zttpXsLsf7LynWF0PC8d/XfUnS5
1v1CcH3JvU2hHOv3fekqAgOJ7Q9rKjA3ZUgzQMkpY6feRcw/6Xtxfg/eSLrb
1aCFdvcxIKtb51ACwXrv9K5iCJc++m/BXcwFk8RLwM3zvwTGPTSvrVUJKPfa
Z11uxnrNvfUl0Nh/4Pz7p2g3oWzOfUb+9tp9z9F7Pe6Xwsk9vNd+vcD+h/s4
9xn3oawGwS509wt5JhgqvzIueod+NAxMWL1P+olcD/aru1sz4c/Xi10b+zFX
3BrFhO4147taBqetp12bwYSmIPhk/RnrSSSbCdmjD8b2jqALJhuZELFONGr8
O9Y3XX3BBM9QJ56jY9OuW3SnnwlrxgYFC/+it12fSYGY5trclVO4nu05EQom
wsKXXuIamO7v711OwYdrd1i6POjVe1dT8N/vWQrNM9E+OloUVGmbXdzJP22u
d9YGFORF5Gi8E5h2zOBVMwq8JlfojwlOu26zlQcFxrC3OVYY64NT9lCwNrra
bN5CzH/yB1MgXvf7Wf4inO/8MIyCKa7NTrISmOu+iKKgd3Py+4tLcb6W3FEK
WuMe++hIYc51I4mC6ntiXxulsd8kK5WCfF7XUCtZrO+6cIIzb9cijSdyWL97
ZiZnf/fafporoFXOZnHOJ5Ny9ZES7m9Z9kkKVOO2hO1QwVz6Ace57yc0H6ji
fC1zjif0rv4yXof1e5Zx+j2ZgddbNDC/uz6DguZ/8oeNNtDnKTpOgYpbj3aT
Ns5zNUmhIJsU/d26Eft/GSZS8GeZza2GTbhfjxOxFLhHzY/aoo/1b6UjKWh8
07Sx3gB9m/sgBcq6sVN623C+nUogBVlF2nfubMd8XpkPBeN/vkeDKdos0I0C
Z8dKvdtmWJ8Zb0tB/fXd3LqWuJ7dgCkFJ8JfxmnZYn6uWJOCHy+ytlyzx9z/
mxIFjpqmvJpOuF+ZbCkK5MZIgro75luf8FKQZhNueNkT+zf6jzFhtGYtn5o3
5rpOnPeP7D+VvMYP8xcbmphgO3IsVTEU54XOi2bCLYstpucOYr3Vrr1MkKma
mCt/COutF9ox4WtA4ImVR7A+J0uZCQmfrTOXJ6PVlZml8MlkvlVpCrr6fUAp
WJxvEpY8jvN6vHRLYamfdvaSLMwZ3e0lUNMvlSfGQLfz/SwGiW0v7XJK0Jfi
bxRDzJkscVEK+3sHjxSDqffMQqEzmCtF8hZDb88nxtwqzN8p8zBA5O0V1owG
zP/4PuX8f50bFVXbiDmLN64ABHQM7P1b6HllqgUwI//pvI5HWP9dNpVzn7Qc
Dj/3EvMLpzXyoO2+vLnFMHrJ5O5sSKss+lssMYjf91of04D/jWeH1TL0racr
0iBeQPES33K0QrJnKkT4XNsdvBLtmd99DPyknz8xUEWrZ7xPBKOc+WVDW9FX
KmfHQsO953FMI3T7750xoDfKcLExQQdFb4oGTXMlkTsWaJZqeCTn983oSJYT
utFkYRjMjIq11gpGM39Z+0HNyOffd/ajO7+v9QWv3falhgfRnxmLd0OD+ZpP
OyPQva4CnhDaUJj+KgpdoyzqDrJaszQ8YtDustbOEC/TFR2QgNZTGrcG9Tyj
lT+T0BZvAi2hd07NfxEp6KodfKZg8DNl4bF09HL+qY3wY8/YDcEsep7pqbVw
6q2He242mqt/ziLgbd5wnl2AjlmTokpqdE9ZKDLo9V4MaxOvS4JjVSX0PGdf
fSIqF1GkSaEzOkS3kYbCPj3CpvdzP8KEhApa9RmcQX9LLzInsvG3U1vL0Mk7
rluSZ7/k11qdp/dzKnonObovu6Ozkq7/K2VD1Hr+RbhV0XlcgS3psd0r3VeN
tvcasiNZrR2N/lfo/TwUdSD6evr+32vp/fSJOpLRmkqhwzfQC15+ciQshcW1
XLfp59Oa40SsSuKdk+7Q630QdSYzRL5xz69H8xv6OJPqJKez2Q10vWiaM/Gc
aDRd0oQ2Uo1zJsLBaqNUC53/MnIm9R+L8+QfoFUN3zuREMfZGy8+op/vpIkT
kXkc2qPxBD3w75gjebqlO+lW+//nMRxI3DWT1Vs66PMEHLUnaqtrn7Z00u9P
np4d6aFkwi1eo/NTntmQLLETy1500eeT0bMm+qm/61266fd1Q7wVGf3n5dvb
Q3+eZygLwgptm7f3I50nqe0g3K5n7cM/0e/rPXUDUvVUeGrqM/28FXKBuG87
wk4Ypvd/f4M6qVO1+Zr1g/bjfC4IOl13cvE47W1jSrBcQlmL+Zvut3LXhhge
nvjKKfr5EGNjUA0PUFDn/oTrPcyzgO7PLx/d4EE375KzBr2OqsXN/Gj+sWwn
4DrnerFHGO215Yk3NH5+EVC6EG0RKukLaaqWKs7i6OzScD9YdG1L5fNldL+g
VSCoNMmfb5anbdcYCs4fR89cALTRsXfRcF06qeSwH7o3TDANjnhzuWruQw85
dKSBwblDy34EovO3FR+HNlV/xr4DaP1viukwsMmy0D0GXZErnQlirktyDXPR
1V8Vs+ENlW3DUzDtmMt/jmUD6+O8hXVFmD8IHMjm3H+4srUodFgIOwcMIj9m
KldgvcGXBXkQUnjxuHA9euGd+gKonShMqm/A+sQFIoUw4ZoYG9KELrL3LISk
FS4Hnj5A+16eLARGhYBL1gvslxuUY8D7+WO2+q/QEQYBDJALfm8x+gY9sruG
AVUa1wyserD/5pBuMdwn3srCXzC/5QUlICBtKVc/jDn4RpSAxVHd5SGj6AGB
2hJ4tU1E9Ok4+tcSxVKQKp+aF/cH3RrrUQpecz/xqU3Sn/+BvFL42lb3N3PG
0LQPjU+Vwrp1FT83z5x23RcQZ0J4Tt7wCN+0Y6I3qzKBxzHgg+U8zP+bdGGC
+IclrULi6IiVVUxw2cp3/67EtPXuXalnAuvsKAlehvNnHHrGBGX/luonMuid
J38yIfhRTUXsSjT3AOf3+6oq88xaeVzvrR/nPrj558HCzNXo2eOc+1+inWf2
ZlWc7z/Fuf89uL7jxIgaWkl1KwVCS7WSKQ2cF5ZqToHtEdk4yw3oDEEHCoq6
BSO5ddCNNzn3wW79vwcubUSHp3PugytP9wV66KFFU4Io8ON7ukdoC3rRec59
5+Ke27vubsXzzh+N4NxPWstcgo0wz3WNoUBbJdtO2gT34/CNcz+Mzoi2fLID
LXyWc79qGPUzibXA+tS4ZAoEbGy3rt2JLo47RoF57eZN723wvKpnOc5evFor
0x698Run/mWE+LrNTvTzd+HcNyXf8qweccH+4eF4CnbpDctR7ui2M5z7Wxnr
1XLLXdjPiuPcX7/wNkpw78b+80fDKVDzuSR6yRcN5SEUhLcw5nvsxf3eGdtL
wW2lZH6hAHTpHi8K1j9b9DArCOflFTpz7t+RZzNF96PFBK0pUFipaZt7gD5P
kzEFrIeNEuLh6GsNehQsPWj7ruAwrvdv1noKciT72EuisF88XZGC5MCZq6Xi
sD5pvxAF3OI5I8x4tNsTHgoO18lelUlCzwvnvD/7hAw2yaWhA9gdTOi73s5T
doJ+nxQ5/0fcPXc1K2SiFSZrmGB1Oc5ydS6uF3ac83+m1UlY7GI+nu+1Kef/
jgEv65VqEdabuexhgqbN3V3qTLTzwU1MWDr+74BOOVrApakUckvTtW9XoMfX
55aCoJHUP7iI881adpXCjAJI1q/BfLns3xLo144q3E7QZ4SWlID7h7lurXVY
XzSvuxhepTJW7LiHXvGWXQwP3tyssGhG182VL4bqI3+I3VPsFxFdwYDI+rAP
3n3ovNr+Avjpx1fWP0Cfl59RAAEief57hrDfIMy8ADy8rv70/4Z+2Hg5Hwxn
/eQL/YO2bQ7JAyHjEOW4+Z+nvSXtcTYw7wrO0RaaNlfwyuBsUNWqHBwRQY/K
C2eDmfzAGY/FWK+dZXUSUma5Sm+WRa/9/DATeO9tF+PSxvrTmgHH4aR2/49a
XXR03Nk0kKmObw/chF77qjsV9Kg7Ge8M0Cp81ikQFa0x54452qoJkmBMR5rr
iDea0tSOhYTL5K2GL9pzbnQMiCo53/7ihzZtS4mGdRJ5h12C0PkbLkRC0K+5
P3Uj0EeuyITBv8Dy9h9R6O6s/w7Aif5t1RUxaEnFsFCo6IgLXJqInr/7XTAM
1vwa/JuBZpT07oFw5dzmyyfRkT5pPsB/at3Zvbloa9jsDXInA7xeF6E7x9rd
4YrA3C0nS9Died4uYBB3TtqEQlfJb3YAz+DetzfOoIP6bSxhZCD2dsg5en9i
MiYQ4y7FUKxAWwi82QKl5o4OhZfQXN9T5Tm/t+OaVjW0LSZ7bhPIEROopR12
S4G8Wd3WfugWWq+xZTMpHRKK4rmDXm5w1pB4ntspd/wuui5Bx4TI+eQ8Fmug
13sUb04GZV+EMxvRqhfrLElFj7iMYgva93reThLEdGy93Eqfl2VoQ9a5MkI3
PkK3JT6wJWNL3i5rakPLR8vbkxsvpZos2un9nXJwIFF5HkGvnqMH5rg5Ej0b
9mKvTvr8rZpOhFfkY/2XV2j78R4n0tQm5x/WhV7AdHMmKSd8F3J30+frqHAm
ZqblJKUHHV7W4kyEBD77iH5Ef0u/7EyeNa0WKulHZ4jucSb5CYE3Vn1C868f
ciJOWy7tuvSZPs+othOR5P4+V2cY/WubgyPpIepXG0bo56W6zYGcjjzoZvaD
zs/MtCe+2tf4O8fonJVjS5R//b7k8RtdJvHLmgxf0XEa+ku/nzwqO0n1/ije
A1P0/iw2WJKDa+9UTnF9wfMPrDEjWsNcdsk8aPdbRdvJRIU+l/AsdMzvKwak
zi/+XBE/evkPrk3EsI9v4sI8dN3+q8vJ7FPbT29YgOZ6cnc+PPBINasXRjPz
Gaqws2s+9XwR7b7ereD+bKHhhDS93ntRR5DNshtOkEUb9Sq6Qr95Qb7gKnp/
Ims8IKB16ZCMMrotOc0bIupXZGxfj1Yt6g0AiPHWat+AJlEVQTADzvY466D1
HT4HQ/J1RY0gPfSFbZGhkFu19lWuMbr5+ItDUFWySbbXFT1SWxYH3w9/5/Pw
oNf/tusorLc7O9S1C30ydHk83BQUvPzCFz3KX5wAjTFvN7eGoPvkWcnw2jPK
rToRfW3yvxMwa9XNwpgL047J2pGaA9t5Ao9MVmG+cM1QDqS9k/E8fBldmGuc
C0L5KQqh17B+/iu+PFg62/GaTz3mN30j8kFt6Ndzsw7MfU7rFcGBporrrZ1o
ZSqnCK6x3YuNXqOP1Q4WwUbnZi/9bnTc0nQGGD3M+67xCS0o/6gYXC6uF1o2
Ne06nR1zmXDV8df8Nq6v096isZYJ82fdmHuUZ9oxCt42TKhz3sg/yD9tvbDM
IibICBj8qxHBXP6pJOf39MrMSR8xzGsvbKSg3b3pj8RizCuJEwXxtcZjMZLo
jsAcCvq8LL+YKmA975spCmCByNA/JVx/k/giFuTdfDZQrYL15WEqLDAStu8V
V8d6zQJHFjBvL+5pXT9trkX2gSz47fv63REtrGevO8qC8juur3sB/Ue7jAUz
9i5/mbcZ6+d6XWeBk1hPh7EBrmd3qoUFNXfZzyYNMa/408mCufu8n1Ztx7zf
u58FXuKr2naZov/2/mDB7XsDD8XMsX7wIDcbxALLW1sscb16iXlsCJDwb4m0
xvz840VsaLy/ummNHbozW5oNUsHDDT0O6PQ9imwIX3qpPscZz7dqhxob2ppC
6ozccB7/Ji02yO9XJ389MK+ATWyIlRy7ecEL98MwMWDDq5ba6x4+WH/A24gN
agcO1Yr6Yf2HVBM2pCzXudLkj+udIjvY8KF1ovpwIOaJk2Zs0A0jVatDcJ6f
kTkbsmViLnSH4jz9Uk7+5eHmipNhWL9gBqff8BBPueFhdH+QMRtKZO+f/R2J
/jJkyIbxx4mnK6Kx326/PhssIozYbnE4fx/fRjaUyQlQwglYn1y2ng3cT1tL
7idhvsBuDRsco44zwlOwP05kFRuq5c0LlY5jvuftMjbMebYg/2065ruuibDB
K/ppTmYWzpNk8bPhlmL2SYMcrHdkTLBAtMMmczwP88GzwyzYF7sovbwQ+yvu
v2eBZGdhygIm5pd07rHg4FHn5HsszOflVrPgsYpk4sHT+Pyez6JYEJNAxb4p
x/oC1QgWzAvjM/aoxHprM18WFPruE+67iFY7bc2CyyZa7OEa9AYeJRb0CT1p
mHEH+wNOP6IghEfzeNJdzAerrlDw7wfDZm4D7r+Ei0GBeKdv38IWtM7+3RSY
lHDxK7TjfpqfjzKhM313W+VznKe7jvP/yCv2Qb5aJ9rkA+e+esQrX0G3C+u9
toQyoUpR1cS8H9eTjO4oBbFatxMH/qJlfcKLgV123/bPJNaL5q4qBtVCJalo
ruFpJ9c+Z8D2qPGLyTOnHfN5QIVzf9yS/qRIEHPRiueF0POYiNavQAP8yYPK
gWVF802xXtHhSSYkFye4vzVD71zmngleVl9WXrBEv7/6NQOW3rpVtcMO+28w
5mRASrpTY5on+oFuahr4ri8YETiEFriSlgAGQ1y1ryLQY4GX4kGK6RtZfgTd
l/7iKHTM3sBnHI9uDZePg61dHUuPpaN9K+uiQCZe1IjvDNpZ+VgwTG2InPei
DG24blkQvPzy4emZ8+iqTUH7IMPusovhJXRGOp8v+M9dskKsBu2/ys8bjO7G
DXy8in7z4I0n/FO02p9wC71BZtAJXr27vsHmDlq1VsMOrmZLT8nWo7sXnrWC
gKlvyQ1NtMd/bwHjy/Zm2f+h60i6Jqz0rRPxeojmcjWSgjdP0kt42um8ntIg
1xLHd7U/R38bP7OZZOu4KbA70W33pIxI0LfGryGv0RZXN5gRk9MqNfpv6f7i
cUsi55h7SPg9eoEL05rMEJyCng/0frYvtCNv73nzVvfR5xG2cSA3wh+2xA6i
mR6uTiR3tUa65We6vnuNCwnuYVhLD6PF1ze7EtM8XomREfp5zRBxJ/Km/u/q
fqAnxtjuhJf72amMcfSzbWIepPuKjp/7H3Sz/h4PcsuPvUZ1Eq2nzvAgeVJz
fv77R3+ePhc8yP8Awv/gUw==
     "]]}, 
   {Hue[0.9060679774997897, 0.6, 0.6], LineBox[CompressedData["
1:eJws13lYTV8XB/BKaJKkUimNmiWJklpuozTQPCrN83hLMqRBEjKT0EQhiRKl
wd0ukn5pkohKklQIIVPCW2u//vF8nu/aa699zumee+V8o+wDuDg4OPJnc3BM
/28ZMPKI/dYJOPBf4y1uE8nolxI6a6ZQLbjYmCzPz865LmE67YSBDGMyKKWY
skVp/bTF91qZEKuWropcCcdp2yp4mhLFTOnz/2Tcpl3QfsWMTFr6nfRR8pq2
a9mStcTF/wfrqIT/tMtjt1uSehPJm/dyAqedfUjVmmgpGJaPy4RMO3jdAxuS
w+V9aXFh2LS1akw3EJ6B1HPOSpHTbp+wsCW1/R0t9xyjp62xr82WRNv6W27M
ipl2o4imHVFif2sY72JOW7Foox15sXSPyQGJOJxHINKOHM8XZy/22Izrr1+1
I5ZzSwxITvy0HZuk7AlH0uoa574t0252LbcnVR+bV3yS2Trtn/4+DiTcy6ti
j8+2aReNKzsS+dZPmrKF26fdLzDpSA5eEVaxU9o57YyRUmdiJl1U9DYoadpC
17e6kJ0Np4XuOCbjeUV0XInbztfrD3xDFwh2uhKdlRoH3LJSps1daOdG5n6M
e7hYNxXn7yhyI+/Os3i/dKFv5Nx3I/c9Z1mQhF3Tll31yo0UiG5I3yeRNu00
RS13sr3lZL1zLdo2tcSdOO/u51Lw2I3Xx9bCgywzVDX69Bs9to9zIxH4FpNU
l5OO8y5t3UiGS2tZewz3TNtA74Inues/Y9KhD518NsWL5EpZ68smZeD1C3Dd
RBI6jyeMyuyddj3M8yYOmS+qqtno4s9h3kTTVOlbms++aeesrfYmvJORy+24
9k87y+CLNxm8fjNGuhANzaI+5HYYR/lbk8xpGzvL+JDTCus+Vg6ic+LFfEh8
zxGN1N0Hph09k8OH2B3rDl2vdBDPU9zrTTSsFC5JPkB/mXXFm/DMCB8eCjo0
bZ77Md6E6dl91I37MN6PDHVvsqnm77XbjmiO0cpNxFpU4dHi8+hmf85NRD9m
7dj+b+jGe/peRFT1sKZr1pFphzvs2Ei4dt+wIUNoHuE9HmSs/1m4ou7RabM7
0tzJw2y5y2Nd6B1RXq4khee68l6J49O23n3FgaitPZJREY32Bzd70rE76m3P
A/RIOacdUZyhcVkz/gTaOM+aNBvxCbi2UJ/6uI5sTh4JT1HMwudPwmwtafhT
pNnZgRZfMc+YRBnsOvRH9SQ+r6sl1xDx7T5jSilooaO6+iTkp3TF1qXZ6Oe/
tYiw7qRwYTqafdBLldRu7o5tfoEuCDWWI343qju/6ZzC3G/TfCLwNWuFTCaa
Y13WN1blss1ZFq+pD6z5Y+gV7fAjRv/0tBkbioVhVtky1zNH0MnC+6Wg7MPc
mvoRNLslSh5cNT5KfFxzBve73rAYOMKaty04ifbmABW4dKmkh/GR5sn/qYL9
SIZBqFkOeranGvxWCso9loNmaE65KMDs762vaG8hJzWwLlLYNGSZi/vrmKnB
twFO9txzaO+LS9QgT65fdtUvdP8OQTUw9yYpvrZ5WN82rAqf8nIG9l+kvlOj
CtkvtplU/kWzt6epgpGUW1GfUz7207RQhXfuujN5rlALzVSFpma+6+JcBTif
d50KLBrd6ndlCbVfmAow+d/ON3ZD9weIqkCDmmv90zQ0u65GGaJCVi7m6EVz
PP6iBPUZ558cn30WvSlDCcSLRdJVl6OTH0soAXvoy5D9PjTbTXsxCPuXFZ/X
O4efH4UWChC4a5Gbvj/am7dZHurOHeBtO4QueLZBHvxfhYX+HEJzbPWQg2qO
HskDwoXY7/agLAjIWj6UA3SBe4wsVHqpaFidKKT3f6kM8O082fuSjWZkBi4C
r9xZB+JG6fqPJdJQcWuzIa94ETr9rxTM6h38kGuCZqzwkwL33w552lHo5Lfd
C6FM8t76B6epC4IWAre+9j+PBlofyL8QXN3Olo19RnM4NUrCpx5HvnOS5zF3
OCcJ6V48AQ4m6ORPJyRB6lXdbe5wNHvLIUm47hclWXUczcHaJgmWQ/Kbg1i0
vs1FEvqDn7aJD9H6JiVJ2PJ+r1qT4AWsfzIsAYKRhru366LZMmck4PzY2EsN
b5oPMSTAILZIvy8DzYh+Lg6Pv7mcOHSNem6AOIQm8I8xumm97OAC4PxNLL9w
XcR+fC4LIDuReb5QHc1hTMTgfupz91mJ6OSTYaKwceaBypvnad5RIQJf9jCE
QlppfmRsPsgeuHj/oUwxeoO9MOw4uVnryF00B2/GHJgvqbrf+D3NLxXzQ0lO
75uv8y9hbnePF7rOmpxxDqB+8nEmaJfOmyXFU0KvV/Wk4X+a971btKizRH4Z
el9LqNvpRh2395vhgaqX0a9KqH9e/GCouOrYw6OPqd+FDBvW1pkrmU5SS+5/
ZWgHE8nfFC+jg5c+MxxhX+m5YEM9Ft1smGTis9I1ntpbo9JQrEHkCG8+df+X
QlapReP72gfUyfPuskwebjcPH6Mujm5mddssPSstUYouGHvEim4f+N1qRL1D
pJM12yHLOTmUeux0Jyvvybpry45RC6x9wlrh+of/dd3/8+dPWc3d5YHHB6nD
7Z+zfD3975jNuYIuvdrL+vVygdSPFdQi8f2sw74P44u9qFtnvGYpvdn5yG0P
9cG/b1isIG0N/nJqHv+3LMd3b9JvPaM+uuwD6334qVcRnFfRYhVjrNRP1gYy
atQw+YVVPn79c8p26kMLf7LWbgmyXl5EnTo6wer7JXlxsJl64M0fFv+/lI1r
F5Wh/1PgItkhLl4a5tQ7m2cQxU4N73mR1Oa7ZhK41OXXw6J+JcJLai5lVd7U
LEfbWAsRjk0pK0uM0cm+RvOIuUj4zRxnNMNypTB5vNOoJmUn9fKFIuSDw+gt
q1bqw+ULiA5vlyEMUJfsEifbyB2i9Z32b7GWIOzY0jUKfNfQR/gkyWzVk2zR
RWh2Wp0kWd+XYsSjTa3utZAcPxZ+d8IMnfxvbCHptnAx+eBGHcmUInJ/jepf
RqAZff1SJPi6hllHCl1frC9NrgYvaKg/QfNFO6XJuDTX2puXqNMuSZPVj0cf
XGJRi9VJk9SMLoucR9QPr0mTRsO7/x18Qy18SJoIfi21TPlF569wlCZOxScf
xs6pwDyIW5rkeKZaB8qh2a/zpciAcESL6wrqVhUpotLost5qHZqjoWAhiUo0
bjP0RCd78C4kVdpLbLViaD9xf0kyObzgkfxuWr+tQoLstf/QMfsK9eel4qR9
9jOHCTatb/VZQMRYdztHO+l+/ZlipFA5++mjSVpf/1iEsCaNu89YX0fzm88j
3BVLPA56Uwf6CRHLIPHe5Dh0svmsuaTr0YcXATnU6mf4yaI9z7xcy6m1x3mJ
v8G9l5b11LpuPOTzhexXS0dpv0M2M4nexl2+8hw3MH/6cgbZOS/ytYjIDfr3
kcZF6htc/WerUAev5iT8O0ze/FpNrTabg9gv0wwc3UD9uP0PK3tIfLjPj9qT
/ZvVd2ZG8KMt1N19v1iL7T6O3NtPPUPzJ0syaa1+0Flq9yPfWUJXCvbz3aQ+
vewba2bPr94rzdT2QuOsCR4HTbsB6ueaX1ljK0uTxn9Qrzv4hfXGf+ajk3Mq
0WlLv7C6j3rJr1ag1pr/hdXOvhnbp0fNWvWFdf+j0P2U9dQehV9YtVKhYov9
qbltv7LKLe8FNW6lTlgzzjqfIFUTdohaP+Yb6/SFzXxzz1MfH/zOOtzZ6lFR
S52d/ZO1m0vlilM7tWTmBGubVsrfn2+oq1iTrCiv7g05v6lb1f+x/DOnvmzM
q0KbveMg7rWZXwaUqN+5c5ENI29M0g3QyWVDM4ip2JoTqvbU9pkzib5p9lBz
EK2PsZxNFAss984/Rs3Px08kWgu7q4qpl/HMIYKTk+ruhFpdfC755VLWWvAW
zXhaMY+0zhUR0WTcxP4HDcTIPcOIgEdOaHa4/wJSHdZQFRdG3bJfnBQ+SHCr
y6L16x9Lkuxvj0q8Sqn9pz4fDiqoT3LeRTPezZImCUkv8iw+UB+RkCERV1aO
veeqxnoJXlni23PI6JA42rtwpyxx5X17VFsTzYgblSU2usaDT0zQBUft5Ihx
wJkVW93o+j+lckTv2Hi6VBRa9sofObLkjs2z22k0P2IsT+Q/XVD1O03z49vk
yQJpju2zytH9WUXyRMDKrfnSferY2/KEa2uFtE0P3f/vf/LkxwX+qLEx2s+R
LU9GO/3Zx2bVYL/MfHkywEXm6UqhkyeD5UmX1gK/7mXUP6XlSbNX9I3EtTX0
8+y2HLmb+d9MOU80u3qDHLlZK+9Sz6T+0ypLSke2Fwdl0Po2kCXnxJ784suj
rmLIkJOmmlZXr9P6Q2+lSSZzT47df2iOkG1SZEvrqjXZ4zRv3ChBBDUr3/zH
U4vr49sWkKIDWpm/pdDsCB0x8sha+bmXGc0P9ggT9YcisYuz0Bwdh2eTu2qH
JVxK0MlCn2YQ13387AxC8xELDrJ7Hdec0SFq5pfPrJcPPl2o0K1D32h9Yxiv
HGYzaEWtNfbZUGDP0FdRb2rBlz8NV5m/YGzNQCeHac2A9vOuwyU51CfjZ0Hg
zM4DveW0XucSLxyrb+pe85zmcq1zQU3RPCXmA80/ec0D9q47yoWctzCPbhKG
D8bVcbPU0AzTbaKQdm75Qj1Asy+wxECSq+xOiD2tb/6yANbeOS/Yso3W/9WS
hD5Zucq/B2m+edVCiEvO8dAqpPlubSng61/A5XuT5v8WSsPZNceKjz2k+Z1v
0qCXL7jh/kvq67cXQevfvd++f6X+b6sM+HvNzFHhYeH8nMKy8JuVbOwuhZbV
2SQLR6UnR/Zr0XxvkSyoJG45xDJFM4QGZIH0flnxyZXW9y+QAyeDyF7ZCHSB
iLkcjJ55m2qfgk5uC5eD1N/+qmkn6Hq9TDkQ9+hvq7yEZm8vkoOyWo/4YRa6
v7lSDswlu6QkOmi9P1sOerfa37McovMk18sB83lLyI4Jut7vrhzwrlondFWQ
4H5utXJQkF1f9VIezSgvlYOVP9d4ztOlZp2Sg2aXuhkmVuj+7hQ58Lu5siRu
E3VIgBxMiFXYXoil9e2mcnA4fsmPrj1o9lZZOWCtUDRdXY4u8G2VBccT+e/C
62l91llZeDcueSTvGc2/MWVhwY15fZyct/HzZtPU9d6Y+dtxUAydPFYrA+f8
3zxs0EBzWNjLwLBBm/ElY5p7ji4CDdGamv2u1F37FgHzwzmtyEjqiKWL4Ob9
zIu2adRDPdIwmRu/aPlpNFv8qDQYx3ufEC2nfu8gDRnrLQV+3qf1TgrS0KKk
s6u7h+6/kUsahP9JT9z6TOtFv0pB6ftd1W0z2GiJCSlo7fr5lS2I5nghKw2f
70UsrZCg+dsAaRApHwgtVEQzHjdIw8oclwvHl6KTDYwWgVtG86vd+jR/1rEI
dsQZSW8xow6Zej7zvKtcg23Rsj4SsnDHWv24mwfN/XbKwqBeQZtlIN3v+jtZ
mLVYlN8ghuaOnnJg/edvyqI9dL5rdvIQ+TaWNfcouuDkI3k48mTkJ0cu2lve
UQGeXumIel2B7m/3VAQfrwuexX00nxGpBGmWC0+dekv3M/+gBBdWHu7cN07r
nUKUYVRwm1UE3x08X6qTCgj+/pjuJYou2FuvAsuG/e5ukEX3L9VUhfjbNqu0
V1KnfVKFU5fvxikYoRme5mpw66RuuYg1mkMlSw36dpW+n+mClj3Ypwac0XLK
P3xoPUNGHRQ3ZvmOhNP9f7iog7kFf97zLWh2XIY6hOgkP29KpU4uV4dM2W8i
tw5Qj7apw1WBUNsr2WjvI0Pq8Ohn3/68QjrfhnF1GB90eHDoKt1v3i91EHvU
yJVSQ/drmMpXsQyBWU/rg4fVYeOliq1+bbTfr3Z12HlCudKxm65PuaYOZ1Ny
xsze0P3n7VWH+oh5Grpj9Hz1U/MPuaUHqfymeY20OvCa/z4nMesu5lI9aqCh
Hd3HNw+dLHVYDdYveiMxuZB63EANYvjcnT4oUb95pQpVAybNbQZotpGoKjy1
SPl8YC11/AUV+H6ViFnbozlclqmA7vZVPo1B6IKyFcpQPX/pd/ZRtHfmzMXw
bGv4wqRcOs/VaEX4+fISw7CY5hHPFUCvVHF/DYuut7ogDzWmkrIVI9RvGLLQ
XeJiFv0VzVjpKgMTQidCNf/SeVJXLAL9F3MrS+bfw7ySXwrcTWy6gxdRr+JZ
CNsu7funpHqP/v0JS8LpuY2Kb5aj2SeWSEDt5pmWhUAd5C4O3T3GUT7rqAPO
LIAJo+TjMo7UFV+m3kfFrJoXXrR/sq8YrBb83XcmhPaf+0EUNsbpcbvHoZOv
HheFHd2bVcWTaD3xEIUcxvX1T/dSl5qKwq0LY7HHj1Nn2opCr4DmKft8uj58
hyhMMsOIUAnNu++LgtTz4tetN+g8O9TEwHDNEM+B2zTnLRYDr/MKmlZN1GYG
C2Anv48D7xNaz/1mAeTF5CU8eEn7qxeIA+nqyd39js5fGiYBfYYS90y+0TzD
TBL+FjqPcHLUY79H6gsBoh9p7xRFc+iLScNtngcP4hlo7yfZstAfyf1Bxwot
O7hIDjieGAl/daJ50tT7i3H21saoMHR/1mV58J49kbIknvarV1eA5Ajdi++T
af3LYgVgr6r4HJRF85MnFaE//5OY0llqOZ7FwDFricHgZTrf5tjFIBse6nOu
ivaXfr4YjDoupnvfQSeX6imBr96by4uaqWuPKEFqnvyj3qe0fuS1Epzj9v5+
+hXdv19TGe6G5i50G6X97ZjKcP1tWJjXd7p+WYkyFAXr1/lx3MdcuEcZjg/z
8IfwoQvquVVgd2CXe6QIzWWVVSD+zfmS2EXoZE5jFQj0j5tIUKH1VlOfhy6v
jS13aqM5hr1VwMJ33uldBuj+O/4qsOrVy7cZ5mh2+1Su5n111UFb2n/O1PqF
L3fsPeZO+28xUgEBL6vn2f50vYiSCvzplVDNi6T9P3OpwEePkYTCBGrpZ8rQ
113VWJyKli0/rwxtbrvFr2bS/EGYMrCfOQRfz6L7p6kpQ7mLfHV1AZ1/3oAS
nH06NpuU0Pqco0pw1Om2y70bdD5XAyXY1XngYiOh8yW/XAxxDht/tDSivR13
LAZnu19Zz3rpvAuLFGFt+4OhF0O0f+lSRdDbkLXy9RjN5asUQMJm+dMP3A2Y
61fKQ69FhOiMJWjZG3tkoeXB6gAeXXRy63sZIOZ8lXOMqMXvL4J804uO4k5o
9l2mFPgyXh1bkkjz9z0LwOF22WvtPWiO02wxMIWdy/WO0Fy7VBQWGyx8bHye
5tx580Gs7q28RRmaYXVRGGbpVzNtamj9KdY8+FGdftf+Hs2PDQjBiK6TsGsL
Xf92gRA8r1Lw9eyi9VeIIDSt+HLN9xW1xeY5UHuDzRn8ntrSRQAuLz9kF/GN
mhnMDzkVnmeZ/2i/k6V8kLlM4/MW3gfo88p8kFg+wUicj04ufMELkUv/O5wq
TfOwDl7YdPVk/x5l6pMz+MB2SaDWgWW03iKcD4xKdZKPrqb5Lh5+0Faf0X7S
jOa+nfygUPJIJncDtWSzAIioFkSdc6P139/PAe7iyNsX/ahdtObCNyXDuVci
qHsthQAGjB/sS6BeKz0P0nMtkoJ3oRnjf+eBmIjjJ4VTtP/w8HxYyRnWdroe
zd4uKQ47b0XvSWij9Z1aEtCwJX6NczftV7dWElw+ppTNG6OeFyMFCT3ZhzIW
NuLzY2QmC+ysvLWBSmgONpEFHvuifybL0N56y+XAdk7JTTkDdP/ic3JwqrEs
6p85zQX45WFgV6XyCzu07JYIeVBbU/eydiPNJxrlgTnBPpkd1EifH2kFqK1s
2BDPpPvfC1EArpjm2Y6J1O5XFcBSo+P2soxG+r54pwBHh7u2zD1G99+8SBF6
zr1Y+iGXesc6RVD0ej3cVIxmHwxThHCJt/nF12m/lDRFuNH50SWd0P2XH1eE
yUPjc/3/o+fdf1oRTK0mHhh10nnjpz5vM2dxJMu8pOf5sE8ROu/M1PvzltZ/
jFME6UT+se5xul+ykyIE6s0rrv5H80oNRbj6Vcw7i+8/zM9NKEx9f5ASjxNF
e4feVgAIlW+3k0UzdLYrQPpilYyl6jRfpqkArf1LGHNWojnOPJMHsZzlP98x
aF6xTR68XFaVN1rR9XdE5OGC8JrgC87oAomLcvCxxVQ2zYdaVFsOkkxtD6/Z
QufZv1wWGv85WUin0v6NTjIgVOfB8TuT9tNbtQgKlgVFV51DJ+8ZWAjsRTtt
l7TSvPWlGPB0T/0VPKfrv0+9721P7GWPvKb9Ry1E4BX/Ca2iXzTfe30ecP26
LLRwcRP2+72bFxa2GH9dsxTNkeozG3TOPn/iv4o6xWEmWG+Ort5rQuudNs2A
gHWzz1y1oY7L4ISd0nmJj11ofXfRP8OszzreP32o21MmDcvuPzSWDqe2Kftl
2HjKd7FxPPXsFT8MX0X8mh2UTD0s+c1wwujwu/37qHlCvhrOF1NuKT9OfUv5
i6HGO1bZk7z/z7fps6EZcTw6UUw9V+KzodfR93Ey16nVNn8xjA9MdTFlUb84
/93wkL6EfsgDas+sP4bFguVSBx9Rv8qeAewB838VPdRXrvFOfR6+eNX1Bs0o
3i0EX/bF1U9+ou5oEQH+TfwX5SbQbJtSCVBcfm6vOfdDvD5yUjJgOHtVeJgg
mr00Ux6ce9rWHxannt+6GKLKApdVylPb26lCxq4/87s10AV75y+BGnX15wpG
aNnq89rQ8e9OnYUVzQ36dODdY9e8CCc0R9YyXZDake53MwRdbqJoACtspc17
Y+l6rzsA6xVvqHDuRD8Lr2VAUvOrD5ZH0e12B0xgQMowoa8WHc15bh1cYn3N
nCnQjOul9zvAyn/eVQ5X0YcV/nqDtQ071awarXM/wgf8zshs0L2Ljr/a6wOH
dfuGJZ+iGbOqfeFtlIfEwB/01SJff+AgtW8ez27BevcmfxATkKy4Pw8dTLQC
wLj4meWlxWgVq18BkNPvtCPaBt15fksQVGhWWvi6oMd/dARB4w4RUUcf9N14
jWD4Jv74iu5mdAP7eTAIBGlvU01CL4peEgLylUfMF+5FB4okhcB6O9uXf3Po
fjxSoeCfX3Z57AK6HoJCYfsHwYSBcnS2XnkoFO9tEWqoR1tarA4DzruWxgdG
0c1XdMJBXKhEMOk7OvxReDhoevH2RHO04udl4LlwcJ94EOsogq6+PzMCoi2U
GeaL0NZJyyNgT1a6gJ4KWnC/VwTc0DY7v9AAnZdYGgFNyUUxc8zRBS5tEdDf
OgP+bUDrhX6KgO9Sfnyf3dAfywQiYU7Y3acDfugKBeVIUKyRK+yMQLezIRL0
Z6dENWxBj6c6RIKtU//q6hS0RmBAJAQWruEp2Y8eDYyLhB2f8zrPnEBzpyZH
wrE1fwsO5KOLbuyNhJIDnhFJl9Bek4cigd1za1XMdbSay7FIeKoqNcuPhXa9
N+XRLds7HB/Q86w5EglcDd155o/QUg/3R4KEiH6YXg+aEbArErR8T+mqvUG/
m5MQCeblP2dIfULb3g+JhI1/Xdrn/EILZ7pGAtP6Zs4/rja8v36mkZBxWizk
swB6wmpJJOSPbF7xWgzNsJgfCVUrn3A+kUUvcv8eAc1pOq0NamjxtKcRoD/3
IdeRFeiV18sjoPiUj64HA629c08EiCn+DFtshW566x4Bu64eLPjkhDb4rRYB
Y3qLn9R4o+2rf4SD17063rQw9EblO+Gg/2yEKZ6C1tO1DIdi36SLA/vRFsO8
4SD2QbS3NAvdG9QQBp85TcyMStFP/64Ig2L13AWhXWj3grEQEKtabq0zgO4e
PRkCaYym5L+jNPc2CIHykt9x6zjb8fp/3hEM+2+r9L0QQzvb9gXCXe64n8ZS
6Fn+0YHwc91t4WI5tNoCjkAI7HRay9RAi58Tn/r7fZtaPssYXe2o5QdbNVub
wtai3UOv+UJ5rMSbdmv0WI2WLyz6WyZxxgVt76XmA7+EX6QujUDLbhf3gnID
XSfXbLS1OcMJhlNSo1i5aA4fWUdY9KBlr3whukiJwwEy7fzJ6BX0+PnbthAc
eEQ55R6tL9tnATKH3/+69BGdLLZsCRCfpEsVX2len7EYvJbPd6v7SfMbPxZC
zlP96mauR5iPbnvGEpfeF/9JjPrNWQ1y86O00s+FaG+1M8uIM/vaEw45tGx0
mw454fdcR1gdXfDgsz7RWRExKKlFfe6FIemcxXlcYQV65KALgwiXqHzVWYNO
WPbPmFzbfuucoSl67IOBKbG1sbU3X0f3Uw0zI2OLBjk3rEcnW+01J4fGtlxz
cUBb1GatJZp3+X28Xem83UctSOuxfKEQT3TwnMR1JCJgOTvGF3240tGSCOg+
iNoWhH62TMKKXObxkNkVjhbq/8+KWHZ/bN0fg7aVCrQmby+n7jwej+Yx+mBN
MhLFNHO3o8UvetkQ5Q0lL84n0/Oer7EhDbJw4OputNbRPzYk8Msjg5v70MVs
1fVkZn3A6O1DaMYuw/Wk6MSvM43Hqb/qriemQQesHp2i/S6Kryev9eR+P8+j
86/vtyGpfJUlA4VovTOHbIhcr4X7+2K6fo2yDWFf6eUdv4LOeHfRmmxKiq6Z
rEC7Wglbk7+23CEzq+n1EQyyIrny2eKCLNq/74IlMRhXbxS7S/sFdKwjvfdv
b5F5QM9v+c6CbD/poKzSTO+X9qe1RDJk+KnWI3q/6l+Zk1r97emrntL7cfau
Gfn54twby356v4idCTlZtvKEwxt6vQ04jcnKlCbTje/ofklnGWSz4pfCiHE6
z/aI1eRLqJHvYZ4OzN2El5AjBk/mnZqD7hdTVyJagiF3zgrTfEJ7EYm8dlj2
uhSao5eznfX+x8u+J1po2fwNmlAVdOiu5Up0gULickjuggu3V6OFNrzSBbGb
uRGXzNHiB4MZYBzvMbljI+03P2sdnB5/KqGYgR78ou0MAf7pf7IPoK1FvF1A
q3PFqznH0CM+ma7QcP148Y9cdNGeV+7wmWmv+/A6Wit4yyaw+NziyHyJNrcT
8of5Pol6w4Poc+1H/aGvXUNq4zu064r5ARBXvv+12Tf0F+c5gZAftY4pwf8Y
3/c3BoMg9OVPp4NCaG4Rx2DQ2VC8aoYY2ruaHQxNmrM5P8ii1fYdCYHvH+oP
sVei/x6YGwZ3PONiVxigS6yCwiCzRcGlxAjd0VEXBvJXUhcdt0YL8HuEwwcp
bS5ee7R10flwqM589SbRBR3eNRoONuGMK0G+aMmB6AgQ7/10uDcIve/ClQgY
sMqPs4tAZ/cNRcCVuvWuDUy0RqpUJCSo/129OgFdv3d9JJicuSJTnoiO/7gj
EgT5PWcs3oUeuXQxEp5vExg+lYHeWNUaCUXv6poED9LzCH6JhMiTGxRCj9F+
8vOiQNf09fb72eiBHI0o4Pgc3ymbh27aahoFTbl8S3YUUle5RsFxy7zdXcVo
YhcSBV4/lvVpX0ULrYuPApWi+ysPXkffOJMUBZ9t3Q69rUYrrdsdBbV/RodN
CZ3fbk8UpJUkMwruoaFyKl/vInLqdyM6b3NyFIhzF392bkVbHN8SBQPlqy0r
HqO3zQ+LgsuebefmPEdPfnOPgjg+v9/BfWjFNWujAG5+d6h/Te/fl6VRwOO/
r1TmLTpOVDQKOoQWzdz+ET2r9Hsk5LCueT79Ss9zqzMSAkLNqpb9QhdYlUWC
5oLnggf+0ufJJz0Sft4LDxqZ0TltJrd7JGRKHxfPF0QLCv+IAOcm5ZiJ+eiK
A+wIkNlS95+TBLqvOj0CKtoHtgko0npz3gjYkRj/OEgVfZx1PxzM1fg07mmi
z81NCofnu5a92LoKHRg3EgbntO6veAJo7rPZYRD+wvWglin6b49ZGHDoJq8Z
Xo/urjoZCkrvWs86+qO9bkiGwFiW70RZCJqDuzIYak2+2/NHocUHrYPBJlea
++5WtPnZzUEQZxseuPQQOnTNlQCAP//IvuPoXlgZALNLji0YOoW2jmP5w+kZ
dY05RejwvgY/uFPFq85Xi+7waPQBQemLnwYH0Qae+h7AcN714vVbdH2moTsw
D216OPCRznOC4QZPOcUv9v9E3+BY6wJ5QxlevQJPpt2s7OEA7TIB1j3z0Jm/
fe2By81Iv1sM7bgp3A4CH/4SfSaLjt7NuwE0y0NbHuugOXTOrwXvt+Z1HavQ
jcI9ZnBUXuHSI0AHjy4whe/He9LaLNDs3GIGqLTeZLbaoIU4fxuC++zj3i32
aO+RKn0gW60NHm5Et0eE6MBYhYpakw9ay9B3GciPcov/F0jr5V5rQLoX62tD
NFo2u1wOqk+eenV/M5rB2SgO79o3t9Vvo/MeWDkHbEw0L99No448+Zm1cwff
qTt7qdf68JHyyqF09kHquu2iZODj3bjbx9DJWsbSREQl35dkU6eukSfmPttt
Wbl0/6ysxSThtAvcOkfPe79QhZQ8Xq5RdxHdn+ivTnoFhCRrS+n8Ck+XEEHz
0dk112gu8n0pYSQ1frtZhR7r7NcizOqi11V16HKJqe9TRZ+TH1Wy0YcTVbTJ
UzXP2zfu0/Oe26NNePxXXbneROsX39Qm+rmiZyraaC5ZqU3Cn37OuNZJz7dr
pzbJm9saX/6c7u8uok3aLUr8y/rQBaIJywhXarr91df0/itc1iI6db6MKyO0
34DnUhI4DpqlH+j6Nt4lJHvJQqnLX+j6no1qpCnwB2/JD5o3uSmTyfzHP4on
6fXzmKFINJ+XvbnI+RTrTTfKEm/hzMcXZqEZka3ipD7NtKxICM1R/XGS9Z0l
m1soSt0x/7Whyo/Jfeck0ckac3khM6QysECRWl5VDt4xrmTwq1GbbFGGteLn
S+KX0vXXeDSB68Hxj9b6aHby+ArYqhgX/2sDOjv/qDE8/R2W7e+Ero45aQo6
j/1q29zRY1IXzWEsxeHv+QC07NJBSwh8qZ1uvx2tNeeVHdRXqRWzktHRMNMB
5A/KN6mk0/OqazjCCwNhwX+H0RY/k53B8fTnE5cvoA93GHqAkVP5ee4OdJGU
ry/kaRQ/iOpCH9320xcmZxS87e5FP/15wA+qKw4tuTZM5+up9AdNoahKzz/o
uJnfAyFzOLCrkatr2rfUUoPgHfH6tZwHrbNfIBjOR6w35JuPzs5aGAJSD5fc
r1JByyvLhsG2c4uH5TTRJTFnwqBrqzTvgeXoZ3oi4XBUZY6NH6Bd3/4Jh7F/
3FGtJmjLksgIWN81eXjVOrTkyd4I4E0f7ZzriGaUTL0vAj0Hv29zQwteEYmC
ep1e8SEvdNHxqfdl8uuHG2+FoIeDxaOhr/beTuUotHOaaTSsPlpXcDQOvf1r
ZDR8Z1weDE5C77tGouFW0fszW9LQsumvoiGVR8MhfS86tI0rBgTbS+8UHkPf
vMKIgc7lHxIqstEL9D1j4PTJJVp3ctEfVBNiQGnT1by+i+g1iy/FwOjdj04f
StHfVG/HQIXS0jmT19CH0h7HQMK+qHq+m2gj7aEYgI9l2yVuoeO0fsQAt/2Y
tsoddPuOWUxoqtR6t7IBrSsqwoTDEjFnzR6iG37IMME58ZqrYzv6qbwaE6Re
fZ7r9wQ9cVybCQOm2g9iutGcNquYUFzM3Jn8Ev1zHTAhUuD6ikOD9P7uN2KC
TvTX0dy3aC4hEyZMPF5eVPoR7fDMmAls3TiPuq/ouYMMJqSfuSHc9BMdstyQ
Cdb/xv979ofO36DLBGG/FSnDXM+m/TFPiwnPGjbrfZ+NvnRLmQl5alWfuOeg
FeSkmeB/8PuF+cLomy1CTFD7stJLfgGao56LCWNOW0SXSaE7Zn6Ngcqam81r
5NAGJ17FwDbpn7vWK6Ez4lpjgJGit9pTHW14oSYGZr1J+BKmhZZdUhgDzRY1
l7atQC8R2B8DR0t/ee/VR+eZx8SAq5C+ePYa9NuXTjEw2FWbXrkOPQckY6Bk
9W/D+vXoP3wT0RCdv/pbhwN6zPxZNEwG3vIb80QXLTocDSLfWQx1JvpnbU8U
dLv9/bFqC9rbd1cUFLCgzGIHehRUokBj923pwHT00MOQSDAVuTNRcBpdQlrC
gS+Bs6IsH216wjsc2nuMQkgRWkzscxhsLLzb1XMV3erGHwZx2vU3xO6hJ3qU
QiBQR7bgSCN63DUvGFxX7tgv0Iq+2zA/GFbr6/hyPUdr9/0MBC7jorkfP6Jv
cZb5wyG7tND7ks+nvfFR0yZIduh3Ysiik02PeQHTycCobjE6YZuHJzi7jS+4
poW+5TjqDlI+/vdzzNHVIuLOUBJtKhvHRHvrs9ZBDrOA/9MWdPC9w2vhQNzk
95BEtIpWpBlEJ9xo2ZSBFi9eZwS+24Rqug+g2YFHARx3hBc5HaP9zC7rg26y
4narPLTQCa3loJKaHNhQiO73ZiwFybReO6NL1O2bVODvnuMqujfoeb4+E4Ox
vWPzK2rQHBEpM+HVfut/GrepZQ8+YNUf4n4q34RmjP8nSqqOeN/JbaN2tpYh
xcdulYo/ofN08SuS0yfEs4910/0ChFXI/pNxuwT7af3yKnWy41R75N436IIj
XzVJ5BkNd+73NPd/rUW8czPMksbQtnxi2sQ+f1Br4hvNO+cuJ6ZnGVKbf6PH
nrQuJysKc2aPcXSjpe10iNL5n19CZ6ELKo/rEPGLjn1v+NHR9id1CN+l8v+8
56HLC5x1yGSJQGWPGPqwTudy8rE0uMBZCp0sLrycvLxav/+RHF1vJzz1feID
96i2MlpL4YUWYWuYWR/XQDMK+jVJedju0m/L0ByBZ9RJQcl9ARddauOPyuTw
25kR1Qbo/ie9CiRFxbxFwpiuj3myiPheaDjQa03r3ZtmEvs3sz4a2lMnD2Qb
miiuXZ/vQucjCbNB8dwDQV9fmpuEy8NQbuOh4S00nxWmC097ecYsEun8w+ar
4cHCdbYlqfS8YmvWQPGp/4QiDqCDF942gdATTUe+nKO+lW4NHzKbj/1poeed
2ewCfQ8Fxr0eo8ezeNyglc/Gkf0MnVlo7g5XM1pEdr2m1//L/Y0QndZ6gucX
OmvvoDeMb28/OV+xBz/fAh8FwGCt0M84VfTAptBAePLL1vWpJnroLWcQVG15
JH5qFbp4lUYwJMR2nFq0Aa1VGRoKwRXCE0mO6AuS30LB7bO9+ys39NiKxDDQ
j3osWeSPLtVID4ffoZ1nVLeho48nRILjSs8jmknoq/ZDkVDKOZS+PA1dkmA3
9fs2+0eM4UH01r650XDTLznI+Bh6i5dRNAgt5fVcm43mj4uJhjv3JS3szqEt
TVuiQfJIoaHzRXT155/RwNyosdyjFM2QVIgBxa+GiwKq0A/rmTGQSBrmh9ah
E1Znx8DTvRt4o9joU2K3YmCPrM94QhN6ydDfGOh///ZtYht65aOp943eTebL
1E70izmrmXAk9Xfnnudo7mxnJryzSWvK7EM/CotmgonEHPaR1+jc3RlMyBk8
UZk1gp49kMeE8bJFl898QA8nXmeCzfaLBQVf0A7ODUy4YK6Vdf4HOj+4iwl/
59XsL5lEb6wYYoLLC6OUMs7eabstG2dCeXFT/I1Z6MLX/5jAG+cQXsOPTn3A
Gwu+a3p9iBB6R8+8WKjlC3C5J4p2XSQeC/OffrBulESLHpKKhfCz8cYtMuhv
GjKxUB/+T7dDER33Y8rSehlLulTR1h8XxUL8jHkKvZro+HlT69taT4m/Wo5W
9lkQCyqn5QWH9NCPXwjFQnLA5RnvDdHqGTyx8FxL59cnY7S0z18maE/e+ji+
Fv0k5AsT9j0wG/xljSaFg0x4fbT1+V87dIrQEyYYeLm0zXBBc1bcY8IJ1f56
no1on33lTPg4Hlw7xwfNnXOGCfn7t51fEIb+b3M4E346zzgjFY0eMLFngq18
5mG5zWgNl5VM4KrJ3a6ehH7j8SsGPNKUYrTS0AZOz2LgxoaywBV70QcLK2Mg
YIhtt+YYOscuLAbItXVrTbPRS+pMYkAsscNgXS464MDU94PG+YPKDhfRcqn3
okHdaPbfwDr0BecZ0VBecln5GRsNe7KiQEfE1m5dA7pVSiEKDIazi9Qfobsf
aEfC+gNqVmND6EYvzXBgPrfJ3ir8YtqzWkuC4LvxlzvvFqADW4WCYHtp1nsP
afQNgc2BkJb0EkAFbVqnFwBZi2PecAFabUO5L9TEHNfODEFbc026A/TobfwT
ib5VddUN7pq+2B0Zh1Y083WFpgVKz22T0J0rW5ygl3UzSfQE2rakzha8lTde
Sj+Ndr03uR7eHOZ4/CMf7W2x1xo++q1T6i5BW2yrXQscfD3NeWy6vkzRENJi
k77PbUAfTm7SA94XCrIpD+n6/H06IFweHuv3FM2xg60CWRLzcjt70P2CX2Rh
4a7KBrNXaPaDJmFQdP4roTKKTl6ZNoMU3z5ncuozdYfyArJEdW0E3w/af8kP
OVJx9H3W9km07LrZKmTl5CH2KGcffh6dZS8htQE67zxno20fHFpGoO3Z/DYB
NIeWkA65q5doyBBGe5duWknWnpMLurYAXe66Q4/oZAsqNUjRfqfM9Inswd+D
3XK03u7lajInbaTwkxI6+t1aQzKx9Ykvtwa64L9EIMNRd+UklqHHNiStIZ0B
Zf1LVqLFIxYzCNsjJ994NTrZO4pBrtjt9XJhUJfmMMjptfHS4Wa0fmspg6Qb
+vUmW6LZh3IZJHa57ZkTG+i876fWe6saupc4oqvDFRnERkZN4rYbWujVljVE
X3TBs8detP/5SCBK/NwnR/zQ/c81Dcl8zs9Of4KpNWpXE44fL0SEI+l51wnr
k9HRpsdKsXT/J3p65PnAzaOrE+j1jVu6kjQ8K7KzTaTX696P5eR66xGhgFR6
fTYeW0YK6ne2bd2Dlr08W5NsLXe1KTxC53F4LE8CL5gJVGfR+xORIUHsc7Qf
Np+hbi3lJRoZAuu+n6eW9hWAl5vYputq6f4e+7Sh2enKDK/bdF7Xwyuh2ur0
XWY9Wqu6TB+O6sYxclrRI8dOG4HZXBWDTwPohBunLeEyObT8BP/LaRdl/XaG
LdKb5F9tROe9TA8AX1st514ftP4GmUBYv4tzX1cg+ntKVSAovS383BKNPv2w
Pwg6b4ywa9PQ1ebyocAerhmv3IvmVrgaCpcl96tcO4hu59YLg9TkJYcvZqPj
dpmFg5Y1c9PxUrSBtlkkSCWZHDt0DR05SSJhdoXIg31VaA7NlVHQt+CmZgob
3cQQjIYmywzfHffRf9hm0VCZ6Ja1pQlt8nh7NGS+/v0nohMtf+h1NCSItSwL
eY4eUhWNAb91eQH+fej5q8xiQL+M0eI+Qs9zqmDq9/XAPE7nD2jHvocxME/0
tY7dF/T5xG8xMLJtd87aSXRg5dTv1XfO6sFnOfrxehkHM8F7bD6XzAz0DtH9
zKnvB5NncmaiF6uUMsFK4c0KSR60d/zDqd+3t1raTvKhe36PMGGlc1WI6Bx0
6g3uWJDfuydXSBhtVb4yFrLlo3UPiqB3jVrHguAt10f8C9Di631iIc3JKGyv
BHplR2ws/PqoOnO2FHptfFosRGYI56ctQo/rHouFQbnfelxyaFXRglhwr3vd
kaSAnitwORbaHZvD/yxGCy68EQvmH2/M2q6CfsSoi4Vbe3ILfqqh1+xgx4K2
XLp+/BI6X/O9WLhYG9n5dSl6xrL7sSDl6BIZo40OuVQfC0c/rOH5pIM+veJu
LPDsUTkXrou+84QVCztl5xm8W4U23XczFsZrfj0JMkA/dCiLhVCHgag3gDZc
fj4W+kebeP2M0HdVT8WCU/r1wn4TNFtvfyw0yeQYepmjX/psjwVGTVpXjwWa
52JILFTZR8S4WaG9+JxjQWPUib/LBm19kBEL1Y7Wt/fZohMUlWPBhGUcCw50
vgP8sdC6eJXyFyc6f/MHJrgfXNpz3hXtOtzChKHviw+5eaDbXl1mAnOTlMkc
L3r97uxhwl4t3stxfugVZquYIHLqn5dKILrsmyATCji/C/cGo/kLB2KgumNg
m0kkWkooLQaG4m5ZCm+l14O3fOr77IuKv/e3o3tj46Phj9mliq076fO2cHU0
iCzIkny1C116YmcUmNREvSs7SH04OAIK/sjvsylCN82qCgaNQAngvIjuFhUN
hputc7/cuETvnzIzCFrzJ92kytDHW5QC4Y/RU9X3NWiuokQ/cE/f+19GG/pn
9j8PGPqYlGjQgfYvznWHGJf4ZWOd6PrlBm6QoeJ3yqUbrTNnhzNUNRmEKL1B
jxgJ2cH8uWM89RNohnb4auhg7duz7g/68P7JlXA0fPGstn/o6LFz2iDc5D6j
m/sVvs9SIxWhI+FbyqbZaI5L+eJwVPkwxxtedHJ9AScI777/55MgtVmEKOlY
7r1j8zxqkRE5cnRgYmJiPlr271MVMo+h9XOmBNr26tjU79GPTfH7F9L+Qb9X
kMO5Ad+EFlE/69MjQr9Pf1moQF2uCqT90oqYs4vRrr/MGeSwa/snJRX0YXtf
I2I7OyyyVA2tJRpoTOZWzfywbAk6O9rOhLT6F4TdXIrmOapgSg7OX/3OQJvO
W9RjStbffRJ8Vwc91p5gRgRjoofX6tJ6mDAjrTL8gS2r0N5Cm8zJwdbzg/YG
1KEXzMn6RIbfM0AzwtvMyRyNnleeRuh+tefmpLl7s/drE7SQ311zkrlX6GWw
OTpj635zYq132fOjBZ3XZYU5ERg26421otdrkG1Gmk/0u/+yQRdzLzUjmabb
n++0RUefSTYl1l9FXbkd0Hp7q0wI/7nyp3ud6PlKHxmTJlsrp7mu6IRXHUZk
3783j4+7oy246hiEz3Pho/xNdN7/0g1IE3/VhsW+9DwFTavIvlrb1hJ/+nx8
HVhJeMXTH1aGoNvTT2qRxgZZy9XhtP5DhBrJ2FzXyI6kTvdVIDyPx+4/jKX3
U/gNJ2lM2W9qF0898HXCMENL6d7TBDpv3ogYzD7owX6VSOdxWa8Bs9Y11P7Y
g2bfk2QA9+0zZQo5aP+jv+2g28DU4mUePf8Zfwcoqx3tP30W3ezR7gjuVYbC
whfROjuuusC1Ky/jOCro8/R0myd45Sjov3iA3vkm1R90JJs7spvQ8WzdAODN
jgtzbEELrnkfADeO3c952IHOO2YTBPz7g/7VvEBr3/odAv08Qtmb+9FP28+G
QlV6tday1+i+zWZh4JvK61s8Qv0tLRyqt16uz/qKNj39KhIO/nDwtP9O/35+
RUeB3+bJb3N+oXtn/okCwRgb5d1/0ZJ+u6Nh8OO32wzOgWkvWdwQDbXhea6T
M9C1gjOnfi8Ff9oby4v+o5E49X4fOim/VADNa1MVA0L+jLp3gmjdsA8xcGvT
kVEfEXTHDicmHH2xarf0AvQFr3QmBHkMSD+XQPsvrGSCsMvyDbYy6LxZArEw
0tkzzC+PPqSkEwss+7TkB4poJ273qfdbu4bELmX02VOJsRC8/sk1UEPv7s+L
BWhOtJzQQG95PPW+m2+p9LpyKdo6onuq/4PW7THaaKNL47FAzLaILFmB/pwq
EAfH78lcGdFFe3yXi4MQo0azIn10/z+dOIDb0X2bDNFmOWZxIGIosWUhA13e
6BAH72rvzO0yRl9K3RQHbL3Q4qNmaOnG4DjIqhI2Wm+Bdj8ZFQdhOnXPea3Q
8z/FTtW3PymttqH9H26OA9GIsaQgW3SA2ZRDefkdxBzQVp7MOLh9frHSfSd6
/+ZHTM1jzPgV64o+FRQwNX+fe7O8B3qnh0cckG2b8x95ohXH1sfB/AWHmcne
aC1lRhwEXy8xW+qHPse1NA5YG+6L9wWgn6YtjAPh0ZfvM4PR6eUz4yAoY4Ks
DkM3ZHyY+v6iKHr0XQR61rzHsTDvztKAU9FoEZuqWKj75c//YzP65OfNsSCU
ldR3PgEd52cfCwHap685bke/O6MRC3PD2lwqktERW7qZ4D/7nZrPLvRdpatM
qCnk/js3HW1SmcQEv95VRRH70Y6ZUkyoTnDcInUQPW9wOAbmiEZZPjyMtl91
LQZu2hSNqWShq/4axgD/bUHDwQL0tl+MaPD2UBU6Vkivx86JKKj8YfLa6AI6
/mxUFGzS2ro3/zLanMc2Eq6fff3EvYrOP3M0DDzSqiMfPURP7CgOhMvrfAvI
d/SNDk1n0NGQgzW/0DyLHjsCEezvuf0bfas3wQHaH3suuMPxGv+e+/+zhXFP
t4P3+NB6L0XWQiJDXMN0Ds137jaFWQpd/9XPRVeP/jECiRHHmQ0iaEbZPH0A
pu2OxkVoDtIiBQ8c50quk0MnJ9bMBFvd1pv/KdBcqXiC5Ttp9bVJhfZ/raVI
3vfxHbFSR3tvN9EgcXf+02xeQutP82mTPelrQ1u0af1Y3CoiFDKLZ/0KtK3T
VwNy2ur++VZddPbhqd+3CpppJhv00SqbWEakVMjkVZsB7b+OYUJWfOVMsl2D
/pl0xZSQJ2ypR0Z03mXc5mRtdVKtnSk93z6TtaT9NLh2mKNdb4RaELfEP9/s
19H6roR1ZGDTrWOPrWh/iQhLEma8fZnjero+19yKjCvqt3Xa0vVp3NYkcfav
cCcHdPCH89Zk1rubfE+d6Pm+qdqQw83xxc6u6P7KQzZEomyFeZc7mr32qQ05
d2T8tYsnNXvShmjEXU95tgn9LPSvDal0Zsq4+aLFrattCKxaxnruT6+nhYIN
ebBwzN09iO7XybAmtn+v/uwOoffXT9iKPO+PyPIIR48EnVpHfO9p6PRGohM2
dK0l78+/f7QxBi20p8WMxGWURL2IpfMmJJqQv6Ehc7zi6X4HRhhkj43K5b4E
dLm9rAER0hq22LQd3e77fgU5LXxh6GUirZcM1SSlXQryr1Kpxxofs1bUDtz2
2U3NHS4DJOes58Aeen2vbteCdh+ZU68z6Xl/7zMCN9O+lf6H6PkUdpvDgFJu
5+ARej7TSiv49l5SaCgLHS3n5gDHc4cf5Jyiz8OfRGdYvuFGkkMOWiD5thvE
VNh8Yp9FR+ZZesOHhOTWM6Vorhu1QZCpZpNuX0afv9M3QkC9VwJ4K9AG5TVh
ELLm+pX4m+jSN6+j4M3MoUy7u2gZHpc4SLtZYcpzH+2bvH0zKIQkTZIHaP8F
RfHg0ywertGCrhjl2AovjlpZzX6G/uUymAhPZK7xsj5MO3nUSiwN4h4l3okd
Q9tY306D+bsst6p9Rc/kDdkNdkOvR07+RBeGkHRoKRVrZM4YnO5XfC1yL9xf
tSNdRQJNHJ4chEqHtTOOm06bwZV87jhkWFXvllo77WSSMXocNpqo8pxfh3nl
3xUngGs5/5yq9Zh/k3pwAtYLt4k9c8U8/sirLJDjY5zy9kDrMJVOwjjntYVv
PXG/8JOhJ+HM56OyE76Yu+eMnYSRdmc1qYhps9/O/ZoNdY0PSouiML94bNkp
OMjWW7qEifmEbtQp0CmX1IEtmA8+Gj4FKYf6DL1TsP+enpbT4LhnA3tkF+bL
x7nPgEoS2zgmHR0juPoMtEaeW5u6H/sdX1V0BiTXB9oVncDzuAmE5sAHs67H
GtnY70NHdg6wDS2cK09j/efkhhwIXKLm0ZCPecWeRbmwavGZF+vPYd7ebZEL
AtIC3l1FmCvxMXPhusBH/5FLuL/wV3YupHNvGo4uxfzSxaFccJ9sC/l1lV4/
Tf484Bi9Fsl3A/vtu2SbB9YPNydoEHSbREseyNwbmrjBxvV3FN7mwZdal0TD
e+iTn2bkw6mSVanrG9HQsCIfws+VcHc1oYdbrPOBcXrhnk0tuJ/iEd98GNr7
Z390B57/tem+fKhJiRT81Yn1Pdo5+ZC59eXhlC60fVdpPmyKsZ3P1431Ostu
5YN2yJ0TR3uxX+qapnyY6aMtvvAl1m/g7MqHZ66Fpwtf4fx3Ng/kQ6mtiLTG
IK4XzRnNhySL3fk3hrD+dOy3fOjwCt6o9Rb7fX82mQ+Km60kSt+jbyVyFsCW
/ZpPlT9Ou8D1w4wCaDo771jhGFqubmYBSFWPb5D5Ou3+z0OzCiCqtUvgzDfs
fyV6dgHcHaz9T+wn5mtcpyzyOzf96MS0vQtyp+oD56WYCP7BvIUx1a9G2Z9j
3z+ct91oaj8BWMuayfVm+jw1BRwF4OWoti2FG21RN5EP5aFzdP/MQgd9/pIP
M1LGvibwTptDffBtPjiffFw+zj/t5L/HXuZD8ZWqiGhBzH04O/Nh4t4ptVGh
aTNeazzIB5vuHcNB8zFXXVCTDwVjm4pei+L6YfalfPgyy8Rnkzjmw2qn8sFU
WmlRjySay3lPPpxcztvjLI39FpvE5YOBd5vjenmc71iQZT4cjK+Y16SI/UTO
Ls+HV5knWs2UcT3v2YX5kF7jYWH4v5brO57q/4sDOFGkISNJRSRZSSIZnSRJ
yMreRCRZKQoZWaGMbBf3c29DoiSl+U6S8dVQShpKkpFKVDTQ7zqf35/Px+uc
836/P/fzuPd9lbE+9nd/CXQ+hpnXVXDeY+sHJaDUJ12vvhbrZSIvlkCb8ICO
8nqsX6cRUgIyCq2/zm7A3Pw/yxI4sOnClRU6uJ68mmoJSPiHrlmih/X5sYPF
4HWfa4WAMc4XsTcrhquvP7xLMMX+zTdli2H2aCOD2xxz0Rl/GHBB8rjY7504
74gBxYBfYYsFBlzQ6z72FIHxiYnGXe44v6uyqgiKT707+s4T8yuBUUWg/+T0
ZIcPzl8wJFLE+b5XG7kfjPMjFmsUgnSXcSc7AfMgR5N8SKnXuWiTjPN8r/Dm
w+hZ5US+VMz3Sd7Og/qQ+ep7M7B/sapSHnjxP01XK8L11L5O5EDZOodtd6uw
vnNO5ElQSfG5+vY15u/Ya9IgN9D+eMZbzO/FH0mFf9bbvfTfY35B92EKtEkp
cX5R0QUH/Y5B8JWv+/aNoCW4zyRCTfeBlROz+qatmL42FpY27p6onI0O8UyM
gYTzdu1uc6fN1RF0LRpsD2rF3hNCz4gSi4LxOZNvUpaiS/+MhIG2Znz2YjV0
/OwCf+jwXLy+WB3NuBnhB/tPXHixXBOtWrvbFyo+dkrI66Kb79h6gWT2amq9
ITrcydwBbtyp179hhG6LKLcBuyG73o0maH7ZJVaQoR+3aqsFnetGG8KMkY7K
nY5orvGkhaRkqb/5C2e0e+pfVaJjxD3i6IZe/lFBl4SWKql7eqFjZhcbkQWt
dc8/7kZ/U0vdQSrHbML27KHz5VKWpG9HzI2gAHr92oM2JO7QQucfQfQ85/12
ROp0+WTYfvS1EnMHcqttU+nfA3R/o4ATsZ94phcdju5efMqZ/Fzl1zMjAj3Q
JeFKsnb+O5oYhc6wDXAjKtHZKwVi6Of1wcydtJYrNB2PQztrPnMnvh3EVygB
/abJ0IPwzrAWyElCi6uf8SDU6sHz4inoTolRDwIOR3Yw0tBGEoqe5FW8yLBU
Or2fxzs8SVhVWQY7E53d6exJRN9sVFuVja4wtfUkVXzt7eW59OdlpuVJTNf5
HlApQJfpz/Ikg66TYtVF9PPJvO1BElOyrmmU0Ga5eRCZq6scrzPR8l2f3Ql5
f+uvLhutd87bnTjNsyquO00/z5fZbuTXhn4wKEPbL9Z0Jdlekd1N5fT5uqqd
iWqGUJxJJT3/C78TeXjzzIrHF9HJC7QdiF+/zn2ranTdvG12ZJbIk90dNfT7
dU7VhrBgN79jLdri7LgV2eT391zXdfr5tzAsSPjdlV96CZo5wb+NiH65ccL3
Lr0/yczN5JK4herne7R5ajXJp8DD+7830++f8v3ujc6Sj39zt6OrNFeawPzF
IVduPqf3uy3GEu6KLAw+0Em/b36pNiA322lgoIs+b86YCwx/7+t4PEDXC/P6
QlzL1OXiKbTya7GDoN5ABdpx909bpSggDPqJgZIQL1rZ+79wMK1JYcXPRodb
Ho+AhaVimXtF0YklxTFQFqoSoKWIblFNSgTHwCcK35XRy/WNkmCeX+jHijXo
332zkyHE7Ybzcg10ce6JY6BjbGjCp4f+vL0oDR5Juco/t5l2zB8z+0z4+d/x
nqBY9JdHK/PgzZznvhNHsX7m3jDO95/p0uGkRMz1LZrzIONR+d+SVMwd3vnk
g+LTJtGHOZgPhxYXwAIRwSL7fPRJMlAA4zttpXsLsf7LynWF0PC8d/XfUnS5
1v1CcH3JvU2hHOv3fekqAgOJ7Q9rKjA3ZUgzQMkpY6feRcw/6Xtxfg/eSLrb
1aCFdvcxIKtb51ACwXrv9K5iCJc++m/BXcwFk8RLwM3zvwTGPTSvrVUJKPfa
Z11uxnrNvfUl0Nh/4Pz7p2g3oWzOfUb+9tp9z9F7Pe6Xwsk9vNd+vcD+h/s4
9xn3oawGwS509wt5JhgqvzIueod+NAxMWL1P+olcD/aru1sz4c/Xi10b+zFX
3BrFhO4147taBqetp12bwYSmIPhk/RnrSSSbCdmjD8b2jqALJhuZELFONGr8
O9Y3XX3BBM9QJ56jY9OuW3SnnwlrxgYFC/+it12fSYGY5trclVO4nu05EQom
wsKXXuIamO7v711OwYdrd1i6POjVe1dT8N/vWQrNM9E+OloUVGmbXdzJP22u
d9YGFORF5Gi8E5h2zOBVMwq8JlfojwlOu26zlQcFxrC3OVYY64NT9lCwNrra
bN5CzH/yB1MgXvf7Wf4inO/8MIyCKa7NTrISmOu+iKKgd3Py+4tLcb6W3FEK
WuMe++hIYc51I4mC6ntiXxulsd8kK5WCfF7XUCtZrO+6cIIzb9cijSdyWL97
ZiZnf/fafporoFXOZnHOJ5Ny9ZES7m9Z9kkKVOO2hO1QwVz6Ace57yc0H6ji
fC1zjif0rv4yXof1e5Zx+j2ZgddbNDC/uz6DguZ/8oeNNtDnKTpOgYpbj3aT
Ns5zNUmhIJsU/d26Eft/GSZS8GeZza2GTbhfjxOxFLhHzY/aoo/1b6UjKWh8
07Sx3gB9m/sgBcq6sVN623C+nUogBVlF2nfubMd8XpkPBeN/vkeDKdos0I0C
Z8dKvdtmWJ8Zb0tB/fXd3LqWuJ7dgCkFJ8JfxmnZYn6uWJOCHy+ytlyzx9z/
mxIFjpqmvJpOuF+ZbCkK5MZIgro75luf8FKQZhNueNkT+zf6jzFhtGYtn5o3
5rpOnPeP7D+VvMYP8xcbmphgO3IsVTEU54XOi2bCLYstpucOYr3Vrr1MkKma
mCt/COutF9ox4WtA4ImVR7A+J0uZCQmfrTOXJ6PVlZml8MlkvlVpCrr6fUAp
WJxvEpY8jvN6vHRLYamfdvaSLMwZ3e0lUNMvlSfGQLfz/SwGiW0v7XJK0Jfi
bxRDzJkscVEK+3sHjxSDqffMQqEzmCtF8hZDb88nxtwqzN8p8zBA5O0V1owG
zP/4PuX8f50bFVXbiDmLN64ABHQM7P1b6HllqgUwI//pvI5HWP9dNpVzn7Qc
Dj/3EvMLpzXyoO2+vLnFMHrJ5O5sSKss+lssMYjf91of04D/jWeH1TL0racr
0iBeQPES33K0QrJnKkT4XNsdvBLtmd99DPyknz8xUEWrZ7xPBKOc+WVDW9FX
KmfHQsO953FMI3T7750xoDfKcLExQQdFb4oGTXMlkTsWaJZqeCTn983oSJYT
utFkYRjMjIq11gpGM39Z+0HNyOffd/ajO7+v9QWv3falhgfRnxmLd0OD+ZpP
OyPQva4CnhDaUJj+KgpdoyzqDrJaszQ8YtDustbOEC/TFR2QgNZTGrcG9Tyj
lT+T0BZvAi2hd07NfxEp6KodfKZg8DNl4bF09HL+qY3wY8/YDcEsep7pqbVw
6q2He242mqt/ziLgbd5wnl2AjlmTokpqdE9ZKDLo9V4MaxOvS4JjVSX0PGdf
fSIqF1GkSaEzOkS3kYbCPj3CpvdzP8KEhApa9RmcQX9LLzInsvG3U1vL0Mk7
rluSZ7/k11qdp/dzKnonObovu6Ozkq7/K2VD1Hr+RbhV0XlcgS3psd0r3VeN
tvcasiNZrR2N/lfo/TwUdSD6evr+32vp/fSJOpLRmkqhwzfQC15+ciQshcW1
XLfp59Oa40SsSuKdk+7Q630QdSYzRL5xz69H8xv6OJPqJKez2Q10vWiaM/Gc
aDRd0oQ2Uo1zJsLBaqNUC53/MnIm9R+L8+QfoFUN3zuREMfZGy8+op/vpIkT
kXkc2qPxBD3w75gjebqlO+lW+//nMRxI3DWT1Vs66PMEHLUnaqtrn7Z00u9P
np4d6aFkwi1eo/NTntmQLLETy1500eeT0bMm+qm/61266fd1Q7wVGf3n5dvb
Q3+eZygLwgptm7f3I50nqe0g3K5n7cM/0e/rPXUDUvVUeGrqM/28FXKBuG87
wk4Ypvd/f4M6qVO1+Zr1g/bjfC4IOl13cvE47W1jSrBcQlmL+Zvut3LXhhge
nvjKKfr5EGNjUA0PUFDn/oTrPcyzgO7PLx/d4EE375KzBr2OqsXN/Gj+sWwn
4DrnerFHGO215Yk3NH5+EVC6EG0RKukLaaqWKs7i6OzScD9YdG1L5fNldL+g
VSCoNMmfb5anbdcYCs4fR89cALTRsXfRcF06qeSwH7o3TDANjnhzuWruQw85
dKSBwblDy34EovO3FR+HNlV/xr4DaP1viukwsMmy0D0GXZErnQlirktyDXPR
1V8Vs+ENlW3DUzDtmMt/jmUD6+O8hXVFmD8IHMjm3H+4srUodFgIOwcMIj9m
KldgvcGXBXkQUnjxuHA9euGd+gKonShMqm/A+sQFIoUw4ZoYG9KELrL3LISk
FS4Hnj5A+16eLARGhYBL1gvslxuUY8D7+WO2+q/QEQYBDJALfm8x+gY9sruG
AVUa1wyserD/5pBuMdwn3srCXzC/5QUlICBtKVc/jDn4RpSAxVHd5SGj6AGB
2hJ4tU1E9Ok4+tcSxVKQKp+aF/cH3RrrUQpecz/xqU3Sn/+BvFL42lb3N3PG
0LQPjU+Vwrp1FT83z5x23RcQZ0J4Tt7wCN+0Y6I3qzKBxzHgg+U8zP+bdGGC
+IclrULi6IiVVUxw2cp3/67EtPXuXalnAuvsKAlehvNnHHrGBGX/luonMuid
J38yIfhRTUXsSjT3AOf3+6oq88xaeVzvrR/nPrj558HCzNXo2eOc+1+inWf2
ZlWc7z/Fuf89uL7jxIgaWkl1KwVCS7WSKQ2cF5ZqToHtEdk4yw3oDEEHCoq6
BSO5ddCNNzn3wW79vwcubUSHp3PugytP9wV66KFFU4Io8ON7ukdoC3rRec59
5+Ke27vubsXzzh+N4NxPWstcgo0wz3WNoUBbJdtO2gT34/CNcz+Mzoi2fLID
LXyWc79qGPUzibXA+tS4ZAoEbGy3rt2JLo47RoF57eZN723wvKpnOc5evFor
0x698Run/mWE+LrNTvTzd+HcNyXf8qweccH+4eF4CnbpDctR7ui2M5z7Wxnr
1XLLXdjPiuPcX7/wNkpw78b+80fDKVDzuSR6yRcN5SEUhLcw5nvsxf3eGdtL
wW2lZH6hAHTpHi8K1j9b9DArCOflFTpz7t+RZzNF96PFBK0pUFipaZt7gD5P
kzEFrIeNEuLh6GsNehQsPWj7ruAwrvdv1noKciT72EuisF88XZGC5MCZq6Xi
sD5pvxAF3OI5I8x4tNsTHgoO18lelUlCzwvnvD/7hAw2yaWhA9gdTOi73s5T
doJ+nxQ5/0fcPXc1K2SiFSZrmGB1Oc5ydS6uF3ac83+m1UlY7GI+nu+1Kef/
jgEv65VqEdabuexhgqbN3V3qTLTzwU1MWDr+74BOOVrApakUckvTtW9XoMfX
55aCoJHUP7iI881adpXCjAJI1q/BfLns3xLo144q3E7QZ4SWlID7h7lurXVY
XzSvuxhepTJW7LiHXvGWXQwP3tyssGhG182VL4bqI3+I3VPsFxFdwYDI+rAP
3n3ovNr+Avjpx1fWP0Cfl59RAAEief57hrDfIMy8ADy8rv70/4Z+2Hg5Hwxn
/eQL/YO2bQ7JAyHjEOW4+Z+nvSXtcTYw7wrO0RaaNlfwyuBsUNWqHBwRQY/K
C2eDmfzAGY/FWK+dZXUSUma5Sm+WRa/9/DATeO9tF+PSxvrTmgHH4aR2/49a
XXR03Nk0kKmObw/chF77qjsV9Kg7Ge8M0Cp81ikQFa0x54452qoJkmBMR5rr
iDea0tSOhYTL5K2GL9pzbnQMiCo53/7ihzZtS4mGdRJ5h12C0PkbLkRC0K+5
P3Uj0EeuyITBv8Dy9h9R6O6s/w7Aif5t1RUxaEnFsFCo6IgLXJqInr/7XTAM
1vwa/JuBZpT07oFw5dzmyyfRkT5pPsB/at3Zvbloa9jsDXInA7xeF6E7x9rd
4YrA3C0nS9Died4uYBB3TtqEQlfJb3YAz+DetzfOoIP6bSxhZCD2dsg5en9i
MiYQ4y7FUKxAWwi82QKl5o4OhZfQXN9T5Tm/t+OaVjW0LSZ7bhPIEROopR12
S4G8Wd3WfugWWq+xZTMpHRKK4rmDXm5w1pB4ntspd/wuui5Bx4TI+eQ8Fmug
13sUb04GZV+EMxvRqhfrLElFj7iMYgva93reThLEdGy93Eqfl2VoQ9a5MkI3
PkK3JT6wJWNL3i5rakPLR8vbkxsvpZos2un9nXJwIFF5HkGvnqMH5rg5Ej0b
9mKvTvr8rZpOhFfkY/2XV2j78R4n0tQm5x/WhV7AdHMmKSd8F3J30+frqHAm
ZqblJKUHHV7W4kyEBD77iH5Ef0u/7EyeNa0WKulHZ4jucSb5CYE3Vn1C868f
ciJOWy7tuvSZPs+othOR5P4+V2cY/WubgyPpIepXG0bo56W6zYGcjjzoZvaD
zs/MtCe+2tf4O8fonJVjS5R//b7k8RtdJvHLmgxf0XEa+ku/nzwqO0n1/ije
A1P0/iw2WJKDa+9UTnF9wfMPrDEjWsNcdsk8aPdbRdvJRIU+l/AsdMzvKwak
zi/+XBE/evkPrk3EsI9v4sI8dN3+q8vJ7FPbT29YgOZ6cnc+PPBINasXRjPz
Gaqws2s+9XwR7b7ereD+bKHhhDS93ntRR5DNshtOkEUb9Sq6Qr95Qb7gKnp/
Ims8IKB16ZCMMrotOc0bIupXZGxfj1Yt6g0AiPHWat+AJlEVQTADzvY466D1
HT4HQ/J1RY0gPfSFbZGhkFu19lWuMbr5+ItDUFWySbbXFT1SWxYH3w9/5/Pw
oNf/tusorLc7O9S1C30ydHk83BQUvPzCFz3KX5wAjTFvN7eGoPvkWcnw2jPK
rToRfW3yvxMwa9XNwpgL047J2pGaA9t5Ao9MVmG+cM1QDqS9k/E8fBldmGuc
C0L5KQqh17B+/iu+PFg62/GaTz3mN30j8kFt6Ndzsw7MfU7rFcGBporrrZ1o
ZSqnCK6x3YuNXqOP1Q4WwUbnZi/9bnTc0nQGGD3M+67xCS0o/6gYXC6uF1o2
Ne06nR1zmXDV8df8Nq6v096isZYJ82fdmHuUZ9oxCt42TKhz3sg/yD9tvbDM
IibICBj8qxHBXP6pJOf39MrMSR8xzGsvbKSg3b3pj8RizCuJEwXxtcZjMZLo
jsAcCvq8LL+YKmA975spCmCByNA/JVx/k/giFuTdfDZQrYL15WEqLDAStu8V
V8d6zQJHFjBvL+5pXT9trkX2gSz47fv63REtrGevO8qC8juur3sB/Ue7jAUz
9i5/mbcZ6+d6XWeBk1hPh7EBrmd3qoUFNXfZzyYNMa/408mCufu8n1Ztx7zf
u58FXuKr2naZov/2/mDB7XsDD8XMsX7wIDcbxALLW1sscb16iXlsCJDwb4m0
xvz840VsaLy/ummNHbozW5oNUsHDDT0O6PQ9imwIX3qpPscZz7dqhxob2ppC
6ozccB7/Ji02yO9XJ389MK+ATWyIlRy7ecEL98MwMWDDq5ba6x4+WH/A24gN
agcO1Yr6Yf2HVBM2pCzXudLkj+udIjvY8KF1ovpwIOaJk2Zs0A0jVatDcJ6f
kTkbsmViLnSH4jz9Uk7+5eHmipNhWL9gBqff8BBPueFhdH+QMRtKZO+f/R2J
/jJkyIbxx4mnK6Kx326/PhssIozYbnE4fx/fRjaUyQlQwglYn1y2ng3cT1tL
7idhvsBuDRsco44zwlOwP05kFRuq5c0LlY5jvuftMjbMebYg/2065ruuibDB
K/ppTmYWzpNk8bPhlmL2SYMcrHdkTLBAtMMmczwP88GzwyzYF7sovbwQ+yvu
v2eBZGdhygIm5pd07rHg4FHn5HsszOflVrPgsYpk4sHT+Pyez6JYEJNAxb4p
x/oC1QgWzAvjM/aoxHprM18WFPruE+67iFY7bc2CyyZa7OEa9AYeJRb0CT1p
mHEH+wNOP6IghEfzeNJdzAerrlDw7wfDZm4D7r+Ei0GBeKdv38IWtM7+3RSY
lHDxK7TjfpqfjzKhM313W+VznKe7jvP/yCv2Qb5aJ9rkA+e+esQrX0G3C+u9
toQyoUpR1cS8H9eTjO4oBbFatxMH/qJlfcKLgV123/bPJNaL5q4qBtVCJalo
ruFpJ9c+Z8D2qPGLyTOnHfN5QIVzf9yS/qRIEHPRiueF0POYiNavQAP8yYPK
gWVF802xXtHhSSYkFye4vzVD71zmngleVl9WXrBEv7/6NQOW3rpVtcMO+28w
5mRASrpTY5on+oFuahr4ri8YETiEFriSlgAGQ1y1ryLQY4GX4kGK6RtZfgTd
l/7iKHTM3sBnHI9uDZePg61dHUuPpaN9K+uiQCZe1IjvDNpZ+VgwTG2InPei
DG24blkQvPzy4emZ8+iqTUH7IMPusovhJXRGOp8v+M9dskKsBu2/ys8bjO7G
DXy8in7z4I0n/FO02p9wC71BZtAJXr27vsHmDlq1VsMOrmZLT8nWo7sXnrWC
gKlvyQ1NtMd/bwHjy/Zm2f+h60i6Jqz0rRPxeojmcjWSgjdP0kt42um8ntIg
1xLHd7U/R38bP7OZZOu4KbA70W33pIxI0LfGryGv0RZXN5gRk9MqNfpv6f7i
cUsi55h7SPg9eoEL05rMEJyCng/0frYvtCNv73nzVvfR5xG2cSA3wh+2xA6i
mR6uTiR3tUa65We6vnuNCwnuYVhLD6PF1ze7EtM8XomREfp5zRBxJ/Km/u/q
fqAnxtjuhJf72amMcfSzbWIepPuKjp/7H3Sz/h4PcsuPvUZ1Eq2nzvAgeVJz
fv77R3+ePhc8yP8Awv/gUw==
     "]]}},
  AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
  Axes->True,
  AxesLabel->{None, None},
  AxesOrigin->{0, 0},
  AxesStyle->Directive[20, 
    Thickness[0.005], 
    RGBColor[0, 0, 1]],
  ImageSize->500,
  LabelStyle->(FontFamily -> "Helvetica"),
  Method->{},
  PlotRange->{All, All},
  PlotRangeClipping->True,
  PlotRangePadding->{Automatic, Automatic}]], "Output",
 CellChangeTimes->{
  3.577697681200103*^9},ImageCache->GraphicsData["CompressedBitmap", "\<\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\
\>"]]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 StyleBox[
  RowBox[{"Plot", "[", 
   RowBox[{
    RowBox[{
     RowBox[{
      StyleBox["solNDS",
       FontColor->RGBColor[1, 0, 0]], "[", "t", "]"}], "-", 
     RowBox[{
      StyleBox["interpolHermite",
       FontColor->RGBColor[0.6, 0.4, 0.2]], "[", "t", "]"}]}], ",", 
    RowBox[{"{", 
     RowBox[{"t", ",", "tini", ",", "tfin"}], "}"}], ",", 
    RowBox[{"PlotRange", " ", "\[Rule]", " ", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        RowBox[{"-", "1."}], "*", 
        SuperscriptBox["10", 
         RowBox[{"-", "15"}]]}], ",", 
       RowBox[{"1.", "*", 
        SuperscriptBox["10", 
         RowBox[{"-", "15"}]]}]}], "}"}]}]}], "]"}],
  FontSize->24]], "Input",
 CellChangeTimes->{{3.442094948375*^9, 3.4420949506875*^9}, {
   3.44209537290625*^9, 3.442095389859375*^9}, 3.442096262890625*^9, {
   3.442101472671875*^9, 3.44210147290625*^9}, {3.44210189990625*^9, 
   3.442101951515625*^9}, {3.495113123203125*^9, 3.495113125203125*^9}, 
   3.561296562531952*^9, {3.561296598793723*^9, 3.5612966281189632`*^9}},
 FontSize->72],

Cell[BoxData[
 GraphicsBox[{{}, {}, 
   {Hue[0.67, 0.6, 0.6], LineBox[CompressedData["
1:eJxF0H0s1AEYB/A7rlHW6fRiPzp2ovIWk5RUKhZ5qXmbLG8T0vWGbKXVdM1J
XmLtJuX9JaUbR+6scmLctMz7EYo7ziXceducGy1XbfU8z/bdd5//vnsYUTf9
Y7RIJJLvn/xtr5iZ/tbZoBOkf0dxM4qXEo6u/32wJL+wgXAHe3cPvy0iAsHB
0ermp0Q0eNzukVs2kQQu3Xk+LYNIBbN0G/Y9JjjgCyFlvKXlSrCehhXqYcID
W/gtzLRn8sG3e5xd81fegw35NAmZ3AJulLl19R5rA7cxi4xDlCKwau9x/Zrr
n8Baa9xtxhadYCdNZGNAbRe4K9Wxp8OqF2yaq1irXugDK9RSyZD9ALhyrqmT
+kQMptJfLcrlg+CsK4LYUvMv4NWTXHlcyjA4yUHE39U+ApbWijL7GV/BP5mD
BZZ3v4GtT+lsxDaNgT3KGZfrDSX4L3qE2WSoFGyjDNIb9p0Ab9df0hWtoykt
Bbw9hZPgq45No5u9ZWDu2ajSj6tolcJo23TeFFgQ4KHNcZeDUzzZJfxpNGPc
a6SC/R189HAqh3CYBoea9K6RxWhVZ7YsnvUDnE8JT/I3n8H9EkG5lgi96T4r
0DlhFkyqDufJDObAiS942QZt6GbrdF3aDQWY5pVo85CqBI/Z9omThei6Yldz
efg8OIznRKNvoB+wy1hjbxbANTP0AqrPIji9iB0pOYeO9p+3qPVD7xYK63yD
0Rk5FzuyotBxTs+XtySjzVJ3eOpUoTeO3Ns6/Bo9Oj81UMVF5wY3hJ2pR2us
/G+xheix/pxibTH6XZr6kngIzXGJsKwYQXu/PMA/LUF/uNP9mTWLzrM9lOOn
RCfICgMZi+j9PtekrStoCnmwMleNnhC4MCPX0UJmhZ39L/QzUz2VRoP+DRRC
Ph8=
     "]]}},
  AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
  Axes->True,
  AxesLabel->{None, None},
  AxesOrigin->{0, 0},
  AxesStyle->Directive[20, 
    Thickness[0.005], 
    RGBColor[0, 0, 1]],
  ImageSize->500,
  LabelStyle->(FontFamily -> "Helvetica"),
  Method->{},
  PlotRange->{{0, 1}, {-1.*^-15, 1.*^-15}},
  PlotRangeClipping->True,
  PlotRangePadding->{
    Scaled[0.02], Automatic}]], "Output",
 CellChangeTimes->{
  3.577697681292816*^9},ImageCache->GraphicsData["CompressedBitmap", "\<\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\
\>"]]
}, Open  ]]
}, Open  ]]
}, Open  ]]
},
WindowToolbars->"EditBar",
CellGrouping->Manual,
WindowSize->{1438, 813},
WindowMargins->{{187, Automatic}, {Automatic, 26}},
PrintingCopies->1,
PrintingPageRange->{Automatic, Automatic},
ShowCellTags->True,
FrontEndVersion->"9.0 for Linux x86 (64-bit) (January 25, 2013)",
StyleDefinitions->"Default.nb"
]
(* End of Notebook Content *)

(* Internal cache information *)
(*CellTagsOutline
CellTagsIndex->{}
*)
(*CellTagsIndex
CellTagsIndex->{}
*)
(*NotebookFileOutline
Notebook[{
Cell[545, 20, 800, 15, 69, "Text"],
Cell[1348, 37, 6042, 140, 689, "Text"],
Cell[7393, 179, 3700, 57, 238, "Text"],
Cell[11096, 238, 3806, 70, 529, "Text"],
Cell[CellGroupData[{
Cell[14927, 312, 1158, 30, 42, "Input"],
Cell[16088, 344, 449, 13, 24, "Output"]
}, Open  ]],
Cell[16552, 360, 2288, 51, 169, "Text"],
Cell[CellGroupData[{
Cell[18865, 415, 241, 6, 33, "Input"],
Cell[19109, 423, 69, 1, 24, "Output"]
}, Open  ]],
Cell[19193, 427, 1258, 26, 74, "Input"],
Cell[CellGroupData[{
Cell[20476, 457, 131, 4, 33, "Input"],
Cell[20610, 463, 72, 1, 24, "Output"]
}, Open  ]],
Cell[20697, 467, 96, 1, 24, "Input"],
Cell[CellGroupData[{
Cell[20818, 472, 356, 7, 53, "Text"],
Cell[CellGroupData[{
Cell[21199, 483, 373, 6, 44, "Text"],
Cell[CellGroupData[{
Cell[21597, 493, 589, 20, 33, "Input"],
Cell[22189, 515, 280, 9, 27, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[22506, 529, 404, 12, 33, "Input"],
Cell[22913, 543, 106, 2, 24, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[23056, 550, 824, 24, 33, "Input"],
Cell[23883, 576, 10122, 176, 251, 2168, 44, "CachedBoxData", "BoxData", \
"Output"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[34054, 758, 751, 14, 93, "Text"],
Cell[34808, 774, 176, 6, 33, "Input",
 CellID->408132437],
Cell[CellGroupData[{
Cell[35009, 784, 767, 24, 33, "Input"],
Cell[35779, 810, 271, 9, 24, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[36087, 824, 849, 22, 33, "Input"],
Cell[36939, 848, 10124, 176, 251, 2168, 44, "CachedBoxData", "BoxData", \
"Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[47100, 1029, 436, 8, 33, "Input"],
Cell[47539, 1039, 143, 4, 24, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[47719, 1048, 436, 13, 33, "Input"],
Cell[48158, 1063, 72, 1, 24, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[48267, 1069, 234, 7, 33, "Input"],
Cell[48504, 1078, 92, 2, 24, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[48633, 1085, 473, 14, 33, "Input"],
Cell[49109, 1101, 71, 1, 24, "Output"]
}, Open  ]]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[49241, 1109, 381, 7, 53, "Text"],
Cell[CellGroupData[{
Cell[49647, 1120, 1096, 19, 93, "Text"],
Cell[CellGroupData[{
Cell[50768, 1143, 652, 10, 44, "Text"],
Cell[CellGroupData[{
Cell[51445, 1157, 406, 11, 33, "Input"],
Cell[51854, 1170, 832, 15, 42, "Output"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[52735, 1191, 883, 16, 69, "Text"],
Cell[CellGroupData[{
Cell[53643, 1211, 520, 16, 33, "Input"],
Cell[54166, 1229, 819, 15, 42, "Output"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[55034, 1250, 646, 11, 44, "Text"],
Cell[CellGroupData[{
Cell[55705, 1265, 835, 22, 33, "Input"],
Cell[56543, 1289, 817, 15, 42, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[57397, 1309, 137, 3, 33, "Input"],
Cell[57537, 1314, 73, 1, 24, "Output"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[57659, 1321, 1219, 25, 44, "Text"],
Cell[58881, 1348, 1335, 29, 93, "Text"],
Cell[CellGroupData[{
Cell[60241, 1381, 765, 18, 62, "Input"],
Cell[61009, 1401, 6841, 125, 264, 1156, 30, "CachedBoxData", "BoxData", \
"Output"]
}, Open  ]],
Cell[67865, 1529, 1320, 30, 93, "Text"],
Cell[69188, 1561, 777, 13, 44, "Text"],
Cell[69968, 1576, 760, 23, 33, "Input"],
Cell[CellGroupData[{
Cell[70753, 1603, 220, 4, 33, "Input"],
Cell[70976, 1609, 71, 1, 24, "Output"]
}, Open  ]],
Cell[71062, 1613, 675, 13, 44, "Text"],
Cell[CellGroupData[{
Cell[71762, 1630, 590, 15, 33, "Input"],
Cell[72355, 1647, 6535, 119, 259, 1269, 31, "CachedBoxData", "BoxData", \
"Output"]
}, Open  ]]
}, Open  ]]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[78963, 1774, 407, 8, 53, "Text"],
Cell[CellGroupData[{
Cell[79395, 1786, 1067, 21, 95, "Text"],
Cell[CellGroupData[{
Cell[80487, 1811, 1058, 28, 33, "Input"],
Cell[81548, 1841, 1220, 24, 49, "Output"]
}, Open  ]],
Cell[82783, 1868, 453, 9, 44, "Text"],
Cell[CellGroupData[{
Cell[83261, 1881, 726, 16, 33, "Input"],
Cell[83990, 1899, 2931, 77, 89, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[86958, 1981, 3093, 74, 153, "Input"],
Cell[90054, 2057, 24173, 408, 258, 3445, 66, "CachedBoxData", "BoxData", \
"Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[114264, 2470, 479, 10, 93, "Text"],
Cell[CellGroupData[{
Cell[114768, 2484, 767, 21, 33, "Input"],
Cell[115538, 2507, 1211, 24, 49, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[116786, 2536, 527, 12, 33, "Input"],
Cell[117316, 2550, 6796, 122, 191, 1021, 25, "CachedBoxData", "BoxData", \
"Output"]
}, Open  ]]
}, Open  ]]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[124185, 2680, 408, 8, 53, "Text"],
Cell[CellGroupData[{
Cell[124618, 2692, 1092, 22, 69, "Text"],
Cell[CellGroupData[{
Cell[125735, 2718, 605, 15, 33, "Input"],
Cell[126343, 2735, 374, 12, 24, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[126754, 2752, 426, 11, 28, "Input"],
Cell[127183, 2765, 49486, 823, 209, 31987, 534, "CachedBoxData", "BoxData", \
"Output"]
}, Open  ]],
Cell[176684, 3591, 1550, 27, 143, "Text"],
Cell[CellGroupData[{
Cell[178259, 3622, 2755, 64, 174, "Input"],
Cell[181017, 3688, 63131, 1046, 266, 34555, 576, "CachedBoxData", "BoxData", \
"Output"]
}, Open  ]],
Cell[244163, 4737, 1363, 22, 93, "Text"],
Cell[CellGroupData[{
Cell[245551, 4763, 629, 20, 28, "Input"],
Cell[246183, 4785, 109, 2, 26, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[246329, 4792, 398, 13, 28, "Input"],
Cell[246730, 4807, 109, 2, 26, "Output"]
}, Open  ]],
Cell[246854, 4812, 1308, 21, 44, "Text"],
Cell[CellGroupData[{
Cell[248187, 4837, 551, 14, 28, "Input"],
Cell[248741, 4853, 93, 1, 26, "Output"]
}, Open  ]],
Cell[248849, 4857, 1635, 31, 44, "Text"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[250533, 4894, 405, 8, 53, "Text"],
Cell[CellGroupData[{
Cell[250963, 4906, 828, 15, 69, "Text"],
Cell[CellGroupData[{
Cell[251816, 4925, 473, 15, 33, "Input"],
Cell[252292, 4942, 370, 12, 24, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[252699, 4959, 805, 19, 33, "Input"],
Cell[253507, 4980, 609, 21, 24, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[254153, 5006, 1566, 40, 103, "Input"],
Cell[255722, 5048, 59780, 993, 200, 37125, 620, "CachedBoxData", "BoxData", \
"Output"],
Cell[315505, 6043, 829, 16, 69, "Text"],
Cell[CellGroupData[{
Cell[316359, 6063, 454, 12, 26, "Input"],
Cell[316816, 6077, 105, 2, 26, "Output"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[316970, 6085, 599, 15, 26, "Input"],
Cell[317572, 6102, 110, 2, 24, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[317719, 6109, 1564, 39, 95, "Text"],
Cell[319286, 6150, 551, 13, 33, "Input"],
Cell[319840, 6165, 702, 17, 33, "Input"],
Cell[CellGroupData[{
Cell[320567, 6186, 2521, 67, 162, "Input"],
Cell[323091, 6255, 17686, 301, 201, 3185, 61, "CachedBoxData", "BoxData", \
"Output"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[340826, 6562, 1154, 22, 44, "Text"],
Cell[CellGroupData[{
Cell[342005, 6588, 1431, 32, 202, "Input"],
Cell[343439, 6622, 57135, 948, 213, 38933, 648, "CachedBoxData", "BoxData", \
"Output"]
}, Open  ]]
}, Open  ]]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[400647, 7578, 410, 8, 53, "Text"],
Cell[CellGroupData[{
Cell[401082, 7590, 1476, 25, 190, "Text"],
Cell[CellGroupData[{
Cell[402583, 7619, 3689, 103, 226, "Input"],
Cell[406275, 7724, 33717, 567, 257, 6682, 122, "CachedBoxData", "BoxData", \
"Output"]
}, Open  ]]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[440053, 8298, 409, 8, 53, "Text"],
Cell[CellGroupData[{
Cell[440487, 8310, 3173, 69, 215, "Text"],
Cell[CellGroupData[{
Cell[443685, 8383, 615, 14, 28, "Input"],
Cell[444303, 8399, 820, 15, 42, "Output"]
}, Open  ]],
Cell[445138, 8417, 1758, 26, 44, "Text"],
Cell[CellGroupData[{
Cell[446921, 8447, 398, 13, 33, "Input"],
Cell[447322, 8462, 306, 10, 24, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[447665, 8477, 474, 13, 33, "Input"],
Cell[448142, 8492, 820, 15, 42, "Output"]
}, Open  ]],
Cell[448977, 8510, 1381, 32, 33, "Input"],
Cell[CellGroupData[{
Cell[450383, 8546, 540, 12, 33, "Input"],
Cell[450926, 8560, 271, 9, 24, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[451234, 8574, 755, 23, 33, "Input"],
Cell[451992, 8599, 10124, 176, 251, 2168, 44, "CachedBoxData", "BoxData", \
"Output"]
}, Open  ]],
Cell[462131, 8778, 515, 11, 44, "Text"],
Cell[CellGroupData[{
Cell[462671, 8793, 1025, 26, 33, "Input"],
Cell[463699, 8821, 80845, 1337, 207, 63440, 1050, "CachedBoxData", "BoxData", \
"Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[544581, 10163, 1070, 29, 40, "Input"],
Cell[545654, 10194, 6276, 114, 210, 1429, 33, "CachedBoxData", "BoxData", \
"Output"]
}, Open  ]]
}, Open  ]]
}, Open  ]]
}
]
*)

(* End of internal cache information *)
