(* Content-type: application/mathematica *)

(*** Wolfram Notebook File ***)
(* http://www.wolfram.com/nb *)

(* CreatedBy='Mathematica 7.0' *)

(*CacheID: 234*)
(* Internal cache information:
NotebookFileLineBreakTest
NotebookFileLineBreakTest
NotebookDataPosition[       145,          7]
NotebookDataLength[     98670,       2497]
NotebookOptionsPosition[     93873,       2342]
NotebookOutlinePosition[     94348,       2362]
CellTagsIndexPosition[     94305,       2359]
WindowFrame->Normal*)

(* Beginning of Notebook Content *)
Notebook[{
Cell["\<\
Evaluation time
\[CapitalDelta]t < 4 s   \
\>", "Text",
 CellChangeTimes->{{3.5613483031229563`*^9, 3.561348339745145*^9}, {
  3.56135098674468*^9, 3.561351023826701*^9}, {3.561351426355578*^9, 
  3.561351561050626*^9}, {3.561351658143539*^9, 3.561351701940361*^9}, {
  3.562308659027141*^9, 3.562308685577752*^9}, {3.5739849802054777`*^9, 
  3.573985010523902*^9}, {3.5739850441078873`*^9, 3.573985091187277*^9}, {
  3.5739852917493277`*^9, 3.573985301197431*^9}, {3.573985387415966*^9, 
  3.573985423188324*^9}, {3.573985799716304*^9, 3.573985871674148*^9}, {
  3.5739859027151823`*^9, 3.573985908625372*^9}, {3.573985970636365*^9, 
  3.573985971137138*^9}, {3.574514403882321*^9, 3.5745144157610006`*^9}},
 FontSize->24,
 FontColor->RGBColor[0, 0, 1],
 Background->RGBColor[1, 0.9, 0.8]],

Cell[TextData[{
 "This notebook is about some aspects of the numerical solution of an ODE , \
for example, \n                             \n                                \
   ",
 Cell[BoxData[
  FormBox[
   RowBox[{
    StyleBox["{",
     FontSize->45], " ", GridBox[{
      {
       RowBox[{
        RowBox[{
         RowBox[{"ODE", "           ", 
          RowBox[{"x", "'"}], 
          RowBox[{"(", "t", ")"}]}], "-", 
         RowBox[{"x", "(", "t", ")"}]}], "=", "0"}]},
      {
       RowBox[{"    ", 
        RowBox[{
         RowBox[{"IC", "      ", 
          RowBox[{"x", "[", "0", "]"}]}], "=", 
         RowBox[{
          RowBox[{"1", " ", "for", " ", "0"}], " ", "<", " ", "t", " ", "<", 
          " ", "t_fin", "  "}]}]}]}
     }]}], TraditionalForm]]],
 "(1)\n \n obtained  by means of the command NDSolve.\n \n Since we do not \
expect to give an exaustive treatment, we will just illustrate, \n even with \
this trivial example,  how it is possible\n to have at least an idea of the \
possibilities offered by the NDSolve command.\n For this purpose, we have to \
introduce two kinds of errors (Note 1):\n \n 1) The global error is here \
defined as\n              ",
 StyleBox[" ",
  FontSize->36],
 Cell[BoxData[
  FormBox[
   RowBox[{
    SubscriptBox["e", "i"], " "}], TraditionalForm]]],
 " =  ",
 StyleBox["x",
  FontSlant->"Italic"],
 "(",
 Cell[BoxData[
  FormBox[
   SubscriptBox["t", "i"], TraditionalForm]]],
 ")",
 Cell[BoxData[
  FormBox[
   RowBox[{" ", 
    RowBox[{"-", " ", 
     SubscriptBox["x", "i"]}]}], TraditionalForm]]],
 " where\n  - ",
 StyleBox["x",
  FontSlant->"Italic"],
 "(",
 Cell[BoxData[
  FormBox[
   SubscriptBox["t", "i"], TraditionalForm]]],
 ") is the",
 StyleBox[" true",
  FontSlant->"Italic"],
 " solution of the ODE at ",
 Cell[BoxData[
  FormBox[
   RowBox[{"t", " ", "=", " ", 
    SubscriptBox["t", "i"], " "}], TraditionalForm]]],
 " ",
 StyleBox[" ",
  FontSlant->"Italic"],
 " and\n -",
 Cell[BoxData[
  FormBox[
   RowBox[{"  ", 
    SubscriptBox["x", "i"]}], TraditionalForm]], "Input"],
 " is the numerical solution found, at the same  ",
 Cell[BoxData[
  FormBox[
   RowBox[{
    RowBox[{"t", " ", "=", " ", 
     SubscriptBox["t", "i"]}], ",", " "}], TraditionalForm]]],
 " by the built-in command NDSolve.\n  However, as  ",
 StyleBox["x",
  FontSlant->"Italic"],
 "(",
 Cell[BoxData[
  FormBox[
   SubscriptBox["t", "i"], TraditionalForm]]],
 ")  is at disposal only in those cases where the analytical solutions know,\n\
  it is useful to resort to the second kind of error\n   \n 2) The residual \
error is obtainable after substitution of the numerical solution, \n          \
 an interpolation function object (IFO, Note 2),  back into the original \
equation to see\n            how well it solves the ODE. Usually, we are \
satisfied when  the residual is \n            near to zero, but it is \
appropriate to recall what Mark Sofroniou (Wolfram) says\n            \n      \
      ",
 StyleBox["While the residual is related to the error you should not mistake \
it\n           for a direct measure of the error. A solution with small \
residual error\n           can have large error",
  FontSlant->"Italic"]
}], "Text",
 CellChangeTimes->{{3.432984958734375*^9, 3.4329849665625*^9}, {
   3.43332981478125*^9, 3.433329816109375*^9}, {3.442057656984375*^9, 
   3.44205774384375*^9}, 3.442058730484375*^9, {3.442059064375*^9, 
   3.442059098265625*^9}, {3.4420603753125*^9, 3.442060384109375*^9}, {
   3.442060422*^9, 3.4420605378125*^9}, {3.49519575603125*^9, 
   3.495195794484375*^9}, {3.495195828203125*^9, 3.495195907859375*^9}, {
   3.495195945171875*^9, 3.49519611775*^9}, {3.4951962355*^9, 
   3.495196298203125*^9}, {3.495196355078125*^9, 3.49519646371875*^9}, {
   3.4951965003125*^9, 3.495196647734375*^9}, {3.49519682521875*^9, 
   3.4951968799375*^9}, {3.495196951078125*^9, 3.49519695415625*^9}, {
   3.495199133890625*^9, 3.49519930815625*^9}, 3.49666944190625*^9, {
   3.496669540609375*^9, 3.49667000575*^9}, 3.49667007896875*^9, {
   3.49667011534375*^9, 3.496670218515625*^9}, {3.496670256015625*^9, 
   3.49667026009375*^9}, {3.496670337*^9, 3.4966703671875*^9}, {
   3.496670478*^9, 3.496670505890625*^9}, {3.496670547234375*^9, 
   3.496670574875*^9}, {3.496670608203125*^9, 3.496670631328125*^9}, {
   3.49672760571875*^9, 3.49672760803125*^9}, {3.496727644203125*^9, 
   3.496727685984375*^9}, {3.4967277201875*^9, 3.49672772178125*^9}, {
   3.49674708671875*^9, 3.496747096609375*^9}, {3.56128282309694*^9, 
   3.5612828308307047`*^9}, {3.561283878860196*^9, 3.5612839225077763`*^9}, {
   3.561283962100245*^9, 3.561283984169382*^9}, {3.561284020422007*^9, 
   3.561284166601224*^9}, {3.5612842611462383`*^9, 3.561284297399015*^9}, {
   3.561284332316331*^9, 3.5612844118409157`*^9}, {3.56128444384931*^9, 
   3.56128458932201*^9}, {3.5612846517560167`*^9, 3.5612847219715347`*^9}, {
   3.561284753686095*^9, 3.561284930446385*^9}, {3.5612849912225313`*^9, 
   3.561285085266478*^9}, 3.561285132195622*^9, {3.56128520264758*^9, 
   3.561285287930707*^9}, {3.561285436626279*^9, 3.561285514684123*^9}, {
   3.56128557569715*^9, 3.5612855887123547`*^9}, {3.561285685798307*^9, 
   3.561285778829077*^9}, {3.5612858719345284`*^9, 3.5612858756819887`*^9}, {
   3.561285961560574*^9, 3.56128597435222*^9}, 3.5612860123055887`*^9, {
   3.5612860817450867`*^9, 3.561286122301196*^9}, {3.561286165064357*^9, 
   3.561286165388467*^9}, {3.5612863146724577`*^9, 3.56128631963903*^9}, {
   3.561286374101522*^9, 3.561286393054981*^9}, {3.561286494618198*^9, 
   3.561286591316832*^9}, {3.5612867061554613`*^9, 3.561286800723712*^9}, {
   3.561286831828373*^9, 3.561286834367888*^9}, {3.561286886917225*^9, 
   3.5612869126834717`*^9}, {3.5612869582731256`*^9, 3.561286959092511*^9}, {
   3.561287139176734*^9, 3.5612871772803707`*^9}, 3.56135064500805*^9, 
   3.561351512300521*^9, {3.5745144454726996`*^9, 3.574514610241124*^9}},
 FontFamily->"Times New Roman",
 FontSize->24,
 FontColor->RGBColor[0, 0, 1],
 Background->RGBColor[1, 1, 0.85]],

Cell[TextData[{
 " Note 1. Any good book on the numerical evaluation of the ODE has some \
sections\n                 discussing the difference between the different \
kinds of errors;\n                 E.g.  M.J. Maron \
\[OpenCurlyDoubleQuote]Numerical Analysis Apractical Approach\
\[CloseCurlyDoubleQuote], 2nd ed, MacMillan Pub. Co, 1987\n",
 StyleBox["\n ",
  FontSlant->"Italic"],
 "Note 2. The numerical solution is representd by an interpolation function \
object, \n               that is, a function passing through the points \
chosen by the algorithm which\n               evaluates the unknown over the \
selected grid points.  \n               We recall that the IFO can be \
differentiated, integrated,  plotted, and so on.\n               In this nb \
we consider only the Default Options offered by NDSolve "
}], "Text",
 CellChangeTimes->{{3.432984958734375*^9, 3.4329849665625*^9}, {
   3.43332981478125*^9, 3.433329816109375*^9}, {3.442057656984375*^9, 
   3.44205774384375*^9}, 3.442058730484375*^9, {3.442059064375*^9, 
   3.442059098265625*^9}, {3.4420603753125*^9, 3.442060384109375*^9}, {
   3.442060422*^9, 3.4420605378125*^9}, {3.49519575603125*^9, 
   3.495195794484375*^9}, {3.495195828203125*^9, 3.495195907859375*^9}, {
   3.495195945171875*^9, 3.49519611775*^9}, {3.4951962355*^9, 
   3.495196298203125*^9}, {3.495196355078125*^9, 3.49519646371875*^9}, {
   3.4951965003125*^9, 3.495196647734375*^9}, {3.49519682521875*^9, 
   3.4951968799375*^9}, {3.495196951078125*^9, 3.49519695415625*^9}, {
   3.495199133890625*^9, 3.49519930815625*^9}, 3.49666944190625*^9, {
   3.496669540609375*^9, 3.49667000575*^9}, 3.49667007896875*^9, {
   3.49667011534375*^9, 3.496670218515625*^9}, {3.496670256015625*^9, 
   3.49667026009375*^9}, {3.496670337*^9, 3.4966703671875*^9}, {
   3.496670478*^9, 3.496670505890625*^9}, {3.496670547234375*^9, 
   3.496670574875*^9}, {3.496670608203125*^9, 3.496670631328125*^9}, {
   3.49672760571875*^9, 3.49672760803125*^9}, {3.496727644203125*^9, 
   3.496727685984375*^9}, {3.4967277201875*^9, 3.49672772178125*^9}, {
   3.49674708671875*^9, 3.496747096609375*^9}, {3.56128282309694*^9, 
   3.5612828308307047`*^9}, {3.561283878860196*^9, 3.5612839225077763`*^9}, {
   3.561283962100245*^9, 3.561283984169382*^9}, {3.561284020422007*^9, 
   3.561284166601224*^9}, {3.5612842611462383`*^9, 3.561284297399015*^9}, {
   3.561284332316331*^9, 3.5612844118409157`*^9}, {3.56128444384931*^9, 
   3.56128458932201*^9}, {3.5612846517560167`*^9, 3.5612847219715347`*^9}, {
   3.561284753686095*^9, 3.561284930446385*^9}, {3.5612849912225313`*^9, 
   3.561285085266478*^9}, 3.561285132195622*^9, {3.56128520264758*^9, 
   3.561285287930707*^9}, {3.561285436626279*^9, 3.561285514684123*^9}, {
   3.56128557569715*^9, 3.5612855887123547`*^9}, {3.561285685798307*^9, 
   3.561285778829077*^9}, {3.5612858719345284`*^9, 3.5612858756819887`*^9}, {
   3.561285961560574*^9, 3.56128597435222*^9}, 3.5612860123055887`*^9, {
   3.5612860817450867`*^9, 3.561286122301196*^9}, {3.561286165064357*^9, 
   3.561286165388467*^9}, {3.5612863146724577`*^9, 3.56128631963903*^9}, {
   3.561286374101522*^9, 3.561286393054981*^9}, {3.561286494618198*^9, 
   3.561286591316832*^9}, {3.5612867061554613`*^9, 3.561286800723712*^9}, {
   3.561286831828373*^9, 3.561286834367888*^9}, {3.561286886917225*^9, 
   3.5612869126834717`*^9}, {3.5612869582731256`*^9, 3.561286959092511*^9}, {
   3.561287139176734*^9, 3.5612871772803707`*^9}, 3.56135064500805*^9, {
   3.573985184168124*^9, 3.5739852827863693`*^9}, {3.574514615297413*^9, 
   3.57451461874561*^9}},
 FontFamily->"Times New Roman",
 FontSize->24,
 FontColor->RGBColor[0, 0, 1],
 Background->RGBColor[1, 1, 0.85]],

Cell[TextData[{
 "We consider seven parts:\n\n1) We calculate ",
 StyleBox["the symbolic solution (with DSolve) and ",
  FontFamily->"Utopia",
  FontSize->24],
 " \n     ",
 StyleBox["the numeric solution  (with NDSolve) ",
  FontFamily->"Utopia",
  FontSize->24],
 "of the system (1)\n2) We  extract the coordinates of the nodes (TimeNodes) \
hit by    \n     the numeric method and evaluate solsymb and solNDS on the \
same nodes\n3) To estimate the GlobalError, we examine the difference ",
 StyleBox[" between \n     the values calculated  by the numeric solution and \
the symbolic \n     solution on the same ",
  FontFamily->"Utopia",
  FontSize->24],
 "TimeNodes",
 StyleBox["\n4) ",
  FontFamily->"Utopia",
  FontSize->24],
 "To estimate the GlobalError, we examine the difference ",
 StyleBox[" between \n       the symbolic solution and the IFO representing \
the numerical solution\n5)   We examine the residual function obtained by \
substituting teh IFO into the system (1)\n",
  FontFamily->"Utopia",
  FontSize->24],
 "6)   We compare the GlobalError and the ResidualError only on the \
TimeNodes,\n      that means, the nodes hit by the numerical method\n 7)  \
Short digression on Hermite interpolation  \n  \n   Conclusion: The \
ResidualError is not a ",
 StyleBox["perfect",
  FontSlant->"Italic"],
 " indicator of the real error \n                         contained in the \
numerical solution but it can be considered \n                          a \
useful tool. \n                          \n                         We invite \
the reader to try the same procedures with more complicated functions and \
enjoy the results!"
}], "Text",
 CellChangeTimes->{{3.441959582546875*^9, 3.44195966165625*^9}, {
   3.442060616203125*^9, 3.44206062196875*^9}, {3.4420611343125*^9, 
   3.442061276953125*^9}, {3.442061320265625*^9, 3.442061394359375*^9}, {
   3.442061487515625*^9, 3.442061887515625*^9}, 3.442061923609375*^9, 
   3.44206238434375*^9, {3.44206255975*^9, 3.44206256028125*^9}, {
   3.442149009734375*^9, 3.442149012859375*^9}, {3.442149050359375*^9, 
   3.442149188640625*^9}, {3.442149226875*^9, 3.4421493121875*^9}, {
   3.442149342640625*^9, 3.442149399421875*^9}, {3.442149433609375*^9, 
   3.44214961746875*^9}, {3.442149678796875*^9, 3.442149714328125*^9}, {
   3.442154405328125*^9, 3.44215440609375*^9}, 3.442298685386031*^9, {
   3.49510363821875*^9, 3.495103649*^9}, {3.49510846128125*^9, 
   3.495108467421875*^9}, 3.495111457765625*^9, {3.49666306821875*^9, 
   3.4966631073125*^9}, {3.49666314753125*^9, 3.49666322784375*^9}, {
   3.496663282171875*^9, 3.4966634096875*^9}, {3.496663513421875*^9, 
   3.496663539984375*^9}, {3.496663651484375*^9, 3.49666368903125*^9}, {
   3.496663756046875*^9, 3.4966637888125*^9}, {3.496663831953125*^9, 
   3.4966638435625*^9}, {3.4966639441875*^9, 3.496664044375*^9}, {
   3.496664085875*^9, 3.496664135015625*^9}, {3.496664227453125*^9, 
   3.49666427475*^9}, {3.496664418171875*^9, 3.496664487015625*^9}, {
   3.496664542640625*^9, 3.49666459959375*^9}, {3.49666475696875*^9, 
   3.49666485115625*^9}, {3.496665516375*^9, 3.4966655215*^9}, {
   3.496665556359375*^9, 3.49666571553125*^9}, {3.4967464605*^9, 
   3.4967464618125*^9}, {3.496749313796875*^9, 3.496749317328125*^9}, {
   3.49683442459375*^9, 3.4968345115*^9}, {3.5612869989920607`*^9, 
   3.5612870402733917`*^9}, {3.56129697056164*^9, 3.561296988217889*^9}, {
   3.561298210351753*^9, 3.561298258341168*^9}, {3.561348920301907*^9, 
   3.561348920515768*^9}, {3.561351178083227*^9, 3.561351201577052*^9}, {
   3.574514692360821*^9, 3.5745147208734517`*^9}, 3.5745147722893925`*^9, {
   3.574514846688648*^9, 3.57451484724868*^9}, {3.5745151302018642`*^9, 
   3.57451519936982*^9}},
 FontSize->24,
 FontColor->RGBColor[0, 0, 1],
 Background->RGBColor[1, 1, 0.85]],

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", 
   RowBox[{"However", ",", " ", 
    RowBox[{
    "if", " ", "you", " ", "are", " ", "Impatient", " ", "and", " ", "you", 
     " ", "have", " ", "someway", " ", 
     StyleBox[
      RowBox[{"a", 
       StyleBox["lready",
        FontVariations->{"Underline"->True}]}]], 
     StyleBox[" ",
      FontVariations->{"Underline"->True}], 
     StyleBox["run",
      FontVariations->{"Underline"->True}], 
     StyleBox[" ",
      FontVariations->{"Underline"->True}], 
     StyleBox["this",
      FontVariations->{"Underline"->True}], 
     StyleBox[" ",
      FontVariations->{"Underline"->True}], 
     StyleBox["nb",
      FontVariations->{"Underline"->True}]}], 
    StyleBox[",",
     FontVariations->{"Underline"->True}], " ", 
    RowBox[{"you", " ", "can", " ", "click", " ", "this", " ", "cell"}]}], 
   " ", "*)"}], "\[IndentingNewLine]", 
  RowBox[{"Hyperlink", "[", "hyphyp", "]"}]}]], "Input",
 CellChangeTimes->{{3.561349979732888*^9, 3.561350019757031*^9}, {
  3.561350697829133*^9, 3.561350746264123*^9}, {3.5613508942216454`*^9, 
  3.561350962456707*^9}, {3.561370354190283*^9, 3.561370355172756*^9}}],

Cell[TextData[{
 "We considere the following  ODE with the initial condition IC\n\n\t\t\t",
 Cell[BoxData[
  FormBox[
   RowBox[{
    StyleBox["{",
     FontSize->45], " ", GridBox[{
      {
       RowBox[{
        RowBox[{
         RowBox[{"ODE", "   ", 
          RowBox[{"x", "'"}]}], "-", "x"}], "=", "0"}]},
      {
       RowBox[{
        RowBox[{"IC", "      ", 
         RowBox[{"x", "[", "0", "]"}]}], "=", "1.", "  "}]}
     }]}], TraditionalForm]]],
 "        (1)\t\n\nThe solution is  ",
 StyleBox[" ",
  FontFamily->"Times New Roman"],
 Cell[BoxData[
  RowBox[{
   RowBox[{"x", 
    RowBox[{"(", "t", ")"}]}], " ", "=", " ", 
   SuperscriptBox["\[ExponentialE]", "t"]}]],
  CellChangeTimes->{
   3.44195948865625*^9, 3.441959712359375*^9, 3.44196010528125*^9, 
    3.4419611048125*^9, 3.4419611419375*^9, {3.44196508165625*^9, 
    3.44196509034375*^9}, {3.441965139859375*^9, 3.441965145890625*^9}, 
    3.441965927140625*^9, 3.44197415546875*^9, 3.442063654859375*^9, 
    3.44206504321875*^9, 3.4420729784375*^9, 3.4420851091875*^9, 
    3.442095234078125*^9, {3.44210079153125*^9, 3.44210080328125*^9}, 
    3.44210188709375*^9, {3.442151937171875*^9, 3.44215195665625*^9}, 
    3.4421544799375*^9, 3.4421799611875*^9, 3.442182094140625*^9, 
    3.442299818117124*^9, 3.442300769908202*^9, 3.4423021008866043`*^9},
  FontFamily->"Times New Roman"]
}], "Text",
 CellChangeTimes->{{3.441959582546875*^9, 3.44195966165625*^9}, {
   3.442060616203125*^9, 3.44206062196875*^9}, {3.4420611343125*^9, 
   3.442061276953125*^9}, {3.442061320265625*^9, 3.442061394359375*^9}, {
   3.442061487515625*^9, 3.442061887515625*^9}, 3.442061923609375*^9, {
   3.442062088828125*^9, 3.44206213271875*^9}, {3.4420622845*^9, 
   3.442062318953125*^9}, {3.442062402703125*^9, 3.442062426421875*^9}, {
   3.44206247659375*^9, 3.44206260809375*^9}, {3.442100619625*^9, 
   3.442100707203125*^9}, {3.442149653421875*^9, 3.44214967221875*^9}, {
   3.442149720984375*^9, 3.442149721234375*^9}, {3.44215201878125*^9, 
   3.4421520224375*^9}, {3.4421543131875*^9, 3.442154313921875*^9}, {
   3.49510366065625*^9, 3.49510371525*^9}, {3.49666293459375*^9, 
   3.49666304296875*^9}, {3.49666312734375*^9, 3.496663140578125*^9}, 
   3.5745147393015056`*^9},
 FontSize->24,
 Background->GrayLevel[0.85]],

Cell[BoxData[
 RowBox[{
  RowBox[{"Clear", "[", "\"\<Global`*\>\"", "]"}], ";", 
  RowBox[{"Remove", "[", "\"\<Global`*\>\"", "]"}], ";", 
  RowBox[{"$Line", "=", "0", "  "}]}]], "Input",
 CellChangeTimes->{3.495103580875*^9},
 FontSize->24],

Cell[BoxData[
 RowBox[{
  RowBox[{"SetOptions", "[", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"Plot", ",", "ListPlot", ",", "Plot3D"}], "}"}], ",", 
    RowBox[{"ImageSize", "\[Rule]", "500"}], ",", 
    RowBox[{"LabelStyle", "\[Rule]", 
     RowBox[{"(", 
      RowBox[{"FontFamily", "\[Rule]", "\"\<Helvetica\>\""}], ")"}]}], ",", 
    RowBox[{"AxesStyle", "\[Rule]", 
     RowBox[{"Directive", "[", 
      RowBox[{"20", ",", 
       RowBox[{"Thickness", "[", "0.005", "]"}], ",", "Blue"}], "]"}]}]}], 
   "]"}], ";"}]], "Input",
 CellChangeTimes->{{3.431404133265625*^9, 3.431404152625*^9}, {
   3.431404184828125*^9, 3.43140419784375*^9}, {3.431404229828125*^9, 
   3.431404286*^9}, {3.431404358734375*^9, 3.431404362015625*^9}, 
   3.43140449659375*^9, {3.431404585328125*^9, 3.431404586390625*^9}, {
   3.431404647765625*^9, 3.431404694953125*^9}, {3.43140617875*^9, 
   3.4314062495625*^9}, {3.431406282875*^9, 3.4314063513125*^9}, {
   3.43140679328125*^9, 3.43140680225*^9}, {3.4314068341875*^9, 
   3.431406876078125*^9}, {3.43228594825*^9, 3.432285987546875*^9}, {
   3.441960481296875*^9, 3.441960483484375*^9}, 3.44205855490625*^9, {
   3.44205867675*^9, 3.442058682359375*^9}, 3.495103580875*^9},
 FontSize->24,
 Background->GrayLevel[0.85]],

Cell[BoxData[
 RowBox[{
  RowBox[{"tini", "=", "0"}], ";", " ", 
  RowBox[{"tfin", " ", "=", " ", "1"}]}]], "Input",
 FontSize->24],

Cell[BoxData[""], "Input",
 CellChangeTimes->{{3.5745148520569553`*^9, 3.5745148537940545`*^9}}],

Cell[CellGroupData[{

Cell["Part I", "Text",
 CellChangeTimes->{{3.4420619435625*^9, 3.4420619460625*^9}, {
  3.495108480859375*^9, 3.49510848184375*^9}, {3.495285762890625*^9, 
  3.495285793703125*^9}, {3.49528627184375*^9, 3.49528627628125*^9}, {
  3.574514859153361*^9, 3.574514860104415*^9}},
 FontSize->36,
 FontColor->RGBColor[0, 0, 1],
 Background->RGBColor[1, 0.9, 0.8]],

Cell[CellGroupData[{

Cell["We evaluate symbolically the solution (solsymb) of the ODE", "Text",
 CellChangeTimes->{{3.4420619435625*^9, 3.4420619460625*^9}, {
  3.495108480859375*^9, 3.49510848184375*^9}, {3.495285762890625*^9, 
  3.495285793703125*^9}, {3.49528627184375*^9, 3.49528627628125*^9}, {
  3.574515224057232*^9, 3.5745152276014347`*^9}},
 FontSize->24,
 Background->GrayLevel[0.85]],

Cell[BoxData[
 RowBox[{
  StyleBox[
   RowBox[{"sol", 
    StyleBox["DS",
     FontColor->RGBColor[0, 0, 1]]}]], "=", 
  RowBox[{"DSolve", "[", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{
      RowBox[{
       RowBox[{
        RowBox[{
         RowBox[{"x", "'"}], "[", "t", "]"}], "-", 
        RowBox[{"x", "[", "t", "]"}]}], "\[Equal]", " ", "0"}], ",", 
      RowBox[{
       RowBox[{"x", "[", "0", "]"}], "\[Equal]", "1"}]}], "}"}], ",", "x", 
    ",", "t"}], "]"}]}]], "Input",
 CellChangeTimes->{
  3.442065042296875*^9, {3.442100765640625*^9, 3.44210077103125*^9}},
 FontSize->24],

Cell[BoxData[
 RowBox[{
  RowBox[{"solsymb", "[", "t_", "]"}], "=", " ", 
  RowBox[{
   RowBox[{"x", "[", "t", "]"}], " ", "/.", " ", 
   RowBox[{"First", "[", 
    StyleBox[
     RowBox[{"sol", 
      StyleBox["DS",
       FontColor->RGBColor[0, 0, 1]]}]], "]"}]}]}]], "Input",
 CellChangeTimes->{{3.442064885734375*^9, 3.44206489003125*^9}, 
   3.4420650454375*^9, 3.495285363296875*^9},
 FontSize->24],

Cell[BoxData[
 RowBox[{"Plot", "[", 
  RowBox[{
   RowBox[{"solsymb", "[", "t", "]"}], ",", 
   StyleBox[
    RowBox[{"{", 
     RowBox[{"t", ",", "tini", ",", "tfin"}], "}"}],
    FontColor->GrayLevel[0]], 
   StyleBox[",",
    FontColor->GrayLevel[0]], 
   StyleBox[
    RowBox[{"PlotRange", "\[Rule]", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"tini", ",", "tfin"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"0", ",", "3"}], "}"}]}], "}"}]}],
    FontColor->GrayLevel[0]]}], "]"}]], "Input",
 CellChangeTimes->{
  3.441959714828125*^9, {3.442063648015625*^9, 3.44206364865625*^9}, {
   3.44206415028125*^9, 3.44206415140625*^9}, {3.4420649815625*^9, 
   3.442064987640625*^9}, {3.44207357215625*^9, 3.44207357578125*^9}, 
   3.44208707471875*^9, 3.49528536753125*^9},
 FontSize->24]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
 "We evaluate numerically the solution (solNDS) of the ODE\n      ( ",
 StyleBox["without  introducing any of the numerous Options of NDSolve)\n     \
 and use some of the tools  offered by ",
  FontColor->GrayLevel[0]],
 "InterpolatingFunctionAnatomy"
}], "Text",
 CellChangeTimes->{{3.442063124046875*^9, 3.44206312528125*^9}, {
   3.49510850378125*^9, 3.49510857546875*^9}, {3.495197200984375*^9, 
   3.495197246390625*^9}, {3.495285807359375*^9, 3.49528582221875*^9}, 
   3.495285997171875*^9, {3.495286281265625*^9, 3.495286285046875*^9}, {
   3.496834527765625*^9, 3.496834554671875*^9}, {3.561289543257484*^9, 
   3.561289589162808*^9}, {3.574515225698326*^9, 3.574515228649495*^9}},
 FontSize->24,
 Background->GrayLevel[0.85]],

Cell[BoxData[
 RowBox[{
  RowBox[{
  "Needs", "[", "\"\<DifferentialEquations`InterpolatingFunctionAnatomy`\>\"",
    "]"}], ";"}]], "Input",
 FontSize->24,
 CellID->408132437],

Cell[BoxData[
 RowBox[{
  StyleBox["solNDS",
   FontColor->RGBColor[1, 0, 0]], "=", 
  RowBox[{"x", " ", "/.", 
   RowBox[{"First", "[", 
    RowBox[{"NDSolve", "[", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{
        RowBox[{
         RowBox[{
          RowBox[{
           RowBox[{"x", "'"}], "[", "t", "]"}], "-", 
          RowBox[{"x", "[", "t", "]"}]}], "\[Equal]", "0"}], ",", 
        RowBox[{
         RowBox[{"x", "[", "0", "]"}], "\[Equal]", "1"}]}], "}"}], ",", "x", 
      ",", 
      RowBox[{"{", 
       RowBox[{"t", ",", "tini", ",", "tfin"}], " ", "}"}]}], "]"}], 
    "]"}]}]}]], "Input",
 CellChangeTimes->{
  3.442065051078125*^9, {3.442100775234375*^9, 3.442100780421875*^9}, {
   3.4951089606875*^9, 3.495108975015625*^9}},
 FontSize->24],

Cell[BoxData[
 RowBox[{"Plot", "[", 
  RowBox[{
   RowBox[{
    StyleBox["solNDS",
     FontColor->RGBColor[1, 0, 0]], "[", "t", "]"}], ",", 
   RowBox[{"{", 
    RowBox[{"t", ",", "tini", ",", "tfin"}], "}"}], ",", 
   StyleBox[
    RowBox[{"PlotRange", "\[Rule]", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"tini", ",", "tfin"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"0", ",", "3"}], "}"}]}], "}"}]}],
    FontColor->GrayLevel[0]]}], "]"}]], "Input",
 CellChangeTimes->{{3.441959759734375*^9, 3.4419597776875*^9}, {
  3.441960135109375*^9, 3.441960165265625*^9}, {3.44206395715625*^9, 
  3.4420639584375*^9}, {3.44206419675*^9, 3.442064197640625*^9}, {
  3.442065068421875*^9, 3.4420650700625*^9}, {3.4420870690625*^9, 
  3.44208707215625*^9}, {3.495109033578125*^9, 3.495109035765625*^9}},
 FontSize->24],

Cell[BoxData[
 RowBox[{"TemporalDomain", "=", " ", 
  RowBox[{"InterpolatingFunctionDomain", "[", "solNDS", "]"}]}]], "Input",
 CellChangeTimes->{{3.49510877171875*^9, 3.495108772953125*^9}, {
  3.495108825265625*^9, 3.4951088274375*^9}, {3.49510886309375*^9, 
  3.495108866390625*^9}, {3.4951089250625*^9, 3.495108944625*^9}, {
  3.495109047234375*^9, 3.495109049828125*^9}, {3.49511156471875*^9, 
  3.495111577875*^9}},
 FontSize->24],

Cell[BoxData[
 RowBox[{"endTime", "=", " ", 
  RowBox[{
   RowBox[{
    StyleBox[
     RowBox[{"InterpolatingFunction", 
      StyleBox["Domain",
       FontColor->RGBColor[1, 0, 0]]}]], "[", "solNDS", "]"}], "[", 
   RowBox[{"[", 
    RowBox[{"1", ",", 
     RowBox[{"-", "1"}]}], "]"}], "]"}]}]], "Input",
 CellChangeTimes->{{3.49510907590625*^9, 3.495109118234375*^9}, {
  3.495111648078125*^9, 3.495111649234375*^9}},
 FontSize->24],

Cell[BoxData[
 RowBox[{
  StyleBox[
   RowBox[{"InterpolatingFunction", 
    StyleBox["InterpolationOrder",
     FontColor->RGBColor[1, 0, 0]]}]], "[", "solNDS", "]"}]], "Input",
 CellChangeTimes->{3.49510912890625*^9},
 FontSize->24],

Cell[BoxData[
 RowBox[{"numTimeNodes", " ", "=", " ", 
  RowBox[{
   RowBox[{"Map", "[", 
    RowBox[{"Length", ",", 
     RowBox[{
      StyleBox[
       RowBox[{"InterpolatingFunction", 
        StyleBox["Coordinates",
         FontColor->RGBColor[1, 0, 0]]}]], "[", "solNDS", "]"}]}], "]"}], "[", 
   RowBox[{"[", "1", "]"}], "]"}]}]], "Input",
 CellChangeTimes->{
  3.495109154296875*^9, {3.4951092309375*^9, 3.4951092768125*^9}, 
   3.4951115569375*^9},
 FontSize->24]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell["Part II", "Text",
 CellChangeTimes->{{3.4420619435625*^9, 3.4420619460625*^9}, {
   3.495108480859375*^9, 3.49510848184375*^9}, {3.495285762890625*^9, 
   3.495285793703125*^9}, {3.49528627184375*^9, 3.49528627628125*^9}, {
   3.574514859153361*^9, 3.574514860104415*^9}, 3.57451490371791*^9},
 FontSize->36,
 FontColor->RGBColor[0, 0, 1],
 Background->RGBColor[1, 0.9, 0.8]],

Cell[CellGroupData[{

Cell["\<\
To estimate the difference between  the symbolic and the numeric solution 
     we need to extract the coordinates of the nodes hit by  the numeric \
method 
     and evaluate solsymb and solNDS on the same nodes\
\>", "Text",
 CellChangeTimes->{{3.441959955203125*^9, 3.441959988515625*^9}, {
   3.44206396709375*^9, 3.44206396775*^9}, {3.44206435590625*^9, 
   3.4420644369375*^9}, {3.442064549234375*^9, 3.442064574015625*^9}, {
   3.44206466409375*^9, 3.44206467515625*^9}, {3.442064711296875*^9, 
   3.44206471734375*^9}, {3.44215441884375*^9, 3.442154421296875*^9}, {
   3.495108614015625*^9, 3.495108615125*^9}, {3.495110375234375*^9, 
   3.49511037740625*^9}, {3.495197288609375*^9, 3.49519739653125*^9}, {
   3.495285673125*^9, 3.495285680078125*^9}, 3.49528573853125*^9, {
   3.49528584253125*^9, 3.495285957703125*^9}, {3.495286075859375*^9, 
   3.4952861430625*^9}, {3.495286186375*^9, 3.4952862223125*^9}, {
   3.495286295125*^9, 3.49528633228125*^9}, 3.495286389578125*^9, {
   3.5745152508647656`*^9, 3.5745152511687827`*^9}},
 FontSize->24,
 Background->GrayLevel[0.85]],

Cell[CellGroupData[{

Cell["We extract the nodes hit by  NDSolve ", "Text",
 CellChangeTimes->{{3.441959955203125*^9, 3.441959988515625*^9}, {
   3.44206396709375*^9, 3.44206396775*^9}, {3.44206435590625*^9, 
   3.4420644369375*^9}, {3.442064549234375*^9, 3.442064574015625*^9}, {
   3.44206466409375*^9, 3.44206467515625*^9}, {3.442064711296875*^9, 
   3.44206471734375*^9}, {3.44215441884375*^9, 3.442154421296875*^9}, {
   3.495108614015625*^9, 3.495108615125*^9}, {3.495110375234375*^9, 
   3.49511037740625*^9}, 3.495197402734375*^9, {3.49528649334375*^9, 
   3.49528653159375*^9}, 3.49528671425*^9, 3.5745152574171405`*^9},
 FontSize->24,
 Background->GrayLevel[0.85]],

Cell[BoxData[
 RowBox[{"TimeNodes", " ", "=", " ", 
  RowBox[{
   RowBox[{
    StyleBox[
     RowBox[{"InterpolatingFunction", 
      StyleBox["Coordinates",
       FontColor->RGBColor[1, 0, 0]]}]], "[", "solNDS", "]"}], "//", 
   "First"}]}]], "Input",
 CellChangeTimes->{{3.495109361859375*^9, 3.495109395546875*^9}, {
   3.495109760984375*^9, 3.495109762734375*^9}, 3.495111458734375*^9},
 FontSize->24]
}, Open  ]],

Cell[CellGroupData[{

Cell["\<\
We extract the values (numsolOnNodes) of solNDS  on the nodes hit 
       by  NDSolve \
\>", "Text",
 CellChangeTimes->{{3.441959955203125*^9, 3.441959988515625*^9}, {
   3.44206396709375*^9, 3.44206396775*^9}, {3.44206435590625*^9, 
   3.4420644369375*^9}, {3.442064549234375*^9, 3.442064574015625*^9}, {
   3.44206466409375*^9, 3.44206467515625*^9}, {3.442064711296875*^9, 
   3.44206471734375*^9}, {3.44215441884375*^9, 3.442154421296875*^9}, {
   3.495108614015625*^9, 3.495108615125*^9}, {3.495110375234375*^9, 
   3.495110390765625*^9}, 3.495197405140625*^9, {3.495286548734375*^9, 
   3.495286589796875*^9}, 3.495286716875*^9, {3.49528679521875*^9, 
   3.495286801546875*^9}, {3.495423414609375*^9, 3.495423419375*^9}, {
   3.561289705686593*^9, 3.5612897058864193`*^9}, 3.5612904466227303`*^9, 
   3.574515259209243*^9},
 FontSize->24,
 Background->GrayLevel[0.85]],

Cell[BoxData[
 RowBox[{
  StyleBox[
   RowBox[{
    StyleBox["numsol",
     FontColor->RGBColor[1, 0, 0]], 
    StyleBox["OnNodes",
     FontColor->GrayLevel[0]]}]], " ", "=", " ", 
  RowBox[{
   StyleBox[
    RowBox[{"InterpolatingFunction", 
     StyleBox["ValuesOnGrid",
      FontColor->RGBColor[1, 0, 0]]}]], "[", "solNDS", "]"}]}]], "Input",
 CellChangeTimes->{{3.495109299453125*^9, 3.495109329125*^9}, {
   3.495109421984375*^9, 3.49510942846875*^9}, 3.495111488984375*^9, 
   3.4951118013125*^9},
 FontSize->24]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[StyleBox["We calculate the values (symbsolOnNodes) of solsymb \
on the same node",
 Background->None]], "Text",
 CellChangeTimes->{{3.44206787890625*^9, 3.442067892984375*^9}, {
   3.4420679595*^9, 3.4420679813125*^9}, {3.44207210578125*^9, 
   3.442072158328125*^9}, {3.44207248221875*^9, 3.442072484296875*^9}, {
   3.4420736696875*^9, 3.442073675828125*^9}, {3.495286436109375*^9, 
   3.495286437375*^9}, {3.495286603890625*^9, 3.4952866434375*^9}, {
   3.49528681759375*^9, 3.49528682165625*^9}, 3.49542321865625*^9, {
   3.49666349775*^9, 3.49666349875*^9}, 3.5745152602173004`*^9},
 FontSize->24,
 Background->GrayLevel[0.85]],

Cell[BoxData[
 StyleBox[
  RowBox[{" ", 
   RowBox[{
    StyleBox[
     RowBox[{
      StyleBox["symbsol",
       FontColor->RGBColor[0, 0, 1]], 
      StyleBox["OnNodes",
       FontColor->GrayLevel[0]]}]], 
    StyleBox[" ",
     FontColor->RGBColor[1, 0, 0]], "=", 
    RowBox[{"Map", "[", 
     RowBox[{"solsymb", ",", "TimeNodes"}], "]"}]}]}],
  FontSize->24]], "Input",
 CellChangeTimes->{{3.442068115359375*^9, 3.4420681323125*^9}, {
   3.442068187671875*^9, 3.442068187828125*^9}, 3.4420683945625*^9, 
   3.44206855365625*^9, {3.44206921278125*^9, 3.4420692448125*^9}, 
   3.442072173546875*^9, 3.49511151078125*^9, 3.495112104171875*^9, {
   3.495197716453125*^9, 3.495197719828125*^9}, {3.495197944515625*^9, 
   3.495197946171875*^9}, 3.495285368609375*^9, {3.5612899285099573`*^9, 
   3.561289938232676*^9}},
 FontSize->48],

Cell[BoxData[
 RowBox[{"Length", "[", "%", "]"}]], "Input",
 CellChangeTimes->{{3.442068150375*^9, 3.442068157328125*^9}},
 FontSize->24]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
 StyleBox["Remarks on ",
  FontFamily->"Times New Roman"],
 "TimeNodes",
 StyleBox["  ",
  FontFamily->"Times New Roman"],
 Cell[BoxData[
  FormBox[
   SubscriptBox["t", "i"], TraditionalForm]]]
}], "Text",
 CellChangeTimes->{{3.441959955203125*^9, 3.441959988515625*^9}, {
   3.44206396709375*^9, 3.44206396775*^9}, {3.44206435590625*^9, 
   3.4420644369375*^9}, {3.442064549234375*^9, 3.442064574015625*^9}, {
   3.44206466409375*^9, 3.44206467515625*^9}, {3.442064711296875*^9, 
   3.44206471734375*^9}, {3.44215441884375*^9, 3.442154421296875*^9}, {
   3.495108614015625*^9, 3.495108615125*^9}, {3.495110375234375*^9, 
   3.49511037740625*^9}, {3.495197288609375*^9, 3.49519739653125*^9}, {
   3.495285673125*^9, 3.495285680078125*^9}, 3.49528573853125*^9, {
   3.49528584253125*^9, 3.495285957703125*^9}, {3.495286075859375*^9, 
   3.4952861430625*^9}, {3.495286186375*^9, 3.4952862223125*^9}, {
   3.495286295125*^9, 3.49528633228125*^9}, {3.495286389578125*^9, 
   3.495286397875*^9}, {3.495286442828125*^9, 3.4952864435*^9}, {
   3.495286727296875*^9, 3.49528672821875*^9}, {3.5612898690156307`*^9, 
   3.5612898793765917`*^9}, 3.574515261857394*^9},
 FontSize->24,
 Background->GrayLevel[0.85]],

Cell[TextData[{
 "When we observe the distribution of the abscissae of the Nodes (",
 Cell[BoxData[
  FormBox[
   SubscriptBox["t", "i"], TraditionalForm]]],
 ")\nwe see that the increment ",
 StyleBox["\[CapitalDelta]t",
  FontColor->RGBColor[1, 0.5, 0]],
 StyleBox[" ",
  FontColor->GrayLevel[0]],
 " is not constant;\n",
 StyleBox["n",
  FontColor->RGBColor[1, 0.5, 0]],
 " is the (ordinal cardinal) number (25) of time steps "
}], "Text",
 CellChangeTimes->{{3.44196020565625*^9, 3.441960209140625*^9}, {
   3.441960444578125*^9, 3.4419604470625*^9}, 3.442065268234375*^9, {
   3.44206533153125*^9, 3.442065339390625*^9}, {3.44206593065625*^9, 
   3.442066002359375*^9}, {3.442066047375*^9, 3.4420660479375*^9}, {
   3.4420665305625*^9, 3.4420665315625*^9}, {3.4420673055*^9, 
   3.4420673123125*^9}, {3.44206746953125*^9, 3.4420674756875*^9}, {
   3.442152383984375*^9, 3.442152385375*^9}, {3.442152419734375*^9, 
   3.44215248025*^9}, {3.442152556421875*^9, 3.44215259575*^9}, {
   3.442153564625*^9, 3.44215357153125*^9}, {3.442153618109375*^9, 
   3.442153618453125*^9}, 3.49511149440625*^9, {3.4952839759375*^9, 
   3.495284057109375*^9}, {3.49528419015625*^9, 3.495284231609375*^9}, {
   3.4952843364375*^9, 3.495284397203125*^9}, {3.496663459859375*^9, 
   3.49666346046875*^9}},
 FontSize->24,
 Background->GrayLevel[0.85]],

Cell[BoxData[
 RowBox[{
  RowBox[{"ListPlot", "[", 
   RowBox[{"TimeNodes", ",", 
    RowBox[{"PlotStyle", "\[Rule]", 
     RowBox[{"PointSize", "[", "0.015", "]"}]}], ",", " ", 
    "\[IndentingNewLine]", 
    RowBox[{"AxesLabel", "\[Rule]", 
     RowBox[{"{", 
      RowBox[{"\"\<\!\(\*
StyleBox[\"n\",
FontColor->RGBColor[1, 0.5, 0]]\)\>\"", ",", "\"\< \!\(\*
StyleBox[\"\[CapitalDelta]t\",
FontColor->RGBColor[1, 0.5, 0]]\)\>\""}], "}"}]}]}], "]"}], "  "}]], "Input",
 CellChangeTimes->{{3.441960038578125*^9, 3.44196003953125*^9}, 
   3.495111504703125*^9, {3.495284074796875*^9, 3.495284098421875*^9}, {
   3.495284139640625*^9, 3.49528414209375*^9}, {3.49528423434375*^9, 
   3.49528423440625*^9}, {3.49666346434375*^9, 3.496663464828125*^9}},
 FontSize->24],

Cell[TextData[{
 "The plot of \[CapitalDelta]",
 Cell[BoxData[
  FormBox[
   SubscriptBox["t", "i"], TraditionalForm]]],
 " = ",
 Cell[BoxData[
  FormBox[
   SubscriptBox["t", 
    RowBox[{"i", "+", "1"}]], TraditionalForm]]],
 " - ",
 Cell[BoxData[
  FormBox[
   SubscriptBox["t", "i"], TraditionalForm]]],
 "  shows that they are Piecewise constant and not always monotone\n(although \
not particularly evident, in this case).\nObserve also that on the horizontal \
axis we have  their abscissae"
}], "Text",
 CellChangeTimes->{{3.442065304875*^9, 3.44206530534375*^9}, {
   3.442066008296875*^9, 3.44206601040625*^9}, {3.44206604471875*^9, 
   3.442066044921875*^9}, {3.442066307*^9, 3.44206638746875*^9}, {
   3.442066471125*^9, 3.442066508109375*^9}, {3.44206700596875*^9, 
   3.44206701925*^9}, {3.4420673786875*^9, 3.442067453640625*^9}, {
   3.442067503546875*^9, 3.442067513296875*^9}, {3.44206758809375*^9, 
   3.442067603046875*^9}, {3.442152616671875*^9, 3.44215261784375*^9}, {
   3.442153579921875*^9, 3.442153580390625*^9}, {3.442153801859375*^9, 
   3.442153804484375*^9}, {3.442155195828125*^9, 3.4421551963125*^9}, {
   3.495284535625*^9, 3.49528474978125*^9}, {3.495284800921875*^9, 
   3.495284862484375*^9}, 3.5612899958456163`*^9, 3.561290241395894*^9},
 FontSize->24,
 Background->GrayLevel[0.85]],

Cell["Therefore ...", "Text",
 CellChangeTimes->{{3.4420660126875*^9, 3.442066041625*^9}, {
  3.4420661958125*^9, 3.442066202890625*^9}, {3.442066517765625*^9, 
  3.44206653765625*^9}, {3.442066634953125*^9, 3.44206666803125*^9}, {
  3.44206671596875*^9, 3.44206673528125*^9}, {3.442066956296875*^9, 
  3.44206695671875*^9}, {3.44206763434375*^9, 3.442067652453125*^9}, {
  3.442067701296875*^9, 3.44206773134375*^9}, {3.442152635921875*^9, 
  3.44215266415625*^9}, {3.442153523265625*^9, 3.442153523796875*^9}, {
  3.442153877484375*^9, 3.442153917*^9}, {3.442153990734375*^9, 
  3.442153991421875*^9}, {3.44215520175*^9, 3.442155218625*^9}, {
  3.495284758*^9, 3.495284766078125*^9}, {3.495284871625*^9, 
  3.495284904078125*^9}},
 FontSize->24,
 Background->GrayLevel[0.85]],

Cell[BoxData[
 RowBox[{
  RowBox[{"finite$diff", " ", "=", " ", 
   RowBox[{"Table", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"TimeNodes", "[", 
        RowBox[{"[", "i", "]"}], "]"}], ",", 
       RowBox[{
        RowBox[{"TimeNodes", "[", 
         RowBox[{"[", 
          RowBox[{"i", "+", "1"}], "]"}], "]"}], "-", 
        RowBox[{"TimeNodes", "[", 
         RowBox[{"[", "i", "]"}], "]"}]}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"i", ",", "1", ",", 
       RowBox[{
        RowBox[{"Length", "[", "TimeNodes", "]"}], "-", "1"}]}], "}"}]}], 
    "]"}]}], ";"}]], "Input",
 CellChangeTimes->{
  3.441960513*^9, {3.4951115079375*^9, 3.495111509984375*^9}, 
   3.561290124983654*^9, 3.561290308183489*^9},
 FontSize->24],

Cell[BoxData[
 RowBox[{"Length", "[", "finite$diff", "]"}]], "Input",
 CellChangeTimes->{{3.441960347953125*^9, 3.44196037834375*^9}, {
   3.441960518671875*^9, 3.44196051928125*^9}, 3.561290126933793*^9},
 FontSize->24],

Cell[TextData[{
 StyleBox["Be careful!",
  FontSlant->"Italic"],
 " In this Plot we see only 21 points, as some are squeezed around the origin"
}], "Text",
 CellChangeTimes->{{3.44196032634375*^9, 3.441960330484375*^9}, {
   3.441960551234375*^9, 3.441960574203125*^9}, {3.442066031640625*^9, 
   3.442066034828125*^9}, {3.442153397890625*^9, 3.44215339821875*^9}, {
   3.44215343309375*^9, 3.442153493375*^9}, {3.442153870453125*^9, 
   3.4421538733125*^9}, 3.442155225328125*^9, {3.49528510971875*^9, 
   3.495285170171875*^9}, {3.561290169689958*^9, 3.561290177116951*^9}, {
   3.5745152695388336`*^9, 3.5745152717459598`*^9}},
 FontSize->24,
 Background->GrayLevel[0.85]],

Cell[BoxData[
 RowBox[{
  RowBox[{"ListPlot", "[", 
   RowBox[{"finite$diff", ",", 
    RowBox[{"PlotStyle", "\[Rule]", 
     RowBox[{"PointSize", "[", "0.015", "]"}]}], " ", ",", 
    RowBox[{"AxesLabel", "\[Rule]", 
     RowBox[{"{", 
      RowBox[{"\"\<\!\(\*
StyleBox[\"t\",
FontColor->RGBColor[1, 0.5, 0]]\)\>\"", ",", "\"\< \!\(\*
StyleBox[\"\[CapitalDelta]t\",
FontColor->RGBColor[1, 0.5, 0]]\)\>\""}], "}"}]}]}], "]"}], "    "}]], "Input",
 CellChangeTimes->{{3.44196053546875*^9, 3.441960535875*^9}, {
   3.4952849975625*^9, 3.495285002*^9}, 3.5612901314544983`*^9},
 FontSize->24]
}, Open  ]]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell["Part III", "Text",
 CellChangeTimes->{{3.4420619435625*^9, 3.4420619460625*^9}, {
  3.495108480859375*^9, 3.49510848184375*^9}, {3.495285762890625*^9, 
  3.495285793703125*^9}, {3.49528627184375*^9, 3.49528627628125*^9}, {
  3.574514859153361*^9, 3.574514860104415*^9}, {3.574514928113305*^9, 
  3.574514929217368*^9}},
 FontSize->36,
 FontColor->RGBColor[0, 0, 1],
 Background->RGBColor[1, 0.9, 0.8]],

Cell[CellGroupData[{

Cell[TextData[{
 "We evaluate the difference between numsolOnNodes  and symbsolOnNodes\n     \
to obtain wht we call  Global Error (on nodes) \n     The error is of a few \
parts per ",
 Cell[BoxData[
  FormBox[
   SuperscriptBox["10", 
    RowBox[{"-", "8"}]], TraditionalForm]]]
}], "Text",
 CellChangeTimes->{{3.44206941684375*^9, 3.442069526640625*^9}, 
   3.442069594109375*^9, {3.442069747109375*^9, 3.442069783640625*^9}, {
   3.442069833640625*^9, 3.4420698405*^9}, {3.442088213421875*^9, 
   3.44208821409375*^9}, {3.442089608390625*^9, 3.442089658171875*^9}, {
   3.49528193915625*^9, 3.49528195596875*^9}, {3.495286736515625*^9, 
   3.49528675934375*^9}, {3.495286836921875*^9, 3.49528695675*^9}, {
   3.495287062953125*^9, 3.495287066984375*^9}, {3.495422119640625*^9, 
   3.49542212121875*^9}, {3.4966658866875*^9, 3.496665888109375*^9}, 
   3.49674646296875*^9, 3.496800160703125*^9, {3.561290398873845*^9, 
   3.561290424183964*^9}, {3.561290471264151*^9, 3.561290472085348*^9}, 
   3.5745153054978905`*^9},
 FontSize->24,
 Background->GrayLevel[0.85]],

Cell[BoxData[
 RowBox[{
  StyleBox["GlobalErrorOnNodes",
   FontColor->RGBColor[1, 0, 1]], "=", " ", 
  RowBox[{"(", 
   RowBox[{
    StyleBox[
     RowBox[{
      StyleBox["symbsol",
       FontColor->RGBColor[0, 0, 1]], 
      StyleBox["OnNodes",
       FontColor->GrayLevel[0]]}]], "-", 
    StyleBox[
     RowBox[{
      StyleBox["numsol",
       FontColor->RGBColor[1, 0, 0]], 
      StyleBox["OnNodes",
       FontColor->GrayLevel[0]]}]]}], 
   StyleBox[")",
    FontColor->RGBColor[1, 0, 0]]}]}]], "Input",
 CellChangeTimes->{{3.442069804375*^9, 3.442069823125*^9}, {
   3.442069874328125*^9, 3.442069883609375*^9}, 3.44207012475*^9, 
   3.49511205315625*^9, {3.495112085828125*^9, 3.495112091265625*^9}, {
   3.495112134125*^9, 3.495112159578125*^9}, {3.495197878828125*^9, 
   3.4951978824375*^9}, {3.495197916703125*^9, 3.495197918765625*^9}, 
   3.49519949678125*^9, 3.49528126609375*^9, 3.496746464046875*^9, {
   3.561271733278864*^9, 3.561271737750537*^9}, 3.561272349629354*^9, {
   3.561290530127079*^9, 3.561290558459846*^9}},
 FontSize->24],

Cell["\<\
We can plot the distribution of the Global Errors on the Nodes\
\>", "Text",
 CellChangeTimes->{{3.4420711055625*^9, 3.442071167671875*^9}, {
   3.442071236765625*^9, 3.442071290875*^9}, {3.44207133446875*^9, 
   3.442071357171875*^9}, {3.442071410546875*^9, 3.44207150603125*^9}, 
   3.442073642703125*^9, 3.495287137640625*^9, {3.4954221466875*^9, 
   3.49542218003125*^9}, 3.496746465015625*^9},
 FontSize->24,
 Background->GrayLevel[0.85]],

Cell[BoxData[
 RowBox[{
  StyleBox["couplesGlobalErr",
   FontColor->RGBColor[1, 0, 1]], "=", " ", 
  RowBox[{"Transpose", "[", 
   RowBox[{"{", 
    RowBox[{"TimeNodes", ",", 
     StyleBox["GlobalErrorOnNodes",
      FontColor->RGBColor[1, 0, 1]]}], "}"}], "]"}]}]], "Input",
 CellChangeTimes->{
  3.441960932421875*^9, {3.442069966828125*^9, 3.442069989515625*^9}, {
   3.442070127140625*^9, 3.442070127828125*^9}, {3.44209703803125*^9, 
   3.442097053265625*^9}, 3.4951115133125*^9, 3.495112168875*^9, 
   3.495198293609375*^9, 3.49519836325*^9, 3.495199498734375*^9, 
   3.495281272984375*^9, 3.4953729181875*^9, {3.496746466015625*^9, 
   3.496746466765625*^9}, 3.561290826480085*^9, 3.56230883537571*^9},
 FontSize->24],

Cell[BoxData[
 RowBox[{
  StyleBox["gra$GlobalErrorOnNodes",
   FontColor->RGBColor[1, 0, 1]], "=", 
  RowBox[{"ListPlot", "[", 
   RowBox[{
    StyleBox["couplesGlobalErr",
     FontColor->RGBColor[1, 0, 1]], 
    StyleBox[",",
     FontSize->16], "\[IndentingNewLine]", 
    RowBox[{"PlotRange", "\[Rule]", "All"}], ",", 
    RowBox[{"Joined", "\[Rule]", "True"}], ",", 
    RowBox[{"ImageSize", "\[Rule]", "600"}], ",", "\[IndentingNewLine]", 
    RowBox[{"Epilog", "\[Rule]", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"PointSize", "[", "0.015", "]"}], ",", 
       RowBox[{"RGBColor", "[", 
        RowBox[{"1", ",", "0", ",", "0"}], "]"}], ",", "\[IndentingNewLine]", 
       RowBox[{"Map", "[", 
        RowBox[{"Point", ",", 
         StyleBox["couplesGlobalErr",
          FontColor->RGBColor[1, 0, 1]]}], "]"}]}], "}"}]}], ",", 
    "\[IndentingNewLine]", 
    RowBox[{"PlotLabel", "->", "\"\<\!\(\*
StyleBox[\"GlobalErrorOnNodes\",
FontSize->18,
FontColor->RGBColor[1, 0, 1]]\)\!\(\*
StyleBox[\" \",
FontSize->18,
FontColor->RGBColor[1, 0, 0]]\)\!\(\*
StyleBox[\"=\",
FontSize->18,
FontColor->RGBColor[1, 0, 0]]\)\!\(\*
StyleBox[\" \",
FontSize->18,
FontColor->RGBColor[1, 0, 0]]\)\!\(\*SuperscriptBox[\(\[ExponentialE]\), \
\(\(t\)\(\\\ \)\)]\)\!\(\*
StyleBox[\" \",
FontSize->18,
FontColor->RGBColor[1, 0, 0]]\)\!\(\*
StyleBox[\"-\",
FontSize->18,
FontColor->RGBColor[1, 0, 0]]\)\!\(\*
StyleBox[\" \",
FontSize->18,
FontColor->RGBColor[1, 0, 0]]\)\!\(\*
StyleBox[\"numsol\",
FontSize->18,
FontColor->RGBColor[1, 0, 0]]\)\!\(\*
StyleBox[\"OnNodes\",
FontSize->18,
FontColor->GrayLevel[0]]\)\>\""}]}], "]"}]}]], "Input",
 CellChangeTimes->{
  3.44196163203125*^9, {3.44196206984375*^9, 3.44196207321875*^9}, {
   3.441962219796875*^9, 3.44196222246875*^9}, {3.441964388390625*^9, 
   3.441964413125*^9}, {3.441964480875*^9, 3.441964512796875*^9}, {
   3.441964582328125*^9, 3.441964613984375*^9}, {3.442097151609375*^9, 
   3.44209730259375*^9}, {3.442097364828125*^9, 3.4420974085625*^9}, {
   3.442097452734375*^9, 3.44209746390625*^9}, {3.4951983005625*^9, 
   3.49519830115625*^9}, {3.495198507546875*^9, 3.495198574375*^9}, {
   3.4951986106875*^9, 3.495198650953125*^9}, {3.495198704859375*^9, 
   3.495198712390625*^9}, 3.495199500359375*^9, 3.49528127353125*^9, {
   3.495281370046875*^9, 3.495281371375*^9}, 3.49528184559375*^9, 
   3.495282013703125*^9, {3.49537236553125*^9, 3.4953723671875*^9}, {
   3.495372928421875*^9, 3.49537292915625*^9}, 3.495422200109375*^9, {
   3.49542292134375*^9, 3.495423036390625*^9}, 3.49551541428125*^9, {
   3.4955155981875*^9, 3.49551562990625*^9}, {3.496746467375*^9, 
   3.496746468546875*^9}, {3.561271707097414*^9, 3.5612717132266607`*^9}, {
   3.561271802928584*^9, 3.561271813708804*^9}, {3.561271925030548*^9, 
   3.5612719574543467`*^9}, {3.561290659458837*^9, 3.561290669886795*^9}, {
   3.561290888928451*^9, 3.5612908975308228`*^9}, {3.561291008538294*^9, 
   3.5612910147406673`*^9}, 3.561291079418614*^9, {3.561291520531279*^9, 
   3.561291524640407*^9}, {3.561291576209609*^9, 3.561291587528001*^9}},
 FontSize->24],

Cell[CellGroupData[{

Cell["\<\
We evaluate the relative Global error on the Nodes 
(not very different from gra$GlobalErrorOnNodes)
We drop the first point (in cases it is  zero)\
\>", "Text",
 CellChangeTimes->{{3.442071687046875*^9, 3.442071706953125*^9}, {
  3.495423135109375*^9, 3.4954231975625*^9}, {3.5612914357747726`*^9, 
  3.5612914419256268`*^9}, {3.561291477480262*^9, 3.561291509863324*^9}, {
  3.5612916137398987`*^9, 3.561291654615952*^9}},
 FontSize->24,
 Background->GrayLevel[0.85]],

Cell[BoxData[
 RowBox[{"RelativeGlobalError", "=", 
  RowBox[{
   RowBox[{"Drop", "[", 
    RowBox[{
     StyleBox["GlobalErrorOnNodes",
      FontColor->RGBColor[1, 0, 1]], ",", "1"}], "]"}], "/", 
   RowBox[{"Drop", "[", 
    RowBox[{
     StyleBox[
      RowBox[{
       StyleBox["symb",
        FontColor->RGBColor[0, 0, 1]], 
       StyleBox["solOnNodes",
        FontColor->RGBColor[1, 0, 0]]}]], 
     StyleBox[" ",
      FontColor->RGBColor[1, 0, 0]], ",", "1"}], "]"}]}]}]], "Input",
 CellChangeTimes->{{3.442071722453125*^9, 3.442071737984375*^9}, 
   3.442072003140625*^9, {3.495112475828125*^9, 3.495112513546875*^9}, 
   3.495199533390625*^9, 3.495281277015625*^9, 3.496746475109375*^9, {
   3.561291395558374*^9, 3.5612913971965857`*^9}},
 FontSize->24],

Cell[BoxData[
 RowBox[{
  RowBox[{"ListPlot", "[", 
   RowBox[{
    StyleBox["RelativeGlobalError",
     FontColor->RGBColor[1, 0, 1]], ",", 
    RowBox[{"PlotStyle", "\[Rule]", 
     RowBox[{"PointSize", "[", "0.015", "]"}]}]}], " ", "]"}], 
  "                                           "}]], "Input",
 CellChangeTimes->{{3.441961399453125*^9, 3.441961400109375*^9}, {
   3.442071888953125*^9, 3.442071891078125*^9}, 3.44207238921875*^9, 
   3.495112526296875*^9, {3.561291406841029*^9, 3.561291408437997*^9}},
 FontSize->24]
}, Open  ]]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell["Part IV", "Text",
 CellChangeTimes->{{3.4420619435625*^9, 3.4420619460625*^9}, {
  3.495108480859375*^9, 3.49510848184375*^9}, {3.495285762890625*^9, 
  3.495285793703125*^9}, {3.49528627184375*^9, 3.49528627628125*^9}, {
  3.574514859153361*^9, 3.574514860104415*^9}, {3.574514944825261*^9, 
  3.5745149458253183`*^9}},
 FontSize->36,
 FontColor->RGBColor[0, 0, 1],
 Background->RGBColor[1, 0.9, 0.8]],

Cell[CellGroupData[{

Cell[TextData[{
 "Still one step before examining directly the Residual punction\n    Now we \
compare - on the  ",
 StyleBox["entire Domain",
  FontWeight->"Bold"],
 " - the symbolic  solution and the IFO ",
 StyleBox["  ",
  FontWeight->"Bold"],
 "  "
}], "Text",
 CellChangeTimes->{{3.44208810684375*^9, 3.442088135015625*^9}, {
   3.442088245765625*^9, 3.4420883806875*^9}, {3.44208841290625*^9, 
   3.442088436875*^9}, {3.442089669109375*^9, 3.442089673796875*^9}, 
   3.44209036175*^9, {3.4421000129375*^9, 3.4421000394375*^9}, {
   3.495199332921875*^9, 3.49519934853125*^9}, {3.49537297840625*^9, 
   3.495373112453125*^9}, {3.495423225921875*^9, 3.495423234578125*^9}, {
   3.496664348359375*^9, 3.496664356625*^9}, {3.496664624828125*^9, 
   3.496664660609375*^9}, {3.561291808819169*^9, 3.561291813805765*^9}, {
   3.5612923515164948`*^9, 3.5612923824343567`*^9}, {3.561292439176154*^9, 
   3.561292440456601*^9}, {3.561294003688833*^9, 3.5612940071212473`*^9}, {
   3.561295256854271*^9, 3.561295298686286*^9}, 3.5745154654900413`*^9},
 FontSize->24,
 Background->GrayLevel[0.85]],

Cell[BoxData[
 RowBox[{
  RowBox[{
   StyleBox["GlobalErrorOnDomain",
    FontColor->RGBColor[1, 0, 1]], "[", "t_", "]"}], " ", "=", 
  RowBox[{
   RowBox[{"solsymb", "[", "t", "]"}], "-", 
   RowBox[{
    StyleBox["solNDS",
     FontColor->RGBColor[1, 0, 0]], "[", "t", "]"}]}]}]], "Input",
 CellChangeTimes->{{3.442081513875*^9, 3.44208155765625*^9}, {
   3.495112587296875*^9, 3.495112589375*^9}, 3.49519964109375*^9, 
   3.495285369296875*^9, 3.495372769421875*^9, 3.5612732751410217`*^9, {
   3.562308886756784*^9, 3.562308888060438*^9}, {3.562309042654132*^9, 
   3.562309043354*^9}},
 FontSize->24],

Cell[BoxData[
 StyleBox[
  RowBox[{"gra$GlobalErrorOnDomain", "=", " ", 
   RowBox[{"Plot", "[", 
    RowBox[{
     RowBox[{"GlobalErrorOnDomain", "[", "t", "]"}], ",", 
     RowBox[{"{", 
      RowBox[{"t", ",", "tini", ",", "tfin"}], "}"}]}], "]"}]}],
  FontColor->RGBColor[1, 0, 1]]], "Input",
 CellChangeTimes->{{3.562309062924403*^9, 3.562309091528368*^9}, {
  3.562309129260788*^9, 3.562309132126886*^9}},
 FontSize->18],

Cell[TextData[{
 "    The maximum difference (blue curve) here amounts to several parts per  ",
 Cell[BoxData[
  FormBox[
   SuperscriptBox["10", 
    RowBox[{"-", "7"}]], TraditionalForm]]],
 ", that is,\n    an order of magnitude higher with respect to \
gra$GlobalErrorOnNodes,\n    Most  of the error visible in \
gra$GlobalErrorOnDomain, \n    where we have added, in the following graph \
the red dots appearing in gra$GlobalErrorOnNodes,\n     is due to \
interpolation error."
}], "Text",
 CellChangeTimes->{{3.44208810684375*^9, 3.442088135015625*^9}, {
   3.442088245765625*^9, 3.4420883806875*^9}, {3.44208841290625*^9, 
   3.442088436875*^9}, {3.442089669109375*^9, 3.442089673796875*^9}, 
   3.44209036175*^9, {3.4421000129375*^9, 3.4421000394375*^9}, {
   3.495199332921875*^9, 3.49519934853125*^9}, {3.49537297840625*^9, 
   3.495373112453125*^9}, {3.495423225921875*^9, 3.495423234578125*^9}, {
   3.496664348359375*^9, 3.496664356625*^9}, {3.496664624828125*^9, 
   3.496664660609375*^9}, {3.561291808819169*^9, 3.561291813805765*^9}, {
   3.5612923515164948`*^9, 3.5612923824343567`*^9}, {3.5612924316454067`*^9, 
   3.561292434500086*^9}, {3.5612924660464973`*^9, 3.5612924887152653`*^9}, {
   3.561292547611281*^9, 3.561292599841251*^9}, {3.561292634227234*^9, 
   3.561292672512847*^9}, {3.561292844064221*^9, 3.561292939340177*^9}, {
   3.5612930584818707`*^9, 3.5612930664274387`*^9}, {3.561293336012689*^9, 
   3.56129333870411*^9}, {3.562309724038978*^9, 3.5623097353218927`*^9}},
 FontSize->24,
 Background->GrayLevel[0.85]],

Cell[BoxData[
 RowBox[{"Show", "[", 
  RowBox[{
   RowBox[{"ListPlot", "[", 
    RowBox[{
     StyleBox["couplesGlobalErr",
      FontColor->RGBColor[1, 0, 1]], 
     StyleBox[",",
      FontSize->16], "\[IndentingNewLine]", 
     RowBox[{"PlotRange", "\[Rule]", "All"}], ",", 
     RowBox[{"Joined", "\[Rule]", "True"}], ",", 
     RowBox[{"ImageSize", "\[Rule]", "600"}], ",", "\[IndentingNewLine]", 
     RowBox[{"PlotLabel", "->", "\"\<\!\(\*
StyleBox[\"GlobalErrorOnNodes\",
FontSize->18,
FontColor->RGBColor[1, 0, 0]]\)\!\(\*
StyleBox[\" \",
FontSize->18,
FontColor->RGBColor[1, 0, 0]]\)\!\(\*
StyleBox[\"and\",
FontSize->18,
FontColor->GrayLevel[0]]\)\!\(\*
StyleBox[\" \",
FontSize->18,
FontColor->RGBColor[1, 0, 0]]\)\!\(\*
StyleBox[\"GlobalErrorOnDomain\",
FontSize->18,
FontColor->RGBColor[0, 0, 1]]\)\>\""}], ",", "\[IndentingNewLine]", 
     RowBox[{"Epilog", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"PointSize", "[", "0.015", "]"}], ",", 
        RowBox[{"RGBColor", "[", 
         RowBox[{"1", ",", "0", ",", "0"}], "]"}], ",", "\[IndentingNewLine]", 
        RowBox[{"Map", "[", 
         RowBox[{"Point", ",", 
          StyleBox["couplesGlobalErr",
           FontColor->RGBColor[1, 0, 1]]}], "]"}]}], "}"}]}]}], "]"}], ",", 
   StyleBox["\[IndentingNewLine]",
    FontSize->16], 
   StyleBox["     ",
    FontSize->16], 
   StyleBox["gra$GlobalErrorOnDomain",
    FontColor->RGBColor[1, 0, 1]]}], 
  StyleBox["]",
   FontColor->RGBColor[1, 0, 1]]}]], "Input",
 CellChangeTimes->{
  3.44196616728125*^9, {3.442081721578125*^9, 3.442081746109375*^9}, 
   3.442081836078125*^9, {3.44229969106015*^9, 3.4422997618665047`*^9}, {
   3.4422998417080393`*^9, 3.4422999164942904`*^9}, {3.4423008777110453`*^9, 
   3.442300914691793*^9}, {3.442301994419495*^9, 3.442302013591947*^9}, {
   3.49519829784375*^9, 3.495198298515625*^9}, {3.495198365875*^9, 
   3.49519836634375*^9}, 3.4951996714375*^9, {3.49519976475*^9, 
   3.495199766125*^9}, {3.49519986484375*^9, 3.495199867140625*^9}, {
   3.49520059715625*^9, 3.49520059896875*^9}, {3.495200632734375*^9, 
   3.495200695265625*^9}, {3.495200766015625*^9, 3.495200771046875*^9}, 
   3.4952812779375*^9, 3.495281870515625*^9, {3.49528212528125*^9, 
   3.495282128109375*^9}, {3.4953727750625*^9, 3.49537277628125*^9}, {
   3.49537293165625*^9, 3.495372932453125*^9}, {3.49542331103125*^9, 
   3.495423360875*^9}, {3.4967464759375*^9, 3.496746477140625*^9}, {
   3.561272414820829*^9, 3.561272465568396*^9}, {3.561272535188488*^9, 
   3.5612725791713257`*^9}, {3.5612732920707073`*^9, 3.5612732952936897`*^9}, 
   3.561291783659618*^9, 3.561292698031069*^9, {3.5612927394355507`*^9, 
   3.561292758773952*^9}, {3.56230890342636*^9, 3.5623089141876173`*^9}},
 FontSize->24],

Cell["\<\
For example, at numerical level, we observe that the value of the blue curve 
when t\[Rule](TimeNodes[[21]]), corresponding to the red spot are equal, 
in fact,  pointblue  = pointred,...\
\>", "Text",
 CellChangeTimes->{{3.44208810684375*^9, 3.442088135015625*^9}, {
   3.442088245765625*^9, 3.4420883806875*^9}, {3.44208841290625*^9, 
   3.442088436875*^9}, {3.442089669109375*^9, 3.442089673796875*^9}, 
   3.44209036175*^9, {3.4421000129375*^9, 3.4421000394375*^9}, {
   3.495199332921875*^9, 3.49519934853125*^9}, {3.49537297840625*^9, 
   3.495373112453125*^9}, {3.495423225921875*^9, 3.495423234578125*^9}, {
   3.496664348359375*^9, 3.496664356625*^9}, {3.496664624828125*^9, 
   3.496664660609375*^9}, {3.561291808819169*^9, 3.561291813805765*^9}, {
   3.5612923515164948`*^9, 3.5612923824343567`*^9}, {3.5612924316454067`*^9, 
   3.561292434500086*^9}, {3.5612924660464973`*^9, 3.5612924887152653`*^9}, {
   3.561292547611281*^9, 3.561292599841251*^9}, {3.561292634227234*^9, 
   3.561292672512847*^9}, {3.561292844064221*^9, 3.561292939340177*^9}, {
   3.5612930584818707`*^9, 3.5612930664274387`*^9}, {3.561293283437543*^9, 
   3.561293399157381*^9}, {3.561293556413988*^9, 3.561293656561858*^9}, {
   3.561293694130718*^9, 3.561293708988505*^9}, {3.562309201825165*^9, 
   3.56230923147756*^9}},
 FontSize->24,
 Background->GrayLevel[0.85]],

Cell[BoxData[
 RowBox[{
  StyleBox["pointblue",
   FontColor->RGBColor[0, 0, 1]], 
  StyleBox[" ",
   FontColor->GrayLevel[0]], 
  StyleBox["=",
   FontColor->RGBColor[1, 0, 1]], 
  StyleBox[" ",
   FontColor->RGBColor[1, 0, 1]], 
  RowBox[{
   RowBox[{
    StyleBox["GlobalErrorOnDomain",
     FontColor->RGBColor[1, 0, 1]], "[", "t", "]"}], "  ", "/.", " ", 
   RowBox[{"t", "\[Rule]", 
    RowBox[{"(", 
     RowBox[{"TimeNodes", "[", 
      RowBox[{"[", "21", "]"}], "]"}], ")"}]}]}]}]], "Input",
 CellChangeTimes->{{3.56129342285572*^9, 3.561293441245575*^9}, {
  3.561293517856161*^9, 3.561293519120549*^9}},
 FontSize->18],

Cell[BoxData[
 RowBox[{
  StyleBox["pointred",
   FontColor->RGBColor[1, 0, 0]], 
  StyleBox[" ",
   FontColor->RGBColor[1, 0, 1]], 
  StyleBox["=",
   FontColor->RGBColor[1, 0, 1]], 
  StyleBox[
   RowBox[{"GlobalErrorOnNodes", "[", 
    RowBox[{"[", "21", "]"}], "]"}],
   FontColor->RGBColor[1, 0, 1]]}]], "Input",
 CellChangeTimes->{{3.561293500600174*^9, 3.561293512798266*^9}},
 FontSize->18],

Cell["\<\
... but, when  t\[Rule](TimeNodes[[21]]+0.05), we have \
\>", "Text",
 CellChangeTimes->{{3.44208810684375*^9, 3.442088135015625*^9}, {
   3.442088245765625*^9, 3.4420883806875*^9}, {3.44208841290625*^9, 
   3.442088436875*^9}, {3.442089669109375*^9, 3.442089673796875*^9}, 
   3.44209036175*^9, {3.4421000129375*^9, 3.4421000394375*^9}, {
   3.495199332921875*^9, 3.49519934853125*^9}, {3.49537297840625*^9, 
   3.495373112453125*^9}, {3.495423225921875*^9, 3.495423234578125*^9}, {
   3.496664348359375*^9, 3.496664356625*^9}, {3.496664624828125*^9, 
   3.496664660609375*^9}, {3.561291808819169*^9, 3.561291813805765*^9}, {
   3.5612923515164948`*^9, 3.5612923824343567`*^9}, {3.5612924316454067`*^9, 
   3.561292434500086*^9}, {3.5612924660464973`*^9, 3.5612924887152653`*^9}, {
   3.561292547611281*^9, 3.561292599841251*^9}, {3.561292634227234*^9, 
   3.561292672512847*^9}, {3.561292844064221*^9, 3.561292939340177*^9}, {
   3.5612930584818707`*^9, 3.5612930664274387`*^9}, {3.561293283437543*^9, 
   3.561293399157381*^9}, {3.561293556413988*^9, 3.561293656561858*^9}, {
   3.561293689121221*^9, 3.5612937152298326`*^9}, 3.561293787828197*^9, {
   3.562309235136279*^9, 3.562309243235322*^9}, {3.574515386121502*^9, 
   3.5745153875295825`*^9}},
 FontSize->24,
 Background->GrayLevel[0.85]],

Cell[BoxData[
 RowBox[{"pointblue605", "=", 
  RowBox[{
   RowBox[{
    StyleBox["GlobalErrorOnDomain",
     FontColor->RGBColor[1, 0, 1]], "[", "t", "]"}], " ", "/.", " ", 
   RowBox[{"t", "\[Rule]", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"TimeNodes", "[", 
       RowBox[{"[", "21", "]"}], "]"}], "+", "0.05"}], ")"}]}]}]}]], "Input",
 CellChangeTimes->{{3.561293762359744*^9, 3.561293774295834*^9}, 
   3.5623095475454197`*^9, {3.562309804110806*^9, 3.5623098220843363`*^9}, {
   3.562309876186084*^9, 3.562309878789918*^9}},
 FontSize->18],

Cell[TextData[{
 "whereas, from gra$GlobalErrorOnNodes, we get a value near",
 StyleBox[" to ",
  FontFamily->"Times New Roman"],
 Cell[BoxData[
  RowBox[{
   RowBox[{"-", "2."}], "\[Times]", 
   SuperscriptBox["10", 
    RowBox[{"-", "8"}]]}]],
  CellChangeTimes->{3.49542438165625*^9, 3.495424419796875*^9},
  FontFamily->"Times New Roman"],
 "."
}], "Text",
 CellChangeTimes->{{3.44208810684375*^9, 3.442088135015625*^9}, {
   3.442088245765625*^9, 3.4420883806875*^9}, {3.44208841290625*^9, 
   3.442088436875*^9}, {3.442089669109375*^9, 3.442089673796875*^9}, 
   3.44209036175*^9, {3.4421000129375*^9, 3.4421000394375*^9}, {
   3.495199332921875*^9, 3.49519934853125*^9}, {3.49537297840625*^9, 
   3.495373112453125*^9}, {3.495423225921875*^9, 3.495423234578125*^9}, {
   3.496664348359375*^9, 3.496664356625*^9}, {3.496664624828125*^9, 
   3.496664660609375*^9}, {3.561291808819169*^9, 3.561291813805765*^9}, {
   3.5612923515164948`*^9, 3.5612923824343567`*^9}, {3.5612924316454067`*^9, 
   3.561292434500086*^9}, {3.5612924660464973`*^9, 3.5612924887152653`*^9}, {
   3.561292547611281*^9, 3.561292599841251*^9}, {3.561292634227234*^9, 
   3.561292672512847*^9}, {3.561292844064221*^9, 3.561292939340177*^9}, {
   3.5612930584818707`*^9, 3.5612930664274387`*^9}, {3.561293283437543*^9, 
   3.561293399157381*^9}, {3.561293556413988*^9, 3.561293656561858*^9}, {
   3.561293689121221*^9, 3.5612937152298326`*^9}, {3.561293787828197*^9, 
   3.561293839021963*^9}, {3.561293875290812*^9, 3.561293940043146*^9}, {
   3.561294058737421*^9, 3.561294063332678*^9}, 3.5745153998742886`*^9},
 FontSize->24,
 Background->GrayLevel[0.85]]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell["Part V", "Text",
 CellChangeTimes->{{3.4420619435625*^9, 3.4420619460625*^9}, {
  3.495108480859375*^9, 3.49510848184375*^9}, {3.495285762890625*^9, 
  3.495285793703125*^9}, {3.49528627184375*^9, 3.49528627628125*^9}, {
  3.574514859153361*^9, 3.574514860104415*^9}, {3.574514959369093*^9, 
  3.574514961105192*^9}},
 FontSize->36,
 FontColor->RGBColor[0, 0, 1],
 Background->RGBColor[1, 0.9, 0.8]],

Cell[CellGroupData[{

Cell["\<\
To obtain  the residual function we introduce the numerical solution (IFO)
    into the original ODE \
\>", "Text",
 CellChangeTimes->{{3.44207339471875*^9, 3.4420734050625*^9}, {
   3.44207345690625*^9, 3.44207347240625*^9}, 3.442073723109375*^9, 
   3.495282611171875*^9, {3.495512351765625*^9, 3.4955124408125*^9}, {
   3.49551251203125*^9, 3.495512558640625*^9}, {3.496029353125*^9, 
   3.496029354078125*^9}, {3.49666470890625*^9, 3.496664745640625*^9}, {
   3.496664865125*^9, 3.4966648658125*^9}, {3.49666588228125*^9, 
   3.49666588290625*^9}, {3.496748114296875*^9, 3.49674811528125*^9}, {
   3.5612945572551117`*^9, 3.561294565424412*^9}, {3.561295367110045*^9, 
   3.561295392578741*^9}, {3.574515409257825*^9, 3.5745154093688316`*^9}},
 FontSize->24,
 FontColor->GrayLevel[0],
 Background->GrayLevel[0.85]],

Cell[BoxData[
 RowBox[{"soln", "=", 
  RowBox[{"NDSolve", "[", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{
      RowBox[{
       RowBox[{
        SuperscriptBox["x", "\[Prime]",
         MultilineFunction->None], "[", "t", "]"}], "==", 
       RowBox[{"x", "[", "t", "]"}]}], ",", 
      RowBox[{
       RowBox[{"x", "[", "0", "]"}], "==", "1"}]}], "}"}], ",", "x", ",", 
    RowBox[{"{", 
     RowBox[{"t", ",", "0", ",", "1"}], "}"}]}], "]"}]}]], "Input",
 FontSize->24],

Cell[BoxData[
 RowBox[{
  RowBox[{
   StyleBox["Residual",
    FontColor->RGBColor[0, 1, 0]], "[", "t_", "]"}], "=", " ", 
  RowBox[{"Evaluate", "[", 
   RowBox[{
    RowBox[{
     RowBox[{
      RowBox[{"x", "'"}], "[", "t", "]"}], "-", 
     RowBox[{"x", "[", "t", "]"}]}], " ", "/.", " ", 
    RowBox[{"First", "[", "soln", "]"}]}], "]"}]}]], "Input",
 CellChangeTimes->{
  3.442072583828125*^9, 3.4420726575625*^9, {3.44207275725*^9, 
   3.442072759046875*^9}, {3.49511315684375*^9, 3.49511316046875*^9}, {
   3.495113224703125*^9, 3.4951132303125*^9}, {3.495113285828125*^9, 
   3.495113291484375*^9}, {3.49511340346875*^9, 3.49511341653125*^9}, 
   3.495282611734375*^9, {3.49551389653125*^9, 3.49551390346875*^9}, {
   3.495513957796875*^9, 3.49551395915625*^9}, 3.4967465493125*^9},
 FontSize->24],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  StyleBox["gra$Residual",
   FontColor->RGBColor[0, 1, 0]], " ", "=", 
  RowBox[{"Plot", "[", 
   RowBox[{
    RowBox[{
     StyleBox["Residual",
      FontColor->RGBColor[0, 1, 0]], "[", "t", "]"}], ",", 
    RowBox[{"{", 
     RowBox[{"t", ",", "tini", ",", "tfin"}], " ", "}"}], ",", 
    "\[IndentingNewLine]", " ", 
    RowBox[{"Epilog", "\[Rule]", 
     RowBox[{"{", 
      RowBox[{"Text", "[", 
       RowBox[{"\"\<\!\(\*
StyleBox[\"ResidualOnDomain\",
FontSize->18,
FontWeight->\"Plain\",
FontColor->RGBColor[0, 0, 1]]\)\>\"", ",", 
        RowBox[{"{", 
         RowBox[{"0.4", ",", 
          RowBox[{"1.", "*", 
           SuperscriptBox["10", 
            RowBox[{"-", "5"}]]}]}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{"0", ",", 
          RowBox[{"-", "1"}]}], "}"}]}], "]"}], "}"}]}]}], 
   "\[IndentingNewLine]", "]"}]}]], "Input",
 CellChangeTimes->{
  3.4419614244375*^9, {3.4419640730625*^9, 3.441964116375*^9}, {
   3.441964203484375*^9, 3.441964221734375*^9}, {3.442073052421875*^9, 
   3.4420731095*^9}, {3.442073143984375*^9, 3.442073153484375*^9}, {
   3.44207318525*^9, 3.4420731965*^9}, 3.442073775265625*^9, 
   3.442073817125*^9, {3.442096611484375*^9, 3.442096616375*^9}, 
   3.4952818811875*^9, {3.495282612375*^9, 3.495282613671875*^9}, {
   3.49528295471875*^9, 3.495282957453125*^9}, {3.495513914046875*^9, 
   3.4955139174375*^9}, {3.495513963390625*^9, 3.495513976421875*^9}, {
   3.496746550609375*^9, 3.496746553609375*^9}, {3.5612951752790623`*^9, 
   3.561295177958907*^9}},
 FontSize->24],

Cell["\<\
The values, e.g., when  t->TimeNodes[[21]] and  \
t\[Rule](TimeNodes[[21]]+0.025) are
significantly different and this is due to interpolation error\
\>", "Text",
 CellChangeTimes->{{3.44207339471875*^9, 3.4420734050625*^9}, {
   3.44207345690625*^9, 3.44207347240625*^9}, 3.442073723109375*^9, 
   3.495282611171875*^9, {3.495512351765625*^9, 3.4955124408125*^9}, {
   3.49551251203125*^9, 3.495512558640625*^9}, {3.496029353125*^9, 
   3.496029354078125*^9}, {3.49666470890625*^9, 3.496664745640625*^9}, {
   3.496664865125*^9, 3.4966648658125*^9}, {3.49666588228125*^9, 
   3.49666588290625*^9}, {3.496748114296875*^9, 3.49674811528125*^9}, {
   3.5612943381167727`*^9, 3.561294350382249*^9}, {3.561294587054325*^9, 
   3.5612946478105288`*^9}},
 FontSize->24,
 FontColor->GrayLevel[0],
 Background->GrayLevel[0.85]],

Cell[BoxData[
 RowBox[{"respoint1", "=", " ", 
  RowBox[{
   RowBox[{
    StyleBox["Residual",
     FontColor->RGBColor[0, 1, 0]], "[", "t", "]"}], "  ", "/.", "  ", 
   RowBox[{"t", "->", 
    RowBox[{"TimeNodes", "[", 
     RowBox[{"[", "21", "]"}], "]"}]}]}]}]], "Input",
 CellChangeTimes->{{3.495282959453125*^9, 3.495282959484375*^9}, {
  3.56126947935096*^9, 3.5612695282454567`*^9}, {3.561294276142832*^9, 
  3.561294291584056*^9}},
 FontSize->16]
}, Open  ]],

Cell[BoxData[
 RowBox[{"respoint6025", "=", " ", 
  RowBox[{
   RowBox[{
    StyleBox["Residual",
     FontColor->RGBColor[0, 1, 0]], "[", "t", "]"}], "  ", "/.", "  ", 
   RowBox[{"t", "\[Rule]", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"TimeNodes", "[", 
       RowBox[{"[", "21", "]"}], "]"}], "+", "0.025"}], ")"}]}]}]}]], "Input",
 CellChangeTimes->{{3.495282959453125*^9, 3.495282959484375*^9}, {
   3.56126947935096*^9, 3.5612695282454567`*^9}, {3.561269573327582*^9, 
   3.5612695838875647`*^9}, 3.561274662037977*^9, {3.561294297283977*^9, 
   3.5612943036124496`*^9}},
 FontSize->16],

Cell[CellGroupData[{

Cell[TextData[{
 StyleBox["It is interesting also to examine the behaviour of the function ",
  Background->None],
 "Residual[t]\nonly on the TimeNodes.",
 StyleBox["\nThe  range, between ",
  FontColor->GrayLevel[0],
  Background->None],
 Cell[BoxData[
  FormBox[
   RowBox[{
    RowBox[{"-", "8.3"}], "\[Times]", 
    SuperscriptBox["10", 
     RowBox[{"-", "9"}]]}], TraditionalForm]],
  Background->None],
 StyleBox[" e ",
  Background->None],
 Cell[BoxData[
  FormBox[
   RowBox[{"6", "\[Times]", 
    SuperscriptBox["10", 
     RowBox[{"-", "9"}]]}], TraditionalForm]],
  Background->None],
 ", is lower by about a factor ten"
}], "Text",
 CellChangeTimes->{
  3.441961594359375*^9, {3.4420967468125*^9, 3.4420967743125*^9}, {
   3.442096862265625*^9, 3.442096863140625*^9}, 3.49528291065625*^9, {
   3.495512720734375*^9, 3.495512784421875*^9}, {3.49551328978125*^9, 
   3.49551329046875*^9}, {3.49551332646875*^9, 3.495513349203125*^9}, {
   3.49551338009375*^9, 3.4955134728125*^9}, {3.496664985125*^9, 
   3.496664986359375*^9}, {3.49666523675*^9, 3.496665238671875*^9}, {
   3.4966652726875*^9, 3.49666531146875*^9}, {3.496748221703125*^9, 
   3.496748233921875*^9}, {3.4967483845625*^9, 3.49674838928125*^9}, 
   3.561273323864769*^9, {3.561290952465419*^9, 3.5612909535322437`*^9}, 
   3.561291786835256*^9, 3.561294812273067*^9, {3.561294849797824*^9, 
   3.561294940192629*^9}, {3.561295473016642*^9, 3.5612955135089483`*^9}, {
   3.5612955685568666`*^9, 3.561295576675688*^9}},
 FontSize->24,
 FontColor->GrayLevel[0],
 Background->GrayLevel[0.85]],

Cell[BoxData[
 StyleBox[
  RowBox[{
   RowBox[{
    StyleBox["ResidualErrorOnNodes",
     FontColor->RGBColor[0, 1, 0]], "=", 
    RowBox[{"Residual", " ", "/@", " ", "TimeNodes"}]}], ";"}],
  FontSize->24]], "Input",
 CellChangeTimes->{{3.442096887859375*^9, 3.442096916453125*^9}, 
   3.495111518*^9, {3.495282911359375*^9, 3.495282912375*^9}, 
   3.495283061609375*^9, 3.495512795359375*^9, {3.495513986421875*^9, 
   3.495513988*^9}, {3.496746589828125*^9, 3.496746590390625*^9}, 
   3.5612950361443367`*^9, 3.5612951451566353`*^9},
 FontSize->96],

Cell[BoxData[
 StyleBox[
  RowBox[{
   RowBox[{"couplesResidualError", "=", " ", 
    RowBox[{"Transpose", "[", 
     RowBox[{"{", 
      RowBox[{"TimeNodes", ",", 
       StyleBox["ResidualErrorOnNodes",
        FontColor->RGBColor[0, 1, 0]]}], "}"}], "]"}]}], ";"}],
  FontSize->24]], "Input",
 CellChangeTimes->{
  3.441961619796875*^9, {3.4420970919375*^9, 3.442097109078125*^9}, 
   3.49511151859375*^9, 3.495198299828125*^9, 3.495282915203125*^9, 
   3.49528306825*^9, 3.495283161125*^9, 3.49551279878125*^9, {
   3.495513992109375*^9, 3.495513993671875*^9}, {3.49551412428125*^9, 
   3.49551412671875*^9}, 3.496746591234375*^9, 3.5612950396122513`*^9, 
   3.5612951471383333`*^9},
 FontSize->36],

Cell[BoxData[
 RowBox[{
  StyleBox["Gra$ResidualErrorOnNodes",
   FontColor->RGBColor[0, 1, 0]], "=", 
  RowBox[{"ListPlot", "[", 
   RowBox[{
    StyleBox["couplesResidualError",
     FontColor->RGBColor[0, 1, 0]], ",", "\[IndentingNewLine]", 
    RowBox[{"PlotRange", "\[Rule]", "All"}], ",", 
    RowBox[{"Joined", "\[Rule]", "True"}], ",", "\[IndentingNewLine]", 
    RowBox[{"Epilog", "\[Rule]", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"PointSize", "[", "0.015", "]"}], ",", 
       RowBox[{"RGBColor", "[", 
        RowBox[{"0", ",", "1", ",", "0"}], "]"}], ",", 
       RowBox[{"Map", "[", 
        RowBox[{"Point", ",", 
         StyleBox["couplesResidualError",
          FontColor->RGBColor[0, 1, 0]]}], "]"}], 
       StyleBox[",",
        FontSize->16], 
       RowBox[{"Text", "[", 
        RowBox[{"\"\<\!\(\*
StyleBox[\"Residuals\",
FontSize->18,
FontWeight->\"Plain\",
FontColor->RGBColor[0, 1, 0]]\)\!\(\*
StyleBox[\" \",
FontSize->18,
FontWeight->\"Plain\",
FontColor->RGBColor[0, 1, 0]]\)\!\(\*
StyleBox[\"on\",
FontSize->18,
FontWeight->\"Plain\",
FontColor->RGBColor[0, 1, 0]]\)\!\(\*
StyleBox[\" \",
FontSize->18,
FontWeight->\"Plain\",
FontColor->RGBColor[0, 1, 0]]\)\!\(\*
StyleBox[\"nodes\",
FontSize->18,
FontWeight->\"Plain\",
FontColor->RGBColor[0, 1, 0]]\)\>\"", ",", 
         RowBox[{"{", 
          RowBox[{"0.4", ",", 
           RowBox[{"4.", "*", 
            SuperscriptBox["10", 
             RowBox[{"-", "9"}]]}]}], "}"}], ",", 
         RowBox[{"{", 
          RowBox[{
           RowBox[{"-", "0.1"}], ",", 
           RowBox[{"-", "1"}]}], "}"}]}], "]"}]}], "}"}]}]}], " ", 
   "\[IndentingNewLine]", "]"}]}]], "Input",
 CellChangeTimes->{
  3.44196163203125*^9, {3.44196206984375*^9, 3.44196207321875*^9}, {
   3.441962219796875*^9, 3.44196222246875*^9}, {3.441964388390625*^9, 
   3.441964413125*^9}, {3.441964480875*^9, 3.441964512796875*^9}, {
   3.441964582328125*^9, 3.441964613984375*^9}, {3.442097151609375*^9, 
   3.44209730259375*^9}, {3.442097364828125*^9, 3.4420974085625*^9}, {
   3.442097452734375*^9, 3.44209746390625*^9}, {3.4951983005625*^9, 
   3.49519830115625*^9}, 3.495281891875*^9, {3.49528291625*^9, 
   3.49528291725*^9}, 3.495283069359375*^9, {3.495283165046875*^9, 
   3.495283166203125*^9}, {3.4952831980625*^9, 3.495283214375*^9}, {
   3.495514068390625*^9, 3.49551406996875*^9}, {3.495514132984375*^9, 
   3.495514143796875*^9}, {3.496746592078125*^9, 3.496746594796875*^9}, {
   3.561294960009885*^9, 3.561294964085278*^9}},
 FontSize->24]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
 "The ",
 StyleBox["compression",
  FontSlant->"Italic"],
 " of the values,clearly shown here, induces a little reflection ..."
}], "Text",
 CellChangeTimes->{
  3.441961709234375*^9, {3.4419617824375*^9, 3.441961783015625*^9}, {
   3.44196579340625*^9, 3.441965855296875*^9}, 3.442097569515625*^9, {
   3.442097609921875*^9, 3.4420976901875*^9}, {3.442098287046875*^9, 
   3.44209835059375*^9}, {3.4420984299375*^9, 3.44209846421875*^9}, {
   3.44209850975*^9, 3.4420985634375*^9}, {3.442098593890625*^9, 
   3.44209860825*^9}, {3.442098643890625*^9, 3.442098647890625*^9}, {
   3.442098803*^9, 3.442098850578125*^9}, {3.442098912765625*^9, 
   3.4420989371875*^9}, 3.44209901884375*^9, 3.442099049453125*^9, {
   3.44209910971875*^9, 3.442099128515625*^9}, 3.44209922421875*^9, {
   3.4421002471875*^9, 3.442100271203125*^9}, {3.442157720359375*^9, 
   3.442157720359375*^9}, {3.49551305659375*^9, 3.49551314809375*^9}, 
   3.495513286265625*^9, {3.495513492671875*^9, 3.49551349534375*^9}, {
   3.49551352540625*^9, 3.495513581703125*^9}, {3.5612956018920593`*^9, 
   3.56129565764437*^9}},
 FontSize->24,
 Background->GrayLevel[0.85]],

Cell[BoxData[
 RowBox[{"Show", "[", "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{"ListPlot", "[", 
    RowBox[{
     StyleBox["couplesResidualError",
      FontColor->RGBColor[0, 1, 0]], ",", "\[IndentingNewLine]", 
     RowBox[{"PlotRange", "\[Rule]", "All"}], ",", 
     RowBox[{"Joined", "\[Rule]", "True"}], ",", "\[IndentingNewLine]", 
     RowBox[{"Epilog", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"PointSize", "[", "0.015", "]"}], ",", 
        RowBox[{"RGBColor", "[", 
         RowBox[{"0", ",", "1", ",", "0"}], "]"}], ",", 
        RowBox[{"Map", "[", 
         RowBox[{"Point", ",", 
          StyleBox["couplesResidualError",
           FontColor->RGBColor[0, 1, 0]]}], "]"}]}], "}"}]}]}], 
    "\[IndentingNewLine]", "]"}], ",", "\[IndentingNewLine]", 
   StyleBox[
    RowBox[{"gra$", 
     StyleBox["Residual",
      FontColor->RGBColor[0, 1, 0]]}]]}], "\[IndentingNewLine]", 
  "]"}]], "Input",
 CellChangeTimes->{{3.442097751625*^9, 3.442097760546875*^9}, {3.442097802*^9,
    3.44209783196875*^9}, {3.442097894078125*^9, 3.442097912609375*^9}, {
   3.442098038359375*^9, 3.4420980613125*^9}, {3.49519830175*^9, 
   3.49519830234375*^9}, 3.495281897515625*^9, {3.49528316853125*^9, 
   3.495283169609375*^9}, {3.495283565609375*^9, 3.49528356628125*^9}, {
   3.49551416509375*^9, 3.495514222640625*^9}, 3.49674660853125*^9, {
   3.56129518698149*^9, 3.561295190609332*^9}},
 FontSize->24]
}, Open  ]]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell["Part VI", "Text",
 CellChangeTimes->{{3.4420619435625*^9, 3.4420619460625*^9}, {
  3.495108480859375*^9, 3.49510848184375*^9}, {3.495285762890625*^9, 
  3.495285793703125*^9}, {3.49528627184375*^9, 3.49528627628125*^9}, {
  3.574514859153361*^9, 3.574514860104415*^9}, {3.5745149766890836`*^9, 
  3.5745149778251486`*^9}},
 FontSize->36,
 FontColor->RGBColor[0, 0, 1],
 Background->RGBColor[1, 0.9, 0.8]],

Cell[CellGroupData[{

Cell[TextData[{
 "Finally, the following Graph  illustrates the distribution of  \n \
GlobalError and of  ResidualError. We can conclude\n that the Residual \
function on the Nodes is not a good indicator\n of the ",
 StyleBox["true ",
  FontSlant->"Italic"],
 "error, confirming the warning indicated by  Wolfram experts.\n However, \
even though  one has to carefully examine the behaviour of the IFO\n on the \
entire domain, and not only on the TimeNodes, the Residual function\n is a \
valuable tool."
}], "Text",
 CellChangeTimes->{{3.441974677375*^9, 3.441974679421875*^9}, {3.442099289*^9,
    3.442099448640625*^9}, {3.442099523390625*^9, 3.442099560453125*^9}, {
   3.442099820171875*^9, 3.442099844734375*^9}, {3.44210027746875*^9, 
   3.44210028125*^9}, {3.495513617171875*^9, 3.495513743734375*^9}, {
   3.495513788375*^9, 3.49551383215625*^9}, {3.495514263578125*^9, 
   3.495514288078125*^9}, 3.4955143389375*^9, 3.495514429078125*^9, {
   3.4955144661875*^9, 3.495514555890625*^9}, {3.495514588515625*^9, 
   3.495514591546875*^9}, {3.495514654625*^9, 3.49551471384375*^9}, {
   3.496665741265625*^9, 3.49666586775*^9}, {3.496748334578125*^9, 
   3.496748338375*^9}, {3.561295661622114*^9, 3.561295879354619*^9}, {
   3.561296153478772*^9, 3.561296199953438*^9}, {3.561350116246757*^9, 
   3.5613501631960583`*^9}, {3.5613511135395813`*^9, 3.561351144523131*^9}, {
   3.5745154901634526`*^9, 3.574515505201313*^9}},
 FontSize->24,
 Background->GrayLevel[0.85]],

Cell[BoxData[
 RowBox[{
  StyleBox[" ",
   Background->RGBColor[1, 1, 0]], 
  RowBox[{
   StyleBox["hyphyp",
    Background->RGBColor[1, 1, 0]], 
   StyleBox["=",
    Background->RGBColor[1, 1, 0]], 
   RowBox[{"Show", "[", 
    RowBox[{
     StyleBox["gra$GlobalErrorOnNodes",
      FontColor->RGBColor[1, 0, 1]], ",", 
     StyleBox[
      RowBox[{"Gra$", 
       StyleBox["ResidualErrorOnNodes",
        FontColor->RGBColor[0, 1, 0]]}]], ",", 
     RowBox[{"Epilog", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"PointSize", "[", "0.015", "]"}], ",", 
        RowBox[{"RGBColor", "[", 
         RowBox[{"1", ",", "0", ",", "0"}], "]"}], ",", 
        RowBox[{"Map", "[", 
         RowBox[{"Point", ",", "couplesGlobalErr"}], "]"}], 
        StyleBox[" ",
         FontSize->18], 
        StyleBox[",",
         FontSize->18], 
        RowBox[{"Text", "[", 
         RowBox[{"\"\<\!\(\*
StyleBox[\"\[CapitalDelta]\",
FontSize->18,
FontColor->RGBColor[1, 0, 0]]\)\!\(\*
StyleBox[\"  \",
FontSize->18,
FontColor->RGBColor[1, 0, 0]]\)\!\(\*
StyleBox[\"Global\",
FontSize->18,
FontColor->RGBColor[1, 0, 0]]\)\!\(\*
StyleBox[\" \",
FontSize->18,
FontColor->RGBColor[1, 0, 0]]\)\!\(\*
StyleBox[\"error\",
FontSize->18,
FontColor->RGBColor[1, 0, 0]]\)\>\"", ",", 
          RowBox[{"{", 
           RowBox[{"0.66", ",", 
            RowBox[{
             RowBox[{"-", "2.5"}], "*", 
             SuperscriptBox["10", 
              RowBox[{"-", "8"}]]}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"0", ",", 
            RowBox[{"-", "1"}]}], "}"}]}], "]"}], ",", "\[IndentingNewLine]", 
        RowBox[{"PointSize", "[", "0.015", "]"}], ",", 
        RowBox[{"RGBColor", "[", 
         RowBox[{"0", ",", "1", ",", "0"}], "]"}], ",", "\[IndentingNewLine]", 
        RowBox[{"Map", "[", 
         RowBox[{"Point", ",", "couplesResidualError"}], "]"}], ",", 
        StyleBox["\[IndentingNewLine]",
         FontSize->16], 
        RowBox[{"Text", "[", 
         RowBox[{"\"\<\!\(\*
StyleBox[\"\[CapitalDelta]\",
FontSize->18,
FontColor->RGBColor[0, 1, 0]]\)\!\(\*
StyleBox[\"  \",
FontSize->18,
FontColor->RGBColor[0, 1, 0]]\)\!\(\*
StyleBox[\"Residual\",
FontSize->18,
FontColor->RGBColor[0, 1, 0]]\)\!\(\*
StyleBox[\" \",
FontSize->18,
FontColor->RGBColor[0, 1, 0]]\)\!\(\*
StyleBox[\"error\",
FontSize->18,
FontColor->RGBColor[0, 1, 0]]\)\>\"", ",", 
          RowBox[{"{", 
           RowBox[{"0.66", ",", 
            RowBox[{"2.", "*", 
             SuperscriptBox["10", 
              RowBox[{"-", "9"}]]}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"0", ",", 
            RowBox[{"-", "1"}]}], "}"}]}], "]"}]}], "}"}]}]}], 
    "\[IndentingNewLine]", "]"}]}]}]], "Input",
 CellChangeTimes->{
  3.44196616428125*^9, {3.4420996166875*^9, 3.442099654890625*^9}, {
   3.4420997593125*^9, 3.44209979509375*^9}, {3.442099870859375*^9, 
   3.442099906484375*^9}, {3.495198304125*^9, 3.495198304671875*^9}, 
   3.4951983668125*^9, {3.49528190625*^9, 3.495281910140625*^9}, 
   3.4952820166875*^9, 3.495283070328125*^9, 3.495283173953125*^9, {
   3.495283668453125*^9, 3.495283669078125*^9}, {3.495283767125*^9, 
   3.49528378671875*^9}, 3.49537293475*^9, 3.495514813890625*^9, {
   3.49551499546875*^9, 3.495514997125*^9}, {3.495515029578125*^9, 
   3.49551503125*^9}, {3.496746610984375*^9, 3.496746612015625*^9}, {
   3.496748345828125*^9, 3.496748349109375*^9}, {3.4967485021875*^9, 
   3.49674850353125*^9}, {3.496748609734375*^9, 3.4967486148125*^9}, {
   3.561290955160486*^9, 3.5612909721628113`*^9}, {3.561294973851232*^9, 
   3.561294988700889*^9}, 3.561348705699731*^9, {3.561349910029133*^9, 
   3.561349913237624*^9}},
 FontSize->24]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell["Part VII", "Text",
 CellChangeTimes->{{3.4420619435625*^9, 3.4420619460625*^9}, {
  3.495108480859375*^9, 3.49510848184375*^9}, {3.495285762890625*^9, 
  3.495285793703125*^9}, {3.49528627184375*^9, 3.49528627628125*^9}, {
  3.574514859153361*^9, 3.574514860104415*^9}, {3.5745149904888725`*^9, 
  3.574514992584993*^9}},
 FontSize->36,
 FontColor->RGBColor[0, 0, 1],
 Background->RGBColor[1, 0.9, 0.8]],

Cell[CellGroupData[{

Cell[TextData[{
 "This part consists of a shor digression... plus two checks...\n\n   The \
following  shows that the IFO contains also the first derivatives\n   of the \
solution of teh ODE on the TimeNodes; in other words, NDSolve performs an  \n \
   interpolation",
 StyleBox[" \[AGrave] la Hermite, ",
  FontSlant->"Italic"],
 "equivalent to \n\n",
 Cell[BoxData[
  RowBox[{
   ButtonBox["Interpolation",
    BaseStyle->"Link",
    ButtonData->"paclet:ref/Interpolation"], "[", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        SubscriptBox[
         StyleBox["x", "TI"], 
         StyleBox["1", "TR"]], "}"}], ",", 
       SubscriptBox[
        StyleBox["y", "TI"], 
        StyleBox["1", "TR"]], ",", 
       SubscriptBox[
        StyleBox[
         RowBox[{"y", "'"}], "TI"], 
        StyleBox["1", "TR"]]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        SubscriptBox[
         StyleBox["x", "TI"], "2"], "}"}], ",", 
       SubscriptBox[
        StyleBox["y", "TI"], "2"], ",", 
       SubscriptBox[
        StyleBox[
         RowBox[{"y", "'"}], "TI"], "2"]}], "}"}], ",", 
     StyleBox["\[Ellipsis]", "TR"]}], "}"}], "]"}]], "InlineFormula"],
 ") \n"
}], "Text",
 CellChangeTimes->{{3.44196595746875*^9, 3.44196596009375*^9}, {
   3.44196609815625*^9, 3.4419661488125*^9}, {3.441974200375*^9, 
   3.441974210453125*^9}, {3.441974295046875*^9, 3.441974310953125*^9}, {
   3.441974345875*^9, 3.441974653*^9}, {3.441979008332594*^9, 
   3.4419790190967293`*^9}, {3.44208976115625*^9, 3.4420899933125*^9}, {
   3.4420903913125*^9, 3.442090450140625*^9}, {3.442090486984375*^9, 
   3.4420905391875*^9}, {3.442090587953125*^9, 3.442090647046875*^9}, {
   3.44209073928125*^9, 3.442090927640625*^9}, {3.44209098921875*^9, 
   3.44209103275*^9}, {3.4420910679375*^9, 3.442091114640625*^9}, {
   3.442091214703125*^9, 3.44209129325*^9}, {3.442091385671875*^9, 
   3.442091602859375*^9}, {3.442091635515625*^9, 3.44209166903125*^9}, {
   3.4420917439375*^9, 3.44209183696875*^9}, {3.4420918740625*^9, 
   3.442091933109375*^9}, {3.442091969421875*^9, 3.44209204984375*^9}, {
   3.44209243234375*^9, 3.44209243340625*^9}, {3.4420932424375*^9, 
   3.442093319953125*^9}, {3.442095443265625*^9, 3.4420955011875*^9}, {
   3.442095655265625*^9, 3.442095845234375*^9}, {3.442095889171875*^9, 
   3.4420961198125*^9}, 3.44210031803125*^9, {3.495111514796875*^9, 
   3.4951115155625*^9}, {3.495112806125*^9, 3.495112808390625*^9}, {
   3.495114069625*^9, 3.49511409396875*^9}, {3.495282497265625*^9, 
   3.495282501328125*^9}, {3.495512316953125*^9, 3.49551232109375*^9}, {
   3.495512485078125*^9, 3.4955124958125*^9}, {3.4967484274375*^9, 
   3.496748447109375*^9}, {3.56129632718645*^9, 3.561296343204586*^9}, {
   3.561296647574409*^9, 3.561296659778904*^9}, {3.561297691646077*^9, 
   3.561297883522846*^9}, {3.5612979416309347`*^9, 3.561297942989006*^9}, {
   3.561348491295784*^9, 3.5613485267250423`*^9}, {3.561351209659326*^9, 
   3.561351210493394*^9}, {3.56135125768546*^9, 3.561351285454668*^9}, {
   3.574515519364123*^9, 3.5745155462326593`*^9}},
 FontSize->24,
 Background->GrayLevel[0.85]],

Cell[BoxData[
 RowBox[{"derOnTimeNodes", "=", 
  RowBox[{"Table", "[", 
   RowBox[{
    RowBox[{"solNDS", "[", 
     RowBox[{"[", 
      RowBox[{"4", ",", "3", ",", "i"}], "]"}], "]"}], ",", 
    RowBox[{"{", 
     RowBox[{"i", ",", "2", ",", "50", ",", "2"}], "}"}]}], "]"}]}]], "Input",
 CellChangeTimes->{{3.561297179465206*^9, 3.561297253201758*^9}, {
  3.561297294514649*^9, 3.5612972954368563`*^9}, {3.561297347702697*^9, 
  3.561297413219369*^9}, {3.5612974656762953`*^9, 3.561297466488941*^9}, {
  3.561297603757675*^9, 3.561297610094159*^9}, {3.561348551203958*^9, 
  3.561348563389862*^9}},
 FontSize->18],

Cell["First simple check ...", "Text",
 CellChangeTimes->{{3.44196595746875*^9, 3.44196596009375*^9}, {
   3.44196609815625*^9, 3.4419661488125*^9}, {3.441974200375*^9, 
   3.441974210453125*^9}, {3.441974295046875*^9, 3.441974310953125*^9}, {
   3.441974345875*^9, 3.441974653*^9}, {3.441979008332594*^9, 
   3.4419790190967293`*^9}, {3.44208976115625*^9, 3.4420899933125*^9}, {
   3.4420903913125*^9, 3.442090450140625*^9}, {3.442090486984375*^9, 
   3.4420905391875*^9}, {3.442090587953125*^9, 3.442090647046875*^9}, {
   3.44209073928125*^9, 3.442090927640625*^9}, {3.44209098921875*^9, 
   3.44209103275*^9}, {3.4420910679375*^9, 3.442091114640625*^9}, {
   3.442091214703125*^9, 3.44209129325*^9}, {3.442091385671875*^9, 
   3.442091602859375*^9}, {3.442091635515625*^9, 3.44209166903125*^9}, {
   3.4420917439375*^9, 3.44209183696875*^9}, {3.4420918740625*^9, 
   3.442091933109375*^9}, {3.442091969421875*^9, 3.44209204984375*^9}, {
   3.44209243234375*^9, 3.44209243340625*^9}, {3.4420932424375*^9, 
   3.442093319953125*^9}, {3.442095443265625*^9, 3.4420955011875*^9}, {
   3.442095655265625*^9, 3.442095845234375*^9}, {3.442095889171875*^9, 
   3.4420961198125*^9}, 3.44210031803125*^9, {3.495111514796875*^9, 
   3.4951115155625*^9}, {3.495112806125*^9, 3.495112808390625*^9}, {
   3.495114069625*^9, 3.49511409396875*^9}, {3.495282497265625*^9, 
   3.495282501328125*^9}, {3.495512316953125*^9, 3.49551232109375*^9}, {
   3.495512485078125*^9, 3.4955124958125*^9}, {3.4967484274375*^9, 
   3.496748447109375*^9}, {3.56129632718645*^9, 3.561296343204586*^9}, {
   3.561296647574409*^9, 3.561296659778904*^9}, {3.561297691646077*^9, 
   3.56129792106236*^9}, {3.574515552185*^9, 3.574515557201287*^9}},
 FontSize->24,
 Background->GrayLevel[0.85]],

Cell[BoxData[
 RowBox[{
  RowBox[{
   StyleBox["DsolNDS",
    FontColor->RGBColor[1, 0, 0]], "[", "t_", "]"}], "=", 
  RowBox[{"D", "[", 
   RowBox[{
    RowBox[{
     StyleBox["solNDS",
      FontColor->RGBColor[1, 0, 0]], "[", "t", "]"}], ",", "t"}], 
   "]"}]}]], "Input",
 CellChangeTimes->{{3.442093392453125*^9, 3.44209349578125*^9}, {
  3.495112728453125*^9, 3.495112739*^9}},
 FontSize->24],

Cell[BoxData[
 RowBox[{
  StyleBox["DsolNDSOnNodes",
   FontColor->RGBColor[1, 0, 0]], 
  StyleBox[" ",
   FontColor->RGBColor[1, 0, 0]], "=", 
  RowBox[{"Map", "[", 
   RowBox[{
    StyleBox["DsolNDS",
     FontColor->RGBColor[1, 0, 0]], ",", " ", "TimeNodes"}], "]"}]}]], "Input",
 CellChangeTimes->{{3.44209355475*^9, 3.44209356546875*^9}, 
   3.49511151621875*^9, {3.49511274909375*^9, 3.4951127753125*^9}, 
   3.561296350639676*^9, 3.561296762667254*^9},
 FontSize->24],

Cell[BoxData[
 RowBox[{
  RowBox[{"couplesHermite", "=", 
   RowBox[{"Table", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"TimeNodes", "[", 
         RowBox[{"[", "i", "]"}], "]"}], "}"}], ",", 
       RowBox[{
        StyleBox["numsolOnNodes",
         FontColor->RGBColor[1, 0, 0]], 
        StyleBox["  ",
         FontColor->RGBColor[1, 0, 0]], "[", 
        RowBox[{"[", "i", "]"}], "]"}], ",", 
       RowBox[{"derOnTimeNodes", "[", 
        RowBox[{"[", "i", "]"}], "]"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"i", ",", "1", ",", 
       RowBox[{"Length", "[", "TimeNodes", "]"}]}], "}"}]}], "]"}]}], 
  ";"}]], "Input",
 CellChangeTimes->{{3.442094173390625*^9, 3.44209417359375*^9}, {
   3.442094235265625*^9, 3.442094284640625*^9}, {3.4420943514375*^9, 
   3.442094379296875*^9}, {3.442094412*^9, 3.442094456859375*^9}, {
   3.442094548046875*^9, 3.4420945845625*^9}, 3.44209465490625*^9, {
   3.442094716046875*^9, 3.442094729390625*^9}, 3.442096182015625*^9, {
   3.49511151678125*^9, 3.49511151734375*^9}, {3.495112859609375*^9, 
   3.49511287259375*^9}, 3.495112968515625*^9, {3.561296353573278*^9, 
   3.561296372889037*^9}, {3.561296480692415*^9, 3.5612964914602747`*^9}, {
   3.561297486494081*^9, 3.56129748670623*^9}, {3.561297657605492*^9, 
   3.561297661489443*^9}, 3.561348586596077*^9},
 FontSize->24],

Cell[BoxData[
 StyleBox[
  RowBox[{
   StyleBox["interpolHermite",
    FontColor->RGBColor[0.6, 0.4, 0.2]], "=", 
   RowBox[{"Interpolation", "[", "couplesHermite", "]"}]}],
  FontSize->24]], "Input",
 CellChangeTimes->{{3.442094686796875*^9, 3.442094691546875*^9}, {
   3.44209619896875*^9, 3.44209620159375*^9}, {3.44218218725*^9, 
   3.442182194171875*^9}, {3.442182266015625*^9, 3.442182289375*^9}, {
   3.442182334875*^9, 3.442182337359375*^9}, 3.5612963822689037`*^9, {
   3.561296499967198*^9, 3.561296512755769*^9}},
 FontSize->216],

Cell[BoxData[
 StyleBox[
  RowBox[{"Plot", "[", 
   RowBox[{
    RowBox[{
     StyleBox["interpolHermite",
      FontColor->RGBColor[0.6, 0.4, 0.2]], "[", "t", "]"}], ",", 
    RowBox[{"{", 
     RowBox[{"t", ",", "tini", ",", "tfin"}], "}"}], ",", 
    StyleBox[
     RowBox[{"PlotRange", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{"tini", ",", "tfin"}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{"0", ",", "3"}], "}"}]}], "}"}]}],
     FontColor->GrayLevel[0]]}], "]"}],
  FontSize->24]], "Input",
 CellChangeTimes->{
  3.44209474746875*^9, 3.44209621421875*^9, {3.44209640834375*^9, 
   3.44209641034375*^9}, {3.442101450078125*^9, 3.442101453734375*^9}, 
   3.5612965231843224`*^9},
 FontSize->96],

Cell["Another check ... the second ...", "Text",
 CellChangeTimes->CompressedData["
1:eJwtyrFLAmEcxvE3GwL19luEBF0EI4SWiuDMsyBwkDbBobKuqWuIbEheTFCH
5kqClDMVIa7+hyaHsIYIisIIqiOnHDTiyPf3NLx8eL6/17uyFU85GGOe4RMy
Zupj558KY6PbUM3CUgG6d11CHkvDThY+50g2W4RlU3hadbaloZq8eitR97/N
k4GRCGmFSB6Zhi9z6OsqdmYJduLom0ns3g52fR/KBzCTx335EN6foDcM7CkT
JlpQv8G9cgftR3j2DsNf+Gd8w2Affcahkq4QDP4bOyK5XYZaM0q9dkXyj2tY
f4L+V9x/bGyvvED72EPycR/sTsDB7yIp28Kqb89tFCyldtGShNrlZPehYin6
xhr5B1tCx1s=
  "],
 FontSize->24,
 Background->GrayLevel[0.85]],

Cell[BoxData[
 StyleBox[
  RowBox[{"Plot", "[", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{
      RowBox[{
       RowBox[{"solsymb", "[", "t", "]"}], "-", 
       RowBox[{
        StyleBox["interpolHermite",
         FontColor->RGBColor[0.6, 0.4, 0.2]], "[", "t", "]"}]}], ",", 
      RowBox[{
       RowBox[{"solsymb", "[", "t", "]"}], "-", 
       RowBox[{
        StyleBox["solNDS",
         FontColor->RGBColor[1, 0, 0]], "[", "t", "]"}]}]}], "}"}], ",", 
    RowBox[{"{", 
     RowBox[{"t", ",", "tini", ",", "tfin"}], "}"}], ",", 
    RowBox[{"PlotRange", " ", "\[Rule]", " ", "All"}]}], "]"}],
  FontSize->24]], "Input",
 CellChangeTimes->{{3.442094855796875*^9, 3.4420948730625*^9}, {
   3.442095019734375*^9, 3.442095048671875*^9}, {3.442095101671875*^9, 
   3.44209510396875*^9}, 3.44209625653125*^9, {3.44210146509375*^9, 
   3.44210146578125*^9}, {3.4421823104375*^9, 3.44218232725*^9}, {
   3.495113046328125*^9, 3.4951130485*^9}, {3.49528537309375*^9, 
   3.4952853745*^9}, 3.56129655181417*^9},
 FontSize->96],

Cell[BoxData[
 StyleBox[
  RowBox[{"Plot", "[", 
   RowBox[{
    RowBox[{
     RowBox[{
      StyleBox["solNDS",
       FontColor->RGBColor[1, 0, 0]], "[", "t", "]"}], "-", 
     RowBox[{
      StyleBox["interpolHermite",
       FontColor->RGBColor[0.6, 0.4, 0.2]], "[", "t", "]"}]}], ",", 
    RowBox[{"{", 
     RowBox[{"t", ",", "tini", ",", "tfin"}], "}"}], ",", 
    RowBox[{"PlotRange", " ", "\[Rule]", " ", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        RowBox[{"-", "1."}], "*", 
        SuperscriptBox["10", 
         RowBox[{"-", "15"}]]}], ",", 
       RowBox[{"1.", "*", 
        SuperscriptBox["10", 
         RowBox[{"-", "15"}]]}]}], "}"}]}]}], "]"}],
  FontSize->24]], "Input",
 CellChangeTimes->{{3.442094948375*^9, 3.4420949506875*^9}, {
   3.44209537290625*^9, 3.442095389859375*^9}, 3.442096262890625*^9, {
   3.442101472671875*^9, 3.44210147290625*^9}, {3.44210189990625*^9, 
   3.442101951515625*^9}, {3.495113123203125*^9, 3.495113125203125*^9}, 
   3.561296562531952*^9, {3.561296598793723*^9, 3.5612966281189632`*^9}},
 FontSize->72]
}, Closed]]
}, Closed]]
},
WindowToolbars->"EditBar",
CellGrouping->Manual,
WindowSize->{1904, 946},
WindowMargins->{{0, Automatic}, {Automatic, 0}},
PrintingCopies->1,
PrintingPageRange->{Automatic, Automatic},
ShowCellTags->True,
FrontEndVersion->"8.0 for Microsoft Windows (64-bit) (February 23, 2011)",
StyleDefinitions->"Default.nb"
]
(* End of Notebook Content *)

(* Internal cache information *)
(*CellTagsOutline
CellTagsIndex->{}
*)
(*CellTagsIndex
CellTagsIndex->{}
*)
(*NotebookFileOutline
Notebook[{
Cell[545, 20, 800, 15, 87, "Text"],
Cell[1348, 37, 6042, 140, 857, "Text"],
Cell[7393, 179, 3700, 57, 297, "Text"],
Cell[11096, 238, 3806, 70, 657, "Text"],
Cell[14905, 310, 1158, 30, 52, "Input"],
Cell[16066, 342, 2288, 51, 213, "Text"],
Cell[18357, 395, 241, 6, 42, "Input"],
Cell[18601, 403, 1258, 26, 93, "Input"],
Cell[19862, 431, 131, 4, 42, "Input"],
Cell[19996, 437, 96, 1, 31, "Input"],
Cell[CellGroupData[{
Cell[20117, 442, 356, 7, 71, "Text"],
Cell[CellGroupData[{
Cell[20498, 453, 373, 6, 42, "Text"],
Cell[20874, 461, 589, 20, 31, "Input"],
Cell[21466, 483, 404, 12, 31, "Input"],
Cell[21873, 497, 824, 24, 31, "Input"]
}, Open  ]],
Cell[CellGroupData[{
Cell[22734, 526, 751, 14, 87, "Text"],
Cell[23488, 542, 176, 6, 31, "Input",
 CellID->408132437],
Cell[23667, 550, 767, 24, 31, "Input"],
Cell[24437, 576, 849, 22, 31, "Input"],
Cell[25289, 600, 436, 8, 31, "Input"],
Cell[25728, 610, 436, 13, 31, "Input"],
Cell[26167, 625, 234, 7, 31, "Input"],
Cell[26404, 634, 473, 14, 31, "Input"]
}, Open  ]]
}, Closed]],
Cell[CellGroupData[{
Cell[26926, 654, 381, 7, 68, "Text"],
Cell[CellGroupData[{
Cell[27332, 665, 1096, 19, 87, "Text"],
Cell[CellGroupData[{
Cell[28453, 688, 652, 10, 42, "Text"],
Cell[29108, 700, 406, 11, 31, "Input"]
}, Open  ]],
Cell[CellGroupData[{
Cell[29551, 716, 883, 16, 65, "Text"],
Cell[30437, 734, 520, 16, 31, "Input"]
}, Open  ]],
Cell[CellGroupData[{
Cell[30994, 755, 646, 11, 42, "Text"],
Cell[31643, 768, 835, 22, 31, "Input"],
Cell[32481, 792, 137, 3, 31, "Input"]
}, Open  ]],
Cell[CellGroupData[{
Cell[32655, 800, 1219, 25, 42, "Text"],
Cell[33877, 827, 1335, 29, 87, "Text"],
Cell[35215, 858, 765, 18, 57, "Input"],
Cell[35983, 878, 1320, 30, 87, "Text"],
Cell[37306, 910, 777, 13, 42, "Text"],
Cell[38086, 925, 760, 23, 31, "Input"],
Cell[38849, 950, 220, 4, 31, "Input"],
Cell[39072, 956, 675, 13, 42, "Text"],
Cell[39750, 971, 590, 15, 31, "Input"]
}, Open  ]]
}, Closed]]
}, Closed]],
Cell[CellGroupData[{
Cell[40401, 993, 407, 8, 68, "Text"],
Cell[CellGroupData[{
Cell[40833, 1005, 1067, 21, 87, "Text"],
Cell[41903, 1028, 1058, 28, 31, "Input"],
Cell[42964, 1058, 453, 9, 42, "Text"],
Cell[43420, 1069, 726, 16, 31, "Input"],
Cell[44149, 1087, 3093, 74, 142, "Input"],
Cell[CellGroupData[{
Cell[47267, 1165, 479, 10, 87, "Text"],
Cell[47749, 1177, 767, 21, 31, "Input"],
Cell[48519, 1200, 527, 12, 31, "Input"]
}, Open  ]]
}, Open  ]]
}, Closed]],
Cell[CellGroupData[{
Cell[49107, 1219, 408, 8, 68, "Text"],
Cell[CellGroupData[{
Cell[49540, 1231, 1092, 22, 65, "Text"],
Cell[50635, 1255, 605, 15, 31, "Input"],
Cell[51243, 1272, 426, 11, 27, "Input"],
Cell[51672, 1285, 1550, 27, 132, "Text"],
Cell[53225, 1314, 2755, 64, 159, "Input"],
Cell[55983, 1380, 1363, 22, 87, "Text"],
Cell[57349, 1404, 629, 20, 27, "Input"],
Cell[57981, 1426, 398, 13, 27, "Input"],
Cell[58382, 1441, 1308, 21, 42, "Text"],
Cell[59693, 1464, 551, 14, 27, "Input"],
Cell[60247, 1480, 1635, 31, 42, "Text"]
}, Closed]]
}, Closed]],
Cell[CellGroupData[{
Cell[61931, 1517, 405, 8, 68, "Text"],
Cell[CellGroupData[{
Cell[62361, 1529, 828, 15, 65, "Text"],
Cell[63192, 1546, 473, 15, 31, "Input"],
Cell[63668, 1563, 805, 19, 31, "Input"],
Cell[CellGroupData[{
Cell[64498, 1586, 1566, 40, 94, "Input"],
Cell[66067, 1628, 829, 16, 65, "Text"],
Cell[66899, 1646, 454, 12, 24, "Input"]
}, Open  ]],
Cell[67368, 1661, 599, 15, 24, "Input"],
Cell[CellGroupData[{
Cell[67992, 1680, 1564, 39, 87, "Text"],
Cell[69559, 1721, 551, 13, 31, "Input"],
Cell[70113, 1736, 702, 17, 31, "Input"],
Cell[70818, 1755, 2521, 67, 150, "Input"]
}, Open  ]],
Cell[CellGroupData[{
Cell[73376, 1827, 1154, 22, 42, "Text"],
Cell[74533, 1851, 1431, 32, 185, "Input"]
}, Open  ]]
}, Closed]]
}, Closed]],
Cell[CellGroupData[{
Cell[76025, 1890, 410, 8, 68, "Text"],
Cell[CellGroupData[{
Cell[76460, 1902, 1476, 25, 177, "Text"],
Cell[77939, 1929, 3689, 103, 175, "Input"]
}, Open  ]]
}, Closed]],
Cell[CellGroupData[{
Cell[81677, 2038, 409, 8, 68, "Text"],
Cell[CellGroupData[{
Cell[82111, 2050, 3173, 69, 201, "Text"],
Cell[85287, 2121, 615, 14, 27, "Input"],
Cell[85905, 2137, 1758, 26, 42, "Text"],
Cell[87666, 2165, 398, 13, 31, "Input"],
Cell[88067, 2180, 474, 13, 31, "Input"],
Cell[88544, 2195, 1381, 32, 31, "Input"],
Cell[89928, 2229, 540, 12, 31, "Input"],
Cell[90471, 2243, 755, 23, 31, "Input"],
Cell[91229, 2268, 515, 11, 42, "Text"],
Cell[91747, 2281, 1025, 26, 31, "Input"],
Cell[92775, 2309, 1070, 29, 36, "Input"]
}, Closed]]
}, Closed]]
}
]
*)

(* End of internal cache information *)
