(* Content-type: application/mathematica *)

(*** Wolfram Notebook File ***)
(* http://www.wolfram.com/nb *)

(* CreatedBy='Mathematica 6.0' *)

(*CacheID: 234*)
(* Internal cache information:
NotebookFileLineBreakTest
NotebookFileLineBreakTest
NotebookDataPosition[       145,          7]
NotebookDataLength[     74174,       1665]
NotebookOptionsPosition[     71756,       1590]
NotebookOutlinePosition[     72184,       1608]
CellTagsIndexPosition[     72141,       1605]
WindowFrame->Normal*)

(* Beginning of Notebook Content *)
Notebook[{
Cell["\<\
Evaluation time
\[CapitalDelta]t <  10 s\
\>", "Text",
 CellChangeTimes->{{3.562472668969658*^9, 3.56247269838091*^9}, {
  3.562472941593423*^9, 3.562473062270509*^9}, {3.5624734139727077`*^9, 
  3.562473440257189*^9}, {3.562473488140106*^9, 3.5624734901697197`*^9}, {
  3.562473647370349*^9, 3.56247375535853*^9}, {3.573982816151486*^9, 
  3.573982844408066*^9}, {3.5739830410639153`*^9, 3.573983093759083*^9}, {
  3.5744857601642675`*^9, 3.574485765203555*^9}},
 FontSize->24,
 FontColor->RGBColor[0, 0, 1],
 Background->RGBColor[1, 0.9, 0.8]],

Cell[TextData[{
 "This notebook deals with a possible inconsistency between the BCs and ICs \
that\nmay occur when we use the Separation of Variables  method.\n\nHere we \
examine the following problem\n\n",
 Cell[BoxData[
  RowBox[{
   StyleBox[
    RowBox[{
     RowBox[{
      RowBox[{"{", 
       RowBox[{
        RowBox[{
         RowBox[{
          SubscriptBox["\[PartialD]", "t"], " ", 
          RowBox[{"T", "[", 
           RowBox[{"x", ",", "t"}], "]"}]}], "\[Equal]", " ", 
         RowBox[{
          SubscriptBox["\[PartialD]", 
           RowBox[{"x", ",", "x"}]], 
          RowBox[{"T", "[", 
           RowBox[{"x", ",", "t"}], "]"}]}]}], " ", ",", "         ", 
        "\[IndentingNewLine]", 
        RowBox[{
         RowBox[{"T", "[", 
          RowBox[{"x", ",", "0"}], "]"}], "\[Equal]", " ", "0"}], ",", 
        "\[IndentingNewLine]", 
        RowBox[{
         RowBox[{"T", "[", 
          RowBox[{"0", ",", "t"}], "]"}], "\[Equal]", 
         SubscriptBox["T", "0"]}], ",", "\[IndentingNewLine]", " ", 
        RowBox[{
         RowBox[{
          RowBox[{
           RowBox[{
            StyleBox["Derivative",
             FontColor->RGBColor[1, 0, 0]], "[", 
            RowBox[{"1", ",", "0"}], "]"}], "[", "T", "]"}], "[", 
          RowBox[{"xmax", ",", "t"}], "]"}], "\[Equal]", "0"}]}], "}"}], ",", 
      "\[IndentingNewLine]", 
      RowBox[{"T", "[", 
       RowBox[{"x", ",", "t"}], "]"}], ",", 
      RowBox[{"{", 
       RowBox[{"x", ",", "0", ",", "xmax"}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{"t", ",", "0", ",", "tmax"}], "}"}]}], "]"}],
    Background->RGBColor[1, 1, 0.85]], " "}]], "Input",
  CellChangeTimes->{{3.432361126078125*^9, 3.43236113771875*^9}},
  FontSize->24],
 "\n\nwhere, clearly,   T[x,0]\[Equal] 0 and T[0,t]\[Equal] ",
 Cell[BoxData[
  FormBox[
   SubscriptBox["T", "0"], TraditionalForm]]],
 " are  inconsistent.\n\nWhereas the SV method (eq 4.2.2) can treat directly \
these conditions,\nwith NDSolve we have to circumvent them somehow.\n\nWe \
show different cases and different ways to face the problem of inconsistency\n\
between BCs and ICs.\n\nFirst of all, we would like to underline that the \
above cited inconsistency cannot be\nrealized in practise. However our \
purpose is to get an analytical solution for two reason:\n\n- it is the \
simplest way to follow under the mathematical point of view;\n- it justifies \
qualitatively (and even quantitatively in simple cases) the experimental \
data.\n\n\nIn Part I  NDsolve is used without paying attention to the message\
\n\[OpenCurlyDoubleQuote]NDSolve::ibcinc: Warning: Boundary and initial \
conditions are inconsistent\[CloseCurlyDoubleQuote]",
 StyleBox["\n\n",
  FontSize->14],
 "In Part II we show the results obtainable when using NDSolve\nwith Version \
6 or 7 (clearly a worthless interpretation of the phaenomenon...)\n\nIn Part \
III we check the correctness of the solution \ngiven in Part I by following a \
trick suggested by Paul Abbott\n \nIn Part IV we introduce a smooth function \
to circumvent\nthe inconsistency\n\nIn Part V we introduce some options of \
NDSolve to observe \ntheir influence on the solution \n\nIn Part VI we show \
that even in the case of a realistic silicon rod, with \nappropriate \
coefficients, we cannot overlook the above considered inconsistency. \n\n\
Conclusion:  the influence of inconsistency cannot be  \n                     \
    overlooked, as we can basically see from Part I and III."
}], "Text",
 CellChangeTimes->{{3.5623273043222113`*^9, 3.562327592982615*^9}, {
   3.562327664407689*^9, 3.562327797042886*^9}, {3.562327842713984*^9, 
   3.5623278556467047`*^9}, {3.562327891640758*^9, 3.562327966758638*^9}, {
   3.562328045914052*^9, 3.562328070459528*^9}, {3.562328103158291*^9, 
   3.562328113377273*^9}, {3.562387449628216*^9, 3.5623875070368023`*^9}, {
   3.562410155580194*^9, 3.562410188048053*^9}, {3.562410222144574*^9, 
   3.562410254361451*^9}, {3.562410667788753*^9, 3.5624109084048777`*^9}, 
   3.562411008290659*^9, {3.5624111023269*^9, 3.5624111076027327`*^9}, {
   3.5624111407926292`*^9, 3.562411414875499*^9}, {3.562413438172681*^9, 
   3.562413475080809*^9}, {3.5624720343303432`*^9, 3.562472097179653*^9}, {
   3.5624722100075703`*^9, 3.562472237166613*^9}, {3.562472476178059*^9, 
   3.562472510512067*^9}, {3.562472544992401*^9, 3.562472620159317*^9}, {
   3.562473347105784*^9, 3.562473347105932*^9}, {3.5744848517283077`*^9, 
   3.5744848589637213`*^9}, {3.574485811948229*^9, 3.5744858676594152`*^9}, {
   3.574485918324313*^9, 3.5744859216755047`*^9}, {3.574486603412498*^9, 
   3.5744866831850605`*^9}, {3.574486747004711*^9, 3.5744868257712164`*^9}, {
   3.574486868984688*^9, 3.5744869482342205`*^9}, {3.574487019436293*^9, 
   3.5744870525721884`*^9}, {3.574487151659856*^9, 3.5744871898120384`*^9}, {
   3.5744873925876365`*^9, 3.574487409244589*^9}},
 FontSize->24,
 FontColor->RGBColor[0, 0, 1],
 Background->RGBColor[1, 1, 0.85]],

Cell[CellGroupData[{

Cell["Part I ", "Text",
 CellChangeTimes->{{3.562410978615988*^9, 3.562410985771182*^9}},
 FontSize->36,
 FontColor->RGBColor[0, 0, 1],
 Background->RGBColor[1, 0.9, 0.8]],

Cell[BoxData[
 RowBox[{
  RowBox[{"Clear", "[", "\"\<Global`*\>\"", "]"}], ";", 
  RowBox[{"Remove", "[", "\"\<Global`*\>\"", "]"}], ";", 
  RowBox[{"$Line", "=", "0"}], ";"}]], "Input",
 FontSize->24],

Cell[BoxData[
 RowBox[{"<<", "\"\</home/MyDir/Book-Mathematica/TellName2.m\>\""}]], "Input",
 CellChangeTimes->{{3.43236400196875*^9, 3.432364010765625*^9}, {
  3.562327977458788*^9, 3.562328014790292*^9}, {3.578549826543706*^9, 
  3.5785498328390656`*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"SetOptions", "[", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{
     "Plot", ",", "Plot3D", ",", "ParametricPlot3D", ",", "ListPlot"}], "}"}],
     ",", 
    RowBox[{"ImageSize", "\[Rule]", "500"}], ",", 
    RowBox[{"LabelStyle", "\[Rule]", 
     RowBox[{"(", 
      RowBox[{"FontFamily", "\[Rule]", "\"\<Helvetica\>\""}], ")"}]}], ",", 
    RowBox[{"AxesStyle", "\[Rule]", 
     RowBox[{"Directive", "[", 
      RowBox[{"20", ",", 
       RowBox[{"Thickness", "[", "0.005", "]"}], ",", "Blue"}], "]"}]}]}], 
   "]"}], ";"}]], "Input",
 CellChangeTimes->{{3.431404133265625*^9, 3.431404152625*^9}, {
   3.431404184828125*^9, 3.43140419784375*^9}, {3.431404229828125*^9, 
   3.431404286*^9}, {3.431404358734375*^9, 3.431404362015625*^9}, 
   3.43140449659375*^9, {3.431404585328125*^9, 3.431404586390625*^9}, {
   3.431404647765625*^9, 3.431404694953125*^9}, {3.43140617875*^9, 
   3.4314062495625*^9}, {3.431406282875*^9, 3.4314063513125*^9}, {
   3.43140679328125*^9, 3.43140680225*^9}, {3.4314068341875*^9, 
   3.431406876078125*^9}, {3.432212273265625*^9, 3.43221228234375*^9}, {
   3.432297653046875*^9, 3.432297655828125*^9}},
 FontSize->16],

Cell[TextData[{
 "We define the parameters  ",
 Cell[BoxData[
  SubscriptBox["T", "0"]], "Input",
  CellChangeTimes->{{3.562472147896184*^9, 3.562472149526985*^9}},
  FontSize->24],
 ", xmax, tmax and set the \ncoefficient of diffusivity  (\[Alpha]) equal to \
1."
}], "Text",
 CellChangeTimes->{{3.562410978615988*^9, 3.562410985771182*^9}, {
  3.562472319596966*^9, 3.562472423542656*^9}},
 FontSize->24,
 Background->GrayLevel[0.85]],

Cell[BoxData[
 RowBox[{
  RowBox[{
   SubscriptBox["T", "0"], "=", "1"}], ";"}]], "Input",
 CellChangeTimes->{{3.562472147896184*^9, 3.562472149526985*^9}},
 FontSize->24],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"xmax", " ", "=", "2"}], ";"}], "             ", 
  RowBox[{"(*", " ", "m", " ", "*)"}]}]], "Input",
 CellChangeTimes->{{3.5623281926579237`*^9, 3.5623282181263657`*^9}},
 FontSize->24],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"tmax", " ", "=", " ", "5"}], ";"}], "             ", 
  RowBox[{"(*", " ", "s", " ", "*)"}]}]], "Input",
 CellChangeTimes->{{3.5623281926579237`*^9, 3.56232822280774*^9}, {
  3.562410125141171*^9, 3.562410125794917*^9}},
 FontSize->24],

Cell[BoxData[
 RowBox[{"Timing", "[", 
  RowBox[{"sol1", " ", "=", "  ", 
   RowBox[{"NDSolve", "[", "\[IndentingNewLine]", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        RowBox[{
         SubscriptBox["\[PartialD]", "t"], " ", 
         RowBox[{"T", "[", 
          RowBox[{"x", ",", "t"}], "]"}]}], "\[Equal]", " ", 
        RowBox[{
         SubscriptBox["\[PartialD]", 
          RowBox[{"x", ",", "x"}]], 
         RowBox[{"T", "[", 
          RowBox[{"x", ",", "t"}], "]"}]}]}], " ", ",", "      ", 
       "\[IndentingNewLine]", 
       RowBox[{
        RowBox[{"T", "[", 
         RowBox[{"x", ",", "0"}], "]"}], "\[Equal]", " ", "0"}], ",", 
       "\[IndentingNewLine]", 
       RowBox[{
        RowBox[{"T", "[", 
         RowBox[{"0", ",", "t"}], "]"}], "\[Equal]", 
        SubscriptBox["T", "0"]}], ",", "\[IndentingNewLine]", " ", 
       RowBox[{
        RowBox[{
         RowBox[{
          RowBox[{
           StyleBox["Derivative",
            FontColor->RGBColor[1, 0, 0]], "[", 
           RowBox[{"1", ",", "0"}], "]"}], "[", "T", "]"}], "[", 
         RowBox[{"xmax", ",", "t"}], "]"}], "\[Equal]", "0"}]}], "}"}], ",", 
     "\[IndentingNewLine]", 
     RowBox[{"T", "[", 
      RowBox[{"x", ",", "t"}], "]"}], ",", 
     RowBox[{"{", 
      RowBox[{"x", ",", "0", ",", "xmax"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"t", ",", "0", ",", "tmax"}], "}"}]}], "]"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.432361126078125*^9, 3.43236113771875*^9}, {
   3.56241051973143*^9, 3.562410530280671*^9}, {3.562410638827619*^9, 
   3.562410640289146*^9}, 3.562472165304247*^9, 3.562472399934577*^9},
 FontSize->24],

Cell[BoxData[
 RowBox[{"Plot3D", "[", 
  RowBox[{
   RowBox[{"Evaluate", "[", 
    RowBox[{
     RowBox[{"T", "[", 
      RowBox[{"x", ",", "t"}], "]"}], " ", "/.", 
     StyleBox[" ",
      FontColor->RGBColor[0, 0, 1]], "sol1"}], "]"}], ",", 
   RowBox[{"{", 
    RowBox[{"x", ",", "0", ",", "xmax"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"t", ",", "0", ",", "tmax"}], "}"}]}], "]"}]], "Input",
 CellChangeTimes->{
  3.432297599046875*^9, {3.562335932322768*^9, 3.562335935094223*^9}, {
   3.5624105701588707`*^9, 3.562410591893426*^9}},
 FontSize->24]
}, Open  ]],

Cell[CellGroupData[{

Cell["Part II ", "Text",
 CellChangeTimes->{{3.562410978615988*^9, 3.562410985771182*^9}, 
   3.5624110868010187`*^9},
 FontSize->36,
 FontColor->RGBColor[0, 0, 1],
 Background->RGBColor[1, 0.9, 0.8]],

Cell["\<\
In the following section we report the result when the above
problem is carried out with Version 6 or 7.
We observe that the solution is worthless...\
\>", "Text",
 CellChangeTimes->{{3.562410303894883*^9, 3.562410358936863*^9}, {
  3.562411457920554*^9, 3.562411496909626*^9}, {3.574487363779989*^9, 
  3.574487366028117*^9}},
 FontSize->24,
 FontColor->GrayLevel[0],
 Background->GrayLevel[0.85]],

Cell["\<\
Plot3D[Evaluate[T[x, t] /. sol1]], {x, 0, xmax}, {t, 0, tmax}]\
\>", "Text",
 CellChangeTimes->{
  3.432297599046875*^9, {3.562335932322768*^9, 3.562335935094223*^9}, 
   3.562409933486018*^9, {3.562410420236252*^9, 3.562410425018527*^9}, {
   3.5624105388126297`*^9, 3.562410557026767*^9}, {3.574487319428452*^9, 
   3.574487320300502*^9}},
 FontSize->24,
 Background->GrayLevel[0.85]],

Cell[BoxData[
 Graphics3DBox[GraphicsComplex3DBox[CompressedData["
1:eJx13HmwXFWdwPHO9pKwSCTsoJbaoEImINugozxRCFxgpKBEgSeLgIMIHWKi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   "], {{
     {EdgeForm[None], GraphicsGroup3DBox[{Polygon3DBox[CompressedData["
1:eJwtmXf8VuMbx+9z7vtJUSpKNDVIGkRlNZDKHtllp/KTEVq2iKIlbXs0VVaU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         "]], Polygon3DBox[CompressedData["
1:eJwtmmOgJUm3RE9l1h2brVF3j/GNbdszPbZt27Zt20aPbdu2/dZ6UT/yVkZm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         "]], Polygon3DBox[CompressedData["
1:eJwt13n8lVMaAPDf7977a0GSQrJNWkyLaEXrtGvXjhajjaGN1tHGtNJiSVEI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         "]]}]}, {}, {}, {}, {}}, {
     {GrayLevel[0], Line3DBox[CompressedData["
1:eJwt0jkvRFEYgOFrX8cS0RINUVCKglIUVCIKOqKgIBEFpULodPwCWiL0Ejr7
MvY1ImJr7Gt4TqJ45zlz5+Te7+ROSXtvU09CFEXDelVYP+pSs4lRlMcFFnOd
lTxlLR/YyG+2MTspimLqti7nIKs5ynpOsIVT7OQ8+7nEF17zXdt61r2WDbTD
Fca5yl2ucS/MxH1u8ICb3NJhuA+PuMNjxnnCXZ5yj2fc5zmnneOGH7oIM4Uz
asxsWxziIvs4xw5OspnjrOMIqzjAMpaqyzqDrfz0jAbesYbHrAjnYhGf7Lvi
m3LD97BXhWbMYQFjzGd22MMsxpjJLGaE5zGdqUxRmnUSU8M7Dtf4q2T9hN/0
JWNEMz5u//8Pf9eHSwE=
       "]]}, {
      Line3DBox[{690, 1009, 473, 689, 1120, 912, 691, 1121, 913, 692, 1122, 
       914, 693, 1123, 915, 694, 1124, 916, 695, 1125, 1015, 1230, 696, 1126, 
       917, 697, 1127, 918, 698, 1128, 919, 699, 1129, 920, 700, 1130, 921, 
       701, 1131, 922, 702, 1336, 1010, 923, 1011}], 
      Line3DBox[{704, 1016, 1231, 703, 488, 705, 1132, 924, 706, 1133, 925, 
       707, 1134, 926, 708, 1135, 927, 709, 1136, 1017, 1232, 710, 1018, 1233,
        711, 1137, 928, 712, 1138, 929, 713, 1139, 930, 714, 1140, 931, 715, 
       1141, 932, 716, 1142, 933, 717}], 
      Line3DBox[{719, 1019, 1234, 718, 1020, 1235, 720, 1143, 934, 721, 1144, 
       935, 722, 1145, 936, 723, 1146, 937, 724, 1147, 1021, 1236, 725, 1022, 
       1237, 726, 1023, 1238, 727, 1148, 938, 728, 1149, 939, 729, 1150, 940, 
       730, 1151, 941, 731, 1152, 942, 732}], 
      Line3DBox[{734, 1024, 1239, 733, 1025, 1240, 735, 1026, 1241, 736, 1153,
        943, 737, 1154, 944, 738, 1155, 945, 739, 1156, 1027, 1242, 740, 1028,
        1243, 741, 1029, 1244, 742, 1030, 1245, 743, 1157, 946, 744, 1158, 
       947, 745, 1159, 948, 746, 1160, 949, 747}], 
      Line3DBox[{749, 1031, 1246, 748, 1032, 1247, 750, 1033, 1248, 751, 1034,
        1249, 752, 1161, 950, 753, 1162, 951, 754, 1163, 1035, 1250, 755, 
       1036, 1251, 756, 1037, 1252, 757, 1038, 1253, 758, 1039, 1254, 759, 
       1164, 952, 760, 1165, 953, 761, 1166, 954, 762}], 
      Line3DBox[{764, 1040, 1255, 763, 1041, 1256, 765, 1042, 1257, 766, 1043,
        1258, 767, 1044, 1259, 768, 1167, 955, 769, 1168, 1045, 1260, 770, 
       1046, 1261, 771, 1047, 1262, 772, 1048, 1263, 773, 1049, 1264, 774, 
       1050, 1265, 775, 1169, 956, 776, 1170, 957, 777}], 
      Line3DBox[{781, 1171, 958, 779, 1172, 959, 783, 1173, 960, 785, 1174, 
       961, 787, 1175, 962, 789, 1176, 963, 791, 1178, 1179, 964, 793, 1180, 
       965, 795, 1181, 966, 797, 1182, 967, 799, 1183, 968, 801, 1184, 969, 
       803, 1185, 970, 805, 1187, 972, 807}], 
      Line3DBox[{806, 971, 1186, 804, 1278, 1063, 802, 1277, 1062, 800, 1276, 
       1061, 798, 1275, 1060, 796, 1274, 1059, 794, 1273, 1058, 792, 1272, 
       1057, 1177, 790, 1271, 1056, 788, 1270, 1055, 786, 1269, 1054, 784, 
       1268, 1053, 782, 1267, 1052, 778, 1266, 1051, 780}], 
      Line3DBox[{809, 1064, 1279, 808, 1188, 973, 810, 1189, 974, 811, 1190, 
       975, 812, 1191, 976, 813, 1192, 977, 814, 1193, 1065, 1280, 815, 585, 
       816, 1194, 978, 817, 1195, 979, 818, 1196, 980, 819, 1197, 981, 820, 
       1198, 982, 821, 1199, 983, 822}], 
      Line3DBox[{824, 1066, 1281, 823, 1067, 1282, 825, 1200, 984, 826, 1201, 
       985, 827, 1202, 986, 828, 1203, 987, 829, 1204, 1068, 1283, 830, 1069, 
       1284, 831, 601, 832, 1205, 988, 833, 1206, 989, 834, 1207, 990, 835, 
       1208, 991, 836, 1209, 992, 837}], 
      Line3DBox[{839, 1070, 1285, 838, 1071, 1286, 840, 1072, 1287, 841, 1210,
        993, 842, 1211, 994, 843, 1212, 995, 844, 1213, 1073, 1288, 845, 1074,
        1289, 846, 1075, 1290, 847, 617, 848, 1214, 996, 849, 1215, 997, 850, 
       1216, 998, 851, 1217, 999, 852}], 
      Line3DBox[{854, 1076, 1291, 853, 1077, 1292, 855, 1078, 1293, 856, 1079,
        1294, 857, 1218, 1000, 858, 1219, 1001, 859, 1220, 1080, 1295, 860, 
       1081, 1296, 861, 1082, 1297, 862, 1083, 1298, 863, 633, 864, 1221, 
       1002, 865, 1222, 1003, 866, 1223, 1004, 867}], 
      Line3DBox[{869, 1084, 1299, 868, 1085, 1300, 870, 1086, 1301, 871, 1087,
        1302, 872, 1088, 1303, 873, 1224, 1005, 874, 1225, 1089, 1304, 875, 
       1090, 1305, 876, 1091, 1306, 877, 1092, 1307, 878, 1093, 1308, 879, 
       649, 880, 1226, 1006, 881, 1227, 1007, 882}], 
      Line3DBox[{884, 1094, 1309, 883, 1095, 1310, 885, 1096, 1311, 886, 1097,
        1312, 887, 1098, 1313, 888, 1099, 1314, 889, 1228, 1100, 1315, 890, 
       1101, 1316, 891, 1102, 1317, 892, 1103, 1318, 893, 1104, 1319, 894, 
       1105, 1320, 895, 665, 896, 1229, 1008, 897}], 
      Line3DBox[{911, 1014, 1335, 1119, 910, 1334, 1117, 909, 1333, 1116, 908,
        1332, 1115, 907, 1331, 1114, 906, 1330, 1113, 905, 1329, 1112, 904, 
       1328, 1327, 1111, 903, 1326, 1110, 902, 1325, 1109, 901, 1324, 1108, 
       900, 1323, 1107, 899, 1322, 1106, 898, 1118, 1321, 1012, 1013}]}, {
      Line3DBox[{251, 474, 1120, 252, 488, 280, 1235, 503, 295, 1240, 518, 
       310, 1247, 533, 325, 1256, 548, 340, 1267, 563, 1172, 355, 578, 1188, 
       370, 1282, 593, 385, 1286, 608, 400, 1292, 623, 415, 1300, 638, 430, 
       1310, 653, 445, 1322, 668, 460}], 
      Line3DBox[{253, 475, 1121, 254, 489, 1132, 281, 504, 1143, 296, 1241, 
       519, 311, 1248, 534, 326, 1257, 549, 341, 1268, 564, 1173, 356, 579, 
       1189, 371, 594, 1200, 386, 1287, 609, 401, 1293, 624, 416, 1301, 639, 
       431, 1311, 654, 446, 1323, 669, 461}], 
      Line3DBox[{255, 476, 1122, 256, 490, 1133, 282, 505, 1144, 297, 520, 
       1153, 312, 1249, 535, 327, 1258, 550, 342, 1269, 565, 1174, 357, 580, 
       1190, 372, 595, 1201, 387, 610, 1210, 402, 1294, 625, 417, 1302, 640, 
       432, 1312, 655, 447, 1324, 670, 462}], 
      Line3DBox[{257, 477, 1123, 258, 491, 1134, 283, 506, 1145, 298, 521, 
       1154, 313, 536, 1161, 328, 1259, 551, 343, 1270, 566, 1175, 358, 581, 
       1191, 373, 596, 1202, 388, 611, 1211, 403, 626, 1218, 418, 1303, 641, 
       433, 1313, 656, 448, 1325, 671, 463}], 
      Line3DBox[{259, 478, 1124, 260, 492, 1135, 284, 507, 1146, 299, 522, 
       1155, 314, 537, 1162, 329, 552, 1167, 344, 1271, 567, 1176, 359, 582, 
       1192, 374, 597, 1203, 389, 612, 1212, 404, 627, 1219, 419, 642, 1224, 
       434, 1314, 657, 449, 1326, 672, 464}], 
      Line3DBox[{261, 479, 1125, 263, 493, 1136, 285, 508, 1147, 300, 523, 
       1156, 315, 538, 1163, 330, 553, 1168, 345, 568, 1177, 1178, 360, 583, 
       1193, 375, 598, 1204, 390, 613, 1213, 405, 628, 1220, 420, 643, 1225, 
       435, 658, 1228, 450, 1327, 673, 465}], 
      Line3DBox[{265, 481, 1126, 266, 1233, 495, 287, 1237, 510, 302, 1243, 
       525, 317, 1251, 540, 332, 1261, 555, 347, 1273, 570, 1180, 362, 585, 
       377, 1284, 600, 392, 1289, 615, 407, 1296, 630, 422, 1305, 645, 437, 
       1316, 660, 452, 1329, 675, 467}], 
      Line3DBox[{267, 482, 1127, 268, 496, 1137, 288, 1238, 511, 303, 1244, 
       526, 318, 1252, 541, 333, 1262, 556, 348, 1274, 571, 1181, 363, 586, 
       1194, 378, 601, 393, 1290, 616, 408, 1297, 631, 423, 1306, 646, 438, 
       1317, 661, 453, 1330, 676, 468}], 
      Line3DBox[{269, 483, 1128, 270, 497, 1138, 289, 512, 1148, 304, 1245, 
       527, 319, 1253, 542, 334, 1263, 557, 349, 1275, 572, 1182, 364, 587, 
       1195, 379, 602, 1205, 394, 617, 409, 1298, 632, 424, 1307, 647, 439, 
       1318, 662, 454, 1331, 677, 469}], 
      Line3DBox[{271, 484, 1129, 272, 498, 1139, 290, 513, 1149, 305, 528, 
       1157, 320, 1254, 543, 335, 1264, 558, 350, 1276, 573, 1183, 365, 588, 
       1196, 380, 603, 1206, 395, 618, 1214, 410, 633, 425, 1308, 648, 440, 
       1319, 663, 455, 1332, 678, 470}], 
      Line3DBox[{273, 485, 1130, 274, 499, 1140, 291, 514, 1150, 306, 529, 
       1158, 321, 544, 1164, 336, 1265, 559, 351, 1277, 574, 1184, 366, 589, 
       1197, 381, 604, 1207, 396, 619, 1215, 411, 634, 1221, 426, 649, 441, 
       1320, 664, 456, 1333, 679, 471}], 
      Line3DBox[{275, 486, 1131, 276, 500, 1141, 292, 515, 1151, 307, 530, 
       1159, 322, 545, 1165, 337, 560, 1169, 352, 1278, 575, 1185, 367, 590, 
       1198, 382, 605, 1208, 397, 620, 1216, 412, 635, 1222, 427, 650, 1226, 
       442, 665, 457, 1334, 680, 472}], 
      Line3DBox[{277, 682, 1336, 683, 278, 501, 1142, 293, 516, 1152, 308, 
       531, 1160, 323, 546, 1166, 338, 561, 1170, 353, 576, 1186, 1187, 368, 
       591, 1199, 383, 606, 1209, 398, 621, 1217, 413, 636, 1223, 428, 651, 
       1227, 443, 666, 1229, 458, 1335, 685, 686, 687}], 
      Line3DBox[{459, 667, 684, 1321, 444, 652, 1309, 429, 637, 1299, 414, 
       622, 1291, 399, 607, 1285, 384, 592, 1281, 369, 577, 1279, 354, 1171, 
       562, 1266, 339, 547, 1255, 324, 532, 1246, 309, 517, 1239, 294, 502, 
       1234, 279, 487, 1231, 250, 473, 681, 688}], 
      Line3DBox[{466, 674, 1328, 451, 659, 1315, 436, 644, 1304, 421, 629, 
       1295, 406, 614, 1288, 391, 599, 1283, 376, 584, 1280, 361, 1179, 569, 
       1272, 346, 554, 1260, 331, 539, 1250, 316, 524, 1242, 301, 509, 1236, 
       286, 494, 1232, 264, 480, 1230, 262}]}, {}, {}}},
   VertexNormals->CompressedData["
1:eJztyLEJgDAARcGP4iDZws4dHEGwzgqO7AipIhjIBveaB1euet5Lkn1L1nw9
/78H55xzzjnnnHPOOeecc86nPsQ555xzzjnnnHPOOeecc84555xzzjnnnHPO
Oeecc84555xzzjnnnHPOOeecc84555xzzjnnnHPOOeecc84557x7A52TKJ0=

    "]],
  Axes->True,
  BoxRatios->{1, 1, 0.4},
  ImageSize->{360., 291.3450937723248},
  Method->{"RotationControl" -> "Globe"},
  PlotRange->{{0, 2}, {0, 5}, {-1., 1.}},
  PlotRangePadding->{
    Scaled[0.02], 
    Scaled[0.02], 
    Scaled[0.02]},
  ViewPoint->{-1.8329664417294735`, 2.4812434812303574`, -1.390562767495753},
  ViewVertical->{0., 0., -1.}]], "Text",
 CellChangeTimes->{{3.562409841728221*^9, 3.562409846358501*^9}}]
}, Closed]],

Cell[CellGroupData[{

Cell["Part III ", "Text",
 CellChangeTimes->{{3.562410978615988*^9, 3.562410985771182*^9}, 
   3.5624110868010187`*^9, 3.562411536510008*^9},
 FontSize->36,
 FontColor->RGBColor[0, 0, 1],
 Background->RGBColor[1, 0.9, 0.8]],

Cell["\<\
As the original problem in physically unfeasable, here is the 
Trick suggested by  Paul Abbott:  
T[x,0]\[Equal] If[x>0,0,1].
We notice that the solution offered by NDSolve (Version 8.0.4)
is only partially correct.\
\>", "Text",
 CellChangeTimes->{{3.562411658844138*^9, 3.562411775111085*^9}, {
  3.5624119352359667`*^9, 3.562411984022476*^9}, {3.5744874191321545`*^9, 
  3.5744874204442296`*^9}},
 FontSize->24,
 Background->GrayLevel[0.85]],

Cell[BoxData[
 RowBox[{"Timing", "[", 
  RowBox[{"sol2", " ", "=", "  ", 
   RowBox[{"NDSolve", "[", "\[IndentingNewLine]", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        RowBox[{
         SubscriptBox["\[PartialD]", "t"], " ", 
         RowBox[{"T", "[", 
          RowBox[{"x", ",", "t"}], "]"}]}], "\[Equal]", " ", 
        RowBox[{
         SubscriptBox["\[PartialD]", 
          RowBox[{"x", ",", "x"}]], 
         RowBox[{"T", "[", 
          RowBox[{"x", ",", "t"}], "]"}]}]}], " ", ",", "\[IndentingNewLine]", 
       RowBox[{
        RowBox[{"T", "[", 
         RowBox[{"x", ",", "0"}], "]"}], "\[Equal]", " ", 
        StyleBox[
         RowBox[{"If", "[", 
          RowBox[{
           RowBox[{"x", ">", "0"}], ",", "0", ",", "1"}], "]"}],
         FontColor->RGBColor[1, 0, 0]]}], ",", "\[IndentingNewLine]", 
       RowBox[{
        RowBox[{"T", "[", 
         RowBox[{"0", ",", "t"}], "]"}], "\[Equal]", "1"}], ",", 
       "\[IndentingNewLine]", " ", 
       RowBox[{
        RowBox[{
         RowBox[{
          RowBox[{"Derivative", "[", 
           RowBox[{"1", ",", "0"}], "]"}], "[", "T", "]"}], "[", 
         RowBox[{"xmax", ",", "t"}], "]"}], "\[Equal]", "0"}]}], "}"}], ",", 
     "\[IndentingNewLine]", 
     RowBox[{"T", "[", 
      RowBox[{"x", ",", "t"}], "]"}], ",", 
     RowBox[{"{", 
      RowBox[{"x", ",", "0", ",", "xmax"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"t", ",", "0", ",", "tmax"}], "}"}]}], "]"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.562328426953515*^9, 3.56232843770173*^9}},
 FontSize->24],

Cell[BoxData[
 RowBox[{"Plot3D", "[", 
  RowBox[{
   RowBox[{"Evaluate", "[", 
    RowBox[{
     RowBox[{"T", "[", 
      RowBox[{"x", ",", "t"}], "]"}], " ", "/.", " ", "sol2"}], "]"}], ",", 
   RowBox[{"{", 
    RowBox[{"x", ",", "0", ",", "xmax"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"t", ",", "0", ",", "tmax"}], "}"}]}], "]"}]], "Input",
 CellChangeTimes->{
  3.432297612796875*^9, {3.5623284607210083`*^9, 3.5623284982811728`*^9}},
 FontSize->24]
}, Closed]],

Cell[CellGroupData[{

Cell["Part IV ", "Text",
 CellChangeTimes->{{3.562410978615988*^9, 3.562410985771182*^9}, 
   3.5624110868010187`*^9, 3.562411536510008*^9, {3.5624120182689533`*^9, 
   3.562412019094137*^9}},
 FontSize->36,
 FontColor->RGBColor[0, 0, 1],
 Background->RGBColor[1, 0.9, 0.8]],

Cell[TextData[{
 StyleBox["We smooth the discontinuity by introducing a smooth\nfunction, \
e.g.:\n \n                        ",
  FontSize->24],
 Cell[BoxData[
  StyleBox[
   RowBox[{
    FractionBox["1", "1048576"], 
    RowBox[{
     RowBox[{"(", 
      RowBox[{"x", "-", "2"}], ")"}], "^", "20"}]}],
   FontColor->RGBColor[1, 0, 0]]],
  FontSize->24,
  FontWeight->"Bold",
  FontColor->RGBColor[0, 1, 0]],
 StyleBox["\n\nIn fact:",
  FontSize->24]
}], "Text",
 CellChangeTimes->{{3.432363186703125*^9, 3.432363200859375*^9}, {
  3.56232858727839*^9, 3.5623286790644712`*^9}, {3.562412027634018*^9, 
  3.562412028355917*^9}, {3.5744874570843253`*^9, 3.5744874941494455`*^9}},
 FontSize->14,
 Background->GrayLevel[0.85]],

Cell[BoxData[
 RowBox[{
  RowBox[{"fun", "[", "x_", "]"}], ":=", " ", 
  StyleBox[
   RowBox[{
    FractionBox["1", "1048576"], 
    RowBox[{
     RowBox[{"(", 
      RowBox[{"x", "-", "2"}], ")"}], "^", "20"}]}],
   FontColor->RGBColor[1, 0, 0]]}]], "Input",
 CellChangeTimes->{{3.56241208102992*^9, 3.562412096779806*^9}},
 FontSize->18],

Cell[BoxData[
 RowBox[{"Plot", "[", 
  RowBox[{
   StyleBox[
    RowBox[{"fun", "[", "x", "]"}],
    FontColor->RGBColor[1, 0, 0]], ",", 
   RowBox[{"{", 
    RowBox[{"x", ",", "0", ",", "xmax"}], "}"}], ",", 
   RowBox[{"PlotRange", "\[Rule]", "All"}]}], "]"}]], "Input",
 CellChangeTimes->{
  3.432297622046875*^9, 3.432363216453125*^9, {3.562412103841061*^9, 
   3.56241210625804*^9}},
 FontSize->16],

Cell[BoxData[
 RowBox[{"Timing", "[", 
  RowBox[{"sol3", " ", "=", "  ", 
   RowBox[{"NDSolve", "[", "\[IndentingNewLine]", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        RowBox[{
         SubscriptBox["\[PartialD]", "t"], " ", 
         RowBox[{"T", "[", 
          RowBox[{"x", ",", "t"}], "]"}]}], "\[Equal]", " ", 
        RowBox[{
         SubscriptBox["\[PartialD]", 
          RowBox[{"x", ",", "x"}]], 
         RowBox[{"T", "[", 
          RowBox[{"x", ",", "t"}], "]"}]}]}], " ", ",", "\[IndentingNewLine]", 
       RowBox[{
        RowBox[{"T", "[", 
         RowBox[{"x", ",", "0"}], "]"}], "\[Equal]", 
        RowBox[{"fun", "[", "x", "]"}]}], 
       StyleBox[" ",
        FontColor->RGBColor[1, 0, 0]], ",", "\[IndentingNewLine]", 
       RowBox[{
        RowBox[{"T", "[", 
         RowBox[{"0", ",", "t"}], "]"}], "\[Equal]", "1"}], ",", 
       "\[IndentingNewLine]", " ", 
       RowBox[{
        RowBox[{
         RowBox[{
          RowBox[{"Derivative", "[", 
           RowBox[{"1", ",", "0"}], "]"}], "[", "T", "]"}], "[", 
         RowBox[{"xmax", ",", "t"}], "]"}], "\[Equal]", "0"}]}], "}"}], ",", 
     "\[IndentingNewLine]", 
     RowBox[{"T", "[", 
      RowBox[{"x", ",", "t"}], "]"}], ",", 
     RowBox[{"{", 
      RowBox[{"x", ",", "0", ",", "xmax"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"t", ",", "0", ",", "tmax"}], "}"}]}], "]"}]}], "]"}]], "Input",
 CellChangeTimes->{
  3.432363177921875*^9, {3.562328699370105*^9, 3.5623287123745317`*^9}, {
   3.562412113206788*^9, 3.562412116148471*^9}},
 FontSize->24],

Cell[BoxData[
 RowBox[{"sol3", "/.", " ", 
  RowBox[{"{", 
   RowBox[{
    RowBox[{"x", "\[Rule]", "2"}], ",", 
    RowBox[{"t", "->", "10"}]}], "}"}]}]], "Input",
 CellChangeTimes->{{3.432361386171875*^9, 3.432361435046875*^9}, {
  3.43236157621875*^9, 3.43236163559375*^9}, {3.432361746125*^9, 
  3.432361748734375*^9}, {3.562328718264624*^9, 3.56232872930359*^9}}],

Cell[BoxData[
 RowBox[{"Plot3D", "[", 
  RowBox[{
   RowBox[{"Evaluate", "[", 
    RowBox[{
     RowBox[{"T", "[", 
      RowBox[{"x", ",", "t"}], "]"}], " ", "/.", " ", "sol3"}], "]"}], ",", 
   "  ", "\[IndentingNewLine]", "                                ", 
   RowBox[{"{", 
    RowBox[{"x", ",", "0", ",", "xmax"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"t", ",", "0", ",", "tmax"}], "}"}], ",", " ", 
   RowBox[{"PlotPoints", "\[Rule]", "50"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.432297631734375*^9, 3.432297631953125*^9}, {
  3.562328770394835*^9, 3.56232877793011*^9}, {3.562328835593*^9, 
  3.562328878378234*^9}},
 FontSize->24],

Cell["\<\
Even if we use a grid to represent better the nodes near the origin
where the gradient is higher, we do not notice (by eye) an
improvement.\
\>", "Text",
 CellChangeTimes->{{3.432362452515625*^9, 3.4323625264375*^9}, {
  3.562412158923624*^9, 3.562412160490308*^9}, {3.56241221605464*^9, 
  3.562412264829258*^9}, {3.5624123278531437`*^9, 3.562412358269404*^9}},
 FontSize->24,
 Background->GrayLevel[0.85]],

Cell[BoxData[
 RowBox[{"grid", "=", " ", 
  RowBox[{"Join", "[", 
   RowBox[{
    RowBox[{"{", "x", "}"}], ",", 
    RowBox[{"Range", "[", 
     RowBox[{"0.", ",", 
      RowBox[{
       RowBox[{"xmax", "/", "5"}], " ", "-", 
       RowBox[{"xmax", "/", "600"}]}], ",", 
      RowBox[{"xmax", "/", "600"}]}], "]"}], ",", "\[IndentingNewLine]", 
    "                                ", 
    RowBox[{"Range", "[", 
     RowBox[{
      RowBox[{"xmax", "/", "5"}], ",", " ", "xmax", ",", 
      RowBox[{"xmax", "/", "40"}]}], "]"}]}], "]"}]}]], "Input",
 CellChangeTimes->{{3.4323626144375*^9, 3.4323626148125*^9}, {
  3.562412586204145*^9, 3.562412588025504*^9}},
 FontSize->24],

Cell[BoxData[
 RowBox[{
  RowBox[{"ListPlot", "[", 
   RowBox[{"Drop", "[", 
    RowBox[{"grid", ",", "1"}], "]"}], "]"}], "      ", 
  RowBox[{"(*", " ", 
   RowBox[{"to", " ", 
    StyleBox["eliminate",
     FontColor->RGBColor[1, 0, 0]], 
    StyleBox[" ",
     FontColor->RGBColor[1, 0, 0]], 
    StyleBox["the",
     FontColor->RGBColor[1, 0, 0]], 
    StyleBox[" ",
     FontColor->RGBColor[1, 0, 0]], 
    StyleBox["x",
     FontColor->RGBColor[1, 0, 0]], " ", "in", " ", "the", " ", "above", " ", 
    "list", " ", "1"}], " ", "*)"}]}]], "Input",
 CellChangeTimes->{
  3.43229764090625*^9, {3.432362316046875*^9, 3.43236232934375*^9}, {
   3.432362368984375*^9, 3.432362395140625*^9}, {3.562412175781897*^9, 
   3.562412177301594*^9}, {3.562412367821539*^9, 3.562412396164542*^9}, {
   3.57448754021708*^9, 3.5744875405741005`*^9}},
 FontSize->24],

Cell[BoxData[
 RowBox[{"Timing", "[", 
  RowBox[{"sol4", " ", "=", "  ", 
   RowBox[{"NDSolve", "[", "\[IndentingNewLine]", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        RowBox[{
         SubscriptBox["\[PartialD]", "t"], " ", 
         RowBox[{"T", "[", 
          RowBox[{"x", ",", "t"}], "]"}]}], "\[Equal]", " ", 
        RowBox[{
         SubscriptBox["\[PartialD]", 
          RowBox[{"x", ",", "x"}]], 
         RowBox[{"T", "[", 
          RowBox[{"x", ",", "t"}], "]"}]}]}], " ", ",", "\[IndentingNewLine]", 
       RowBox[{
        RowBox[{"T", "[", 
         RowBox[{"x", ",", "0"}], "]"}], "\[Equal]", 
        StyleBox[
         RowBox[{
          FractionBox["1", "1048576"], 
          RowBox[{
           RowBox[{"(", 
            RowBox[{"x", "-", "2"}], ")"}], "^", "20"}]}],
         FontColor->RGBColor[1, 0, 0]]}], 
       StyleBox[" ",
        FontColor->RGBColor[1, 0, 0]], ",", "\[IndentingNewLine]", 
       RowBox[{
        RowBox[{"T", "[", 
         RowBox[{"0", ",", "t"}], "]"}], "\[Equal]", "1"}], ",", 
       "\[IndentingNewLine]", " ", 
       RowBox[{
        RowBox[{
         RowBox[{
          RowBox[{"Derivative", "[", 
           RowBox[{"1", ",", "0"}], "]"}], "[", "T", "]"}], "[", 
         RowBox[{"xmax", ",", "t"}], "]"}], "\[Equal]", "0"}]}], "}"}], ",", 
     "\[IndentingNewLine]", 
     RowBox[{"T", "[", 
      RowBox[{"x", ",", "t"}], "]"}], ",", "grid", ",", 
     RowBox[{"{", 
      RowBox[{"t", ",", "0", ",", "tmax"}], "}"}]}], "]"}]}], "]"}]], "Input",
 CellChangeTimes->{
  3.43236312371875*^9, {3.562386808238887*^9, 3.562386819667313*^9}, 
   3.5623868528501167`*^9, {3.562412280451754*^9, 3.562412282159609*^9}},
 FontSize->24],

Cell[BoxData[
 RowBox[{"Plot3D", "[", 
  RowBox[{
   RowBox[{"Evaluate", "[", 
    RowBox[{
     RowBox[{"T", "[", 
      RowBox[{"x", ",", "t"}], "]"}], " ", "/.", 
     StyleBox[" ",
      FontColor->RGBColor[1, 0, 1]], "sol4"}], "]"}], ",", 
   "\[IndentingNewLine]", "                                ", 
   RowBox[{"{", 
    RowBox[{"x", ",", "0", ",", "xmax"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"t", ",", "0", ",", "tmax"}], "}"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.43229767921875*^9, 3.432297679796875*^9}, {
  3.56238685999695*^9, 3.562386868966709*^9}},
 FontSize->24]
}, Closed]],

Cell[CellGroupData[{

Cell["Part V ", "Text",
 CellChangeTimes->{{3.562410978615988*^9, 3.562410985771182*^9}, 
   3.5624110868010187`*^9, 3.562411536510008*^9, {3.5624120182689533`*^9, 
   3.562412019094137*^9}, 3.5624736029483967`*^9},
 FontSize->36,
 FontColor->RGBColor[0, 0, 1],
 Background->RGBColor[1, 0.9, 0.8]],

Cell["\<\
We introduce, with and without the Abbott\[CloseCurlyQuote]s trick, some \
options in NDSolve.
 The results have to be compared with those result
equivalent to that obtained in part I and Part III, respectively.
We conclude that the problem of inconsistency has to be considered carefully \
case by case.\
\>", "Text",
 CellChangeTimes->{{3.43236145353125*^9, 3.432361502828125*^9}, {
  3.562412920269644*^9, 3.562412985171072*^9}, {3.562413177819916*^9, 
  3.562413235327396*^9}, {3.56241331402498*^9, 3.5624133882607737`*^9}, {
  3.5744875673886347`*^9, 3.5744875944921846`*^9}},
 FontSize->24,
 Background->GrayLevel[0.85]],

Cell[BoxData[
 RowBox[{"kodmet", "=", "1"}]], "Input",
 CellChangeTimes->{{3.562412782957952*^9, 3.56241278536825*^9}},
 FontSize->18],

Cell[BoxData[
 RowBox[{"Timing", "[", 
  RowBox[{"numsol1", "=", 
   RowBox[{"NDSolve", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        RowBox[{
         SubscriptBox["\[PartialD]", "t"], " ", 
         RowBox[{"T", "[", 
          RowBox[{"x", ",", "t"}], "]"}]}], "\[Equal]", " ", 
        RowBox[{
         SubscriptBox["\[PartialD]", 
          RowBox[{"x", ",", "x"}]], 
         RowBox[{"T", "[", 
          RowBox[{"x", ",", "t"}], "]"}]}]}], " ", ",", "\[IndentingNewLine]", 
       RowBox[{
        RowBox[{"T", "[", 
         RowBox[{"x", ",", "0"}], "]"}], "\[Equal]", " ", 
        StyleBox["0",
         FontColor->RGBColor[1, 0, 0]]}], ",", "\[IndentingNewLine]", 
       RowBox[{
        RowBox[{"T", "[", 
         RowBox[{"0", ",", "t"}], "]"}], "\[Equal]", "1"}], ",", 
       "\[IndentingNewLine]", " ", 
       RowBox[{
        RowBox[{
         RowBox[{
          RowBox[{"Derivative", "[", 
           RowBox[{"1", ",", "0"}], "]"}], "[", "T", "]"}], "[", 
         RowBox[{"xmax", ",", "t"}], "]"}], "\[Equal]", "0"}]}], "}"}], ",", 
     "\[IndentingNewLine]", 
     RowBox[{"T", "[", 
      RowBox[{"x", ",", "t"}], "]"}], ",", 
     RowBox[{"{", 
      RowBox[{"x", ",", "0", ",", "xmax"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"t", ",", "0", ",", "tmax"}], "}"}], ",", 
     RowBox[{"PrecisionGoal", "\[Rule]", "8"}], ",", 
     RowBox[{"AccuracyGoal", "\[Rule]", "6"}], ",", 
     RowBox[{"MaxSteps", "\[Rule]", "Infinity"}], ",", 
     RowBox[{"Method", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{"\"\<MethodOfLines\>\"", ",", 
        RowBox[{"If", "[", 
         RowBox[{
          RowBox[{"kodmet", "\[Equal]", "1"}], ",", 
          RowBox[{"Method", "\[Rule]", "StiffnessSwitching"}], ",", 
          RowBox[{"{", "}"}]}], "]"}], ",", 
        RowBox[{"\"\<SpatialDiscretization\>\"", "\[Rule]", 
         RowBox[{"{", 
          RowBox[{"\"\<TensorProductGrid\>\"", ",", 
           RowBox[{"DifferenceOrder", "\[Rule]", "6"}], ",", 
           RowBox[{"\"\<MinPoints\>\"", "\[Rule]", "1000"}]}], "}"}]}]}], 
       "}"}]}]}], "]"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.56233514166324*^9, 3.562335141665347*^9}, {
   3.562335224248621*^9, 3.562335275290904*^9}, {3.562335725053763*^9, 
   3.5623357390860167`*^9}, {3.562335988127739*^9, 3.562335990935549*^9}, 
   3.56233626956417*^9, 3.562336359040451*^9, 3.5623363975658827`*^9, {
   3.562387208425746*^9, 3.562387216521965*^9}, {3.5624127677306557`*^9, 
   3.5624127685779057`*^9}, {3.562413017473525*^9, 3.56241302163964*^9}, {
   3.562413262990995*^9, 3.5624132634501047`*^9}},
 FontSize->16],

Cell[BoxData[
 RowBox[{"Plot3D", "[", 
  RowBox[{
   RowBox[{"Evaluate", "[", 
    RowBox[{
     RowBox[{"T", "[", 
      RowBox[{"x", ",", "t"}], "]"}], "/.", "numsol1"}], "]"}], ",", 
   RowBox[{"{", 
    RowBox[{"x", ",", "0", ",", "2"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"t", ",", "0", ",", "tmax"}], "}"}], ",", 
   RowBox[{"PlotRange", "\[Rule]", "All"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.562335340970544*^9, 3.5623354091139393`*^9}, 
   3.562336008914845*^9, {3.562336143802618*^9, 3.5623361512057877`*^9}, {
   3.562336223638405*^9, 3.5623362467494793`*^9}, {3.562336434294126*^9, 
   3.562336435416767*^9}, {3.562336502573344*^9, 3.5623365035881433`*^9}, {
   3.56238725709818*^9, 3.5623872587131023`*^9}, {3.562412815487645*^9, 
   3.562412819315022*^9}, 3.562413039251382*^9, {3.562413268575859*^9, 
   3.562413269147355*^9}}],

Cell[BoxData[
 RowBox[{"Timing", "[", 
  RowBox[{"numsol2", "=", 
   RowBox[{"NDSolve", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        RowBox[{
         SubscriptBox["\[PartialD]", "t"], " ", 
         RowBox[{"T", "[", 
          RowBox[{"x", ",", "t"}], "]"}]}], "\[Equal]", " ", 
        RowBox[{
         SubscriptBox["\[PartialD]", 
          RowBox[{"x", ",", "x"}]], 
         RowBox[{"T", "[", 
          RowBox[{"x", ",", "t"}], "]"}]}]}], " ", ",", "\[IndentingNewLine]", 
       RowBox[{
        RowBox[{"T", "[", 
         RowBox[{"x", ",", "0"}], "]"}], "\[Equal]", " ", 
        StyleBox[
         RowBox[{"If", "[", 
          RowBox[{
           RowBox[{"x", ">", "0"}], ",", "0", ",", "1"}], "]"}],
         FontColor->RGBColor[1, 0, 0]]}], ",", "\[IndentingNewLine]", 
       RowBox[{
        RowBox[{"T", "[", 
         RowBox[{"0", ",", "t"}], "]"}], "\[Equal]", "1"}], ",", 
       "\[IndentingNewLine]", " ", 
       RowBox[{
        RowBox[{
         RowBox[{
          RowBox[{"Derivative", "[", 
           RowBox[{"1", ",", "0"}], "]"}], "[", "T", "]"}], "[", 
         RowBox[{"xmax", ",", "t"}], "]"}], "\[Equal]", "0"}]}], "}"}], ",", 
     "\[IndentingNewLine]", 
     RowBox[{"T", "[", 
      RowBox[{"x", ",", "t"}], "]"}], ",", 
     RowBox[{"{", 
      RowBox[{"x", ",", "0", ",", "xmax"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"t", ",", "0", ",", "tmax"}], "}"}], ",", 
     RowBox[{"PrecisionGoal", "\[Rule]", "8"}], ",", 
     RowBox[{"AccuracyGoal", "\[Rule]", "6"}], ",", 
     RowBox[{"MaxSteps", "\[Rule]", "Infinity"}], ",", 
     RowBox[{"Method", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{"\"\<MethodOfLines\>\"", ",", 
        RowBox[{"If", "[", 
         RowBox[{
          RowBox[{"kodmet", "\[Equal]", "1"}], ",", 
          RowBox[{"Method", "\[Rule]", "StiffnessSwitching"}], ",", 
          RowBox[{"{", "}"}]}], "]"}], ",", 
        RowBox[{"\"\<SpatialDiscretization\>\"", "\[Rule]", 
         RowBox[{"{", 
          RowBox[{"\"\<TensorProductGrid\>\"", ",", 
           RowBox[{"DifferenceOrder", "\[Rule]", "6"}], ",", 
           RowBox[{"\"\<MinPoints\>\"", "\[Rule]", "1000"}]}], "}"}]}]}], 
       "}"}]}]}], "]"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.56233514166324*^9, 3.562335141665347*^9}, {
   3.562335224248621*^9, 3.562335275290904*^9}, {3.562335725053763*^9, 
   3.5623357390860167`*^9}, {3.562335988127739*^9, 3.562335990935549*^9}, 
   3.56233626956417*^9, 3.562336359040451*^9, 3.5623363975658827`*^9, {
   3.562387208425746*^9, 3.562387216521965*^9}, {3.5624127677306557`*^9, 
   3.5624127685779057`*^9}, 3.5624132740379763`*^9},
 FontSize->16],

Cell[BoxData[
 RowBox[{"Plot3D", "[", 
  RowBox[{
   RowBox[{"Evaluate", "[", 
    RowBox[{
     RowBox[{"T", "[", 
      RowBox[{"x", ",", "t"}], "]"}], "/.", "numsol2"}], "]"}], ",", 
   RowBox[{"{", 
    RowBox[{"x", ",", "0", ",", "2"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"t", ",", "0", ",", "tmax"}], "}"}], ",", 
   RowBox[{"PlotRange", "\[Rule]", "All"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.562335340970544*^9, 3.5623354091139393`*^9}, 
   3.562336008914845*^9, {3.562336143802618*^9, 3.5623361512057877`*^9}, {
   3.562336223638405*^9, 3.5623362467494793`*^9}, {3.562336434294126*^9, 
   3.562336435416767*^9}, {3.562336502573344*^9, 3.5623365035881433`*^9}, {
   3.56238725709818*^9, 3.5623872587131023`*^9}, {3.562412815487645*^9, 
   3.562412819315022*^9}, 3.5624132773183527`*^9}]
}, Closed]],

Cell[CellGroupData[{

Cell["Part VI", "Text",
 CellChangeTimes->{{3.562410978615988*^9, 3.562410985771182*^9}, 
   3.5624110868010187`*^9, 3.562411536510008*^9, {3.5624120182689533`*^9, 
   3.562412019094137*^9}, {3.562413590522455*^9, 3.562413594248151*^9}, 
   3.5624736902299223`*^9, {3.5744857497406707`*^9, 3.5744857537398996`*^9}, 
   3.574487194780322*^9, {3.574487229379301*^9, 3.574487231139402*^9}, 
   3.5744876690604496`*^9},
 FontSize->36,
 FontColor->RGBColor[0, 0, 1],
 Background->RGBColor[1, 0.9, 0.8]],

Cell["\<\
It is interesting to remark that even when a realistic silicon rod, with 
appropriate coefficients, is considered,  the message cannot be overlooked. \
It is interesting to
underline the small value of \[Alpha] of silicon... \
\>", "Text",
 CellChangeTimes->{{3.43236145353125*^9, 3.432361502828125*^9}, {
  3.562412920269644*^9, 3.562412985171072*^9}, {3.562413177819916*^9, 
  3.562413235327396*^9}, {3.56241331402498*^9, 3.5624133882607737`*^9}, {
  3.562413626020153*^9, 3.562413640677326*^9}, {3.562413731474312*^9, 
  3.5624137820211487`*^9}, {3.5624138136245537`*^9, 3.562413830237064*^9}, {
  3.5744871459475293`*^9, 3.574487147299607*^9}, {3.5744876361005645`*^9, 
  3.5744876569797587`*^9}},
 FontSize->24,
 Background->GrayLevel[0.85]],

Cell[BoxData[
 RowBox[{
  RowBox[{"\[Rho]Si", " ", "=", " ", "2359"}], ";", "   ", 
  RowBox[{"kSi", " ", "=", " ", "156"}], ";", "   ", 
  RowBox[{"cvSi", " ", "=", " ", "713"}], ";"}]], "Input",
 CellChangeTimes->{{3.562329082876912*^9, 3.5623291289241734`*^9}},
 FontSize->16],

Cell[BoxData[
 RowBox[{"\[Alpha]Si", "=", " ", 
  RowBox[{
   RowBox[{"0.01", "*", 
    RowBox[{"kSi", "/", 
     RowBox[{"(", 
      RowBox[{"\[Rho]Si", " ", "cvSi"}], ")"}]}]}], " ", "//", 
   "N"}]}]], "Input",
 CellChangeTimes->{{3.5623291486136847`*^9, 3.562329195712062*^9}, {
  3.5623293653302097`*^9, 3.562329387200379*^9}}],

Cell[BoxData["tmax"], "Input",
 CellChangeTimes->{{3.562387057907617*^9, 3.562387066039235*^9}}],

Cell[BoxData[
 RowBox[{"Timing", "[", 
  RowBox[{"sol6", " ", "=", "  ", 
   RowBox[{"NDSolve", "[", "\[IndentingNewLine]", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        RowBox[{
         SubscriptBox["\[PartialD]", "t"], " ", 
         RowBox[{"T", "[", 
          RowBox[{"x", ",", "t"}], "]"}]}], "\[Equal]", " ", 
        RowBox[{"\[Alpha]Si", " ", 
         RowBox[{
          SubscriptBox["\[PartialD]", 
           RowBox[{"x", ",", "x"}]], 
          RowBox[{"T", "[", 
           RowBox[{"x", ",", "t"}], "]"}]}]}]}], " ", ",", 
       "\[IndentingNewLine]", 
       RowBox[{
        RowBox[{"T", "[", 
         RowBox[{"x", ",", "0"}], "]"}], "\[Equal]", 
        StyleBox[
         RowBox[{
          FractionBox["1", "1048576"], 
          RowBox[{
           RowBox[{"(", 
            RowBox[{"x", "-", "2"}], ")"}], "^", "20"}]}],
         FontColor->RGBColor[1, 0, 0]]}], 
       StyleBox[" ",
        FontColor->RGBColor[1, 0, 0]], ",", "\[IndentingNewLine]", 
       RowBox[{
        RowBox[{"T", "[", 
         RowBox[{"0", ",", "t"}], "]"}], "\[Equal]", "1"}], ",", 
       "\[IndentingNewLine]", " ", 
       RowBox[{
        RowBox[{
         RowBox[{
          RowBox[{"Derivative", "[", 
           RowBox[{"1", ",", "0"}], "]"}], "[", "T", "]"}], "[", 
         RowBox[{"xmax", ",", "t"}], "]"}], "\[Equal]", "0"}]}], "}"}], ",", 
     "\[IndentingNewLine]", 
     RowBox[{"T", "[", 
      RowBox[{"x", ",", "t"}], "]"}], ",", "grid", ",", 
     RowBox[{"{", 
      RowBox[{"t", ",", "0", ",", "tmax"}], "}"}]}], "]"}]}], "]"}]], "Input",
 CellChangeTimes->{
  3.432362627875*^9, 3.432363116109375*^9, {3.562329222833213*^9, 
   3.562329233337311*^9}, {3.5623869937738132`*^9, 3.5623870061885*^9}, {
   3.562413559218567*^9, 3.562413560904895*^9}},
 FontSize->24],

Cell[BoxData[
 RowBox[{
  RowBox[{"Plot3D", "[", 
   RowBox[{
    RowBox[{"Evaluate", "[", 
     RowBox[{
      RowBox[{"T", "[", 
       RowBox[{"x", ",", "t"}], "]"}], " ", "/.", " ", "sol6"}], "]"}], ",", 
    "\[IndentingNewLine]", "                                  ", 
    RowBox[{"{", 
     RowBox[{"x", ",", "0", ",", "xmax"}], "}"}], ",", 
    RowBox[{"{", 
     RowBox[{"t", ",", "0", ",", "tmax"}], "}"}], ",", 
    RowBox[{"PlotRange", "\[Rule]", "All"}]}], "]"}], " "}]], "Input",
 CellChangeTimes->{
  3.432297696578125*^9, {3.562329264072742*^9, 3.5623292797911053`*^9}, {
   3.56238709545781*^9, 3.562387103795713*^9}},
 FontSize->24],

Cell[BoxData[
 RowBox[{"Timing", "[", 
  RowBox[{"sol7", " ", "=", "  ", 
   RowBox[{"NDSolve", "[", "\[IndentingNewLine]", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        RowBox[{
         SubscriptBox["\[PartialD]", "t"], " ", 
         RowBox[{"T", "[", 
          RowBox[{"x", ",", "t"}], "]"}]}], "\[Equal]", " ", 
        RowBox[{"\[Alpha]Si", " ", 
         RowBox[{
          SubscriptBox["\[PartialD]", 
           RowBox[{"x", ",", "x"}]], 
          RowBox[{"T", "[", 
           RowBox[{"x", ",", "t"}], "]"}]}]}]}], " ", ",", 
       "\[IndentingNewLine]", 
       RowBox[{
        RowBox[{"T", "[", 
         RowBox[{"x", ",", "0"}], "]"}], "\[Equal]", 
        StyleBox["0",
         FontColor->RGBColor[1, 0, 0]]}], 
       StyleBox[" ",
        FontColor->RGBColor[1, 0, 0]], ",", "\[IndentingNewLine]", 
       RowBox[{
        RowBox[{"T", "[", 
         RowBox[{"0", ",", "t"}], "]"}], "\[Equal]", "1"}], ",", 
       "\[IndentingNewLine]", " ", 
       RowBox[{
        RowBox[{
         RowBox[{
          RowBox[{"Derivative", "[", 
           RowBox[{"1", ",", "0"}], "]"}], "[", "T", "]"}], "[", 
         RowBox[{"xmax", ",", "t"}], "]"}], "\[Equal]", "0"}]}], "}"}], ",", 
     "\[IndentingNewLine]", 
     RowBox[{"T", "[", 
      RowBox[{"x", ",", "t"}], "]"}], ",", 
     RowBox[{"{", 
      RowBox[{"x", ",", "0", ",", "xmax"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"t", ",", "0", ",", "tmax"}], "}"}]}], "]"}]}], "]"}]], "Input",
 CellChangeTimes->{
  3.432362627875*^9, 3.432363116109375*^9, {3.562329222833213*^9, 
   3.562329233337311*^9}, {3.5623869937738132`*^9, 3.5623870061885*^9}, {
   3.562413559218567*^9, 3.562413560904895*^9}, {3.5624136691779613`*^9, 
   3.562413702036456*^9}},
 FontSize->24],

Cell[BoxData[
 RowBox[{
  RowBox[{"Plot3D", "[", 
   RowBox[{
    RowBox[{"Evaluate", "[", 
     RowBox[{
      RowBox[{"T", "[", 
       RowBox[{"x", ",", "t"}], "]"}], " ", "/.", " ", "sol7"}], "]"}], ",", 
    "\[IndentingNewLine]", "                                  ", 
    RowBox[{"{", 
     RowBox[{"x", ",", "0", ",", "xmax"}], "}"}], ",", 
    RowBox[{"{", 
     RowBox[{"t", ",", "0", ",", "tmax"}], "}"}], ",", 
    RowBox[{"PlotRange", "\[Rule]", "All"}]}], "]"}], " "}]], "Input",
 CellChangeTimes->{
  3.432297696578125*^9, {3.562329264072742*^9, 3.5623292797911053`*^9}, {
   3.56238709545781*^9, 3.562387103795713*^9}, {3.562413707637092*^9, 
   3.5624137090725727`*^9}},
 FontSize->24]
}, Closed]]
},
CellGrouping->Manual,
WindowSize->{1904, 946},
WindowMargins->{{0, Automatic}, {Automatic, 0}},
PrintingCopies->1,
PrintingPageRange->{Automatic, Automatic},
FrontEndVersion->"8.0 for Microsoft Windows (64-bit) (February 23, 2011)",
StyleDefinitions->"Default.nb"
]
(* End of Notebook Content *)

(* Internal cache information *)
(*CellTagsOutline
CellTagsIndex->{}
*)
(*CellTagsIndex
CellTagsIndex->{}
*)
(*NotebookFileOutline
Notebook[{
Cell[545, 20, 555, 12, 87, "Text"],
Cell[1103, 34, 4967, 97, 1410, "Text"],
Cell[CellGroupData[{
Cell[6095, 135, 171, 4, 71, "Text"],
Cell[6269, 141, 201, 5, 42, "Input"],
Cell[6473, 148, 257, 4, 31, "Input"],
Cell[6733, 154, 1181, 26, 33, "Input"],
Cell[7917, 182, 436, 12, 88, "Text"],
Cell[8356, 196, 171, 5, 42, "Input"],
Cell[8530, 203, 231, 6, 42, "Input"],
Cell[8764, 211, 282, 7, 42, "Input"],
Cell[9049, 220, 1662, 44, 213, "Input"],
Cell[10714, 266, 559, 16, 42, "Input"]
}, Open  ]],
Cell[CellGroupData[{
Cell[11310, 287, 200, 5, 71, "Text"],
Cell[11513, 294, 408, 10, 87, "Text"],
Cell[11924, 306, 396, 9, 42, "Text"],
Cell[12323, 317, 32968, 534, 228, "Text"]
}, Closed]],
Cell[CellGroupData[{
Cell[45328, 856, 223, 5, 68, "Text"],
Cell[45554, 863, 454, 11, 132, "Text"],
Cell[46011, 876, 1576, 43, 159, "Input"],
Cell[47590, 921, 459, 13, 31, "Input"]
}, Closed]],
Cell[CellGroupData[{
Cell[48086, 939, 274, 6, 68, "Text"],
Cell[48363, 947, 723, 22, 160, "Text"],
Cell[49089, 971, 339, 11, 45, "Input"],
Cell[49431, 984, 403, 12, 24, "Input"],
Cell[49837, 998, 1579, 43, 159, "Input"],
Cell[51419, 1043, 367, 8, 23, "Input"],
Cell[51789, 1053, 648, 16, 57, "Input"],
Cell[52440, 1071, 417, 9, 87, "Text"],
Cell[52860, 1082, 675, 18, 57, "Input"],
Cell[53538, 1102, 855, 23, 31, "Input"],
Cell[54396, 1127, 1716, 47, 234, "Input"],
Cell[56115, 1176, 592, 16, 57, "Input"]
}, Closed]],
Cell[CellGroupData[{
Cell[56744, 1197, 297, 6, 68, "Text"],
Cell[57044, 1205, 636, 13, 110, "Text"],
Cell[57683, 1220, 134, 3, 27, "Input"],
Cell[57820, 1225, 2629, 63, 111, "Input"],
Cell[60452, 1290, 854, 18, 23, "Input"],
Cell[61309, 1310, 2665, 65, 111, "Input"],
Cell[63977, 1377, 806, 17, 23, "Input"]
}, Closed]],
Cell[CellGroupData[{
Cell[64820, 1399, 497, 9, 68, "Text"],
Cell[65320, 1410, 756, 14, 87, "Text"],
Cell[66079, 1426, 279, 6, 24, "Input"],
Cell[66361, 1434, 332, 9, 23, "Input"],
Cell[66696, 1445, 96, 1, 23, "Input"],
Cell[66795, 1448, 1813, 50, 234, "Input"],
Cell[68611, 1500, 650, 17, 57, "Input"],
Cell[69264, 1519, 1771, 48, 159, "Input"],
Cell[71038, 1569, 702, 18, 57, "Input"]
}, Closed]]
}
]
*)

(* End of internal cache information *)
