(* Content-type: application/mathematica *)

(*** Wolfram Notebook File ***)
(* http://www.wolfram.com/nb *)

(* CreatedBy='Mathematica 7.0' *)

(*CacheID: 234*)
(* Internal cache information:
NotebookFileLineBreakTest
NotebookFileLineBreakTest
NotebookDataPosition[       145,          7]
NotebookDataLength[    424625,       8023]
NotebookOptionsPosition[    418167,       7848]
NotebookOutlinePosition[    418611,       7867]
CellTagsIndexPosition[    418568,       7864]
WindowFrame->Normal*)

(* Beginning of Notebook Content *)
Notebook[{
Cell["\<\
Evaluation time
\[CapitalDelta]t < 15 s\
\>", "Text",
 CellChangeTimes->{{3.551694552719824*^9, 3.551694572667306*^9}, {
  3.573983313081932*^9, 3.5739833137160883`*^9}, {3.5744932340776553`*^9, 
  3.5744932375078516`*^9}},
 FontSize->18,
 FontColor->RGBColor[0, 0, 1],
 Background->RGBColor[1, 0.9, 0.8]],

Cell[TextData[{
 "This notebook examines the following non homogeneous Fourier equation \n\
with ",
 StyleBox["homogeneous BCs of Dirichlet type",
  FontWeight->"Bold"],
 " (see section 4.2.1.4)\n \n",
 Cell[BoxData[{
  RowBox[{
   RowBox[{"k", " ", 
    RowBox[{
     SubscriptBox["U", 
      RowBox[{"x", "\[InvisibleComma]", "x"}]], "[", 
     RowBox[{"x", ",", "t"}], "]"}]}], "=", 
   RowBox[{
    RowBox[{"\[Rho]", " ", "c", " ", 
     RowBox[{
      SubscriptBox["U", "t"], "[", 
      RowBox[{"x", ",", "t"}], "]"}]}], "  ", "-", 
    RowBox[{
     RowBox[{"q", "[", 
      RowBox[{"x", ",", "t"}], "]"}], "               ", 
     RowBox[{"(", "1.1", ")"}]}]}]}], "\n", 
  RowBox[{
   RowBox[{"U", "[", 
    RowBox[{"0", ",", "t"}], "]"}], "=", 
   RowBox[{
    RowBox[{"U", "[", 
     RowBox[{"p", ",", "t"}], "]"}], "=", 
    RowBox[{
     RowBox[{"0", "        ", "t"}], "\[GreaterEqual]", 
     RowBox[{"0", "                         ", 
      RowBox[{"(", "1.2", ")"}]}]}]}]}], "\n", 
  RowBox[{
   RowBox[{"U", "[", 
    RowBox[{"x", ",", "0"}], "]"}], "=", 
   RowBox[{
    RowBox[{"0", "                    ", "0"}], "\[LessEqual]", "x", 
    "\[LessEqual]", 
    RowBox[{"p", "                     ", 
     RowBox[{"(", "1.3", ")"}]}]}]}], "\[IndentingNewLine]"}],
  FontFamily->"Times New Roman"],
 "\nwhere p, k, \[Rho] and c have the usual meaning.\n\nThe section rod is \
negligible with respect to its length p.\nThe units of the source ",
 Cell[BoxData[
  FormBox[
   RowBox[{"q", "[", 
    RowBox[{"x", ",", "t"}], "]"}], TraditionalForm]]],
 " are (",
 StyleBox["W",
  FontSlant->"Italic"],
 "/",
 StyleBox["m",
  FontSlant->"Italic"],
 ").\n\nIn Part I,  we summarize the main formulae described in the above \
cited section.\n\nIn Part II we define the caracteristics of the silicon rod.\
\n\nIn Part III we consider tha case  ",
 Cell[BoxData[
  FormBox[
   RowBox[{
    RowBox[{"q", "[", 
     RowBox[{"x", ",", "t"}], "]"}], "=", 
    RowBox[{
     RowBox[{"x", "(", 
      RowBox[{"p", "-", "x"}], ")"}], 
     RowBox[{"Cos", "[", 
      RowBox[{"2", "\[Pi]", " ", "f", " ", "t"}], "]"}]}]}], 
   TraditionalForm]], "None"],
 ",\n    symbolically in part III.1  and numerically in part III.2; \n    in \
part III.3 we examine the relative differences.   \n    \nWe invite the \
reader to check the section 4.2.1.5, where this notebook can offer\na good ",
 StyleBox["beginning",
  FontWeight->"Bold"],
 " for facing the case of a homogeneous PDE with ",
 StyleBox["non-homogeneous BCs\nof third type dependent on time",
  FontWeight->"Bold"],
 "."
}], "Text",
 CellChangeTimes->{{3.4921746780625*^9, 3.49217481878125*^9}, {
   3.4921749095625*^9, 3.49217498575*^9}, {3.49217502803125*^9, 
   3.492175076578125*^9}, {3.492175107703125*^9, 3.49217517828125*^9}, 
   3.492175265328125*^9, {3.4921753810625*^9, 3.492175437671875*^9}, {
   3.492176079078125*^9, 3.49217615596875*^9}, {3.49223369803125*^9, 
   3.492233766109375*^9}, {3.492233806890625*^9, 3.492233808765625*^9}, {
   3.492234776453125*^9, 3.492234780171875*^9}, {3.49223501709375*^9, 
   3.492235038015625*^9}, {3.492254034765625*^9, 3.492254038203125*^9}, {
   3.49225413125*^9, 3.4922541324375*^9}, {3.49225572415625*^9, 
   3.492255765015625*^9}, {3.4922559539375*^9, 3.4922559875625*^9}, {
   3.492256388203125*^9, 3.492256492125*^9}, {3.49225663409375*^9, 
   3.492256658078125*^9}, {3.49225680621875*^9, 3.4922568499375*^9}, {
   3.492256889140625*^9, 3.492256900921875*^9}, {3.493875638359375*^9, 
   3.493875664875*^9}, {3.574493304650692*^9, 3.574493307524856*^9}, {
   3.574493465396886*^9, 3.574493516205792*^9}, {3.57449362702013*^9, 
   3.57449371898039*^9}},
 TextJustification->0.,
 FontSize->16,
 FontColor->RGBColor[0, 0, 1],
 Background->RGBColor[1, 1, 0.85]],

Cell[BoxData[
 RowBox[{
  RowBox[{"Remove", "[", "\"\<Global`*\>\"", "]"}], ";", 
  RowBox[{"$Line", "=", "0"}], ";"}]], "Input",
 FontSize->16],

Cell[BoxData[
 RowBox[{"Date", "[", "]"}]], "Input",
 CellChangeTimes->{{3.551694373583191*^9, 3.5516943752568893`*^9}}],

Cell[BoxData[
 RowBox[{"<<", "\"\</home/MyDir/Book-Mathematica/TellName2.m\>\""}]], "Input",
 CellChangeTimes->{{3.551694327711035*^9, 3.5516943685431757`*^9}, {
  3.578549867648057*^9, 3.5785498729273586`*^9}}],

Cell[BoxData["$Version"], "Input",
 CellChangeTimes->{{3.507447892078125*^9, 3.507447894828125*^9}},
 FontSize->14],

Cell[BoxData[
 RowBox[{
  RowBox[{"SetOptions", "[", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"Plot", ",", "Plot3D"}], "}"}], ",", 
    RowBox[{"ImageSize", "\[Rule]", "500"}], ",", 
    RowBox[{"LabelStyle", "\[Rule]", 
     RowBox[{"(", 
      RowBox[{"FontFamily", "\[Rule]", "\"\<Helvetica\>\""}], ")"}]}], ",", 
    RowBox[{"AxesStyle", "\[Rule]", 
     RowBox[{"Directive", "[", 
      RowBox[{"20", ",", 
       RowBox[{"Thickness", "[", "0.005", "]"}], ",", "Blue"}], "]"}]}]}], 
   "]"}], ";"}]], "Input",
 CellChangeTimes->{{3.431404133265625*^9, 3.431404152625*^9}, {
   3.431404184828125*^9, 3.43140419784375*^9}, {3.431404229828125*^9, 
   3.431404286*^9}, {3.431404358734375*^9, 3.431404362015625*^9}, 
   3.43140449659375*^9, {3.431404585328125*^9, 3.431404586390625*^9}, {
   3.431404647765625*^9, 3.431404694953125*^9}, {3.43140617875*^9, 
   3.4314062495625*^9}, {3.431406282875*^9, 3.4314063513125*^9}, {
   3.43140679328125*^9, 3.43140680225*^9}, {3.4314068341875*^9, 
   3.431406876078125*^9}, {3.491650035328125*^9, 3.491650036578125*^9}, {
   3.491709218609375*^9, 3.49170923096875*^9}, {3.49190971265625*^9, 
   3.491909717109375*^9}, {3.492175595359375*^9, 3.49217559728125*^9}},
 FontSize->14,
 Background->GrayLevel[0.85]],

Cell[CellGroupData[{

Cell["Part I ", "Text",
 CellChangeTimes->{{3.44258518478125*^9, 3.44258519865625*^9}, {
   3.44258529084375*^9, 3.442585294265625*^9}, {3.44258532753125*^9, 
   3.442585334765625*^9}, {3.44942116988004*^9, 3.449421170320674*^9}, 
   3.4494864070941954`*^9, {3.4494865195759363`*^9, 3.4494865340868015`*^9}, {
   3.449487521636829*^9, 3.449487522017376*^9}, {3.449488445975963*^9, 
   3.4494884514638543`*^9}, 3.449579794386456*^9, 3.449640877921875*^9, {
   3.4921761771875*^9, 3.492176200296875*^9}, {3.49223382640625*^9, 
   3.49223383178125*^9}},
 FontSize->24,
 FontColor->RGBColor[0, 0, 1],
 Background->RGBColor[1, 0.9, 0.8]],

Cell["We summarize the main formulae", "Text",
 CellChangeTimes->{{3.44258518478125*^9, 3.44258519865625*^9}, {
   3.44258529084375*^9, 3.442585294265625*^9}, {3.44258532753125*^9, 
   3.442585334765625*^9}, {3.44942116988004*^9, 3.449421170320674*^9}, 
   3.4494864070941954`*^9, {3.4494865195759363`*^9, 3.4494865340868015`*^9}, {
   3.449487521636829*^9, 3.449487522017376*^9}, {3.449488445975963*^9, 
   3.4494884514638543`*^9}, 3.449579794386456*^9, 3.449640877921875*^9, {
   3.4921761771875*^9, 3.492176200296875*^9}, {3.49223382640625*^9, 
   3.492233835859375*^9}},
 FontSize->12,
 Background->GrayLevel[0.85]],

Cell["\<\
As the source term q(x,t) prevents the separation of variables, we 
have fisrt to examine the homogeneous equation \
\>", "Text",
 CellChangeTimes->{{3.449487580601616*^9, 3.449487619898122*^9}, {
   3.449488266167411*^9, 3.449488300246414*^9}, {3.4494883334942226`*^9, 
   3.4494884937045937`*^9}, 3.449507334115774*^9, {3.4921762199375*^9, 
   3.492176258828125*^9}, {3.492233978015625*^9, 3.492233997640625*^9}},
 TextJustification->0.,
 FontSize->12,
 Background->GrayLevel[0.85]],

Cell[BoxData[
 RowBox[{"                                    ", 
  RowBox[{
   RowBox[{"k", " ", 
    RowBox[{
     SubscriptBox["U", "xx"], "[", 
     RowBox[{"x", ",", "t"}], "]"}]}], "=", 
   RowBox[{"\[Rho]", " ", "c", " ", 
    RowBox[{
     RowBox[{
      SubscriptBox["U", "t"], "[", 
      RowBox[{"x", ",", "t"}], "]"}], "."}]}]}]}]], "EquationNumbered",
 CellChangeTimes->{{3.4494884683681617`*^9, 3.4494884740963984`*^9}, {
   3.4494890672292814`*^9, 3.4494890673594685`*^9}, 3.492166487*^9, {
   3.492176261171875*^9, 3.4921762638125*^9}, 3.4922338568125*^9},
 FontSize->12],

Cell["The usual Ansatz", "Text",
 CellChangeTimes->{{3.449488514314229*^9, 3.449488544567731*^9}, {
  3.492176274484375*^9, 3.49217631421875*^9}},
 TextJustification->0.,
 FontSize->12,
 Background->GrayLevel[0.85]],

Cell[BoxData[
 RowBox[{"                                      ", 
  RowBox[{
   RowBox[{"U", "[", 
    RowBox[{"x", ",", "t"}], "]"}], "=", 
   RowBox[{
    RowBox[{"X", "[", "x", "]"}], 
    RowBox[{"E", "[", "t", "]"}]}]}]}]], "Equation",
 CellChangeTimes->{{3.4494885531901293`*^9, 3.4494885617524414`*^9}, {
  3.4497198555625*^9, 3.44971986040625*^9}, {3.492176299*^9, 
  3.492176300953125*^9}},
 FontSize->12],

Cell["yields the ODE ", "Text",
 CellChangeTimes->{{3.4494885733391027`*^9, 3.4494886410664897`*^9}, {
  3.449488793715989*^9, 3.4494888067246943`*^9}, {3.49217630665625*^9, 
  3.492176326375*^9}},
 TextJustification->0.,
 FontSize->12,
 Background->GrayLevel[0.85]],

Cell[BoxData[
 RowBox[{"                              ", 
  RowBox[{
   FractionBox[
    RowBox[{
     SuperscriptBox["X", "\[DoublePrime]"], "[", "x", "]"}], 
    RowBox[{"X", "[", "x", "]"}]], "=", 
   RowBox[{
    RowBox[{
     FractionBox[
      RowBox[{"\[Rho]", " ", "c"}], "k"], 
     FractionBox[
      RowBox[{
       SuperscriptBox["E", "\[Prime]"], "[", "t", "]"}], 
      RowBox[{"E", "[", "t", "]"}]]}], "=", "\[Alpha]"}]}]}]], "Equation",
 CellChangeTimes->{{3.4494886483269296`*^9, 3.449488702685093*^9}, {
   3.449488737034485*^9, 3.4494887912724752`*^9}, {3.449489049734125*^9, 
   3.4494890708845377`*^9}, {3.4494895178872957`*^9, 
   3.4494895182878723`*^9}, {3.4494907944328785`*^9, 
   3.4494907955645056`*^9}, {3.44971983240625*^9, 3.4497198365625*^9}, {
   3.44971988834375*^9, 3.449719929484375*^9}, {3.450355050546875*^9, 
   3.4503550540625*^9}, 3.492166488046875*^9, {3.4921763305*^9, 
   3.492176332125*^9}},
 FontSize->12],

Cell["the solution of which are ", "Text",
 CellChangeTimes->{{3.4494888107905407`*^9, 3.449488854503397*^9}, {
   3.449488887040182*^9, 3.449488924113491*^9}, {3.4494889557890387`*^9, 
   3.4494889780510497`*^9}, {3.449489640964272*^9, 3.449489676825838*^9}, {
   3.4494902162715235`*^9, 3.449490238253131*^9}, 3.4496410618125*^9, {
   3.492176365046875*^9, 3.49217637159375*^9}, 3.49223386690625*^9},
 TextJustification->0.,
 FontSize->12,
 Background->GrayLevel[0.85]],

Cell[BoxData[
 RowBox[{"                               ", 
  RowBox[{
   RowBox[{
    RowBox[{
     SuperscriptBox["X", "\[DoublePrime]"], "[", "x", "]"}], "=", 
    RowBox[{"\[Alpha]", " ", 
     RowBox[{"X", "[", "x", "]"}]}]}], "\[LineSeparator]", 
   "                                ", 
   RowBox[{
    RowBox[{
     RowBox[{
      SuperscriptBox["E", "\[Prime]"], "[", "t", "]"}], "=", 
     RowBox[{
      SuperscriptBox["a", "2"], "\[Alpha]", " ", 
      RowBox[{"E", "[", "t", "]"}]}]}], ","}]}]}]], "Equation",
 CellChangeTimes->{{3.449488991450317*^9, 3.4494890442762766`*^9}, {
   3.449489250522845*^9, 3.4494892563712544`*^9}, {3.449489522133402*^9, 
   3.4494895402694798`*^9}, {3.449490334741875*^9, 3.449490339969392*^9}, {
   3.4494907906574497`*^9, 3.449490791919264*^9}, {3.449490858785413*^9, 
   3.4494908988129697`*^9}, {3.449719943515625*^9, 3.44971994834375*^9}, {
   3.450355057109375*^9, 3.45035505890625*^9}, {3.49217637378125*^9, 
   3.49217637825*^9}, 3.492233876875*^9},
 FontSize->12],

Cell["where", "Text",
 CellChangeTimes->{{3.4494903249878497`*^9, 3.44949033716536*^9}, {
  3.4494909047615232`*^9, 3.449490908186448*^9}, {3.4921763809375*^9, 
  3.492176383078125*^9}},
 TextJustification->0.,
 FontSize->12,
 Background->GrayLevel[0.85]],

Cell[BoxData[
 RowBox[{"                                   ", 
  RowBox[{
   SuperscriptBox["a", "2"], "=", 
   RowBox[{
    FractionBox["k", 
     RowBox[{"\[Rho]", " ", "c"}]], ".", "                       ", 
    RowBox[{"(", "1.4", ")"}]}]}]}]], "EquationNumbered",
 CellChangeTimes->{{3.4494909215056*^9, 3.449490928936285*^9}, 
   3.49216648884375*^9, {3.4921763851875*^9, 3.49217638703125*^9}, 
   3.49223387971875*^9, {3.49225489065625*^9, 3.492254894515625*^9}},
 FontSize->12],

Cell["The homogeneous BC lead to omogenee:", "Text",
 CellChangeTimes->{{3.4494892685187216`*^9, 3.4494892730352163`*^9}, {
   3.4494894259350753`*^9, 3.449489427757696*^9}, 3.449490346478752*^9, {
   3.492176403921875*^9, 3.4921764175625*^9}},
 TextJustification->0.,
 FontSize->12,
 Background->GrayLevel[0.85]],

Cell[BoxData[
 RowBox[{"                                 ", 
  RowBox[{
   RowBox[{
    RowBox[{"U", "[", 
     RowBox[{"0", ",", "t"}], "]"}], "=", 
    RowBox[{
     RowBox[{
      RowBox[{"X", "[", "0", "]"}], 
      RowBox[{"E", "[", "t", "]"}]}], "=", 
     RowBox[{
      RowBox[{"0", " ", "\[DoubleLeftRightArrow]", " ", 
       RowBox[{"X", "[", "0", "]"}]}], "=", "0"}]}]}], "\[LineSeparator]", 
   "                                  ", 
   RowBox[{
    RowBox[{"U", "[", 
     RowBox[{"p", ",", "t"}], "]"}], "=", 
    RowBox[{
     RowBox[{
      RowBox[{"X", "[", "p", "]"}], 
      RowBox[{"E", "[", "t", "]"}]}], "=", 
     RowBox[{
      RowBox[{"0", " ", "\[DoubleLeftRightArrow]", " ", 
       RowBox[{"X", "[", "p", "]"}]}], "=", "0"}]}]}]}]}]], "Equation",
 CellChangeTimes->{{3.4494893122215633`*^9, 3.4494893648071775`*^9}, {
  3.449489400017808*^9, 3.449489421799128*^9}, {3.4494905844709682`*^9, 
  3.449490584701299*^9}, {3.449490799199733*^9, 3.4494908003013167`*^9}, {
  3.49217642084375*^9, 3.49217642534375*^9}},
 FontSize->12],

Cell[TextData[{
 "Since we have non trivial solutions only when ",
 Cell[BoxData[
  FormBox[
   RowBox[{
    RowBox[{
     RowBox[{"\[Alpha]", "<", "0"}], " ", "\[Implies]", " ", "\[Alpha]"}], 
    "=", 
    RowBox[{"-", 
     SuperscriptBox["\[Lambda]", "2"]}]}], TraditionalForm]]],
 "\[LineSeparator]we obtain"
}], "Text",
 CellChangeTimes->{{3.449489443079728*^9, 3.449489513350773*^9}, {
   3.44948954878172*^9, 3.449489576401435*^9}, {3.4494897101437473`*^9, 
   3.4494897253055487`*^9}, {3.44948979497573*^9, 3.4494898061117425`*^9}, {
   3.449489859127976*^9, 3.449489865086544*^9}, {3.4494903744790144`*^9, 
   3.4494904293178687`*^9}, 3.4494907644697933`*^9, {3.492176441015625*^9, 
   3.492176484640625*^9}},
 TextJustification->0.,
 FontSize->12,
 Background->GrayLevel[0.85]],

Cell[BoxData[
 RowBox[{"                             ", 
  RowBox[{
   RowBox[{
    SubscriptBox["X", "n"], "[", "x", "]"}], "=", 
   RowBox[{"Sin", "[", 
    RowBox[{
     SubscriptBox["\[Lambda]", "n"], " ", "x"}], 
    "]"}]}]}]], "EquationNumbered",
 CellChangeTimes->{{3.4494897418192945`*^9, 3.449489766865309*^9}, {
   3.449489810227661*^9, 3.4494898196812544`*^9}, {3.44948985337971*^9, 
   3.4494898566844625`*^9}, {3.4494903964205647`*^9, 3.4494904556857843`*^9}, 
   3.4494905568512526`*^9, {3.449490588076152*^9, 3.449490600754382*^9}, {
   3.4494906742600784`*^9, 3.449490682221526*^9}, {3.492176487609375*^9, 
   3.4921764891875*^9}},
 FontSize->12],

Cell[BoxData[
 RowBox[{"                              ", 
  RowBox[{
   RowBox[{
    SubscriptBox["E", "n"], "[", "t", "]"}], "=", 
   RowBox[{
    SubscriptBox["c", "n"], " ", 
    SuperscriptBox["\[ExponentialE]", 
     RowBox[{
      RowBox[{"-", 
       SuperscriptBox["a", "2"]}], 
      SuperscriptBox[
       SubscriptBox["\[Lambda]", "n"], "2"], "t"}]]}]}]}]], "Equation",
 CellChangeTimes->{{3.4494906612413588`*^9, 3.449490705765381*^9}, 
   3.4494908035059247`*^9, {3.49217649121875*^9, 3.492176497765625*^9}},
 FontSize->12],

Cell[BoxData[
 RowBox[{"                              ", 
  RowBox[{
   SubscriptBox["\[Lambda]", "n"], "=", 
   FractionBox[
    RowBox[{"n", " ", "\[Pi]"}], "p"]}]}]], "Equation",
 CellChangeTimes->{{3.492176494265625*^9, 3.492176495859375*^9}},
 FontSize->12],

Cell[" and", "Text",
 CellChangeTimes->{{3.449490761836006*^9, 3.4494907666729617`*^9}, {
  3.492176506671875*^9, 3.49217650915625*^9}},
 TextJustification->0.,
 FontSize->12,
 Background->GrayLevel[0.85]],

Cell[BoxData[
 RowBox[{"                            ", 
  RowBox[{
   RowBox[{
    SubscriptBox["U", "n"], "[", 
    RowBox[{"x", ",", "t"}], "]"}], "=", 
   RowBox[{
    RowBox[{
     RowBox[{
      SubscriptBox["X", "n"], "[", "x", "]"}], 
     RowBox[{
      SubscriptBox["E", "n"], "[", "t", "]"}]}], "=", 
    RowBox[{
     SubscriptBox["c", "n"], 
     RowBox[{"Sin", "[", 
      RowBox[{
       SubscriptBox["\[Lambda]", "n"], " ", "x"}], "]"}], " ", 
     SuperscriptBox["\[ExponentialE]", 
      RowBox[{
       RowBox[{"-", 
        SuperscriptBox["a", "2"]}], 
       SuperscriptBox[
        SubscriptBox["\[Lambda]", "n"], "2"], "t"}]]}]}]}]}]], "Equation",
 CellChangeTimes->{{3.449490770137944*^9, 3.449490809324291*^9}, {
  3.4494911203415117`*^9, 3.4494911328695264`*^9}, {3.492176511546875*^9, 
  3.49217651309375*^9}},
 FontSize->12],

Cell[TextData[{
 StyleBox["The coefficients  ",
  Background->GrayLevel[0.85]],
 Cell[BoxData[
  FormBox[
   SubscriptBox["c", "n"], TraditionalForm]]],
 StyleBox[" have to be determined by forming a linear combination\n",
  Background->GrayLevel[0.85]],
 "\n",
 Cell[BoxData[
  RowBox[{
   RowBox[{"U", "[", 
    RowBox[{"x", ",", "t"}], "]"}], "=", 
   RowBox[{
    UnderoverscriptBox["\[Sum]", 
     RowBox[{"n", "=", "1"}], "\[Infinity]"], 
    RowBox[{
     SubscriptBox["U", "n"], "[", 
     RowBox[{"x", ",", "t"}], "]"}]}]}]]],
 "\n\n",
 StyleBox["and imposing the initial condition",
  Background->GrayLevel[0.85]],
 "\n\n",
 Cell[BoxData[
  RowBox[{
   RowBox[{"U", "[", 
    RowBox[{"x", ",", "0"}], "]"}], "=", 
   RowBox[{
    RowBox[{
     UnderoverscriptBox["\[Sum]", 
      RowBox[{"n", "=", "1"}], "\[Infinity]"], 
     RowBox[{
      RowBox[{
       SubscriptBox["X", "n"], "[", "x", "]"}], 
      RowBox[{
       SubscriptBox["E", "n"], "[", "0", "]"}]}]}], "=", 
    RowBox[{
     RowBox[{
      UnderoverscriptBox["\[Sum]", 
       RowBox[{"n", "=", "1"}], "\[Infinity]"], 
      RowBox[{
       SubscriptBox["c", "n"], 
       RowBox[{"Sin", "[", 
        RowBox[{
         SubscriptBox["\[Lambda]", "n"], " ", "x"}], "]"}]}]}], "=", 
     RowBox[{"f", "[", "x", "]"}]}]}]}]]]
}], "Text",
 CellChangeTimes->{{3.4494902579614706`*^9, 3.44949026731492*^9}, {
  3.4494903613801794`*^9, 3.4494903644345713`*^9}, {3.44949096331572*^9, 
  3.449491020317685*^9}, {3.449491091650256*^9, 3.4494911076332383`*^9}, {
  3.4494911603390255`*^9, 3.44949124622252*^9}, {3.449491277497491*^9, 
  3.449491277667736*^9}, {3.4494913173347745`*^9, 3.4494913175851345`*^9}, {
  3.4921765345*^9, 3.492176700171875*^9}},
 TextJustification->0.,
 FontSize->12],

Cell["Then", "Text",
 CellChangeTimes->{{3.449491225973403*^9, 3.4494912306701565`*^9}, 
   3.4494912765561376`*^9, {3.4494914377979918`*^9, 3.44949143874936*^9}, {
   3.492176717359375*^9, 3.49217672184375*^9}},
 TextJustification->0.,
 FontSize->12,
 Background->GrayLevel[0.85]],

Cell[BoxData[
 RowBox[{"                                     ", 
  RowBox[{
   SubscriptBox["c", "n"], "=", 
   RowBox[{
    FractionBox["2", "p"], 
    RowBox[{
     SubsuperscriptBox["\[Integral]", "0", "p"], 
     RowBox[{
      RowBox[{"f", "[", "x", "]"}], 
      RowBox[{"Sin", "[", 
       RowBox[{
        SubscriptBox["\[Lambda]", "n"], " ", "x"}], "]"}], 
      RowBox[{"\[DifferentialD]", "x"}]}]}]}]}]}]], "Equation",
 CellChangeTimes->{{3.449491442154256*^9, 3.4494914825022736`*^9}, {
  3.49217672371875*^9, 3.492176725625*^9}},
 FontSize->12],

Cell["Now we assume that (1.1) can be written as ", "Text",
 CellChangeTimes->{{3.449492594140731*^9, 3.449492634568864*^9}, {
   3.449492675497717*^9, 3.449492678612195*^9}, {3.449492778756195*^9, 
   3.449492796021021*^9}, 3.4495073470944366`*^9, {3.492234715921875*^9, 
   3.4922347228125*^9}, {3.4922347903125*^9, 3.49223481225*^9}},
 TextJustification->0.,
 FontSize->12,
 Background->GrayLevel[0.85]],

Cell[BoxData[
 RowBox[{"                  ", 
  RowBox[{
   RowBox[{"U", "[", 
    RowBox[{"x", ",", "t"}], "]"}], "=", 
   RowBox[{
    UnderoverscriptBox["\[Sum]", 
     RowBox[{"n", "=", "1"}], "\[Infinity]"], 
    RowBox[{
     RowBox[{
      SubscriptBox["X", "n"], "[", "x", "]"}], 
     RowBox[{
      RowBox[{
       SubscriptBox["E", "n"], "[", "t", "]"}], 
      "."}]}]}]}]}]], "EquationNumbered",
 CellChangeTimes->{{3.449486981600294*^9, 3.4494869938178625`*^9}, {
   3.44948704668388*^9, 3.4494870809932146`*^9}, {3.492234010328125*^9, 
   3.49223401146875*^9}, 3.492254183328125*^9},
 FontSize->12],

Cell["Therefore, we  have", "Text",
 CellChangeTimes->{{3.4494915792714205`*^9, 3.449491636984408*^9}, {
   3.4494920344158864`*^9, 3.4494922464407635`*^9}, {3.449492279177837*^9, 
   3.449492297363987*^9}, {3.4494924078027906`*^9, 3.4494924080631647`*^9}, {
   3.4494925820733795`*^9, 3.449492603644397*^9}, {3.449492671201539*^9, 
   3.4494926717323027`*^9}, 3.4494931528040495`*^9, 3.4495073428082733`*^9, {
   3.492254187359375*^9, 3.492254220140625*^9}, {3.492254255046875*^9, 
   3.4922542605625*^9}, 3.574494296532424*^9},
 TextJustification->0.,
 FontSize->12,
 Background->GrayLevel[0.85]],

Cell[BoxData[
 RowBox[{"                      ", 
  RowBox[{
   RowBox[{
    RowBox[{
     SubscriptBox["U", "t"], "[", 
     RowBox[{"x", ",", "t"}], "]"}], "=", 
    RowBox[{
     UnderoverscriptBox["\[Sum]", 
      RowBox[{"n", "=", "1"}], "\[Infinity]"], 
     RowBox[{
      RowBox[{
       SubscriptBox["X", "n"], "[", "x", "]"}], 
      RowBox[{
       SubsuperscriptBox["E", "n", "\[Prime]"], "[", "t", "]"}]}]}]}], ",", 
   "\[IndentingNewLine]", "                     ", 
   RowBox[{
    RowBox[{
     SubscriptBox["U", "xx"], "[", 
     RowBox[{"x", ",", "t"}], "]"}], "=", 
    RowBox[{
     RowBox[{
      UnderoverscriptBox["\[Sum]", 
       RowBox[{"n", "=", "1"}], "\[Infinity]"], 
      RowBox[{
       RowBox[{
        SubsuperscriptBox["X", "n", "\[Prime]\[Prime]"], "[", "x", "]"}], 
       RowBox[{
        SubscriptBox["E", "n"], "[", "t", "]"}]}]}], "=", 
     RowBox[{"-", 
      RowBox[{
       UnderoverscriptBox["\[Sum]", 
        RowBox[{"n", "=", "1"}], "\[Infinity]"], 
       RowBox[{
        SuperscriptBox[
         SubscriptBox["\[Lambda]", "n"], "2"], 
        RowBox[{
         SubscriptBox["X", "n"], "[", "x", "]"}], 
        RowBox[{
         SubscriptBox["E", "n"], "[", "t", "]"}]}]}]}]}]}]}]}]], "Equation",
 CellChangeTimes->{
  3.449492251838525*^9, {3.4494923178133917`*^9, 3.449492319115264*^9}, {
   3.4494924119086943`*^9, 3.449492541064411*^9}, {3.449719957*^9, 
   3.44972000909375*^9}, {3.449720094453125*^9, 3.44972011109375*^9}, 
   3.492162080453125*^9, {3.492234682375*^9, 3.49223468571875*^9}, {
   3.492254223765625*^9, 3.492254224734375*^9}, {3.492254265015625*^9, 
   3.49225431625*^9}, {3.492254578796875*^9, 3.492254591734375*^9}},
 FontSize->12],

Cell[TextData[{
 "and we can look for a generalized Forier expansion of  ",
 Cell[BoxData[
  FormBox[
   RowBox[{"q", "[", 
    RowBox[{"x", ",", "t"}], "]"}], TraditionalForm]]]
}], "Text",
 CellChangeTimes->{{3.449492594140731*^9, 3.449492634568864*^9}, {
   3.449492675497717*^9, 3.449492678612195*^9}, {3.449492778756195*^9, 
   3.449492796021021*^9}, 3.4495073470944366`*^9, {3.49225463415625*^9, 
   3.492254682328125*^9}},
 TextJustification->0.,
 FontSize->12,
 Background->GrayLevel[0.85]],

Cell[BoxData[
 RowBox[{"                         ", 
  RowBox[{
   RowBox[{
    UnderoverscriptBox["\[Sum]", 
     RowBox[{"n", "=", "1"}], "\[Infinity]"], 
    RowBox[{
     RowBox[{"(", 
      RowBox[{
       RowBox[{"\[Rho]", " ", "c", " ", 
        RowBox[{
         SubsuperscriptBox["E", "n", "\[Prime]"], "[", "t", "]"}]}], "+", 
       RowBox[{"k", " ", 
        SuperscriptBox[
         SubscriptBox["\[Lambda]", "n"], "2"], 
        RowBox[{
         SubscriptBox["E", "n"], "[", "t", "]"}]}]}], ")"}], 
     RowBox[{
      SubscriptBox["X", "n"], "[", "x", "]"}]}]}], "=", 
   RowBox[{
    RowBox[{"q", "[", 
     RowBox[{"x", ",", "t"}], "]"}], "."}]}]}]], "Equation",
 CellChangeTimes->{{3.4494926828783293`*^9, 3.449492720462373*^9}, 
   3.44972001609375*^9, {3.49216208634375*^9, 3.49216208796875*^9}, 
   3.492166489984375*^9, {3.492234687203125*^9, 3.492234688625*^9}, 
   3.492254696453125*^9},
 FontSize->12],

Cell[TextData[{
 "Since the funxtions ",
 Cell[BoxData[
  FormBox[
   SubscriptBox["X", "n"], TraditionalForm]]],
 " are orthogonal, we have the following first order ODE"
}], "Text",
 CellChangeTimes->{{3.4494866458174624`*^9, 3.4494866592567873`*^9}, {
  3.449487366944392*^9, 3.449487375606848*^9}, {3.449492800527501*^9, 
  3.4494928738028655`*^9}, {3.4922547170625*^9, 3.49225477890625*^9}},
 TextJustification->0.,
 FontSize->12,
 Background->GrayLevel[0.85]],

Cell[BoxData[
 RowBox[{"                          ", 
  RowBox[{
   RowBox[{
    RowBox[{
     SubsuperscriptBox["E", "n", "\[Prime]"], "[", "t", "]"}], "+", 
    RowBox[{
     SuperscriptBox["a", "2"], 
     SuperscriptBox[
      SubscriptBox["\[Lambda]", "n"], "2"], 
     RowBox[{
      SubscriptBox["E", "n"], "[", "t", "]"}]}]}], "=", 
   RowBox[{
    RowBox[{
     SubscriptBox["Q", "n"], "[", "t", "]"}], "                             ", 
    RowBox[{"(", "1.5", ")"}]}]}]}]], "EquationNumbered",
 CellChangeTimes->{{3.449492896034834*^9, 3.449492938606048*^9}, {
   3.449492974307384*^9, 3.4494930833942432`*^9}, {3.449493295188789*^9, 
   3.4494933030500927`*^9}, 3.449720020578125*^9, {3.492234834515625*^9, 
   3.49223483596875*^9}, {3.492238352203125*^9, 3.49223835665625*^9}, {
   3.49225497584375*^9, 3.492254980046875*^9}},
 FontSize->12],

Cell[TextData[{
 "with  ",
 Cell[BoxData[
  FormBox[
   SuperscriptBox["a", "2"], TraditionalForm]]],
 "  given by (1.4)  and "
}], "Text",
 CellChangeTimes->{{3.449493164280552*^9, 3.4494931750059743`*^9}, {
   3.449493306745406*^9, 3.4494933068956223`*^9}, 3.4495073512103553`*^9, {
   3.492254904640625*^9, 3.492254928578125*^9}, {3.574494271916016*^9, 
   3.5744942722530355`*^9}},
 TextJustification->0.,
 FontSize->12,
 Background->GrayLevel[0.85]],

Cell[BoxData[
 RowBox[{"                           ", 
  RowBox[{
   RowBox[{
    SubscriptBox["Q", "n"], "[", "t", "]"}], "=", 
   RowBox[{
    FractionBox["2", "p"], 
    FractionBox[
     SuperscriptBox["a", "2"], "k"], 
    RowBox[{
     SubsuperscriptBox["\[Integral]", "0", "p"], 
     RowBox[{
      RowBox[{"q", "[", 
       RowBox[{"x", ",", "t"}], "]"}], 
      RowBox[{
       SubscriptBox["X", "n"], "[", "x", "]"}], 
      RowBox[{"\[DifferentialD]", "x"}]}]}]}]}]}]], "EquationNumbered",
 CellChangeTimes->{{3.4494933187927294`*^9, 3.4494933198542557`*^9}, {
   3.4495521273632307`*^9, 3.4495521312187743`*^9}, {3.4495528989927793`*^9, 
   3.4495529083862867`*^9}, 3.492166491*^9, {3.492234837125*^9, 
   3.49223483859375*^9}},
 FontSize->12],

Cell["The solution of (1.5)  is...", "Text",
 CellChangeTimes->{{3.449493356226557*^9, 3.4494934488096848`*^9}, 
   3.449507355766907*^9, {3.492254943703125*^9, 3.492255002390625*^9}, {
   3.574494269763893*^9, 3.5744942700759106`*^9}},
 TextJustification->0.,
 FontSize->12,
 Background->GrayLevel[0.85]],

Cell[BoxData[
 RowBox[{"                           ", 
  RowBox[{
   RowBox[{
    SubscriptBox["E", "n"], "[", "t", "]"}], "=", 
   RowBox[{
    SuperscriptBox["\[ExponentialE]", 
     RowBox[{
      RowBox[{"-", 
       SuperscriptBox["a", "2"]}], 
      SuperscriptBox[
       SubscriptBox["\[Lambda]", "n"], "2"], "t"}]], 
    RowBox[{"(", 
     RowBox[{
      SubscriptBox["c", "n"], "+", 
      RowBox[{
       SubsuperscriptBox["\[Integral]", "0", "t"], 
       RowBox[{
        SuperscriptBox["\[ExponentialE]", 
         RowBox[{
          SuperscriptBox["a", "2"], 
          SuperscriptBox[
           SubscriptBox["\[Lambda]", "n"], "2"], "\[Tau]"}]], 
        RowBox[{
         SubscriptBox["Q", "n"], "[", "\[Tau]", "]"}], 
        RowBox[{"\[DifferentialD]", "\[Tau]"}]}]}]}], ")"}]}]}]}]], "Equation",
 CellChangeTimes->{{3.4494934577124863`*^9, 3.449493460035827*^9}, {
  3.4494992374233027`*^9, 3.4494992987514877`*^9}, {3.492234840765625*^9, 
  3.492234842265625*^9}},
 FontSize->12],

Cell[TextData[{
 "By imposing the initial condition (1.3) we find the coefficients  ",
 Cell[BoxData[
  FormBox[
   SubscriptBox["c", "n"], TraditionalForm]]]
}], "Text",
 CellChangeTimes->{{3.4494993530395503`*^9, 3.449499370755024*^9}, 
   3.4495073632877216`*^9, {3.492255014953125*^9, 3.49225507628125*^9}, 
   3.492255468484375*^9, {3.5744942636845455`*^9, 3.574494266892729*^9}},
 TextJustification->0.,
 FontSize->12,
 Background->GrayLevel[0.85]],

Cell[BoxData[
 RowBox[{"                            ", 
  RowBox[{
   RowBox[{"U", "[", 
    RowBox[{"x", ",", "0"}], "]"}], "=", 
   RowBox[{
    RowBox[{
     UnderoverscriptBox["\[Sum]", 
      RowBox[{"n", "=", "1"}], "\[Infinity]"], 
     RowBox[{
      RowBox[{
       SubscriptBox["X", "n"], "[", "x", "]"}], 
      RowBox[{
       SubscriptBox["E", "n"], "[", "0", "]"}]}]}], "=", 
    RowBox[{
     RowBox[{
      UnderoverscriptBox["\[Sum]", 
       RowBox[{"n", "=", "1"}], "\[Infinity]"], 
      RowBox[{
       RowBox[{
        SubscriptBox["X", "n"], "[", "x", "]"}], 
       SubscriptBox["c", "n"]}]}], "=", 
     RowBox[{
      RowBox[{"0", " ", "\[Implies]", " ", 
       SubscriptBox["c", "n"]}], "=", "0."}]}]}]}]}]], "Equation",
 CellChangeTimes->{{3.449499383122808*^9, 3.449499447946019*^9}, {
   3.492234843265625*^9, 3.4922348448125*^9}, 3.492255079703125*^9},
 FontSize->12],

Cell["Summarizing...", "Text",
 CellChangeTimes->{{3.449499458541254*^9, 3.449499459021946*^9}, {
  3.492255470578125*^9, 3.4922554853125*^9}, {3.5744942544920197`*^9, 
  3.5744942606363707`*^9}},
 TextJustification->0.,
 FontSize->12,
 Background->GrayLevel[0.85]],

Cell[BoxData[
 RowBox[{"                          ", 
  RowBox[{
   RowBox[{
    RowBox[{
     SubscriptBox["X", "n"], "[", "x", "]"}], "=", 
    RowBox[{
     RowBox[{
      RowBox[{"Sin", "[", 
       RowBox[{
        SubscriptBox["\[Lambda]", "n"], "x"}], "]"}], "              ", 
      "with", "     ", 
      SubscriptBox["\[Lambda]", "n"]}], "=", 
     FractionBox[
      RowBox[{"n", " ", "\[Pi]"}], "p"]}]}], ","}]}]], "Equation",
 CellChangeTimes->{{3.492234849203125*^9, 3.49223485065625*^9}, {
  3.492255504421875*^9, 3.492255531453125*^9}, {3.492255602296875*^9, 
  3.4922556039375*^9}, {3.492255635703125*^9, 3.492255649625*^9}},
 FontSize->12],

Cell[BoxData[
 RowBox[{"                        ", 
  RowBox[{
   RowBox[{
    SubscriptBox["Q", "n"], "[", "t", "]"}], "=", 
   RowBox[{
    FractionBox["2", "p"], 
    FractionBox[
     SuperscriptBox["a", "2"], "k"], 
    RowBox[{
     SubsuperscriptBox["\[Integral]", "0", "p"], 
     RowBox[{
      RowBox[{"q", "[", 
       RowBox[{"x", ",", "t"}], "]"}], 
      RowBox[{
       SubscriptBox["X", "n"], "[", "x", "]"}], 
      RowBox[{"\[DifferentialD]", "x"}], "   ", "and"}]}]}]}]}]], "Equation",
 CellChangeTimes->{{3.4495529546528144`*^9, 3.44955295814784*^9}, 
   3.492166491578125*^9, {3.4922348539375*^9, 3.4922348553125*^9}, {
   3.492255641265625*^9, 3.49225564515625*^9}},
 FontSize->12],

Cell[BoxData[
 RowBox[{"                         ", 
  RowBox[{
   RowBox[{
    SubscriptBox["E", "n"], "[", "t", "]"}], "=", 
   RowBox[{
    SuperscriptBox["\[ExponentialE]", 
     RowBox[{
      RowBox[{"-", 
       SuperscriptBox["a", "2"]}], 
      SuperscriptBox[
       SubscriptBox["\[Lambda]", "n"], "2"], "t"}]], 
    RowBox[{
     SubsuperscriptBox["\[Integral]", "0", "t"], 
     RowBox[{
      SuperscriptBox["\[ExponentialE]", 
       RowBox[{
        SuperscriptBox["a", "2"], 
        SuperscriptBox[
         SubscriptBox["\[Lambda]", "n"], "2"], "\[Tau]"}]], 
      RowBox[{
       SubscriptBox["Q", "n"], "[", "\[Tau]", "]"}], 
      RowBox[{"\[DifferentialD]", "\[Tau]"}], "   ", "we", " ", "obtain", 
      "                            "}]}]}]}]}]], "EquationNumbered",
 CellChangeTimes->{{3.4494994828261747`*^9, 3.4494995731660767`*^9}, 
   3.4495024740072813`*^9, {3.4495521368668957`*^9, 3.4495521389999633`*^9}, {
   3.4495528844819136`*^9, 3.449552888367501*^9}, {3.4495529282949133`*^9, 
   3.449552969814616*^9}, {3.4922348516875*^9, 3.492234853109375*^9}, {
   3.492238330109375*^9, 3.492238361125*^9}, {3.4922556525*^9, 
   3.49225565696875*^9}},
 FontSize->12],

Cell[BoxData[
 RowBox[{"                       ", 
  RowBox[{
   RowBox[{"U", "[", 
    RowBox[{"x", ",", "t"}], "]"}], "=", 
   RowBox[{
    UnderoverscriptBox["\[Sum]", 
     RowBox[{"n", "=", "1"}], "\[Infinity]"], 
    RowBox[{
     RowBox[{
      SubscriptBox["X", "n"], "[", "x", "]"}], 
     RowBox[{
      SubscriptBox["E", "n"], "[", "t", "]"}]}]}]}]}]], "Equation",
 CellChangeTimes->{{3.49223484696875*^9, 3.4922348483125*^9}},
 FontSize->12]
}, Closed]],

Cell[CellGroupData[{

Cell["Part II ", "Text",
 CellChangeTimes->{{3.44258518478125*^9, 3.44258519865625*^9}, {
   3.44258529084375*^9, 3.442585294265625*^9}, {3.44258532753125*^9, 
   3.442585334765625*^9}, {3.44942116988004*^9, 3.449421170320674*^9}, 
   3.4494864070941954`*^9, {3.4494865195759363`*^9, 3.4494865340868015`*^9}, {
   3.449487521636829*^9, 3.449487522017376*^9}, {3.449488445975963*^9, 
   3.4494884514638543`*^9}, 3.449579794386456*^9, 3.449640877921875*^9, {
   3.4921761771875*^9, 3.492176200296875*^9}, {3.49223382640625*^9, 
   3.49223383178125*^9}, 3.49225578146875*^9},
 FontSize->24,
 FontColor->RGBColor[0, 0, 1],
 Background->RGBColor[1, 0.9, 0.8]],

Cell["Characteristics of the silicon rod", "Text",
 CellChangeTimes->{{3.4495549182663517`*^9, 3.449554992623272*^9}, {
  3.49223488384375*^9, 3.49223490221875*^9}, {3.492255262*^9, 
  3.4922552658125*^9}, {3.492255697875*^9, 3.492255712140625*^9}},
 TextJustification->0.,
 FontSize->12,
 Background->GrayLevel[0.85]],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{
   RowBox[{"pvalue", " ", "=", " ", "1"}], ";"}], "                ", 
  RowBox[{"(*", " ", 
   RowBox[{"[", "m", "]"}], "  ", "*)"}]}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"kvalue", " ", "=", " ", "156."}], " ", ";"}], "        ", 
  RowBox[{"(*", " ", 
   RowBox[{
    RowBox[{"(", 
     RowBox[{"W", " ", "m"}], ")"}], "/", "k"}], "   ", "*)"}]}], "\n", 
 RowBox[{
  RowBox[{
   RowBox[{"\[Rho]value", " ", "=", " ", "2350."}], " ", ";"}], "        ", 
  RowBox[{"(*", " ", 
   RowBox[{"kg", "/", 
    RowBox[{"m", "^", "3"}]}], " ", "*)"}]}], "\n", 
 RowBox[{
  RowBox[{
   RowBox[{"cvalue", " ", "=", " ", "713."}], ";"}], "           ", 
  RowBox[{"(*", " ", 
   RowBox[{"J", "/", 
    RowBox[{"(", 
     RowBox[{"kg", " ", "k"}], ")"}]}], " ", 
   "*)"}]}], "\[IndentingNewLine]"}], "Input",
 InitializationCell->True,
 CellChangeTimes->{{3.4505441405*^9, 3.45054414078125*^9}, {
  3.49223491803125*^9, 3.492234988140625*^9}, {3.492255303625*^9, 
  3.492255310484375*^9}, {3.492406336890625*^9, 3.49240659378125*^9}},
 FontSize->12],

Cell[BoxData[""], "Input",
 InitializationCell->True,
 CellChangeTimes->{{3.4505441405*^9, 3.45054414078125*^9}, {
  3.49223491803125*^9, 3.492234988140625*^9}, {3.492255303625*^9, 
  3.492255310484375*^9}, {3.492406336890625*^9, 3.492406581296875*^9}},
 FontSize->12],

Cell[BoxData[
 RowBox[{
  RowBox[{"a", "=", 
   SqrtBox[
    FractionBox["k", 
     RowBox[{"\[Rho]", " ", "c"}]]]}], ";"}]], "Input",
 InitializationCell->True,
 CellChangeTimes->{{3.4495481076932287`*^9, 3.4495481232556067`*^9}, {
   3.4495500412735806`*^9, 3.4495500547329345`*^9}, {3.449555766305773*^9, 
   3.4495557666562767`*^9}, 3.492166493109375*^9, 3.49225527803125*^9},
 FontSize->12]
}, Open  ]],

Cell["We set ", "Text",
 CellChangeTimes->{{3.4495480937231407`*^9, 3.4495481010937395`*^9}, 
   3.449548159537778*^9, 3.4495557645532527`*^9, {3.492255395515625*^9, 
   3.49225540109375*^9}},
 TextJustification->0.,
 FontSize->12,
 Background->GrayLevel[0.85]],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"\[Lambda]", "[", "n_", "]"}], ":=", 
   FractionBox[
    RowBox[{"n", " ", "\[Pi]"}], "p"]}], ";"}]], "Input",
 InitializationCell->True,
 CellChangeTimes->{{3.4495481076932287`*^9, 3.4495481232556067`*^9}, {
   3.4495500412735806`*^9, 3.4495500547329345`*^9}, {3.449555766305773*^9, 
   3.4495557666562767`*^9}, 3.492166493109375*^9, 3.49225527803125*^9},
 FontSize->12],

Cell[BoxData[
 RowBox[{
  RowBox[{"Xn", "[", 
   RowBox[{"x_", ",", "n_"}], "]"}], ":=", 
  RowBox[{"Sin", "[", 
   RowBox[{
    RowBox[{"\[Lambda]", "[", "n", "]"}], "x"}], "]"}]}]], "Input",
 InitializationCell->True,
 CellChangeTimes->{{3.4495481076932287`*^9, 3.4495481232556067`*^9}, {
   3.4495500412735806`*^9, 3.4495500547329345`*^9}, {3.449555766305773*^9, 
   3.4495557666562767`*^9}, 3.492166493109375*^9, 3.49225527803125*^9},
 FontSize->12],

Cell["and the conditions (1.2) e (1.3) ", "Text",
 CellChangeTimes->{{3.449558283675573*^9, 3.449558301641406*^9}, {
  3.449558470674464*^9, 3.449558479537208*^9}, {3.492255410625*^9, 
  3.492255423796875*^9}},
 TextJustification->0.,
 FontSize->12,
 Background->GrayLevel[0.85]],

Cell[BoxData[{
 RowBox[{
  RowBox[{"bc", "[", 
   RowBox[{"u_", "[", 
    RowBox[{"x_", ",", "t_"}], "]"}], "]"}], ":=", 
  RowBox[{
   RowBox[{"u", "[", 
    RowBox[{"0", ",", "t"}], "]"}], "\[Equal]", 
   RowBox[{"u", "[", 
    RowBox[{"p", ",", "t"}], "]"}], "\[Equal]", 
   "0"}]}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"ic", "[", 
   RowBox[{"u_", "[", 
    RowBox[{"x_", ",", "t_"}], "]"}], "]"}], ":=", 
  RowBox[{
   RowBox[{"u", "[", 
    RowBox[{"x", ",", "0"}], "]"}], "\[Equal]", "0"}]}]}], "Input",
 InitializationCell->True,
 CellChangeTimes->{{3.449558313318197*^9, 3.449558368727872*^9}, {
  3.4495592686318703`*^9, 3.449559278265723*^9}},
 FontSize->12],

Cell[TextData[{
 "By the way, we confirm that ",
 StyleBox["Mathematica",
  FontSlant->"Italic"],
 " is not able to solve symbolically \nthe problem. \nWe introduce the \
following definitions (Operator, Equation and System)"
}], "Text",
 CellChangeTimes->{{3.449556808013675*^9, 3.449556832669128*^9}, 
   3.44955687728328*^9, {3.449558112138915*^9, 3.4495581529275665`*^9}, {
   3.492235069015625*^9, 3.492235148796875*^9}, {3.492235270171875*^9, 
   3.492235288734375*^9}, {3.49223532121875*^9, 3.492235337046875*^9}, {
   3.492255842453125*^9, 3.492255858765625*^9}},
 TextJustification->0.,
 FontSize->12,
 Background->GrayLevel[0.85]],

Cell[BoxData[{
 RowBox[{
  RowBox[{"FourierOper", "[", 
   RowBox[{"u_", "[", 
    RowBox[{"x_", ",", "t_"}], "]"}], "]"}], ":=", 
  RowBox[{
   RowBox[{"k", " ", 
    RowBox[{
     SubscriptBox["\[PartialD]", 
      RowBox[{"x", "\[InvisibleComma]", "x"}]], 
     RowBox[{"u", "[", 
      RowBox[{"x", ",", "t"}], "]"}]}]}], "-", 
   RowBox[{"\[Rho]", " ", "c", " ", 
    RowBox[{
     SubscriptBox["\[PartialD]", "t"], 
     RowBox[{"u", "[", 
      RowBox[{"x", ",", "t"}], "]"}]}]}]}]}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"FourierEq", "[", 
   RowBox[{
    RowBox[{"u_", "[", 
     RowBox[{"x_", ",", "t_"}], "]"}], ",", "q_"}], "]"}], ":=", 
  RowBox[{
   RowBox[{
    RowBox[{"FourierOper", "[", 
     RowBox[{"u", "[", 
      RowBox[{"x", ",", "t"}], "]"}], "]"}], "+", "q"}], "\[Equal]", 
   "0"}]}], "\n", 
 RowBox[{
  RowBox[{"FourierSys", "[", 
   RowBox[{
    RowBox[{"u_", "[", 
     RowBox[{"x_", ",", "t_"}], "]"}], ",", "q_"}], "]"}], ":=", 
  RowBox[{"{", 
   RowBox[{
    RowBox[{"FourierEq", "[", 
     RowBox[{
      RowBox[{"u", "[", 
       RowBox[{"x", ",", "t"}], "]"}], ",", "q"}], "]"}], ",", 
    RowBox[{"bc", "[", 
     RowBox[{"u", "[", 
      RowBox[{"x", ",", "t"}], "]"}], "]"}], ",", 
    RowBox[{"ic", "[", 
     RowBox[{"u", "[", 
      RowBox[{"x", ",", "t"}], "]"}], "]"}]}], "}"}]}]}], "Input",
 InitializationCell->True,
 CellChangeTimes->{{3.44955691950399*^9, 3.449556922017605*^9}, {
   3.4495578789135537`*^9, 3.4495579638556943`*^9}, {3.449558121872912*^9, 
   3.449558122183358*^9}, {3.4495581568532114`*^9, 3.4495581573339024`*^9}, {
   3.4495587126023393`*^9, 3.4495587127625694`*^9}, {3.449559100840598*^9, 
   3.4495591028534927`*^9}, {3.4495591420498543`*^9, 3.449559145494808*^9}, {
   3.4495592049503007`*^9, 3.4495592143037505`*^9}, 3.492166494171875*^9, {
   3.4922351885*^9, 3.492235189015625*^9}, {3.4922353505625*^9, 
   3.492235377171875*^9}},
 FontSize->10],

Cell["The system takes the form ", "Text",
 CellChangeTimes->{{3.44955816438404*^9, 3.4495581756902976`*^9}, {
  3.4922357165625*^9, 3.49223572934375*^9}},
 TextJustification->0.,
 FontSize->12,
 Background->GrayLevel[0.85]],

Cell[BoxData[
 RowBox[{"TableForm", "[", 
  RowBox[{"FourierSys", "[", 
   RowBox[{
    RowBox[{"u", "[", 
     RowBox[{"x", ",", "t"}], "]"}], ",", 
    RowBox[{"q", "[", 
     RowBox[{"x", ",", "t"}], "]"}]}], "]"}], "]"}]], "Input",
 CellChangeTimes->{{3.4495580358592305`*^9, 3.449558046294235*^9}, {
   3.4495580812044334`*^9, 3.4495580822559457`*^9}, {3.4495581827003775`*^9, 
   3.449558195298493*^9}, {3.449564064648203*^9, 3.449564068393589*^9}, 
   3.49223537934375*^9, {3.49223566840625*^9, 3.492235683109375*^9}},
 FontSize->12],

Cell["but there no way to use DSolve", "Text",
 CellChangeTimes->{{3.4495587950809374`*^9, 3.4495588292801137`*^9}, {
  3.449559357699944*^9, 3.449559358360894*^9}, {3.4496342739375*^9, 
  3.4496342863125*^9}, {3.49223575946875*^9, 3.4922357796875*^9}},
 TextJustification->0.,
 FontSize->12,
 Background->GrayLevel[0.85]],

Cell[BoxData[
 RowBox[{"DSolve", "[", 
  RowBox[{
   RowBox[{"FourierSys", "[", 
    RowBox[{
     RowBox[{"u", "[", 
      RowBox[{"x", ",", "t"}], "]"}], ",", 
     RowBox[{"Cos", "[", 
      RowBox[{"2", "\[Pi]", " ", "t"}], "]"}]}], "]"}], ",", "u", ",", 
   RowBox[{"{", 
    RowBox[{"x", ",", "t"}], "}"}]}], "]"}]], "Input",
 CellChangeTimes->{
  3.449558869578059*^9, {3.4495593655512333`*^9, 3.4495593683352365`*^9}, {
   3.4495594589955997`*^9, 3.449559488558109*^9}, {3.4495595418447313`*^9, 
   3.449559541984933*^9}, 3.49223538940625*^9},
 FontSize->12]
}, Closed]],

Cell[CellGroupData[{

Cell["Part III", "Text",
 CellChangeTimes->{{3.44258518478125*^9, 3.44258519865625*^9}, {
   3.44258529084375*^9, 3.442585294265625*^9}, {3.44258532753125*^9, 
   3.442585334765625*^9}, {3.44942116988004*^9, 3.449421170320674*^9}, 
   3.4494864070941954`*^9, {3.4494865195759363`*^9, 3.4494865340868015`*^9}, {
   3.449487521636829*^9, 3.449487522017376*^9}, {3.449488445975963*^9, 
   3.4494884514638543`*^9}, 3.449579794386456*^9, 3.449640877921875*^9, {
   3.4921761771875*^9, 3.492176200296875*^9}, {3.49223382640625*^9, 
   3.49223383178125*^9}, 3.49225578146875*^9, {3.492255900328125*^9, 
   3.49225590225*^9}, {3.492256253765625*^9, 3.4922562644375*^9}, {
   3.4922575040625*^9, 3.49225752615625*^9}, {3.574493795588772*^9, 
   3.574493795987795*^9}},
 FontSize->24,
 FontColor->RGBColor[0, 0, 1],
 Background->RGBColor[1, 0.9, 0.8]],

Cell[CellGroupData[{

Cell["Part  III.1  Analytical solution ", "Text",
 CellChangeTimes->{{3.449411809610634*^9, 3.4494118132658896`*^9}, {
   3.4495478930846367`*^9, 3.4495478951275744`*^9}, 3.4495798226571074`*^9, {
   3.4496405459375*^9, 3.449640559890625*^9}, {3.4922359399375*^9, 
   3.492235965828125*^9}, 3.4922360090625*^9, {3.49225592715625*^9, 
   3.492255936390625*^9}, {3.4922562916875*^9, 3.49225631484375*^9}},
 FontSize->14,
 Background->GrayLevel[0.85]],

Cell["The source is given by", "Text",
 CellChangeTimes->{{3.449547939932*^9, 3.449547940042158*^9}, {
  3.449550198750021*^9, 3.4495502122093744`*^9}, {3.4495509922510195`*^9, 
  3.4495509947145615`*^9}, {3.49223599575*^9, 3.492236004703125*^9}},
 FontSize->12,
 Background->GrayLevel[0.85]],

Cell[BoxData[
 RowBox[{
  RowBox[{"sourceqxt", "[", 
   RowBox[{"x_", ",", "t_", ",", "f_", ",", "q0_"}], "]"}], ":=", 
  RowBox[{"q0", " ", "x", 
   RowBox[{"(", 
    RowBox[{"p", "-", "x"}], ")"}], 
   RowBox[{"Cos", "[", 
    RowBox[{"2", "\[Pi]", " ", "f", " ", "t"}], "]"}], "    ", 
   RowBox[{"(*", " ", 
    RowBox[{"W", "/", "m"}], " ", "*)"}]}]}]], "Input",
 CellChangeTimes->{{3.4495479600008574`*^9, 3.449547979138376*^9}, {
   3.449548019175947*^9, 3.449548027187467*^9}, {3.4495530879945507`*^9, 
   3.449553089056077*^9}, {3.45054011128125*^9, 3.45054012790625*^9}, {
   3.45058245671875*^9, 3.450582460671875*^9}, {3.450582502046875*^9, 
   3.4505825264375*^9}, {3.450582577578125*^9, 3.450582581921875*^9}, {
   3.450582636703125*^9, 3.450582643609375*^9}, {3.45058294615625*^9, 
   3.450582976578125*^9}, 3.49223587425*^9, {3.492257485890625*^9, 
   3.492257491453125*^9}, {3.49225826453125*^9, 3.4922582651875*^9}, 
   3.49225949734375*^9},
 FontSize->12],

Cell["where the intensity is given by ", "Text",
 CellChangeTimes->{{3.450582472171875*^9, 3.45058247384375*^9}, {
  3.450582569109375*^9, 3.4505825700625*^9}, {3.492236149546875*^9, 
  3.492236162609375*^9}},
 FontSize->12,
 Background->GrayLevel[0.85]],

Cell[BoxData[
 RowBox[{
  RowBox[{"q0", "=", "1000"}], "    ", 
  RowBox[{"(*", " ", 
   RowBox[{"W", "/", "m"}], " ", "*)"}], ";"}]], "Input",
 CellChangeTimes->{{3.450582477734375*^9, 3.450582496328125*^9}, 
   3.45058298128125*^9, {3.4921668558125*^9, 3.4921668563125*^9}, {
   3.492170719546875*^9, 3.492170719953125*^9}, {3.49217081615625*^9, 
   3.492170816640625*^9}, 3.492258277828125*^9},
 FontSize->12],

Cell["To have a period of 1 second, we put", "Text",
 CellChangeTimes->{{3.449556628635742*^9, 3.4495566351250734`*^9}, {
  3.450582465484375*^9, 3.450582470390625*^9}, {3.492236073765625*^9, 
  3.4922360926875*^9}, {3.4922361234375*^9, 3.49223612528125*^9}},
 FontSize->12,
 Background->GrayLevel[0.85]],

Cell[BoxData[{
 RowBox[{
  RowBox[{"fvalue", "=", 
   RowBox[{"1", "/", 
    RowBox[{"(", 
     RowBox[{"2", "\[Pi]"}], ")"}]}]}], "   ", 
  RowBox[{"(*", " ", "Hz", " ", "*)"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"T", "[", "f_", "]"}], ":=", 
   RowBox[{"1", "/", "f"}]}], "          ", 
  RowBox[{"(*", " ", "s", "  ", "*)"}], ";"}]}], "Input",
 CellChangeTimes->{{3.44259198075*^9, 3.44259208715625*^9}, {
   3.44259222646875*^9, 3.442592269421875*^9}, {3.44259238734375*^9, 
   3.442592566*^9}, {3.442592596046875*^9, 3.4425925970625*^9}, 
   3.44259428575*^9, {3.442595047078125*^9, 3.442595086328125*^9}, {
   3.4492968033125*^9, 3.44929681625*^9}, {3.449296847015625*^9, 
   3.449296847359375*^9}, 3.44929709203125*^9, 3.449300577421875*^9, {
   3.44930086553125*^9, 3.449300889390625*^9}, 3.449301375515625*^9, {
   3.449308109875*^9, 3.4493081246875*^9}, {3.4493089131875*^9, 
   3.449308914828125*^9}, {3.44930896478125*^9, 3.449308997015625*^9}, {
   3.449309086984375*^9, 3.449309089828125*^9}, {3.4493147146597347`*^9, 
   3.4493147313637533`*^9}, {3.4493160288294177`*^9, 
   3.4493160464747906`*^9}, {3.4493161103766766`*^9, 3.4493161136313567`*^9}, 
   3.4493180643263187`*^9, 3.449320679646965*^9, {3.449323692829709*^9, 
   3.4493237102747936`*^9}, {3.4493238009652*^9, 3.4493238040195923`*^9}, {
   3.4493240650849857`*^9, 3.4493240937261696`*^9}, {3.4493264294047103`*^9, 
   3.449326449373424*^9}, {3.4494637956875*^9, 3.44946384140625*^9}, {
   3.4495548026300755`*^9, 3.4495548690555906`*^9}, {3.4495556791003776`*^9, 
   3.449555695133432*^9}, {3.4495566409634686`*^9, 3.449556649756112*^9}, {
   3.4495566982858944`*^9, 3.4495567064075727`*^9}, {3.45053995828125*^9, 
   3.450539966375*^9}, {3.450540120578125*^9, 3.450540121375*^9}, {
   3.450544103265625*^9, 3.450544134984375*^9}, {3.492236106265625*^9, 
   3.492236113421875*^9}},
 FontSize->12],

Cell["\<\
This function is consistent with the boundary conditions (1.2) 
and is symmetric with respect to p/2; in fact, \
\>", "Text",
 CellChangeTimes->{{3.4495482815632415`*^9, 3.4495483062887955`*^9}, {
  3.49223620840625*^9, 3.492236256375*^9}, {3.49223628959375*^9, 
  3.492236324234375*^9}},
 FontSize->12,
 Background->GrayLevel[0.85]],

Cell[BoxData[
 RowBox[{
  RowBox[{"sourceqxt", "[", 
   RowBox[{"0", ",", "t", ",", "f", ",", "q0"}], "]"}], "===", 
  RowBox[{"sourceqxt", "[", 
   RowBox[{"p", ",", "t", ",", "f", ",", "q0"}], "]"}], "===", "0"}]], "Input",
 CellChangeTimes->{{3.449551078745392*^9, 3.449551113765749*^9}, {
  3.4495511942414675`*^9, 3.4495511998094735`*^9}, {3.449553095275019*^9, 
  3.449553098629843*^9}, {3.45058267465625*^9, 3.45058267759375*^9}, {
  3.4505829913125*^9, 3.450582992421875*^9}, {3.450585277140625*^9, 
  3.45058528153125*^9}, {3.492235882390625*^9, 3.492235882875*^9}, {
  3.49225828153125*^9, 3.492258286703125*^9}},
 FontSize->12],

Cell[BoxData[
 RowBox[{
  RowBox[{"sourceqxt", "[", 
   RowBox[{
    RowBox[{"p", "-", "x"}], ",", "t", ",", "f", ",", "q0"}], "]"}], "===", 
  RowBox[{"sourceqxt", "[", 
   RowBox[{"x", ",", "t", ",", "f", ",", "q0"}], "]"}]}]], "Input",
 CellChangeTimes->{{3.4495482867206573`*^9, 3.4495482972257633`*^9}, {
   3.449553091790008*^9, 3.4495530922306414`*^9}, {3.450582613484375*^9, 
   3.450582613796875*^9}, 3.45058298825*^9, {3.45058514853125*^9, 
   3.450585152609375*^9}, 3.45058522875*^9, {3.492235875765625*^9, 
   3.492235881609375*^9}, {3.49225828396875*^9, 3.4922582898125*^9}},
 FontSize->12],

Cell[TextData[{
 "To calculate  ",
 Cell[BoxData[
  FormBox[
   SubscriptBox["Q", "n"], TraditionalForm]]],
 " (1.q) and ",
 Cell[BoxData[
  FormBox[
   RowBox[{
    SubscriptBox["E", "n"], " ", 
    RowBox[{"(", 
     RowBox[{"1.", "e"}], ")"}]}], TraditionalForm]]],
 ", we set"
}], "Text",
 CellChangeTimes->{{3.4495513460697856`*^9, 3.4495513553631487`*^9}, {
   3.4495514169316797`*^9, 3.449551448847573*^9}, {3.449552238242667*^9, 
   3.449552272832405*^9}, {3.449552393035248*^9, 3.449552397111109*^9}, {
   3.449553007659034*^9, 3.4495530427294626`*^9}, {3.49223657675*^9, 
   3.492236583203125*^9}, {3.492236620671875*^9, 3.4922366494375*^9}, 
   3.5744939325096035`*^9},
 FontSize->12,
 Background->GrayLevel[0.85]],

Cell[BoxData[
 RowBox[{
  RowBox[{"Qn", "[", 
   RowBox[{"t_", ",", "n_", ",", "f_", ",", "q0_"}], "]"}], "=", 
  RowBox[{
   FractionBox["2", "p"], 
   FractionBox[
    SuperscriptBox["a", "2"], "k"], 
   RowBox[{"Integrate", "[", 
    RowBox[{
     RowBox[{
      RowBox[{"sourceqxt", "[", 
       RowBox[{"x", ",", "t", ",", "f", ",", "q0"}], "]"}], 
      RowBox[{"Xn", "[", 
       RowBox[{"x", ",", "n"}], "]"}]}], ",", 
     RowBox[{"{", 
      RowBox[{"x", ",", "0", ",", "p"}], "}"}], ",", 
     RowBox[{"Assumptions", "\[Rule]", 
      RowBox[{"n", "\[Element]", "Integers"}]}]}], "]"}]}]}]], "Input",
 CellChangeTimes->{{3.442595297328125*^9, 3.442595301765625*^9}, {
   3.442595339515625*^9, 3.44259534096875*^9}, {3.442595382078125*^9, 
   3.4425954484375*^9}, {3.442595489828125*^9, 3.442595552609375*^9}, {
   3.442595586609375*^9, 3.442595662859375*^9}, {3.442595700296875*^9, 
   3.442595709375*^9}, {3.442595929484375*^9, 3.442595941859375*^9}, 
   3.44259598628125*^9, {3.442596034984375*^9, 3.44259603803125*^9}, {
   3.4425960985625*^9, 3.442596124328125*^9}, 3.442596943046875*^9, {
   3.442597013859375*^9, 3.442597068109375*^9}, {3.44259734934375*^9, 
   3.442597356171875*^9}, {3.4493223565582447`*^9, 3.44932236590168*^9}, {
   3.4493239208075247`*^9, 3.4493239249835296`*^9}, {3.4493239580811214`*^9, 
   3.4493239582113085`*^9}, {3.4493248076727743`*^9, 3.449324809966072*^9}, {
   3.44946230728125*^9, 3.449462321828125*^9}, {3.449462364546875*^9, 
   3.44946237184375*^9}, {3.449552310837053*^9, 3.4495523572938547`*^9}, {
   3.450582681984375*^9, 3.450582695765625*^9}, {3.450582995171875*^9, 
   3.4505829964375*^9}, 3.492166497625*^9, 3.4922358835625*^9, 
   3.49223646396875*^9, {3.4922582969375*^9, 3.492258301265625*^9}},
 FontSize->12],

Cell["and", "Text",
 CellChangeTimes->{{3.4495513460697856`*^9, 3.4495513553631487`*^9}, {
  3.4495514169316797`*^9, 3.449551448847573*^9}, {3.449552238242667*^9, 
  3.449552272832405*^9}, {3.449552393035248*^9, 3.449552397111109*^9}, {
  3.449553007659034*^9, 3.4495530427294626`*^9}, {3.49223657675*^9, 
  3.492236583203125*^9}, {3.492236620671875*^9, 3.4922366494375*^9}, {
  3.492248594625*^9, 3.4922485986875*^9}},
 FontSize->12,
 Background->GrayLevel[0.85]],

Cell[BoxData[
 RowBox[{
  RowBox[{"En", "[", 
   RowBox[{"t_", ",", "n_", ",", "f_", ",", "q0_"}], "]"}], "=", 
  RowBox[{
   SuperscriptBox["\[ExponentialE]", 
    RowBox[{
     RowBox[{"-", 
      SuperscriptBox["a", "2"]}], 
     SuperscriptBox[
      RowBox[{"\[Lambda]", "[", "n", "]"}], "2"], "t"}]], 
   RowBox[{"Integrate", "[", 
    RowBox[{
     RowBox[{
      SuperscriptBox["\[ExponentialE]", 
       RowBox[{
        SuperscriptBox["a", "2"], 
        SuperscriptBox[
         RowBox[{"\[Lambda]", "[", "n", "]"}], "2"], "\[Tau]"}]], 
      RowBox[{"Qn", "[", 
       RowBox[{"\[Tau]", ",", "n", ",", "f", ",", "q0"}], "]"}]}], ",", 
     RowBox[{"{", 
      RowBox[{"\[Tau]", ",", "0", ",", "t"}], "}"}]}], "]"}]}]}]], "Input",
 CellChangeTimes->{{3.450582703515625*^9, 3.4505827205625*^9}, {
   3.450582999796875*^9, 3.450583002359375*^9}, 3.49223646525*^9, 
   3.492236525390625*^9, {3.492258309375*^9, 3.492258321265625*^9}},
 FontSize->12],

Cell["Then:", "Text",
 CellChangeTimes->{{3.449553209298978*^9, 3.4495532100700865`*^9}, 
   3.449553262715787*^9, {3.49223677071875*^9, 3.492236773453125*^9}, 
   3.5744939349407425`*^9},
 FontSize->12,
 Background->GrayLevel[0.85]],

Cell[BoxData[
 RowBox[{
  RowBox[{"Un", "[", 
   RowBox[{"x_", ",", "t_", ",", "n_", ",", "f_", ",", "q0_"}], "]"}], ":=", 
  RowBox[{
   RowBox[{"Xn", "[", 
    RowBox[{"x", ",", "n"}], "]"}], "*", 
   RowBox[{"En", "[", 
    RowBox[{"t", ",", "n", ",", "f", ",", "q0"}], "]"}]}]}]], "Input",
 CellChangeTimes->{{3.442595890953125*^9, 3.44259589565625*^9}, {
   3.442595972375*^9, 3.442595980359375*^9}, {3.44259610390625*^9, 
   3.442596159375*^9}, {3.4493239828667617`*^9, 3.449323990307461*^9}, {
   3.449462344796875*^9, 3.4494623475625*^9}, {3.449462424765625*^9, 
   3.449462430609375*^9}, {3.449463413734375*^9, 3.449463415734375*^9}, {
   3.449463679515625*^9, 3.449463680046875*^9}, {3.4495532838662*^9, 
   3.449553284597251*^9}, {3.450582729625*^9, 3.450582738734375*^9}, {
   3.45058301503125*^9, 3.45058301734375*^9}, 3.492236529578125*^9, {
   3.492236728796875*^9, 3.49223672975*^9}, {3.49223678021875*^9, 
   3.492236798296875*^9}, {3.49225832659375*^9, 3.4922583311875*^9}},
 FontSize->12],

Cell[BoxData[
 RowBox[{"Un", "[", 
  RowBox[{"x", ",", "t", ",", "n", ",", "f", ",", "A"}], "]"}]], "Input",
 CellChangeTimes->{{3.442595890953125*^9, 3.44259589565625*^9}, {
   3.442595972375*^9, 3.442595980359375*^9}, {3.44259610390625*^9, 
   3.442596159375*^9}, {3.4493239828667617`*^9, 3.449323990307461*^9}, {
   3.449462344796875*^9, 3.4494623475625*^9}, {3.449462424765625*^9, 
   3.449462430609375*^9}, {3.449463413734375*^9, 3.449463415734375*^9}, {
   3.449463679515625*^9, 3.449463680046875*^9}, {3.4495532838662*^9, 
   3.449553284597251*^9}, {3.450582729625*^9, 3.450582738734375*^9}, {
   3.45058301503125*^9, 3.45058301734375*^9}, 3.492236529578125*^9, {
   3.492236728796875*^9, 3.49223672975*^9}, {3.49223678021875*^9, 
   3.492236798296875*^9}},
 FontSize->12],

Cell[TextData[{
 "Since ",
 Cell[BoxData[
  FormBox[
   RowBox[{"(", 
    RowBox[{
     RowBox[{"-", "1"}], "+", 
     SuperscriptBox[
      RowBox[{"(", 
       RowBox[{"-", "1"}], ")"}], "n"]}], ")"}], TraditionalForm]]],
 ", ",
 Cell[BoxData[
  FormBox[
   SubscriptBox["U", "n"], TraditionalForm]]],
 " is zero when",
 StyleBox[" n",
  FontSlant->"Italic"],
 " is even. Anyway, this rule is useful"
}], "Text",
 CellChangeTimes->{{3.4493244687454205`*^9, 3.4493245566418095`*^9}, {
   3.4506781488125*^9, 3.450678189109375*^9}, 3.450678441015625*^9, {
   3.492248656515625*^9, 3.492248686453125*^9}, {3.492248720390625*^9, 
   3.4922487295*^9}, 3.492256037921875*^9, 3.5744939395890083`*^9},
 FontSize->12,
 Background->GrayLevel[0.85]],

Cell[BoxData[
 RowBox[{"TrigId", "=", 
  RowBox[{"{", 
   RowBox[{
    RowBox[{
     RowBox[{"Cos", "[", 
      RowBox[{"\[Pi]", " ", "n_"}], "]"}], "\[Rule]", 
     SuperscriptBox[
      RowBox[{"(", 
       RowBox[{"-", "1"}], ")"}], "n"]}], ",", 
    RowBox[{
     RowBox[{"Sin", "[", 
      RowBox[{"\[Pi]", " ", "n_"}], "]"}], "\[Rule]", "0"}]}], 
   "}"}]}]], "Input",
 CellChangeTimes->{{3.49223718946875*^9, 3.492237197296875*^9}},
 FontSize->14],

Cell[BoxData[
 RowBox[{
  RowBox[{"Simplify", "[", 
   RowBox[{
    RowBox[{"Un", "[", 
     RowBox[{"x", ",", "t", ",", 
      RowBox[{"2", "m"}], ",", "f", ",", "q0"}], "]"}], ",", 
    RowBox[{"Assumptions", "\[Rule]", 
     RowBox[{"m", "\[Element]", "Integers"}]}]}], "]"}], " ", "/.", " ", 
  "TrigId"}]], "Input",
 CellChangeTimes->{{3.449324460583685*^9, 3.4493244607238865`*^9}, 
   3.44946246278125*^9, {3.450582743125*^9, 3.450582743359375*^9}, 
   3.45058302065625*^9, 3.49223673725*^9, {3.49223721740625*^9, 
   3.4922372189375*^9}, 3.492258338125*^9},
 FontSize->12],

Cell[TextData[{
 "Therefore, we make in ",
 Cell[BoxData[
  FormBox[
   SubscriptBox["U", "n"], TraditionalForm]]],
 " the substitution   ",
 Cell[BoxData[
  FormBox[
   RowBox[{"n", "\[Rule]", 
    RowBox[{
     RowBox[{"2", "m"}], "+", "1"}]}], TraditionalForm]]]
}], "Text",
 CellChangeTimes->{{3.4493244687454205`*^9, 3.449324567217016*^9}, {
   3.449463372125*^9, 3.449463381921875*^9}, {3.4495533746166925`*^9, 
   3.4495533952363424`*^9}, 3.449555596261261*^9, {3.4495596452734547`*^9, 
   3.449559655007451*^9}, {3.492248766296875*^9, 3.4922488116875*^9}},
 FontSize->12,
 Background->GrayLevel[0.85]],

Cell[BoxData[
 RowBox[{
  RowBox[{"Un", "[", 
   RowBox[{"x_", ",", "t_", ",", "m_", ",", "f_", ",", "q0_"}], "]"}], "=", 
  RowBox[{"Simplify", "[", 
   RowBox[{
    RowBox[{"Un", "[", 
     RowBox[{"x", ",", "t", ",", 
      RowBox[{
       RowBox[{"2", "m"}], "+", "1"}], ",", "f", ",", "q0"}], "]"}], ",", 
    RowBox[{"Assumptions", "\[Rule]", 
     RowBox[{"m", "\[Element]", "Integers"}]}]}], "]"}]}]], "Input",
 CellChangeTimes->{{3.4493244098006625`*^9, 3.449324428697835*^9}, 
   3.449462464484375*^9, {3.449462915359375*^9, 3.4494629175625*^9}, 
   3.449463386*^9, {3.4494634395*^9, 3.449463545875*^9}, {3.449463582625*^9, 
   3.449463639734375*^9}, {3.449463675015625*^9, 3.449463683890625*^9}, {
   3.449463804234375*^9, 3.449463805828125*^9}, {3.449553351353242*^9, 
   3.449553354617936*^9}, {3.450582753078125*^9, 3.450582762265625*^9}, {
   3.45058302528125*^9, 3.450583027640625*^9}, {3.492236738234375*^9, 
   3.492236740390625*^9}, 3.492237234703125*^9, {3.492237554625*^9, 
   3.492237564609375*^9}, {3.49225834290625*^9, 3.492258346859375*^9}},
 FontSize->12],

Cell[TextData[{
 "An approximation of ",
 Cell[BoxData[
  FormBox[
   RowBox[{"U", "[", 
    RowBox[{"x", ",", "t"}], "]"}], TraditionalForm]]],
 ", summing the first ",
 StyleBox["n",
  FontSlant->"Italic"],
 " terms, is given by"
}], "Text",
 CellChangeTimes->{{3.449555527452318*^9, 3.449555568200912*^9}, {
  3.492237972046875*^9, 3.4922380259375*^9}},
 FontSize->12,
 Background->GrayLevel[0.85]],

Cell[BoxData[
 RowBox[{
  RowBox[{"Usymb", "[", 
   RowBox[{"x_", ",", "t_", ",", "n_", ",", "f_", ",", "q0_"}], "]"}], ":=", 
  RowBox[{
   RowBox[{"Sum", "[", 
    RowBox[{
     RowBox[{"Un", "[", 
      RowBox[{"x", ",", "t", ",", "m", ",", "f", ",", "q0"}], "]"}], ",", 
     RowBox[{"{", 
      RowBox[{"m", ",", "0", ",", "n"}], "}"}]}], "]"}], "/.", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"k", "\[Rule]", "kvalue"}], ",", 
     RowBox[{"\[Rho]", "\[Rule]", "\[Rho]value"}], ",", 
     RowBox[{"c", "\[Rule]", "cvalue"}], ",", 
     RowBox[{"p", "\[Rule]", "pvalue"}]}], "}"}]}]}]], "Input",
 CellChangeTimes->{{3.45058277915625*^9, 3.450582783953125*^9}, {
   3.45058303340625*^9, 3.450583034609375*^9}, {3.492166515921875*^9, 
   3.492166516515625*^9}, 3.49223674134375*^9, 3.492237630328125*^9, {
   3.4922377731875*^9, 3.49223777421875*^9}, {3.49225835425*^9, 
   3.49225835734375*^9}},
 FontSize->12],

Cell[TextData[{
 "where ",
 StyleBox["m",
  FontSlant->"Italic"],
 " must start from zero"
}], "Text",
 CellChangeTimes->{{3.449555958592267*^9, 3.449556016014837*^9}, {
  3.4495596623379917`*^9, 3.4495596649517508`*^9}, {3.49224885590625*^9, 
  3.49224888428125*^9}},
 FontSize->12,
 Background->GrayLevel[0.85]],

Cell["Summarizing :", "Text",
 CellChangeTimes->{{3.449553705202051*^9, 3.4495537069145136`*^9}, {
  3.492238035921875*^9, 3.4922380416875*^9}, {3.492238216921875*^9, 
  3.492238224515625*^9}},
 FontSize->12,
 Background->GrayLevel[0.85]],

Cell[BoxData[
 RowBox[{"                    ", 
  RowBox[{
   RowBox[{
    SubscriptBox["Q", "m"], "[", "t", "]"}], "=", 
   RowBox[{
    SuperscriptBox[
     RowBox[{"(", 
      FractionBox["2", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{
          RowBox[{"2", "m"}], "+", "1"}], ")"}], " ", "\[Pi]"}]], ")"}], "3"], 
    FractionBox[
     SuperscriptBox["p", "2"], "k"], 
    RowBox[{"Cos", "[", 
     RowBox[{"2", "\[Pi]", " ", "f", " ", "t"}], 
     "]"}]}]}]}]], "EquationNumbered",
 CellChangeTimes->{{3.4495562160024047`*^9, 3.449556273715392*^9}, 
   3.49216651946875*^9, {3.492238091828125*^9, 3.492238093046875*^9}},
 FontSize->12],

Cell[BoxData[
 RowBox[{"                     ", 
  RowBox[{
   RowBox[{
    SubscriptBox["E", "m"], "[", "t", "]"}], "=", 
   RowBox[{
    FractionBox[
     RowBox[{"32", "q0", " ", 
      SuperscriptBox["p", "2"]}], 
     RowBox[{
      SuperscriptBox[
       RowBox[{"(", 
        RowBox[{
         RowBox[{"2", "m"}], "+", "1"}], ")"}], "5"], 
      SuperscriptBox["\[Pi]", "5"], "k"}]], 
    FractionBox["1", 
     RowBox[{"1", "+", 
      RowBox[{
       SuperscriptBox[
        RowBox[{"(", 
         RowBox[{"2", "\[Pi]", " ", "f"}], " ", ")"}], "2"], 
       SuperscriptBox[
        RowBox[{"(", 
         FractionBox["p", 
          RowBox[{"a", " ", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{"2", "m"}], "+", "1"}], ")"}], " ", "\[Pi]"}]], ")"}], 
        "4"]}]}]], "*", "\[IndentingNewLine]", "                      ", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"2", "\[Pi]", " ", "f", " ", 
       SuperscriptBox[
        RowBox[{"(", 
         FractionBox["p", 
          RowBox[{"a", " ", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{"2", "m"}], "+", "1"}], ")"}], " ", "\[Pi]"}]], ")"}], 
        "2"], "Sin", 
       RowBox[{"(", 
        RowBox[{"2", "\[Pi]", " ", "f", " ", "t"}], ")"}]}], "+", 
      RowBox[{"Cos", 
       RowBox[{"(", 
        RowBox[{"2", "\[Pi]", " ", "f", " ", "t"}], ")"}]}], "-", 
      SuperscriptBox["\[ExponentialE]", 
       RowBox[{
        RowBox[{"-", "t"}], 
        SuperscriptBox[
         RowBox[{"(", 
          RowBox[{"a", " ", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{"2", "m"}], "+", "1"}], ")"}], " ", 
           RowBox[{"\[Pi]", "/", "p"}]}], ")"}], "2"]}]]}], 
     "}"}]}]}]}]], "EquationNumbered",
 CellChangeTimes->{{3.449556127585267*^9, 3.4495561625755806`*^9}, {
   3.45058537428125*^9, 3.45058537765625*^9}, {3.450585470859375*^9, 
   3.450585475046875*^9}, 3.492166520046875*^9, {3.49223809440625*^9, 
   3.49223810103125*^9}, 3.4922489076875*^9, 3.492260205171875*^9},
 FontSize->12],

Cell[BoxData[
 RowBox[{"                        ", 
  RowBox[{
   RowBox[{"U", 
    RowBox[{"(", 
     RowBox[{"x", ",", "t"}], ")"}]}], "=", 
   RowBox[{
    UnderoverscriptBox["\[Sum]", 
     RowBox[{"m", "=", "0"}], "\[Infinity]"], 
    RowBox[{
     FractionBox[
      RowBox[{"32", "q0", " ", 
       SuperscriptBox["p", "2"]}], 
      RowBox[{
       SuperscriptBox[
        RowBox[{"(", 
         RowBox[{
          RowBox[{"2", "m"}], "+", "1"}], ")"}], "5"], 
       SuperscriptBox["\[Pi]", "5"], "k"}]], 
     FractionBox["1", 
      RowBox[{"1", "+", 
       RowBox[{
        SuperscriptBox[
         RowBox[{"(", 
          RowBox[{"2", "\[Pi]", " ", "f"}], " ", ")"}], "2"], 
        SuperscriptBox[
         RowBox[{"(", 
          FractionBox["p", 
           RowBox[{"a", " ", 
            RowBox[{"(", 
             RowBox[{
              RowBox[{"2", "m"}], "+", "1"}], ")"}], " ", "\[Pi]"}]], ")"}], 
         "4"]}]}]], "*", "\[IndentingNewLine]", "                     ", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"2", "\[Pi]", " ", "f", " ", 
        SuperscriptBox[
         RowBox[{"(", 
          FractionBox["p", 
           RowBox[{"a", " ", 
            RowBox[{"(", 
             RowBox[{
              RowBox[{"2", "m"}], "+", "1"}], ")"}], " ", "\[Pi]"}]], ")"}], 
         "2"], "Sin", 
        RowBox[{"(", 
         RowBox[{"2", "\[Pi]", " ", "f", " ", "t"}], ")"}]}], "+", 
       RowBox[{"Cos", 
        RowBox[{"(", 
         RowBox[{"2", "\[Pi]", " ", "f", " ", "t"}], ")"}]}], "-", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         SuperscriptBox[
          RowBox[{"t", "(", 
           RowBox[{"a", " ", 
            RowBox[{"(", 
             RowBox[{
              RowBox[{"2", "m"}], "+", "1"}], ")"}], " ", 
            RowBox[{"\[Pi]", "/", "p"}]}], ")"}], "2"]}]]}], "}"}], "Sin", 
     RowBox[{"(", 
      RowBox[{
       FractionBox[
        RowBox[{
         RowBox[{"(", 
          RowBox[{
           RowBox[{"2", "m"}], "+", "1"}], ")"}], " ", "\[Pi]"}], "p"], "x"}],
       ")"}]}]}]}]}]], "EquationNumbered",
 CellChangeTimes->{{3.449553846044573*^9, 3.449553855087576*^9}, 
   3.450585480390625*^9, 3.49216652059375*^9, {3.49223810503125*^9, 
   3.492238110875*^9}, 3.49224891115625*^9, 3.49226022065625*^9},
 FontSize->12],

Cell["\<\
We can verify that the equation is satisfied; in fact,\
\>", "Text",
 CellChangeTimes->{{3.4495551304314303`*^9, 3.449555179792408*^9}, 
   3.4495552158542624`*^9, {3.449555296710528*^9, 3.4495553448898067`*^9}, {
   3.449555376094677*^9, 3.449555376254907*^9}, {3.492238535734375*^9, 
   3.492238609921875*^9}, 3.49224893021875*^9, {3.5744939586440983`*^9, 
   3.5744939671725855`*^9}},
 TextJustification->0.,
 FontSize->12,
 Background->GrayLevel[0.85]],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{
    RowBox[{
     SubscriptBox["\[PartialD]", "t"], " ", 
     RowBox[{"En", "[", 
      RowBox[{"t", ",", "n", ",", "f", ",", "q0"}], "]"}]}], "+", 
    RowBox[{
     SuperscriptBox["a", "2"], 
     SuperscriptBox[
      RowBox[{"\[Lambda]", "[", "n", "]"}], "2"], 
     RowBox[{"En", "[", 
      RowBox[{"t", ",", "n", ",", "f", ",", "q0"}], "]"}]}]}], "==", 
   RowBox[{"Qn", "[", 
    RowBox[{"t", ",", "n", ",", "f", ",", "q0"}], "]"}]}], "//", 
  "Simplify"}]], "Input",
 CellChangeTimes->{{3.4495553967443695`*^9, 3.449555423262501*^9}, {
   3.45058280278125*^9, 3.45058280715625*^9}, {3.450583039578125*^9, 
   3.4505830415*^9}, 3.49223647259375*^9, {3.49223653159375*^9, 
   3.49223653215625*^9}, {3.49225836646875*^9, 3.492258374203125*^9}},
 FontSize->12],

Cell[BoxData[{
 RowBox[{
  RowBox[{
   RowBox[{"sourceqxt", "[", 
    RowBox[{"x_", ",", "t_"}], "]"}], "=", 
   RowBox[{
    RowBox[{"sourceqxt", "[", 
     RowBox[{"x", ",", "t", ",", "fvalue", ",", "q0"}], "]"}], "/.", 
    RowBox[{"p", "\[Rule]", "pvalue"}]}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{"Plot3D", "[", 
  RowBox[{
   RowBox[{"sourceqxt", "[", 
    RowBox[{"x", ",", "t"}], "]"}], ",", 
   RowBox[{"{", 
    RowBox[{"x", ",", "0", ",", "pvalue"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"t", ",", "0", ",", 
     RowBox[{"2", 
      RowBox[{"T", "[", "fvalue", "]"}]}]}], "}"}], ",", 
   RowBox[{"PlotLabel", "\[Rule]", 
    RowBox[{"Style", "[", 
     RowBox[{
      RowBox[{"q", "[", 
       RowBox[{"x", ",", "t"}], "]"}], ",", "Medium", ",", "Bold"}], 
     "]"}]}]}], "]"}]}], "Input",
 CellChangeTimes->{{3.449309229109375*^9, 3.449309230234375*^9}, 
   3.449314482716216*^9, {3.4493147506615024`*^9, 3.4493148026061954`*^9}, {
   3.4493160507509394`*^9, 3.449316056208787*^9}, {3.4493161212322865`*^9, 
   3.44931612601917*^9}, {3.4493264891105633`*^9, 3.449326499866029*^9}, {
   3.4493265325530305`*^9, 3.44932656468924*^9}, {3.4494176615753455`*^9, 
   3.449417666762805*^9}, {3.449463848265625*^9, 3.449463851421875*^9}, {
   3.4495559195160785`*^9, 3.44955592115844*^9}, {3.4495653666303616`*^9, 
   3.4495653972043247`*^9}, {3.4495654395852656`*^9, 3.449565457521056*^9}, {
   3.44959522615625*^9, 3.449595227421875*^9}, {3.45058281471875*^9, 
   3.450582816078125*^9}, 3.4505830444375*^9, {3.4922358845*^9, 
   3.492235886640625*^9}, {3.492238738890625*^9, 3.492238743328125*^9}, 
   3.492259636671875*^9},
 FontSize->14],

Cell[TextData[{
 "As ",
 Cell[BoxData[
  FormBox[
   RowBox[{
    SubscriptBox["U", "m"], "=", 
    RowBox[{"O", "(", 
     FractionBox["1", 
      SuperscriptBox[
       RowBox[{"(", 
        RowBox[{
         RowBox[{"2", "m"}], "+", "1"}], ")"}], "5"]], ")"}]}], 
   TraditionalForm]]],
 ", the dominant term is the first one"
}], "Text",
 CellChangeTimes->{{3.4493267361858397`*^9, 3.4493267560043373`*^9}, {
  3.449559715554514*^9, 3.44955971886928*^9}, {3.449559771675211*^9, 
  3.4495598122034883`*^9}, {3.449560177458699*^9, 3.4495602577842016`*^9}, {
  3.4495636110759983`*^9, 3.449563625436648*^9}, {3.4495636758891954`*^9, 
  3.449563684101003*^9}, {3.450678228828125*^9, 3.45067825709375*^9}, {
  3.492238846984375*^9, 3.49223888059375*^9}},
 TextJustification->0.,
 FontSize->14,
 Background->GrayLevel[0.85]],

Cell[BoxData[
 RowBox[{"Usymb", "[", 
  RowBox[{"x", ",", "t", ",", "0", ",", "fvalue", ",", "q0"}], "]"}]], "Input",
 CellChangeTimes->{{3.4493267638856707`*^9, 3.449326778797112*^9}, {
   3.449330169943341*^9, 3.4493301940980735`*^9}, {3.44933040771524*^9, 
   3.4493304149155936`*^9}, {3.4493305046145744`*^9, 
   3.4493305114544096`*^9}, {3.44946401146875*^9, 3.4494640125625*^9}, {
   3.450582827171875*^9, 3.45058284315625*^9}, 3.450583049484375*^9, {
   3.450583744171875*^9, 3.450583747109375*^9}, 3.492237637859375*^9, {
   3.492238918765625*^9, 3.492238919859375*^9}, 3.4922585875*^9},
 FontSize->14],

Cell["It looks like:", "Text",
 CellChangeTimes->{{3.4495603380696464`*^9, 3.449560406978733*^9}, {
   3.492248999375*^9, 3.49224900615625*^9}, 3.574494075924806*^9},
 FontSize->14,
 Background->GrayLevel[0.85]],

Cell[BoxData[{
 RowBox[{
  RowBox[{
   RowBox[{"Uoneterm", "[", 
    RowBox[{"x_", ",", "t_"}], "]"}], "=", 
   RowBox[{"Usymb", "[", 
    RowBox[{"x", ",", "t", ",", "0", ",", "fvalue", ",", "q0"}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{"Plot3D", "[", 
  RowBox[{
   RowBox[{"Uoneterm", "[", 
    RowBox[{"x", ",", "t"}], "]"}], ",", 
   RowBox[{"{", 
    RowBox[{"x", ",", "0", ",", "pvalue"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"t", ",", "0", ",", 
     RowBox[{"2", 
      RowBox[{"T", "[", "fvalue", "]"}]}]}], "}"}], ",", 
   RowBox[{"PlotLabel", "\[Rule]", 
    RowBox[{"Style", "[", 
     RowBox[{
      RowBox[{
       SubscriptBox["U", "0"], "[", 
       RowBox[{"x", ",", "t"}], "]"}], ",", "Medium", ",", "Bold"}], 
     "]"}]}]}], "]"}]}], "Input",
 CellChangeTimes->{{3.449300688015625*^9, 3.44930078109375*^9}, {
   3.44930905521875*^9, 3.44930906403125*^9}, {3.449309098484375*^9, 
   3.449309151*^9}, {3.449309194609375*^9, 3.449309223265625*^9}, {
   3.4493127345624943`*^9, 3.4493127375367713`*^9}, 3.4493139094318733`*^9, {
   3.449313951151864*^9, 3.449313954266342*^9}, {3.449314814813749*^9, 
   3.4493148421730895`*^9}, {3.449314943558875*^9, 3.449314947915139*^9}, {
   3.4493160592231216`*^9, 3.4493160624077005`*^9}, {3.4493161290935907`*^9, 
   3.4493161326086445`*^9}, {3.449316285688763*^9, 3.4493162865500016`*^9}, 
   3.449318071396485*^9, {3.44932072244851*^9, 3.449320733824869*^9}, {
   3.4493268894462175`*^9, 3.44932689266084*^9}, {3.4494638565*^9, 
   3.449463859390625*^9}, {3.449464163296875*^9, 3.449464171828125*^9}, 
   3.449555940816707*^9, {3.4495649451943665`*^9, 3.449565000233509*^9}, {
   3.4495651028710947`*^9, 3.4495651102416925`*^9}, {3.4495651417169523`*^9, 
   3.4495651859205136`*^9}, 3.4495652803462915`*^9, 3.449565325260875*^9, {
   3.449565546128467*^9, 3.4495655562229824`*^9}, 3.44959523584375*^9, {
   3.450582891421875*^9, 3.450582892953125*^9}, 3.450583048609375*^9, {
   3.492237641953125*^9, 3.49223764534375*^9}, {3.4922389340625*^9, 
   3.4922389351875*^9}, {3.492249085203125*^9, 3.49224909*^9}, 
   3.492258600453125*^9},
 FontSize->14],

Cell[TextData[{
 "If we sum up to ",
 Cell[BoxData[
  FormBox[
   RowBox[{"m", "=", "5"}], TraditionalForm]]],
 ", "
}], "Text",
 CellChangeTimes->{{3.44956041336792*^9, 3.4495604238229537`*^9}, 
   3.45054280625*^9, {3.492249017046875*^9, 3.492249031484375*^9}},
 FontSize->14,
 Background->GrayLevel[0.85]],

Cell[BoxData[{
 RowBox[{
  RowBox[{
   RowBox[{"Ufiveterms", "[", 
    RowBox[{"x_", ",", "t_"}], "]"}], "=", 
   RowBox[{"Usymb", "[", 
    RowBox[{"x", ",", "t", ",", "5", ",", "fvalue", ",", "q0"}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{"Plot3D", "[", 
  RowBox[{
   RowBox[{"Ufiveterms", "[", 
    RowBox[{"x", ",", "t"}], "]"}], ",", 
   RowBox[{"{", 
    RowBox[{"x", ",", "0", ",", "pvalue"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"t", ",", "0", ",", 
     RowBox[{"2", 
      RowBox[{"T", "[", "fvalue", "]"}]}]}], "}"}]}], "]"}]}], "Input",
 CellChangeTimes->{{3.44946440721875*^9, 3.449464409875*^9}, {
   3.4495565135502577`*^9, 3.4495565157233825`*^9}, {3.449565122990024*^9, 
   3.4495651233805857`*^9}, {3.449565566848261*^9, 3.4495655857654624`*^9}, {
   3.4495659590321937`*^9, 3.4495659592224674`*^9}, 3.449595240546875*^9, {
   3.4505415721875*^9, 3.45054157659375*^9}, 3.45054161846875*^9, {
   3.450542807828125*^9, 3.4505428110625*^9}, 3.450582905515625*^9, 
   3.45058305553125*^9, {3.492237646421875*^9, 3.49223764959375*^9}, {
   3.49223933240625*^9, 3.492239333578125*^9}, {3.49224915175*^9, 
   3.492249153265625*^9}, 3.492258610234375*^9},
 FontSize->14],

Cell[TextData[{
 "up to ",
 Cell[BoxData[
  FormBox[
   RowBox[{"m", "=", "10"}], TraditionalForm]]],
 ", "
}], "Text",
 CellChangeTimes->{{3.44956041336792*^9, 3.4495604238229537`*^9}, 
   3.45054280625*^9, {3.492249017046875*^9, 3.492249031484375*^9}, {
   3.492249541640625*^9, 3.492249548671875*^9}},
 FontSize->14,
 Background->GrayLevel[0.85]],

Cell[BoxData[{
 RowBox[{
  RowBox[{
   RowBox[{"Utenterms", "[", 
    RowBox[{"x_", ",", "t_"}], "]"}], "=", 
   RowBox[{"Usymb", "[", 
    RowBox[{"x", ",", "t", ",", "10", ",", "fvalue", ",", "q0"}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{"Plot3D", "[", 
  RowBox[{
   RowBox[{"Ufiveterms", "[", 
    RowBox[{"x", ",", "t"}], "]"}], ",", 
   RowBox[{"{", 
    RowBox[{"x", ",", "0", ",", "pvalue"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"t", ",", "0", ",", 
     RowBox[{"2", 
      RowBox[{"T", "[", "fvalue", "]"}]}]}], "}"}]}], "]"}]}], "Input",
 CellChangeTimes->{{3.44946440721875*^9, 3.449464409875*^9}, {
   3.4495565135502577`*^9, 3.4495565157233825`*^9}, {3.449565122990024*^9, 
   3.4495651233805857`*^9}, {3.449565566848261*^9, 3.4495655857654624`*^9}, {
   3.4495659590321937`*^9, 3.4495659592224674`*^9}, 3.449595240546875*^9, {
   3.4505415721875*^9, 3.45054157659375*^9}, 3.45054161846875*^9, {
   3.450542807828125*^9, 3.4505428110625*^9}, 3.450582905515625*^9, 
   3.45058305553125*^9, {3.492237646421875*^9, 3.49223764959375*^9}, {
   3.49223933240625*^9, 3.492239333578125*^9}, {3.492239415703125*^9, 
   3.492239421453125*^9}, 3.492249154046875*^9, 3.492249377046875*^9, {
   3.492249426046875*^9, 3.49224945609375*^9}, 3.492258620421875*^9},
 FontSize->14],

Cell["Absolute difference...", "Text",
 CellChangeTimes->{{3.44956041336792*^9, 3.4495604238229537`*^9}, 
   3.45054280625*^9, {3.492249017046875*^9, 3.492249031484375*^9}, {
   3.492249541640625*^9, 3.492249579328125*^9}, {3.492251236765625*^9, 
   3.49225123753125*^9}, {3.574494082220166*^9, 3.5744940833642316`*^9}},
 FontSize->14,
 Background->GrayLevel[0.85]],

Cell[BoxData[
 RowBox[{"Plot3D", "[", 
  RowBox[{
   RowBox[{
    RowBox[{"Uoneterm", "[", 
     RowBox[{"x", ",", "t"}], "]"}], "-", 
    RowBox[{"Utenterms", "[", 
     RowBox[{"x", ",", "t"}], "]"}]}], ",", 
   RowBox[{"{", 
    RowBox[{"x", ",", "0", ",", "pvalue"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"t", ",", "0", ",", 
     RowBox[{"2", 
      RowBox[{"T", "[", "fvalue", "]"}]}]}], "}"}], ",", 
   RowBox[{"PlotPoints", "\[Rule]", "35"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.492239362171875*^9, 3.492239375171875*^9}, {
   3.492239427734375*^9, 3.49223942865625*^9}, 3.49224909165625*^9, 
   3.49224937803125*^9, {3.49224948471875*^9, 3.492249491984375*^9}},
 FontSize->16],

Cell[TextData[{
 "We calculate at what time (",
 StyleBox["tAmpU",
  FontSlant->"Italic"],
 ") the first maximum, along  ",
 Cell[BoxData[
  FormBox[
   RowBox[{"x", "=", 
    RowBox[{"p", "/", "2"}]}], TraditionalForm]]],
 ", appears with a certain amplitude ",
 StyleBox["AmpU",
  FontSlant->"Italic"]
}], "Text",
 CellChangeTimes->{{3.450542876703125*^9, 3.4505429058125*^9}, {
  3.450542941453125*^9, 3.4505429526875*^9}, {3.450543026921875*^9, 
  3.45054302784375*^9}, {3.45058358159375*^9, 3.450583582359375*^9}, {
  3.492251078*^9, 3.49225117865625*^9}, {3.49225126734375*^9, 
  3.49225127171875*^9}},
 FontSize->14,
 Background->GrayLevel[0.85]],

Cell[BoxData[
 RowBox[{
  RowBox[{"{", 
   RowBox[{"AmpU", ",", "tAmpU"}], "}"}], "=", 
  RowBox[{"FindMaximum", "[", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{
      RowBox[{"Utenterms", "[", 
       RowBox[{
        RowBox[{"pvalue", "/", "2"}], ",", "t"}], "]"}], ",", 
      RowBox[{"t", ">", "0"}]}], "}"}], ",", 
    RowBox[{"{", 
     RowBox[{"t", ",", "0"}], "}"}]}], "]"}]}]], "Input",
 CellChangeTimes->{{3.45054291690625*^9, 3.45054300875*^9}, {
   3.4505430943125*^9, 3.4505431105625*^9}, 3.45054453290625*^9, 
   3.450544602484375*^9, {3.45054659740625*^9, 3.45054662159375*^9}, {
   3.450546779609375*^9, 3.45054678353125*^9}, {3.450584981703125*^9, 
   3.450584988921875*^9}, 3.492237653734375*^9, 3.492249381890625*^9, {
   3.492250920484375*^9, 3.4922509249375*^9}},
 FontSize->14],

Cell[TextData[{
 "Behaviour of  ",
 Cell[BoxData[
  FormBox[
   RowBox[{
    SubscriptBox["U", "10"], "  ", "at", " "}], TraditionalForm]]],
 " x = p/2."
}], "Text",
 CellChangeTimes->{{3.4493267361858397`*^9, 3.4493267560043373`*^9}, {
   3.4493303328676147`*^9, 3.449330359976595*^9}, {3.449464457171875*^9, 
   3.449464484296875*^9}, 3.449563710789379*^9, {3.45054279190625*^9, 
   3.450542795421875*^9}, {3.450542841703125*^9, 3.4505428445625*^9}, {
   3.450543118234375*^9, 3.450543127140625*^9}, {3.4505447101875*^9, 
   3.450544711953125*^9}, {3.492251365046875*^9, 3.49225142428125*^9}},
 FontSize->14,
 Background->GrayLevel[0.85]],

Cell[BoxData[
 RowBox[{"Plot", "[", 
  RowBox[{
   RowBox[{"Uoneterm", "[", 
    RowBox[{
     RowBox[{"pvalue", "/", "2"}], ",", "t"}], "]"}], ",", 
   RowBox[{"{", 
    RowBox[{"t", ",", "0", ",", 
     RowBox[{"2", 
      RowBox[{"T", "[", "fvalue", "]"}]}]}], "}"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.449330365113982*^9, 3.4493303716533856`*^9}, {
   3.449330423217531*^9, 3.4493304582078447`*^9}, {3.4493308406778097`*^9, 
   3.4493308442028785`*^9}, {3.4494640180625*^9, 3.449464058671875*^9}, {
   3.44946411859375*^9, 3.449464119265625*^9}, {3.4494642970625*^9, 
   3.44946430753125*^9}, 3.449464452828125*^9, 3.4495565947770557`*^9, {
   3.4495773609373283`*^9, 3.449577375378093*^9}, 3.450540232796875*^9, 
   3.450542848515625*^9, 3.45054313065625*^9, 3.492237658046875*^9, 
   3.492249093859375*^9},
 FontSize->14],

Cell[TextData[{
 "Sections of  ",
 Cell[BoxData[
  FormBox[
   RowBox[{
    SubscriptBox["U", "10"], "  ", "when", " ", "time", " ", "varies"}], 
   TraditionalForm]]]
}], "Text",
 CellChangeTimes->{{3.4495639215324125`*^9, 3.4495639698719215`*^9}, 
   3.4495773582134113`*^9, {3.492251573265625*^9, 3.492251601890625*^9}},
 FontSize->14,
 Background->GrayLevel[0.85]],

Cell[BoxData[
 RowBox[{"Manipulate", "[", 
  RowBox[{
   RowBox[{"Plot", "[", 
    RowBox[{
     RowBox[{"Utenterms", "[", 
      RowBox[{"x", ",", "t"}], "]"}], ",", 
     RowBox[{"{", 
      RowBox[{"x", ",", "0", ",", "pvalue"}], "}"}], ",", 
     RowBox[{"PlotRange", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{
         RowBox[{"-", "1.1"}], "AmpU"}], ",", 
        RowBox[{"1.1", "AmpU"}]}], "}"}]}], ",", "\[IndentingNewLine]", 
     RowBox[{"ImageSize", "\[Rule]", "400"}]}], "]"}], ",", 
   RowBox[{"{", 
    RowBox[{"t", ",", "0", ",", 
     RowBox[{"T", "[", "fvalue", "]"}]}], "}"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.449315486479557*^9, 3.449315542309837*^9}, {
   3.449315590559216*^9, 3.4493155929726863`*^9}, {3.449315633981654*^9, 
   3.4493156426541247`*^9}, {3.4493157138064365`*^9, 3.449315723430275*^9}, {
   3.4493157963851795`*^9, 3.449315825547112*^9}, {3.4493158665861235`*^9, 
   3.4493159170186415`*^9}, {3.449315947732806*^9, 3.4493159517385664`*^9}, {
   3.4493162450603423`*^9, 3.4493162529516897`*^9}, {3.449316309543064*^9, 
   3.4493163286905966`*^9}, {3.4493181338262544`*^9, 3.449318137311266*^9}, {
   3.4493207802215843`*^9, 3.4493208016524*^9}, {3.4493208457758465`*^9, 
   3.449320863571435*^9}, {3.449330217161237*^9, 3.4493302229095025`*^9}, {
   3.4493302699070816`*^9, 3.449330309083414*^9}, {3.4493309721668816`*^9, 
   3.449330997042651*^9}, {3.4494640648125*^9, 3.44946406821875*^9}, {
   3.449464318296875*^9, 3.44946432178125*^9}, 3.449464492109375*^9, 
   3.4495565980117073`*^9, {3.4495657906100144`*^9, 3.4495657924726925`*^9}, 
   3.449595268984375*^9, {3.45054026553125*^9, 3.450540269109375*^9}, {
   3.450540337859375*^9, 3.45054034340625*^9}, {3.450540378265625*^9, 
   3.450540380140625*^9}, {3.45054313746875*^9, 3.450543138046875*^9}, {
   3.450583110453125*^9, 3.45058313134375*^9}, {3.450586683199518*^9, 
   3.450586684771779*^9}, 3.49223765890625*^9, {3.492239532453125*^9, 
   3.49223953971875*^9}, {3.492239788015625*^9, 3.492239789265625*^9}, 
   3.492249094921875*^9, {3.49225067703125*^9, 3.492250684859375*^9}, {
   3.492250928125*^9, 3.49225092871875*^9}, {3.49225132684375*^9, 
   3.492251330703125*^9}, {3.492251609875*^9, 3.492251628796875*^9}, {
   3.492251660265625*^9, 3.492251660953125*^9}},
 FontSize->14]
}, Closed]],

Cell[CellGroupData[{

Cell["Part  III.2  Numerical solution ", "Text",
 CellChangeTimes->{{3.449411809610634*^9, 3.4494118132658896`*^9}, {
   3.4495478930846367`*^9, 3.4495478951275744`*^9}, 3.4495798226571074`*^9, {
   3.4496405459375*^9, 3.449640559890625*^9}, {3.4922359399375*^9, 
   3.492235965828125*^9}, 3.4922360090625*^9, {3.49225592715625*^9, 
   3.492255936390625*^9}, {3.4922562916875*^9, 3.49225631484375*^9}, {
   3.492256350875*^9, 3.492256359140625*^9}},
 FontSize->14,
 Background->GrayLevel[0.85]],

Cell["We recal the system with the appropriate parameters", "Text",
 CellChangeTimes->{{3.4495637805997615`*^9, 3.44956380424376*^9}, {
  3.492252151171875*^9, 3.492252163640625*^9}, {3.492252212984375*^9, 
  3.4922522251875*^9}},
 FontSize->14,
 Background->GrayLevel[0.85]],

Cell[BoxData[
 RowBox[{"TableForm", "[", 
  RowBox[{"FS", "=", 
   RowBox[{
    RowBox[{"FourierSys", "[", 
     RowBox[{
      RowBox[{"u", "[", 
       RowBox[{"x", ",", "t"}], "]"}], ",", 
      RowBox[{"sourceqxt", "[", 
       RowBox[{"x", ",", "t"}], "]"}]}], "]"}], "/.", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"k", "\[Rule]", "kvalue"}], ",", 
      RowBox[{"\[Rho]", "\[Rule]", "\[Rho]value"}], ",", 
      RowBox[{"c", "\[Rule]", "cvalue"}], ",", 
      RowBox[{"p", "\[Rule]", "pvalue"}]}], "}"}]}]}], "]"}]], "Input",
 CellChangeTimes->{{3.4493171370729933`*^9, 3.4493171844611344`*^9}, {
   3.4493174094646735`*^9, 3.4493174134003325`*^9}, 3.449317835056645*^9, {
   3.449318156528899*^9, 3.4493181682858047`*^9}, {3.4493184948153315`*^9, 
   3.4493185591678658`*^9}, {3.449318652291771*^9, 3.4493186786096144`*^9}, {
   3.4493188103991184`*^9, 3.4493188121616526`*^9}, {3.449318898545867*^9, 
   3.4493189443517327`*^9}, {3.449319005119112*^9, 3.449319044435646*^9}, {
   3.4493190901013107`*^9, 3.44931912774544*^9}, {3.449319193790408*^9, 
   3.4493191958934317`*^9}, {3.4493192339281235`*^9, 3.4493192356506*^9}, {
   3.449319471359533*^9, 3.449319479080635*^9}, {3.4493196099187713`*^9, 
   3.449319625000458*^9}, {3.4493203735167713`*^9, 3.4493204009862704`*^9}, {
   3.4493220910064*^9, 3.449322101030814*^9}, {3.449331037040165*^9, 
   3.449331037691101*^9}, {3.449331207605426*^9, 3.4493312426758547`*^9}, {
   3.4494645150625*^9, 3.44946452553125*^9}, {3.44946457265625*^9, 
   3.449464583421875*^9}, {3.4495637249697695`*^9, 3.4495637697842093`*^9}, {
   3.449563986656056*^9, 3.4495640185819635`*^9}, {3.4495641156315136`*^9, 
   3.4495641162924643`*^9}, {3.4495642036380606`*^9, 3.449564210407795*^9}, {
   3.449564283452829*^9, 3.4495642952197485`*^9}, {3.492167009328125*^9, 
   3.4921670098125*^9}, 3.4922353915*^9, 3.4922358875*^9, 
   3.492251800515625*^9, {3.4922519305625*^9, 3.492251951140625*^9}},
 FontSize->14],

Cell["\<\
We could use  NDSolve without Options, but  experience says that it is not \
wise.
In questo caso, se cambiano i parametri (per esempio q0 =1 invece di 1000), \
la soluzione
\[EGrave]  distante da quella ~vera~.\
\>", "Text",
 CellChangeTimes->{{3.4495644573028126`*^9, 3.4495644649037423`*^9}, {
  3.449564509838355*^9, 3.4495645266124754`*^9}, {3.49216623725*^9, 
  3.492166252921875*^9}, {3.49225239875*^9, 3.492252442296875*^9}, {
  3.492252478765625*^9, 3.492252596984375*^9}, {3.492260252796875*^9, 
  3.49226025409375*^9}},
 FontSize->14,
 Background->GrayLevel[0.85]],

Cell["\<\
Unum[x_, t_] = u[x, t] /. NDSolve[FS, u, {x, 0, pvalue},
                                                                            {\
t, 0, 5 T[fvalue]}][[1]];\
\>", "Text",
 CellChangeTimes->{
  3.4493312556044445`*^9, {3.449331382466864*^9, 3.4493313825569935`*^9}, 
   3.449331508668333*^9, {3.449464532328125*^9, 3.4494645799375*^9}, {
   3.449564121529995*^9, 3.4495641484787455`*^9}, {3.449564402003296*^9, 
   3.44956440626943*^9}, 3.449564530387904*^9, {3.4495747333390274`*^9, 
   3.449574745696797*^9}, {3.4495755028054657`*^9, 3.449575532027485*^9}, 
   3.449595281921875*^9, {3.44963477540625*^9, 3.44963477646875*^9}, {
   3.450543214671875*^9, 3.4505432194375*^9}, 3.492170514125*^9, 
   3.49223766796875*^9, 3.492251857375*^9, {3.49225228415625*^9, 
   3.492252288328125*^9}, {3.492252432125*^9, 3.492252436234375*^9}},
 FontSize->14,
 Background->GrayLevel[0.85]],

Cell[CellGroupData[{

Cell[TextData[{
 "Plot3D[Unum[x, t], {x, 0, pvalue}, {t, 0, 2 T[fvalue]}]    (if ",
 Cell[BoxData[
  FormBox[
   SubscriptBox["q", "0"], TraditionalForm]]],
 " =1, here we see which is the output of NDSolve without Options...)"
}], "Text",
 CellChangeTimes->{
  3.4493312556044445`*^9, {3.449331382466864*^9, 3.4493313825569935`*^9}, 
   3.449331508668333*^9, {3.449464532328125*^9, 3.4494645799375*^9}, {
   3.449564121529995*^9, 3.4495641484787455`*^9}, {3.449564402003296*^9, 
   3.44956440626943*^9}, 3.449564530387904*^9, {3.4495747333390274`*^9, 
   3.449574745696797*^9}, {3.4495755028054657`*^9, 3.449575532027485*^9}, 
   3.449595281921875*^9, {3.44963477540625*^9, 3.44963477646875*^9}, {
   3.450543214671875*^9, 3.4505432194375*^9}, 3.4921653463125*^9, {
   3.492166123546875*^9, 3.49216616421875*^9}, 3.4922376706875*^9, {
   3.49225284946875*^9, 3.492252879296875*^9}, {3.492259934578125*^9, 
   3.492259962984375*^9}, {3.574494119637306*^9, 3.5744941419485826`*^9}},
 FontSize->14,
 Background->GrayLevel[0.85]],

Cell[BoxData[
 Graphics3DBox[GraphicsComplex3DBox[CompressedData["
1:eJxcnXdYzt//x0shDUK0pD3sZGXUfWQTUZItI9JSSaVCKe00tJNSVFoqmZGd
kJW9sslKRlbS1yfn+Xp/L79/vtf1uO7rfZ/34zx+Pvd97vM+aS5bY2nXTkxM
bJGMmJjEn//d9fb4sImBy0zfjcwbu0Yh3VRMzNbPs/OL0cVWTzyO5O4UgfcX
S6zyXa5tIqZ17vHh3FLi7ttljg8vMzLpk6oWkuh7hPi0J5NGO4qPNunT6Uji
4dyTxI0PPS0oshhrYjrhxevcrlXEs2aND5eoGm9iGSBvkuh7gfiaaXeMDz6b
ZLLy2OiYoBeXiXsXhx+szptqcsxvn9vh3GvEh5m6dzDuMd3knMqUtJIH14mr
yIXptu9jYXLtUN2Z3K63iHuJlkgruc80uT/Ho2HHxDvEJco6OizUnmXy4ksn
pUTfe8QPic6UWuTNMvkQlzE2quQB8VeXMp58FLM0+WE4zDHoRR3x6h2xP8wG
WJpsXmV3wSTqMfGiwzFtPGS44ZLDuU+Iv3HLartOZPvmz0NPPSXu6Hax7X1j
b5wNLXnwjLjuF7G2cSZmx6j1//aceOTwhW33lea+oCy360vB2+HwNg+ZY/Um
afd/JVyny19vu+U/3t8xsZ64L/ec/6jCVWXpa+KZ5n/nZW9xcPtE3zfEr9j8
ncfyDbNSuya+Jb5w7t95P2zea1BUyTviG4+Yt3VSqfrqtNTF98QTx3Rv6+r0
m9K5QS8aiN8JiWnr8MJhv/etrR+I936yuq1b9Bz5c3VaXMV9kZiY6/7kCC0T
9AwudeJ4p+8qS03RM/j8xrGRqptdTdEzuFk/t+SIe16m6BlcMf75Gs3Ejabo
Gbw2pf+DkPmbTdEz+Kvz8utyVLeYomfwpfGFs5y2hpiiZ/BqrXD3u2VhpugZ
vF/7W7ffh0aYomfwl8YJAXvko0zRM/jhmnNrZKduNUXP4CEVzlk9h0Wbomdw
+/YhytXXok3RM/jAm2EO8vIxpuj5X46ewR34ddAzeAR/X/QMfoSPEz2TN35f
6Jnel3tAz+AXuTf0DG7HPaNn8Hd8XtAz+G0+j+gZXJPPO3oGn8E7Qc/kk3eF
nsENeIfoGVziZ1Fbt+h5o39VWWzF2z89a8ilvRhEPYOPOlIy8IajM/UMfnX0
qRYHOz/qGXx4p86DFwcFUc/gP7fnJvW3CKeewatjjycM3BZNPYPrdjo+zcgg
jnoGz22nd2zluHjqGTz+YUHmUNVE6hn84dXTTWl7k6hnus7dPUe3i6VQz+Bl
OsuahndOpZ7pfhe9y3C4k0o9g38InHx0xJI06pnuN9Fz6o6sNOoZ/Bvn6Bn8
Pb8Oega/xd8XPYOX83GiZ/A8fl/oGfwx94CewRO4N/QMnsM9o2dwfT4v6Bn8
Ep9H9Az+m887egYX8U7QM3ngXaFncCfeIXoGX9V7Q1u36Pm++DuZopov//37
3OmVpCH1DJ6cvuOuzP/1DH7Gt2/LizlCz+DxZpOnffcUegbvfqNLJ3EToWdw
/zGqj1b7CT2Dy2ZU6ZxQEXoGv6C1y1F9qNAz+A0b1xpLaaFn8Ocqx83mpws9
g79yqr8y7H0y9Qz+UF/G48WPFOoZ/N1o3UGrTws9g5/dMVz85BShZ/AxM0Vv
3kUKPYOP4hw9g5/i10HP4O/5+6Jn8Ed8nOgZvJ7fF3oGf8k9oGfwW9wbega/
zD2jZ/BufF7QM/gWPo/oGVyFzzt6Bs/knaBn8DreFXqm3niH6Bk8+Hx2W7fo
2eu0h2lsRfOfnv27Kk7UoZ7B028d8rGZtYx6Bi9b1FFxUbAb9UzXMY97p2G2
nnoGv6w3Oen2QH/qGbxk37BpA1cHUs/gsxotlBtmBlPP4KoHbSdLvwylnsET
P9W1bjaIoJ7B/Y18+sxViqKewYPVCy+G7d9KPYP3qQj5LCMWQz2Df+tyyUTc
L4Z6Bvf9vPvMrssx1DP4XLtuoV+/CZ83wOdxjp7Bffh10DP4Z/6+6PnfcaJn
8FB+X+gZPJB7QM/gKdwbegbX4J7RM/hCPi/omXrg84ie/5139AwuyztBz+BV
vCv0DF7KO0TP4KfTjrV1i57DT208NMpanImJnfhQX3ZkDHoG9+rsrvc4U74S
PYMfSojsf3tSn0r0DB5ophn5XTS0Ej2D54/Y2K4wf1QlegY3+do0e781q0TP
4BKdp0S1kxpXiZ7BtTT8G3Y4T6hEz+CjQgf3CQ6eVImewR8PPHX4iOWUSvQM
rvzL783o2qmV6Bnc43Pf/E7tzSvRM/jJx/U/tN+aV6Jn8M6njt4ND5peiZ7B
Kwpzpphem16JnsHncI6ewetP/r0OegY//uTv+6Jn8AQ+TvQMLs3vCz2D3+Ee
0DPNL/eGnsGjuWf0DN6Rzwt6Bi/h84iewTca/5139AweyjtBz/R63hV6Bg/r
+rdD9Aw+vN648b9u0fNc7dPXCmsk//Qs9sw6yuAYega3jJpXdKliFfUMvrvr
Le9fc72oZ3A9GYP7dV/9qWdw51/2myLOb6GewcOsagdLDwynnsEXtPoUftfc
Sj2DX8oMOVtRG0M9g/cNKRoybmEc9QxeZuZSGVe0jXoGb6+zcFF+VTz1DL5z
4p4u4bkJ1DN40+tlNwfPTKSewb9bhxXvPJFIPYPvj+iVdvd7IvUMXs45ev73
OugZ/Cd/X/QMns3HiZ7BO/D7Qs/0vtwDegYfxL2hZ/Ba7hk9g9vweUHP4LF8
HtEz+EY+7+gZ3JB3gp7BS3lX6Bk8hXeInsG3lc5o6xY96wV1fNt7vNSfnuW1
EoeMpJ7BX0h7zljU7EU9gx/yap/Y5BZCPYMvvWSapSweSz2DK52IGlp/PYF6
Bj9x/M7ReyNSqWdwH+mMq7P77aCewZ8m63QbfjuTega/m3V7ZIxtFvUM/qHA
5vOh0mzqGXxZruTIkgu7qGfwbrtmS3sW7KaewZ/5zVwlPTuHegY3XPbdwvlM
DvUMnjfb/MyOXznUM3gO5+gZfBC/DnoGf8XfFz2DK/Bxomfw5fy+0DP4R+4B
PYM/5N7QM80794yewX35vKBn8PN8HtEzuB6fd/QM7sg7Qc/g1bwr9AyuI/O3
Q/QM/nrqqrZu0fOX59MkYytk/vSssWzaGjPqGfxVyLnvyzwDqGdwpa6N6yZK
x1LP4MYVqytmlSdTz+DfxKsfKezPoJ7Bt1zupjhdOpt6Bn+qVTzdtX439Qz+
pqTZW3xdHvUMrnDxsYtYST71DD4sqfNk55RC6hm8R6fYlkmDi6ln8L5Tjm2N
8dpLPYM/0L2yQXt4CfUMPk9PJWt/SAn1DO6bIyrfWFJCPf/L0fO/10HP4HX8
fdEzeD8+TvQM3pPfF3oGH8E9oGdwZe4NPYN/4J7RM/gzPi/oGTyczyN6Bpdq
93fe0TP4RN4JegbX4l2hZ/CuoX87RM/gTv6r2rpFz6cmxKhJDOnyp+fM42P3
TKSewRcVKK8bsWYL9Qwe97Ru0exX8dQz+Lz8kJpH5juoZ/DhOg7TdrplU8/g
j9uLLa+fl0s9g+u8H/ZUuS6fegb3Td7QZeLvIuoZ/Hy9gfXwRSXUM/iIqWbP
JoaVUs/g6yfb750dWEY9gxe0qhxeMm0f9Qxe+9pWzP7JPuoZfIjhqC3OE8qp
Z3D16zmTXL3KqWdwNc7RM7gRvw56Br/J3xc9gxfzcaJncB9+X+gZfCT3gJ7B
a7g39Ay+mXtGz+AGfF7QM/grPo/oGdyMzzt6BnfinaBn8EzeFXoGj+Udomfw
RKn3bd2i58lWDmmjrLv+6dnf127DJOoZPGfgyfZLjIOpZ3D/p5FyJwsSqGfw
wpY1rx+szqCewftofDpbZrCLegbXchpp9G1YHvUMvssqpmXl/QLqGfzb6AFM
U3kv9Qzev7fOtLhvQs/gZmn3Rx4aWEY9g6/u9nZzO6N91DN45paj2m7i5dQz
uLXWvF6S6eXUM7hExEmnCsn91DN49NEmhSTj/dQzeBTn6BlcnF8HPYPP5e+L
nsGz+DjR87/3hZ7Bx3MP6Bl8EPeGnsFbuGf0/O+8oGeaXz6P6Bl8OJ939Axe
yTtBz+BbeVfoGfwO7xA9g38+fa+tW/S8N1A277N89z89z2xw1ZtAPYP31V9z
QU0qiHoGt6o9Xfk9Yhv1DH5nU3w3BZvt1DO4WfXD4oWGWdQz+MiQ3qdv39lN
PYOPXpq53Vd7D/UMPiV8yZJA+ULqGfx88KBFbzOKqWfwiVoKj+/Yl1DP4McP
vt/61rKUegZfkbKwfEDnMuoZfFG8y8yM1DLqGVzPRHc5+15GPYNnhPm/k9ff
Rz2Dp3OOnsF1+HXQM7gtf1/0DG7Hx4mewU/w+0LP4JO4B/QMfoV7Q8/gFtwz
egY34fOCnsFFfB7RM/gMPu/oGfwN7wQ9gy/mXaFn8IW8Q/QMPr41rq1b9Nyz
vLi8sEbhT8+Guw+EMuoZPOfB+PhtqzdRz+DtFgxS3leylXoGT5UoNh9plkg9
g9sdnP1DFL+degZf7PN4//W+O6ln8GOx9X0iT2ZTz+BWWxd1yu+cQz2Dz7yX
GaLXLY96pvdt6C7z++Ie6hk8blXLwcFjCqhn8Pi6petOLiuknsGrGu3HFYmK
qGfwPXOVtJpqi6hn8OqGNV1TehVTz+CnOUfP4Lv4ddAzeA1/X/QMnsjHiZ7B
t/H7Qs/gq7gH9Aw+h3tDz+DzuWf0/O+8oGfwFXwe0TP4ej7v6Bk8j3eCnsG7
8a7QM3gT7xA9g784vqKtW/S84fnMk3ahPf9br1vQresw6hn895F9iu59PKhn
cMlHxjqBpwKpZ/A5B98Yi5dFUs/g84bkT2t2iaOewZOv2VqvNkiknsHrT95S
Tw1IoZ7B3+5+XL7bdzv1DH7hhMMYr54Z1DN46/ID+8T3ZFLP4DkS817oJe2k
nsEXeNXJFlhnUc/g5+T8+m59nkU9g0f4jTK9Oi6begZ/sEV5stvabOoZ/A7n
6Bk8lF8HPYPX8PdFz+AL+TjR87/3hZ5pflf89YCewW9wb+gZ/Bv3jJ7Bn/N5
Qc/gGXwe0TO4A5939Eycd4KewaV4V+gZ3KTib4foGdxA0bStW/T8XOHzpd7j
lf5br7N8Z6BBPYMfdM0ql/20hHoGn7HD0Mrr0BrqGVzSMUrFW8eLegaXlbnX
Yf+VDdQz+NdbLR26NgVQz+BH+hY9v1AaRD2DiyIDK95rhFDP4Gc6KecwszDq
Gfz17EF2u3pEUM/g7HX/B1ppkdQzeOek1aMqaqOoZ/BTpz77Ox/dSj2DJ5/9
uXfk3GjqGdx36oZz6jnR1DO4I+foGTyMXwc9g1/n74uewaX5ONEzuAm/L/QM
/oZ7QM/gtdwbegafyT2jZ/AiPi/oGbyFzyN6Bp/E5x09g6vzTtAzjZ93hZ7B
J7v97RA9g5/eMa6tW/Q8bULCvdutyv99HzwttUaefu8GH2n/9Y190DT6vRv8
TZbnN8nF8+j3bvApy9f7X29ZSr93g1c/Wnx07JWV9Hs3+MTD3c1NVR3p925w
x9lWLS8l19Dv3eA/95nUfzF1o9+76folqS5lp93p925wcVc//WZ5D/q9G7y0
wavzAb119Hs3uKzTt0EvJD3p925ws8I1YaEFnvR7N/iZN6tVMlW86Pdu8KXB
r5/2s/Si37vBQzhHz+Dv+XXQM7gOf1/0DK7Ox4mewY/y+0LP4JLcA3oGP8K9
oWfweu4ZPYMX8HlBz+AiPo/oGdyDzzt6BjfinaBncMvsv12hZ/D7q/52iJ7p
fgfvb+sWPZetG/EqpkL1T88xp2469aOewc9Mu7mvzxN76hk8Ueps4unrXtQz
eHK/zjHf9QKoZ3DP118XazdsoZ7B3552VE9m4dQzuObpR+GX9bdSz+CPGhau
rrkSQz2Dh12sy9CdHUc9g0/KLpsivXMb9Qwur5shvvZAPPUM/udWltnGJ1DP
4NPuXHOoHZVIPYO3Vxiien5PIvUMvsplxdrxTxKpZ3B3ztEzjYdfBz2Dj+fv
i57BA/k40TO4Ar8v9Aw+hXtAz+Ah3Bt6Bn/APaNn8GF8XtAz+Cc+j+iZPPB5
R8//doKewU/wrtAz+B3eIXoG7930sK1b9Kycc/fzFC+1/9af/dOnD6aewdcN
i5bbnbaGegYXzT6Xp7RwI/UMPlAxsGnD4y3UM3jxd6vFi35FUM/gT6pPtQ47
FUM9gxfOGzVq6tht1DP4zkTxUb3XJ1DP4D4GDk2vVidRz+DezrbfTnRPoZ7B
A42fOWd4plLP4CdlnEqC4tKoZ3CJjrczXVdtp57Bx4eojl3etJ16Bh+sZha7
cEw69Qw+mnP0DG7Br4OewVs6/H1f9AxezceJnsFD+H2hZ/LDPaDnf72hZ/Ad
3DN6Bj/I5wU9g7/g84ie6Tp83tEz+ADeCXoGd+VdoWfwBN4hegbfmHitrVv0
7H/LV0xiiPqfnpn5xYH9qWfwza+SZg1LXk09g/cf43PJIdCbegYv3mJavzdb
+PcZvGRPi5ZNRDD1DJ4rc6vn8Gbh32fwgMFGd6e2CP8+g88qd3JeMjGWega/
vzo1XOGm8O8z+FK1uyfr+sZTz+BxP4Yk752UQD2D1765OCC8XyL1DH6nzFbJ
5Zbw7zO42ZsVSxZMTqKewavDvrSzDEiinsFvco6ewWfy66BnGg9/X/QMfpeP
Ez2DJ/L7Qs/gy7gH9Ax+j3tDz+DTuWf0DB7F5wU9gxfxeUTP4Fl83tHzv52g
Z/D5vCv0DB7OO0TP4AdfpbR1i549JKI7LPbS+NNzSXaTpyL1DP60j6SU49LZ
1DP4qbSQDuY9l1PP4F979p9QNciRegb3u3pp/igzN+oZXHpYUaBJpAf1DP6w
oFElMMyLegYvV2gM7G/oQz2D5/+YtOpegB/1DD7RcLfXx40bqWfwKZ9nTIru
7k89g3eKWGY05pg/9Qxe5OR+ccOYAOoZnH2yHjw7NoB6Bt9uuWHF8YoA6hl8
P+foGXwRvw56Bt/B3xc9g/fk40TP4Bb8vtAz+GTuAT3T9bk39AyeyT2jZ/BG
Pi/oGfz30L/ziJ7B5/B5R8/gr3kn6Bn8E+8KPYOf5h2iZ/CNqb/bukXPeaqP
I0dZa/73eWNTkHVPWt8AF/UWFf8OmEPrG+BmtW9dtiWupPUN8Of7Umr2JbrS
+gb46eM/JUK919H6Brhr6e8Jyz+vp/UNuk5U6dA1XzbQ+gb4HfcXqudO+dP6
Bvhja+UJ0y030/oGeOW98a2peYG0vgFe4Tg3pf5sEK1vgK98p52uk7+F1jfA
a/Xzz86yDqb1DfDv6u8frzkXTOsb4Iq9RzZsFAuh9Q3w32p/OXoGf8Cvg57B
n/L3Rc/g8/k40TP4AX5f6Bn8BPeAnsHfcG/oGfwF94yewa/yeUHP4Fv4PKJn
8B983tEz+C/eCXoGH867Qs/g+3mH6Bl86Le6tm7R84Mhg7srDtH67/PGw2Yv
I+oZvNrgoVpIqRv1DJ7jrGc0ZkkA9Qx+IHyj9ZWJYdQzuLvm4qYl42KoZ/Bw
o5RFYbHbqGdwm+DGFfZhidQzeL8L4pvdBqRQz+DLtNUbv/mlUc/gV9e1aL70
SqeewddLlPaw7Z1BPYOPeG/9or9xJvUMXlC/KfHNgUzqma7zs1R2tcxO6hm8
U4+iSXnDdlLP4JKco2fwtfw66Bm8hL8vegYfxseJnsG9+H2hZ/Dr3AN6Bnfg
3tAz+FDuGT2DW/N5Qc/gcXwe0TN4IJ939Exd8U7QM3gh7wo9U599/naInsF9
dvu0dYue5c03p3yW1/5vf90hJTER9Qy+6/jDbpedN1DP4BEbnNttqIqknsE/
Vmac3/IinnoG3+wwuIPug1TqGdxucpz0CN1M6hn8kJJhROfELOoZ/OHB15ev
ndxFPYN32jhWWjkvh3oGV0gd4HBvch71TNdxMbjQb9ce6hk8Y4zu1vZH8qln
8Hwr00/24QXUM/jFoyceWfcopJ7BzVMWzKmZX0g9g0/iHD2DV/HroGfwvfx9
0TN4Oh8nev73vtAzuCL3gJ7BO3Nv6Bn8GfeMnsEP83lBz+BOfB7RM3g8n3f0
DN7CO0HP4Nt5V+gZ/BPvED2De/s5tHWLnsevuK5+teG/nmNq6krHU8/gU5TH
Bw2JD6SewY9tLc6Zqybs3wBfFmdWYV2ZRj2Dbw/PWL+/dif1DG4V9mnFekdh
/wb4pMLdzfa5edQz+PKvksuOhxRQz+BdnuW/kZQV9m+A1572NVZSEfZvgNc4
LdozQEzYvwHe/4feWNNDpdQz+PUZ7NhUM2H/Brj7HVl5qx3C/g3wB/0XjrSp
KaOewe9yjp7BXfl10DP4Lf6+6Bm8Hx8nev73vtAzjZ97QM/gPbg39Ay+mntG
z+CT+bygZ/AFfB7RM3gun3f0DO7GO0HP4Od5V+gZ3Jd3iJ7BE2xutHWLnr39
dHIKa3T+9Nx4dq69sL8OPMv1+9vxvYX9deC/bWZeUk8Q9teBW4rnzT4+S9hf
B+7Yda32iN7C/jpw56a1+7/0F/bXgQ+dYd7Q/bqwvw7cPWi33O2uwv46cNMH
i2sWfhH214F3b1HMuttP2F8HHtG8RNN1kLC/DrxkJeuk2irsFwUP7BY18X6q
sL8OfOC73WdK2gn768ATJb0D04YL++vA4zlHz+AD+HXQM3gwf1/0/O840fO/
94WewRW4B/QMPpZ7Q8/g67ln9Aw+nM8Legb35POInonzeUfP4La8E/QM3nnu
367QM/gd3iF6Bu8pLar6r1v0XBi/rn9Yvu5/+5Fm7IsS9j+Df1r+Kmf7TGH/
M7iC4ZlbDpeE/c/gv2pu2RkOFvY/gxfa2h/ysBP2P4PPvOEYtNRC2P8MLnuo
SHXhDWH/M7izbETPvU3C/mfwCxv8fFfOE3oGr605f/X2FmH/M/ilG+/zR/kL
+5/BRTWrzoVOFnoGD5ub5nu6Ttj/DH7u5870N2bC/mfwooZ3A357CPufwQs4
R8/gVfw66Bk8kr8vev53nOj53/tCz+A3uAf0TK/n3tAzuAf3jJ7BO/N5Qc/g
8/g8omfwg3ze0TO49KW/naBncG3eFXoG11vxt0P0DH6n0a2tW/T8uLCqzC5U
70/PV6cVfBeeTwH3z/XO8vwiPJ8CPrQsRPxUmPB8Crhp4KoR571SqGfwde2v
L+20OJN6Bp+t6OZ0slB4PgV8eb7kkw45OdQzuKv9ysAB0/ZQz+ClvjHlO9MK
qGdwZ4foBNukIuoZfLVn0r0w073UM/jgVxkTQiaXUM/gQW8HmK4/JzyfAr6z
54FIlV6l1DP4WtcNRo4TS6lnGj/n6Bl8B78OegYP5u+Lnv8dJ3r+977QM70v
94CewQ9wb+gZ3JN7Rs/gdnxe0DP4Aj6P6Bl8I5939Aw+jXeCnsEZ7wo9gxfz
DtEzuNUSHfP/ukXPCmcVR5qt1P9v//Nv5V6jqWfwqSOnFPieWE89g/uNH/Hx
59Aw6hncfeV9qxFWcdQzeIOmr837uCTqGXxj4zGbyvnbqWfi16TmT7bKpJ7B
h+dM2Rc9Jot6BpdZ0Nk+vT6begaX62cZ7m6zm3oGL5l36sGgsBzqGVwtVirv
9IZc6hk88/VlvSHD8qhn8BUerR4b9uZRz+ARH4YnZb3Lo57BQzhHz+C2/Dro
GTyHvy96Bu/Nx4mewUv5faFn8C7cA3oGl+fe0DP4GO4ZPf87L+gZPIzPI3oG
b+Xzjp7BN/FO0DN4HO8KPYNH8w7RM3iS75G2bun5lIf2x3uPN/hvvS4z7kJ/
4fkUzr/EbX3oscdReD6F81XyEttvinyF51M4b3ZbFTHzaaDwfArnh2ZdCP2+
K0x4PoVzz9Nmkj1fbhWeT+F8xr5n4/dcjhWeT+FcJjdKWq9+m/B8CudXvX5Y
TKtMEJ5P4VxraI8b2rOShOdTOB+UMefqp8xk4fkUziPbn5KOLkoRnk/hfKRX
vngHr1Th+RTOqze5mVq3pArPp3Aue+HZZT+WJjyfwnl7zun5FM5P8evQ8ymc
m/H3pedTOI/j46TnUzgfzO+Lnk/hXJt7oOdTOL/NvdHzKZx3557p+RTOp/F5
oedTOA/i80jPp3B+ic87PZ/CeSf3v53Q8ymc+/Ou6PkUzmdu+9shPZ+C+aqN
auuWzpNpOjyhWbPPf/vrrlxd9eMonSfDua/BmZvf9E2oZ/AW7+avpjMtqGdw
l1uqXilfbKhncC3deP2+D5ZQz+AZpYo5n5KWU8/gH754Lmm5uZJ6Bp//vDV4
+vHV1DP4XJmFxWJTnahn8EvLvRpKPV2oZ/Duu6QnnNF2pZ7BNw5o1yv4oSv1
DH62NXP3Y3s36hk8Qj956rmzbtQzePgbv9mjvrhRz+DunNN5Mpx78OvQeTKc
1/P3pfNkOE/j46TzZDhX5vdF58lg/NwDnSeD++Xe6DwZzkO5ZzpPhvMKPi90
ngznh/k80nkynCfyeafzZDgv4p3QeTKcs/V/u6LzZDg/3edvh3SeDLoKOdbW
rfTBHukVubGi3IYSp/iKi6KgpstGyz+MNUXn4GJirl+11bubTLRU1D7l/oFe
f5S/HtcHvzsup+31uL7t6th2cvsMmGtu95XtC2dU4vrgf/7/aIVOrPoxXB98
Td7f14PT+EWm1hpa/SpxfZwz2eX+84nqR4Vxgp+zOd/G8Xpcx3XM3+tg/Hjf
gMvv28ZzasPG98dyA0QPbpl2Sa6oEHnf77/P31HLVKrDVKmlhz8QP805Xu+0
V1cn6I0BUzjz3kpumlElXg+udPYvp9+z+HXExMTOTvSRMMHrMf4Cb0OxtfUS
Jrg+xi9VbWX045IyjR/XtxkjtXb3pW40flyn1+uFbdeh3yP4+57XMWt7X4wH
1/nzfcr9v+tgPHjfvIt/39f7bWKAmFgJXV9j0+0eGu0Gm4DjvMR4leMTfKVc
THfWho0QEztBrz81v+d0zTMiE3C8/py5suh8Fz/T4EGTB4qJVdPr33berddO
e6IJOF5/30Ve1D460HT4xMBuf8ZMr7ePGx/xfNw0E3C8vvnbs5QQxVDTPI+n
cmJiN4Tzb1f43Tg43sIEHK9f9d0tbvXOCFOV7LGdxMSEc2jLsrvVDZGbZQKO
14t8xLs91tpqGnktU1JMTDiH1ntwgZHoxSwTcLzesrfFrquZ0aa/W//7v0f0
+tH9/55PC/7veZ7GSXtbWluF82lPjd3bdn1wvN6aX99t4JLm1lbhfFr3hbJt
4wfH6xkff/7Zzj9aW1/Q6/fFb2jzA07niHI/zxZWfm1tFc6tzQ3+6x+czn39
/td/ry/OX1pbhXNr33f7O7/geP1TPr/WEWqfWluFc2vtyxXb+gGnc0F5P1u1
Ln1obRXOrf094GFbn+B4fSXvE93iXMTOy7bWbr6xnroFj2k/cLC6dij1Sed/
rhur2lwbQx2CL1/fcfj8w/HUG7jDYKN2hWeSqCvwWarTigPfpVA/4O0POWYr
DkujTsB/8PMwMe/gHfjrMb/gVvz6mEdwZz4ezNe/48e8gEvy+4V/8DTuB57p
XFPuE55xXp/1cuWf2dWCZ/DAlucnj3UTPIOnbL11q7RK8AwuZ3h7XOEewTO4
ZElss02Z4Bl849XgTRZ3BM/gTwbFRp9VFzyDj+bnNMIz+GP+engGD+DXh2fw
jnw88AzelY8fnsEz+P3CM3gs9wPP4D7cJzzjHLmNmS6FSa/XkGdwcblrN+ft
20CewYcPXDosrjiIPIP/nMA88zzDyDOdZzgrfVw/oyjyDL5eJlu76lY0eQZf
1n9z/rXyGPL877mC8Axuy18Pz/9eH57BZ/PxwDOd3zjx7/jhGVzE7xee6Rw/
7gee6bw+7hOe6Vy+tzW31yrrVcIznS+3QPVAnplxJTyDZ89MVTsYOLYSnsEN
fPofu/N5QiU8g5ffv1RT5jClEp7pvLWhwz7trZtWCc/gOREX9qXOnl4Jz/R6
fq4dPIM/4K+HZ/Bd/PrwDF7IxwPP4OF8/PBM5+bx+4Vn8EkL//qBZ/C+3Cc8
49ytRCsXh/rB68gz+KedV0+G/wwkz3T+WG+/kFP1EeQZ3E6l6061YbHkGfyc
xiJjnePbyDP4jKwlyi4RCeQZfMTsoiMb0xPJ87/nsMEz+Ej+engGn8mvD8/g
F/h44BncgY8fnsEr+P3CM507l/XXDzyDl3Cf8IzzoKZuFk0xMN9CnsG765Yc
uycZT57B3fw36dp+SiPP4LYLum6PHLmTPNP5Xb5lqyafzibP4H67+s5cFL2b
PIOHvhm3asbOHPIMnsvPAYNn8DD+engG38ivD8/ge/h44Bl8BR8/PNO5avx+
4ZnO1+J+4BncnvuEZ5xTZLZlWucXX7eSZ/A1uTplFxXSyTO48+mvG/2m7SLP
4Ou+eQw/KbGHPINbVa78/KaskDyDG5xM8js3Yy95Bjc6cOrrCJcS8vzv+VTw
DD6Evx6ewfvw68Mz+Bw+Hnim6/PxwzP4Wn6/8Ezng3E/8Ay+mvuEZ5yfo+8v
Or70dxx5pvOdqnzPutzcSZ7B5dJypSuf5ZFn8JM5RgcsiorJM7hqvuSJV8ml
5Bn8bN5zm8VG+8gz+LCpBy720ysnz+C9+blJ8Pzv6+EZvJpfH57pOnw88Ezn
R/HxwzN4T36/8Ay+k/uBZ3DGfcIzznVZFR95+mbJNvIMnm/lpz9lQxZ5Bndw
G6Q69/Ie8gwu/2tfj6zLe8kz+P44p7p3pmXkGXykTZZF4CvBM/j0N5nals8F
z3ReDT/PB57Bzfnr4Rl8NL8+PIMf5OOBZ3BFPn54Bnfn9wvP4Ie5H3gGD+A+
4RnnjUQH/3jhdyqWPINrrasqiSrOJM/gKXMmuW+akkuewR3Cri9eVF5InsF3
VIjL+HiVkGfwQceK15z9WkqewVcZmMv9vldGnuk6/JwZeP739fAMPphfH57p
HBs+HngGd+Pjh2fwnfx+4RnckPuBZ/Dd3Cc84xyMzIaF872eRJBn8O9DEr03
DEslz+BJkrvsz5hnkWc6X2Vpg0FYdA55putseTpB/Nke8gxebrF/wweTQvIM
bhQaUNiwq4g80zkq/PwTeAYfzF8Pz+AH+PXhGbyZjwee6dwSPn54Bk/n9wvP
4PJD//qBZ/BT3Cc843yGis65ovcfA8gzuPeyr1OOvYwhz+BHHL4UuWQkkWfw
7P6ne87XSifP4D+jrnZ4fjCTPNM5FdXvQ+6ZZJFn8IYfnZNl9LLJM/g9fi4H
PIO/56+HZ/CX/PrwDN7MxwPP4CV8/PAMfoLfLzyDh3E/8EzngXCf8IxzAwwr
gnXizjiRZ3ApC5OBGy18yTN4WsRPmyz9QPIMvvOtgafZnhDyDD5oYIb5rwER
5Bl8tnjWwOqCKPIMvj9+8pMw/WjyDL6WnxcBz+Al/PXwDD6LXx+e6X75eOAZ
vIyPH57Bt/P7hWc6n4H7gWdwU+4TnvE8u/ZGxUeXDG3oeze40rV6u0NidvS9
G1wvKkPZ+5oTfe8GH/j5xhSdTDf63g3+Tv/dzTlaHvS9m84r8Ds3Tf31Ovre
DT76oOqx+m+e9L2bnuvn5xjAM/gM/np4Bl/Lrw/P4I18PPAM3puPH57Bx/L7
hWfwR1f/+oFn8PXcJzzTc+U9F17vW7qOPIObZS2ZtVY7iDyDxwW6NBxviiDP
4NIrWw48NYwlz+ArHAfftC3bRp7BL+f2O5DlnUCewReUKkj2Ckkkz+BO/Pl6
eAa35a+HZ/Bb/PrwDL6SjweewaX4+OEZPIvfLzyDm3A/8EzeuE94xvO/nktX
bXbc6UuewXvvap/0ujSMPIOPVLK5e/luLHkGV6q4nzezKYE8g/dJra5r6JNC
nsHnfVSRklqTRp7BDdU7rOl4fjt5Bh/On/uGZ+L89fAMbsuvD8/g/fl44Bm8
Jx8/PIOP4/cLz3S/3A88gxdxn/CM51KTt6ZUyczyJM/gg341OXmXCz2DD19Y
10/9aCR5Bi/XPFQumy/0DK5z0fRKwZh48gye/07pfucuieQZ/GPykJEndZLI
M/hl/jwyPIP/4K+HZ/BSfn14Btfj44Fnej0fPzzTc9P8fuEZvC/3A8/0PDX3
Cc94XtInrvNlkeNS8gw+4pLbtH1n1pBn8A6H7zXJ3F9Hnuk5TbmqX0lnfMgz
eEGFwhSPlI3kGbyrklhChzx/8gy++c7Gwdc8A8gzeB5/ThaewWP56+EZvDe/
PjyDF/PxwDP4Ez5+eKbnkfn9wjM9F8z9wDN4DvcJz3iOr2DLuvwQzxX0eQPc
YsHwNXey19LnDXou8qPTxjv7fOnzBniqo1FOnl4Afd4Av9z95Z01RwLp8wb4
LL/8XulRW+jzBriTkb13VXYwfd4Al+HPdcIz+GL+engGn8ivD8/0HCUfDzyD
5/LxwzP4a36/8Ay+kfuBZ3oOlPuEZzxfVvtaUV8mchN5Jq52tuzs5SjyDD5k
1ZXGnw/jyTM9J6gRpmZ1MoU803OFxcYnp8elk2d6Pk7UYaqcdiZ5Bn89+1SI
+MdM8gzekT9XCM/gL/nr4Rm8il8fnsGL+XjgmZ7j4+OHZ/BR/H7hGfwL9wPP
4F+5T3jGc0/fjx97FqMdTp7B+13wsdiTkUyewcOsblsmDN9JnsHt9xxPXz56
N3kGXzppgH/04jzyDP4qa7f11KR88kzP/TWH3Hz7uoA8g0/lz7vBM/gH/np4
Bn/Jrw/P4Cv4eOAZfA0fPzyDx/D7hWdwxv3AM7jyib8+4RnP48wdfuP+0UXC
+ga4gpHGpqU2wvoGeHr94+FlN3PIM3i028AzVw2E9Q16vqwuLHq9gbC+AZ55
bsDAMTuF9Q16rup9f8+YAGF9A/w+fw4Lnv99PTz/e314pufR+HjgGTyRjx+e
wXfz+4VncE3uB57B13Cf8IznROTiGs3FtgvrdeBajh3nDHcX1uvAx223XJx1
VlivA18X61gSfU5YrwNv9pOV7j5GWK8DnzZvfKHuC2G9DryPgamc6VNhvQ48
gT8fBM//vh6ewc359eEZ/BcfDzyDb+Djh2fw6fx+4Rl8EPcDzzQe7hOe8fyC
i5LuxnUvhfVn8Hub53XIqhbWn+l5nNxkvei7wvoz+IjQnK1fdwnrz+CWck6/
NyQI68/gs6LuSGwaJHim53rqW5ft0BY80/M7/LkVeP739fD87/XhGXw2Hw88
0/MsfPzwDN7M7xeeweu5H3im53S4T3jGvvpfGp/9Sx9Gk2fwTsmdB3m120Ge
wfNz3a5c+SH8ngI+9n1J9NRHwu8p4APePupzvbSIPIOXLU34uXhICXkGNwjr
p5MnXkqewd358xTwDK7PXw/P/14fnul5Cj4eeAafzMcPz3Qdfr/wDK7O/cAz
jUfzr094xn5vybMyfoovgskzeMZo9Z6d0hLIM3j8Vi3bN6N3kGdwp+s+Gtty
s8gz+LcB65dsddhNnsENL2QMHLwklzyDd5wSM2ZiWB55pv3wfJ8/PIN34K+H
Z/DB/PrwDP6Tjwee6TkLPn54Bt/B7xeewfdxP/AMrsd90u8pfB+yyv2QwBMV
3sLvKZxfMzkb9sM3RPg9hXNHuzkiDd8Y4fcUzk3S6hfsXRQv/J7C+fWpd09r
rEwSfk/h/ESyR2BzRIrwewrnqtPX+i68nir8noJ913z/Of2egvHz19PvKZxX
8evT7ymc3+Tjod9TOJ/Ax0+/p3Duyu+Xfk/hvJ77od9TOB/HfdI+GewHPnBg
xaf+5uQZfEfHVS+sXiwkz+Bdlwy2UZSwI8/gKg23Zv5c6kCeaR+12eC5x7e5
kGfwWWO0n0yvciXP4GpvpUccz3Mjz7QPme+Lpn0ynCvx19M+Gc4d+fVpnwzn
cnw8tE+G80l8/LRPhnNZfr+0T4bz9lJ//dA+Gc43cJ/wPGd14LpVobdEz1N6
/Ha67kDfuzXubLcYY31N1LjkW8hNtbX0vftylJOV1vhq0cLG+b2GeLvT9+4m
vn916tlB7nVlq+l7t93kuLqiijTRSlnpQ1Xy0+l798kU3c0a4++ILIYkaV/0
D6fv3eFSooVN8tdFBY3qZqMeb6Hv3Sl8P/NxycVRXeX96Xu3es0zDVPrk6JH
+sUmgwPW0vfucznzZ2dUFIh0egT7H5JfRN+7FS6c23q39a7o0Y0xqkuuhtH3
7ofGT+yLa26IrC0SS6/lBwjrohZNWzoMuSLqZqSnd2+3B33vrutvMKqk5ozI
UKJ65dtnS+l792OFAw/21ZSLOqo6iQLzRtL37mcjrqv/0nwtSrmgOKih0Js8
T/7wKHJl6EuR8c9FMp5vhHWkwpx3P642PBMFmWq4KA0PJ8+Ki3+sHG39RKS0
OCnK8VAkef7eVzZvmtdDUdfH72PdGyPJs9JMnZw7//33fMiVYp/0ZGEfY8fB
3cetfCVqJ3b93slSYR3pUaWJf1HNc5H8cP/5NncTyDPznPpecchTUd9JJ1Qq
rbaR56kLisslhzwSndzlJ7XeNoY8m9mv67//4RtRvInHZn01YX9djvrmFPXx
9aJZVQPG1NvHkWeZ21s7hOe/EFmprO347Hc4eXbdmrb2i/wzUWXpwrNRLIA8
35yQ93ix12PRVZ05E2v7uZLnrYvczZ5u+iyS7Nn91IH/28fIDn/3VhzySSRm
0OX7aUVhH+MnhU17zV82ihKqhvZVviTsY7R4Il0jMeSD6HPS9xOa+4V9jOXJ
iiNdUt6Jdqis3LbutLCPMe916parDZ9FPX/3XnT0nrCPccEEzaPtsz6JvB2u
tJujJ+xjlNmZ+2mU9UdR6uf5qWeThH2MR38N6OMq1Shy3jDAMGSgsI/xYYn9
8ale70UV78uu9nwj7GM8tu50deWiL6LrVYsctu4TPK+5NqX1s/xnUUDXl4ee
Fwn7GLUGXB3W58xHkZTJs3PbaoR9jDdC5zgt9moUqd+XaFbqLexjlDt/eIK+
dYMoZG+8tOv/7Rftq97sUeXyU/TqXq/jQ1tdyfMDn4CCZs0fIuPB1feenQ8g
z1tvdXxqePObaMC0uEPL1wvr/OONtiqtDP0qWv39QKN+ZBx5/hqlYJE2ukk0
OLzxnaGy4Hl8gfah8oc/RbbXug8qVYslz9865De8jvkh6n3kva7W223kOXeZ
oa76+O+iS/cMDruZCev8cysPLJj97atIP0tXYd1rYV1URsUkLiy/SfQ0aPwy
8Zxk8jxvhHlzlnmzqH36I9v1K7aSZ5lttYPvtP4Qzdzv36u0NIo8VzbMtZfb
9100U8yvb9yp/+t56qMdZiu/iR5atq8N1tpCnrVy7G56KX8V3bwzpOvoSm/y
vLzxpNXNYjGmofvr0vWhg8nzmN7tP6yREmP5D0aPHffAljz3TY5R6HHmt2i1
49PGZxc9yPPjzz2nTfVqEQ04nZ3uPGMzeY6zSA/Y1PeXyKbbdwex/sK+erfh
c9aZvxRjj2ePjLVea0mep65IkX8lEmPjVcN3pHd1J8/jdQ7bSAxpFbUMOpvg
1En49/nLJtFW45ctIveszffCI4LJc+79s2ecU36JsqPmurteiCDPvn5vEk+r
iTN/K6Wvbx71I8+z8wcYLfYSYzXv9IY0aa8iz/NLnqR+3NkqUs3tn3je1p08
y8raX9Oz/i3qvPraHrmTa8nz8VUNHRdKtYhWTjdqslvqRJ4Hz+rgPElPkj0+
PfXCWcm19HlDetMUqaebJFgPiUgjl/3/9ztsYWS239127MCb53NOBArropX3
rpgqDmnHTMM7qYQv9qDPG0lS3e+VRoozlYQRnw5Z2tLnDVFS6tbKRZKsJnVH
J0e5bfR5Q+nswz7zDkqwtGV1Ep53hd9hGz9pnP0sL8HkT66OWv5KWBc9r7HC
dqtDO/btgdvILOeN9Hkja0Zus8EZcfYlNMHnzCsH+rwx5eHAkmEJkqx5u1+J
ln8cfd7QknGfdrVBgk0c0XhiSGoYfd5oNt7/0mGyBMveXpU2euNG+rxxY+X3
gPZZ7Vjru/eHskMc6fNGcfxotcxmcTb+UJdvbh8m0ueN1tKpwYfTO7IX2ZID
7foEkec7j6I0Z3/rwPRUGl8fqRX2FZTJXTvaMLMD63p08o9X0cK6aORohblh
+e2ZTHjXj7MvJ5Bnu9U2n7Ul2zOvz7kpXWQTyLPc97pcw5sdWe21Rw1uZrvI
80tdrXEXB3Zk8saWjXHawr6CSiu7OrvQDsx0+vvqLWOEddGkgLz1Yk/bM43D
MXlNyenk2XXvW4W00e3Z9klN98frJpNnRdO153NlpZh5N7mDtb2EfYyNjgdW
mK3syJQmadU/uSvsKzif8qP1wfEOrPz6lzV35ySQ56xzY9K8lDuwmwdnrr6w
OJw8+zVtGt5tbXvmKf8808XLizxf6had0a+HDKvpLy4a1xhFnnNY7agqF2lm
urU8L3GwsE/G36XHLdvqTmyQrnLuyqZM8jx/+1y3Zs1OzG231R776dnkeciF
NNlEXyl2emzzs9J5u8jz/bnaJ7PMZdinoR2CvmgWk+fy4JULTXKk2SnVAa0P
yoV9MpHle77dbu3Eaq7a9bw8UFgXtXv6Ls59XiemN3q79ZPqPeTZVN5woNw+
KbbX8Ohkw6M55PnFjoNPlYNk2LDval4BvYR9jJU1PzeUP5RmK4uM+rz4IOyT
SfppomwxQpp5Lk5/M8FCWBd1NQgofx3Tic001TjXpT6RPE+dc8Yi6I0Uu38v
TOmCpfB9MG3t9UPpkZ3ZjZqk63IZwjqSx86es41fyrGjfSZq3agW1kVnXJn3
oVYkx173+7T3q6ewLmrQsj3cOUWW9Rw5a8LC4HzyLN7vsa7UZxlWe8Cn01gN
YX1jz+FV9xTOdGaTS66OlTpbRp43v8pft1etM/t+tH5Zjtg+8jy/R4P8VC85
dnHM5w3ftgnrokPGDS58flWWuYyLWXJsm7C+IevmMWlTX1kmf3fJjcMKwvrG
vtbm5ojmzuxh0c/yMcuEdaTIAaIkPevOTM9uTm553yLybLdgs9HJYjkWb1R4
d9whYV3UNOzspQVScmzQk+jvYgMzyLPSQanVX5fKMrl3qS8i9wvrG8PeyLzu
2K4rU3r8S+5nurAuqhlQNPxmsTyTPiNfdneSsC7aWckiKGuBPHuhn1EVbSms
izYXN15bIyXP1o41LN3wU1ivuxKhI/Jx6MKO3BqTXpstrNeNlru1/rRaV9bc
Mjih6JqwXmewy+tczAV5tmvus/mle4T1OoXRyj0We8mzW5NmFEvcEdbrxGqP
LOunI8/q7q+Nr7EV1uvuXTtk+3FnF9a+nXW3oZOF9TpmmCm9aeSf+105VLzd
UGFddMC5sXPNX8ozu6UHVDwChHVRlcXPditvk2dpz0csCV4irIt2aAr6/FIk
z9icV6PqpIV10ZeK0zfb3+3Coode8TDpKqyLblcpbjpxrBsbNyJMQuKbsM4f
WmoxbqtDN3Z4e5d53c2EddF1kz/GLFDsxhZ5VWk8SRfWRZc9iqszONOVFVx2
Pnf9/zxbeA7t/9W1K5M+1n9Ns4aw/pxl4h3sd7cbC7IfOCPPSOg5+obyjSnB
3dhZj/ZRx3yFnn0dKzQVh3RjPbUrxG4MEjyvardozfNHXVlj+qvsuHGC59kp
v4+WRnZlrwq03DILBM95tmaKxk3d2LTYsT6OCcI6f/y3ZyvaZ3Vjtw8oF/UL
FXoO2LqlrHZGN1Yys8Tp63phXdRZV18ss7kr0+o/ZNPp18K66Pyj1dOd87qy
y89+7bbwEzxLTJvZzme9Apsyy1FFsTSSPH948tFikp4Ci8mq2WyxYbvw+6D3
tnSF693Z9bc9S3IahHXR812GvX2yqTubWremzzv5AvJ8IOeW8d7+3dnii7WP
+o8Rfk/p5KKybViCAiuRd+ur06+IPH+VPPq4nZkCu/3unuwteWGf+dO0RQOv
NnRnAWz7kWIVYV30slGrb3pad1bQWjonY7vw70bF+czzDpO7s/IHM5X7+Qu/
p3SOfa79sUSBbVzJtqfNyyfPzfrBbpWLFNgGWcvFP43yyHN9pf7xCGkFtnrN
jb7pucK66A3r87LzDnZnNb5zbKb0EP7dOPnOYb7eiu7M0vpT+6L5wu8pDr6f
Og8Z1pM92zN7eWPrZvI8p1v8QrGnPZj7TplIo7pt5HncnmH5l7b2YAEbw1Of
eAvroobs9rfU0T3Yrc3bXC477yLPare9J9jXK7BDokPJJZOF/aKuO45mNMzs
yZZamz31dc8mz4uGLX5f0dKDPRS7a7FlmfDcxJSa1lFh+T2Y5ZEz/dtXC+ui
w5bvDJ1j04NNDDj4xcM+nzxr/TS7pS3Zg5mettWe0amAPHueDDbMd+rJ2I2f
+4Za7iTPy+YabPRS7snuehw9+6oskzxbfDh/cXxVD+bXVPq8x4l08jw62FG5
29oeTLXJf7iUaRJ5NlCTW/VIvQfbYbV3uMd14ffBawXxqu8aFZntWpO6/fmu
5PmY2fDVh9MV2TADv457ugeR5/y7tw8ET1VkzEY2K6NFWBdNcl0vOftbT7Y7
3XGh5JZk8hzUUdVSc1dPtqz0rXadvLBf9PblxYW5skqsxf15VrNbLHk+Yyf2
0+OwIgs5KrO3f4LwHFDJr52TzFYqMr8730f+WCisi27fNi6hS3dFdijggNve
qRnkOazvi6cPjvdkJ7vonLr84f9+7/5oYLLcQIllZhrd6X4hijyfD70QbnhT
kT2WdGr66hZDng+oO91pCVBkNvNejMgcJqyLZh2Q07s4UJG5jI/OjlkaQZ6j
p+9dm3y/J3snkX/3wCV/8mz8YLjB7kJl5l63fIaE6XT6Pqiz9s4693nKbKa2
58eQy8JzbV2lfU6LOiizmuKXbOxNB/L8O1O1q9w+JaaWs6PFS2wjeX474tji
e0uUWO9MexeFilDybNoqdti2WpmFht7b3TrKnr4P9kvM6jBwnTJzNfP7XJY2
lTwrDhg/u1lTmZmHSN3q1LKWPEucebGz+rIS+/1ls9U98c3kuXF+yIcEXyU2
+8VQ9+9nQ4XfYbUuTun1XJktVPxt1Hm9C30fNDzslPQ6Rpn5r3OtvrWlO30f
VJvZ+cUBE2V2+dPy9le/rSDPnV7tNQp6o8R0Oi3/7h7kQp6/bpjlPytJid34
vE2q0NeePGfI3h262F6VOT4Ut+0j7kGeI7J9NvfrocpcV16sG3d+I33v9h7V
6+r3kyrMvsBDXSQeQN+77a4dU6tyUWFx3eRmLBq3ib53W9ovcdymqsJmujsN
C23xou/duwdln1UOUmXZmx07SEdsI89xVeO7vzJUZaNur3mvMT9WeO540Uvb
8ocqrN3V3k5X9kfS926HLyHFAeEq7H707Yg3N7fQ926biD6/Zoz48/qu1dKb
MzbQ9+58S+c5NzNUWdXcWRviK+LIc9LrzruyzFXZrKN1bw1iIshzkH/JxzU/
VJhzxdKbdQabhfUNRUuRSY4K85hY//V3i/C9e1Hx50hpKxXWZal/4fXGRfS9
u4OJ71hFHTUW9bnl44dWH/L86Xqv6OdXe7GzF3/E2LwLIc+PHCoflG7oxfIK
M4I806PJc424bd9NfXuxSSa25laewjrS4WRxb/Pbqmx7YVPa8s7C/jpZ2wm1
tSI19s4lzqfdwVTy/OPrS/XMd71Yor/O7x73U8nzi6hQZ+eUXuzqBKvNVzun
kudrOn0rRk3sxb5ZfPWQW5dMnisrLkpJfVZlY/uWj8szFPbXdQvssnzrAjX2
ca6k0rtLyeT5t3JpyQIpNXbrmXf3x3uF9bq3JZa/Dfb3YvsCTbd+bi+s192e
9GXa16W9WKyPo03718I60pm6hJTTnXuxPkFnl+dYCvvrnJ3VZlx91Ju9PGbM
Fj8R9jHOkzyelh7Zmx0v+1A6YVoweZ6YZvvaYWRvdj3C9njOUGFddIhRuxHG
L9XYmov6l1WvCuuiGuezg9pvU2Mjc5yftN5KJs9rY17VRTT3ZqE3Lt98Vy7s
Y7TVD+s/L683M912R6Lb02TybF7Z10fPujcLslKdenux4NnYuubcZ/He7K3O
0l0HZIR1Ud13zj1OFquxLZ3s5PqeTyXP3vtK10xSVGdKx1NqUqOFfYx2U62O
KZzpzRZ2dYoee0VYf7Z88kX6qWtvFnXkxd4REoJnU+/EuXvVerPI9zKWvVSF
ddF+XYxz/C6osSVG1VLKXYX9om8uLyk6M12Dfd2TeiZ3xgrybJtqOLufjgaL
Df6w0kDSmzwXXWz3VbtJnfWRPaay3Ep4vjt12a5xH3eqs3w5WbcL66PIc8iP
CbGVM9SZtsRXi0v2wv5nl8dn1mUt0GCdjLXj/L8FkufnBQm9OhlpsFnB+qUN
88LJ83yvlafXSGmwhJSUe8mDhOe7M7e43Cg8ps4UzZasN9oXR54je8lr+Tio
s4qFIQ9mrYonz40f+5j6r9ZgL9+rant98SfPK4/9fP5SpMGOjDn3NXVMIHl+
GHoxYnpPDbarsLOs2RzhHImcPGM7+7vqzLhwvmxstj95jhPdKxsWrM66BFpd
tHnkQZ57vyoZsrOfJqsfvuTkMDdb+rwRXxZwr2M7TabwSqrg+C5b+u+gzEbL
AJc7GmymxJkrj08Y038HA6ZoG9ws1mBdz1/2b2paQZ6/KXy5PHqLBqu80mo+
4fd68pz1vcevjSM12bqYBA2XT/7Cet2Zl1kvumgy2dDewx0jPei/g1ujD04x
f6nBjAd80PvdzZr+Oyi5ILSx7OifTvKSZorbrSDPPnrzkpS3/fEz99bgvcre
5FlH2vfMwkma7Hz6/fl3nALo80bqzWmOp9U0WdWADvLlEu70eaPrzl7d+n7R
YI1PbBp+GM2i/w6GOL0/FHNBg01uVjUMGmdJnltGVC75lqnB7oc0nr9/cT55
tmwVP7KhkxZLXrXn5N3JG8hz9YVa2+ePNFmob7c9612F37tFidkdpx3QZC6K
7cbvlRSe796/1KO4NFKTPchtNo+dGU6fN/oNmGCttFyThRV1sHw4K5g+b9yS
X7V5gaIWq3vxVqWoOJ08mz8Y0efUe02WOcPGuP174ffuU7lSVw3OaLKghaMl
qpuE57uN1971jE7VZHM8lnZ/MjGOPm8Um+arfXXVZIl733b2PhouPN+tVTN1
pK4Wq16aJ5k0cTt5vvx++8eMZk02b7POhcX9E8jzhMPOyR1qNdmdQdcfGMVG
kueKIFORc54ma7kyfayxoT993hg8s8vL6xs1mWa45bo3v4TPG8GKVmz+Ky12
vfTsmDedwsjzr6far04c02Jx219K1AUL+zfWFn+J0o/XYrJmrr/7TBCe7369
/uzQrQ5aLL9nVo7m8B3kecmExPtfmBazLNQa+f7GDvIs3eeQlHGTFhu/u+Jh
/uw95Nn/S+jeHRe12GafB3NvhAj7N74enzenfZYW07ORtBhVLTzf7RTRt8XR
W4vNvOUsqWy1izw/ndOcXTtDi9mZNJ4stNtJniNHqV3rIaHNIicbnxEdyyXP
7To0ePnd1WJWA4fM+yWWTZ7XX6vs/WyvFhtRI5fc3H47ef6wPfrslGAtFnX0
q85AsTjybGdv61SyUIupSQSNKnwkfH4+MmhX1fCz2qzJeGZJS30MeTZs9nBO
T9NmD2ZnS6xTE/Yj5VZNUJB012Y9z0g/71+XTZ7V4npWOEzWZoXt7iUsVsgl
z9sWvVp6rbc26+xywNvyubBf1HRsp2iF63/eN3PXsPWqwj7Gctl7w3z3aLMn
sU/916sI+5H63sl/8GSTNqv8Nb6szk94vjsz2zdw8hxtJr2v1wnlQ8XC84Nr
zPvu7a/NjBsPTryaJXwfPGHpYvPpsTbrkRiuZ3hxL3ke3lv0e+5BbWahpFBz
0yKfPBe97rL7eJQ26+ZdtFtloPC9W3v/42l6K7RZ8F3Fqd8M08hzin/pp8hR
2qzuyNlRXeSE5wcbJjWZd8/WYQ/3jCjovERYr1vRverz+vU6zHrl+LC4KmEd
6X5dYupjCx3mcaWT+CVjYR1pVv6qsZP0dNhbvX0fWtSLyPO5dcb1Rb+02YyO
0gedpwnrG+7z5vf4WPLnOh3HLzLJENbr6nX6HbUJ0WHt+s15GvN/z3cvbmxe
VrlIhx1Ucli8XlxYR7pRUdNJd6gOS3yjsNPEZB95nhqSXhIhrcM8lQdu0Hkl
rG98cTj+8HKlDusyO/Jpb2Vhvc5heEzQsAQdpv7gZdCyq8L+uifiS/ttd9Rh
7vv7xIcsE9aRbC4Nrm1npsPeDX82rb2EsI50Kbnd+tVKOmxH76gNxanC+oaW
7cTrH/x1WUbpjvHHfgjrz8n9FH3m2OiygqMa14/+Fjx3+fZK49gAXRY3asCn
wXOEddEtpw6d05bUZaOX/QxR8BH2izZHhbmE39Nh0fN3l6kPFtbrctwK0i5t
1WV9anPK7CYInnuZ+JkNtdNlRu6OtXaLBc9xUtNfp47WZTvXl92puSl4lrqh
FiPeTZfJ7KhN98wV1us2ZjQMt6//M48Kni2mV4T1OoNA+RUF23XZiUHXrd0y
hfXnHTOeSHdbq8t8DioedPskeO6hUlbqPUWXFXWqjGudLKyLRrzYPPeRui6z
HczCVMcI66LipVatE77qsO/fPYMPhQrrdXO8k+bVLNZjfT49m+knEv7dqBln
LzZkmB4rtfJ+3HIuQ1hH6jIyN0VGj30vbXgwpb3wfPfhe51miD3VZSb2spX9
lgg9D8q592XlIV126G1slssqYf35XtgvzXwnPfZ815SyDdHCPsaZ1peq5cfp
sZEVi2w+fBf+3ajS2LHGS1mPRQ8aVlL+UFjnH/POpWfdB10meeDSIJv+Qs9l
B0XHxlfpMo2pOua218vI88K0pW9CfPTYqoHxTz7KFZPn2pVGsQ0z9dh4uWm2
PXQLyPMUIwlja309tjddVbnHZWGd/3jL9bqKFl3Wc/euoroXwv7nYed3bdG6
ocseHTjy/lqCsF80PKb+Ud4YfSYbslbr6Z0Q8iy28HBwl+76zKlq7cXjk4X9
/F764QM8X+uxc97LPbYPE57vfv9p/o0Hx/VYT7sYv7BPwr/Pyyv7+Y5L1GO2
Ke3CN+gJv6d0zpqeFzxVn1U5z3d5sC6PPAc597Z4r6HPRliZd7RcJ+zn/2n8
ocnq2x//9Uobjx4tIs+ukie2H7mkx7Sk0jaMV9xLnl9eiRmnuUuP1aq77u82
Uzh/I2ZfmeuKufrs4qY5rc+ahH2MHTYFKl4cqM92LkgbMjt+l/Dc8dTZlYPb
67ORnuoRBk+F360+99C1S76vx+bKHVl/Yrbw7/PqJ00yraV6TGNJxL2Xr4Xz
NyrzRq7comLAuhk/rvzyzYc8D/WQlnvXqM9ety67EXRWeD6lQHR/n+U5fVax
bqP6umPC892aMoXzD6f/Gaejp+Ewu0zh9+5bfuIaHvps9rFB39udE34fNDuy
Y+ByAwM2fkGqRh+V7eT50JY1N8//1mcNhUlT9t8Wnk8ZOIv5Gd7UZ1MdZm9y
nSg8372rV1ftpAJ9lm9WZihS3U2eVeqfnG8J0Gdf6mVtVZSE3wfPXJT4xoYb
MN3+TnEjipLJ86ikG+m5sgbsucPH0Y5Pk8lz6bLd4zs/02dzN/7clPAjkTzr
D/R863FYnxXOv+o6zlP4vJH+Y2Lc/Wh9Vpy4ZHFLlXCeTMOJ8HdLv/+530zH
VbpKNuTZLnLBturLBmxaxdHfWs+F560e2PQfNWi3ATsZc0vpxmPh+e7Z2i2P
E3wNmOnoIyp3M6PJ88WGSyG/ZhkwZ5n63MxeieTZrfZDuahDHzZ3RNGJGd18
hf8Opp9YkPPAgCnfKTazzRGet1rCz9vcJymxIuKY8Hz3raHL9qwNM2CP0ur0
F77ZRp6niw2ZeW+JAZNTiZvW/D1R+O/gs9kb1BT6sOodD1Ufr/Egz478HMuj
zinLpFZuIs9Pfb5eeHPCgH2LzRptNGczeZ438ZzbrCQDZnaye0icXgB5vto1
WemQswFrPj/O09rXsxLn/WJ/3cyI06/yeznSuangYmJ7tx9ZMcAE5wCD5w/w
Uarp60N/JxQ8XEJvR6f6zfR3QsGd0/cvWmUaSn8nFHyqxBfLaKUo+juh4Asv
BHmzihj6O6Hg8vI2O9UK4+jvhIJPS5qs+2hxPP2dUHDDvm8ltlxPoL8TCj7g
9xqTLtJJ9HdCwdutv3dtQ7tk+juh4Jet+568ejSZ/k4oePm2JTJSI1Po74SC
7zLyKdH2SqG/Ewq+k3OcAwxexq+Dc4DBa/n74hxgcEk+TpwDDD6Q3xfOAQY3
4h5wDjC4OfeGc4D/9YxzgMEX83nBOcDgM/g84hxgcDc+7zgHGDyOd4JzgMHP
8K5wDjD4Jt4nzn0Fj5/UIf2/PunvJ/J9dGPELXo3+6yknsHFxSTLfPcaUM/g
P0NnO8fEr6OewV13zqrZqrWJegav7vhZU/9LIPUM3lpVkLWiMYR6Bvd7v/Lt
ruAI6hk8PPJby8MDW6ln8OM1Gb9CTsRQz+B1d1vs0j/FUs/gpZ+2m+z9GEc9
g7+XOBx47Ng26hncQ2OGcfWceOoZ/NCQhQuuHI2nnsFdTJ69q/0QTz3/y+nv
KnJ+gF+H/q4i5+78fenvKnLewMdJf1eR8zJ+X/R3FTl/zD3Q31Xk/AT3Rn9X
kfMY7pn+riLnoXxe6O8qct7u3N95pL+ryPlFPu/0dxU59+ed0N9V5Fw+7G9X
9HcVOZ/H+6RzjDnfNHdWW5/oGfvlDBZL3W2eZ03nLYP/jg5KTRb1OIaewcuY
uc/yWXZ0Tjv4AAfb9Vt6raFz2sFvmMepzhfzoHPa/1fWmcfF2L1/PNkiWxSV
hAahsReFbluGskRKoWJUMqJlEm3SMpUi7VNpLzUtZNok5UiFmFJa0I6MCFEh
HuH3LPd1zuvn+/z5fnndc9/nvJvnzHU+97mAWxuGZutPcMbntAM/Vt5SqVvg
hs9pBy44wL13pt8Dn9MOfEJEFs/plSc+px24xM75g1XTvfE57cAPjfjI1Jrp
g89pB74/6dqce70++Jx24HGlZzvsAnn4nHbg0o8O7l/Zz8PntAPf9UQ/WmGe
Lz6nHbgezcFn4GPp64DPwDPpzwWfgZvR9wk+A2fTzwU+A5ekxwF8Bi5Ljxv4
DPwGPc7gM54vel7AZ+Cn6HkEn4G/pecdfAa+nvYEfAZeQnsFPgP3of0En4Eb
Hqj610/wGXJxs7evPV1U5Ip9Bi4pEae3V3kt9hm4iYq7TaxiIPYZ+LNzARnd
H0hfGOChu0wPrtgejX0GLjuoFjN2STz2GbiAKXhx4CHpCwNcbN7yLgORvjDA
375X2HL85GXsM/DyI75S6e9IXxjgdbdVF+6dI8A+A99XY5vtrpyBfQZ+6ZPF
BYUW0hcGeL3p6BqmcSb2GfityftOXI/MxD4DL6U5+Az8MX0d8Bl4Av254DPw
A/R9gs/4OvRzgc/AK+lxAJ+Bf6DHDXzG40mPM/gMPIOeF/AZ+Ax6HsFn4En0
vIPPwLtoT8Bn4Edpr8Bn4Fa0n+Az8COaw7b94yf4XEfn38IYc3ofuPlin4FL
SJj/8LnOwj4DDy1vnh87QPrQAQ9esjfhmjnpQwf8S+pki8lnSB864DpxA/qZ
1qQPHfAL4e/yez+QPnTA88POlQ9MzME+A58Zd0627QjpQwd8a2f2t/hw0ocO
uLxT0oV1F0kfOuDS8ndry/aSPnTA95+YVT77A+lDB/x5Wp7F4d2kDx3w63fc
Crx9SB864AU0B5+Bd9LXAZ+Bm9GfCz4DH0/fJ/gMXIF+LvAZuB49DuAzcBV6
3MBn4DfpcQafgYfQ8wI+A99GzyP4DHzY5f/mHXwGnkx7Aj4DT6S9Ap+B36P9
BJ+Bb3+V/a+f4HMqnSeUP9rcN3cnD/sM/PfvL2f1HTZjn4GbfI6r6qslfW+B
h360W3SiOA77DJzaU+ZgbZeCfQbe1DUs121OOvYZuP9BJOXimol9Bn5mvcv0
KIcr2GfgLvEGvPox17DPwK1kdogikknfW+BTLE6ceHSR9L0F3sPfqsLfnod9
Bj799bu371pI31vgL+6ZVNZq5WOfgQ8tCc7dwMnHPgP/i+bgM/BO+jrgM3Bl
+nPBZ+Dv6fsEn4HL0s8FPgM/Qo8D+Az8LD1u4DNwH3qcwWfg5+h5AZ+Bt9Lz
CD4D16PnHXwGnkp7Aj4Dt6C9Ap/xdWg/wWfgzYNrPP/xE3w2p3ODbnLJF92v
nsY+A//2u+bu4sea2GfgpeK7s/qZ/thn4LMm+e95+TgE+wyc7/7xTtKlSOwz
8PNt5qUXvsZgn4GbSsiFyLyMxz4DP+OkqDD1WhL2Gbjz13mjrTRSsM/ANROH
B3/yScU+A28+zNxy89Jl7DO+T3//8eUuadhn4EJZ1svRs9Oxz8B3PLa7ez4k
HfsMPMFvRNGOqnTsM/BLNAefgevR1wGfgRfSnws+A4+i7xN8Bt5CPxf4DHw1
PQ7gM3APetzAZ+A8epzBZ+D76HkBn4FH0PMIPgPPoOcdfAbOpD0Bn4FX0l6B
z8Bv036Cz8DrBQr3/vETfFag84F6a1XXPVuyEfsM3PD3ujuJd3+Xgs/AA7c7
PT05Zg/2GfgubnKB0jZT7DPw55ey5ssePYx9Bt5f19ftbXoE+wy8JUuop/KC
g30GLmv54OJryRPYZ+BbD0e1Pyqzwz4Dz1ByeDxvvAP2Gfjlvk+N90dzsc/A
y56fSNlax8U+A9/7fs3azCOO2GfgPbV3U94+dMQ+A//l91/eEnwG3kZz8Bn4
Pfo64DNwZ/pzwWfgefR9gs/AL9HPBT7/OQ7gM3B7etzAZzye9DiDz8CT6HkB
n4GPePzfPILPwFmx/807+Aw8jvYEfMb/nvYKfAY+Vvs/P8Fn4G+mXv7XT/C5
kc4B1lt2rrP/cQzX64BLSageMcom9WfgG8usmOYdLrheB3xtYfm6/iRSfwZO
/arwiKz3x/U64KxGR6OHvhdwvQ74DNWPy6YeJvVn4LssQv4q1CH1Z+CXTC7t
7+8Jx/U64O793w52GZL6M/CFNie7PL35uF4HvDv86k2RYxSu1wF/dyq/tWI+
qT8Dn3hDegsnORrX64CPLyweKmmPxvU64NNoDj4DV6SvAz4Df0V/LvgM/CN9
n+Az8MX0c4HPwD3ocQCfgUfT4wY+A99JjzP4DHw+PS/gM/Ad9DyCz/h+6HkH
n//0BHwGbkt7BT4D76H9BJ+Bx/Ld/vUTfA6m837Ki8TGm7Otsc/AP/zuX8ue
tRD7DHy37Qr1w5dPYZ+Bp8odmnFjqyf2GTj3sd6riY942GfgdjNWMsNfncM+
A//25eY1Lf4F7DPwsrW37i/oCMY+Az9o6lXtaR6KfQa+gHHAyTUmDPsM3JeT
EtOfGI59Bi7P18x+7xCBfQa+qkJ6+dGJkdhn4OOvBK20co7EPgPPqGm/0XUl
EvsMvJDm4DPw6fR1wGfgy+jPBZ+Bz6TvE3wGHkA/F/gMfCE9DuAzcHN63MBn
4DfocQafgY/4+t+8gM/AT9LzCD4Dt6DnHXz+0xPwGfgZ2ivwGTiD9hN8Bm4U
wdL+x0/weS6dn6x62zK5qmEPXm8AHydh017qPAWvn4HbxkacvvvDAq83gPfa
7SiJsD6B1xvAH66c0NE6zhGvN4BPHbDQ4kifxusN4MbHiiaGxLni9QZwxZUT
Lyx/eAavN4Df8gyKV9Al9WfgMRbhFQquXni9Abzpy47pu5298XoD+A+eWkjO
JlJ/Bh5lHl2t3uaD1xvAn/dWJXZtIPVn4PJF48eUnOTh9Qbw39f/4+Az8Ar6
OuAz8HT6c8FnPM70fYLPwGvp5wKfgcfR4wA+A79Pjxv4DFydHmfwGbgOPS/g
M/CF9DyCz8AlVv037+AzcAX7/zwBn4Efor0Cn4Fr9fznJ/gMfJ5y8r9+gs+Q
k3weE29U6kHqz8D7f1t7yXSswT4D5xUfeHTlPelLDtw7qXvDr0ZSfwa+PHro
zoAGqT8DZxZv6FZXIvVn4NsZkl+K7pD6M3AVH7vz0kWk/gz8rWTh3dwTpP4M
nHr5IjxJTOrPwAMcDVveK5P6M/Dio30WwQqk/gy848bOAwFNpP4MfOG4n1kt
BqT+DHzxt2sGPqGk/oz/Pc3BZ+Bz6OuAz8Bf0p8LPgMvou8TfP7zucBn4Ovp
cQCfgffS4wY+A1elxxl8Br6DnhfwGbgmPY/gM3Adet7BZ+BBtCfgM/Bw2ivw
Gfj8S//5CT4Dz/LL+ddP8LmTzkNaBsbsbB9G6s/Av/9uOuqjSerPwN8Fc67c
8CT1Z+BlSednb7gTj30GfsxvHmfxDFJ/Bq64d035zm+kXgfc0Jox57sdqT8D
38gKzjvuexX7DDzglh5LTonUn4EPu9w1XE6H1J+BT27vGFexmtSf8f2zCh0U
JUj9Gfhzd7exShGk/gzcbyDl7v2vpF4HfPET6dQZ80n9GTiT5uAzcB59HfAZ
eBf9ueDzn/cJPv/5XOAzcEl6HMBn4BfocQOfgevS4ww+A99Lzwv4DJxBzyP4
DPwUPe/gM/BHtCfgM/aN9gp8Bh5D+wk+A/96YBbnHz/B51I692jUrm01YQKp
PwOfILF9R50GqT8D/+BZ4ycdQerPwI/KnCjItCH1Z+A880+nr2wk9WfgnjUn
3Kz607DPwH8Z5Mwd2kjqz8CH6ZudRRqk/gw8XySDlB7mYJ+BDx8R8EvKk9Sf
ga+TfuzTYUPqz8CPPCldeW4+qT8DL9APuzz6Oqk/A9/sqxtlKkt8Bm45M3Wi
/yZSfwZ+mObgM3Ad+jrgM/Dr9OeCz3/eJ/j853OBz8BH0OMAPgMvpscNfAYu
RY8z+AxcYs9/8wI+Az9HzyP4DPwiPe/gM3An2hPwGfgP2ivwGbg/7Sf4jL1t
ifjXT/A5hs43RrR9stvCI/Vn4CwJQXt9Mak/A7ddFt8zegypPwNX/LrCq7GM
1J+BnxrezXh2kdSfgUvwhUXbP5L6M3CzUVr6ch2k/gz8pXKmwbccUn8GfmS8
9OcnK0n9GfiUMp3jGX6k/gx8uNTr9KAEUn8GLpgXwD7pQerPwNcqCGcenkfq
z8AfLO95b8Qn9WfgdT83PNJ/ROrPwKtpDj4Dv0dfB3wGvoH+XPAZeAZ9n+Az
8BH0c4HPwOXocQCfgdvQ4wY+A39DjzP4DNyUnhfwGfhYeh7BZ+C+9LyDz8Dn
0Z6Az8C9aa/AZ+BNtJ/gM/awbkTHP36urRl2IlgYh3N3duyw+LhuayrZ4oNq
e8MNkkvkD5txe5U3Jf4wu7utoYyc3yjy3v04zp/6a8GO1SLtu5gbyi4YyvC9
QE044hxULHiAeYvVkktzXUIolZTU5wIZkv+Uc8qQPeAQRk2361YQaZP8Z9/j
FT0n1SKouePPbCrnkvzn13HHFR0FkdSS7MknigVNmO+R8UszEvOpTd3aZQIZ
kvM8dv9Y9f30aGqHb8PbBBbJed5T1zhqvDCGMmZwpvDdSM6TOVxsLrKLoXIP
nU1gmfxvzvP6Er0V5VyS81xQ8dn00PoYquSXbJV2EMl5lhUYWnqJoqmymk7T
YgHJeVqPvnTPTz6auhuX1adeTnKeY0srfexVo6ja1eunMwdJztO34P6EvsAI
qnGMtFAgQ/Kcx5ps2vw7w6jmZ006DCbJc+6zWjFy+NcQqkOQ1JzAInlOg+qE
iXfjgqiuUza2imyS5zxywbNgx+Nz1JvNK4fz3Uie80iTSVZigA/1QXZYtAyf
5DlrpSoU2efdqP4uETNISPKcibvP3Twib0t9z+PfkRKRPGdp/OvhXhlalNLA
+k+ZMnyci5tT2NacI95LKSy6VcVgFmHeYyaq7+G4UtcnFAb2cioxf3LW2iD+
my/1UO95e1tDFeZdTHeftXcCqA4/6WUi7RrMb3Ien3vCCKJc2NPL2xrqMG/V
3HNDfVII5fNb+K5BiuQwb+xKinE9EEoFxbPkRNpNmH9yvPqm1DGMSm52OFos
aCb5RpM59SulI6hCufgSgQzJVb7866xTypMI6vm+GK4+439zleL5lqNF2iRX
uenU7frfTRFUz+DiOJYJyVV6pcmqLgiIoD7e+760nEtylY6il293jomgPkdW
3tUOIrnK2m8LpjvsDad+rdj/Ub2c5Cq7jX5WZRmHUlL1H+WZgyQ/aTQp6NAV
hSBqfPLNqwIZkpNM8OePrSkMoCbb+25kMElO8vPOVdzed77UtHW7niawSE5y
p2DP1cASL0ppwvTjimySk4ysbjmivsOVmt0uluC7kZzkhVzdyGH77SnVK8JI
GT7JSd6sEDrrTdpL/Vwm0X1OfBHnzcTLPwzsqTREYV8vcI7xCjGvHDEt5EK4
LeIOKLXK8CswH+eSM7j12WkUa+Po1cupJjk997j7Jvc90NM9+sd6OXUkX2d8
ySLysSd60fcqXJxQj/lczSnKsdLe6F2w6622hkbMmY6aKbdkfNBvUdokkXYz
5joT8/pMvHloitRji2JBO+aT4g/pWjN8kayKR2uDFMkfskbrZ775zEMKfVvt
9Rkkf+i3xNy9MZiHlMumjBRpk/zhrR1nZNq/+iBGcEcMy4TkD6eoXDkqudAH
LVp0skI7iOQPezNvm6V+9kSrRGM+qJeTnGFBsrDCttMNbeAkTmUOkjzh5vlO
tYdWnkQszWPZAhmSGwwfyJs2KsQObRutsZ7BJLlB1fRIC9MWK7Trye/GBBbJ
DVpSdfLs83vR3rSHHEU2yQ3ykvkqqoWSqPqMx4dbAi+cv1KJjTeyOsVG48pM
x+a25WN+bFBzQvLHILTkGU9No7wcc+OigTzZVzHIZFfrYxm+CPOFIa5MzxPJ
aP0r+bWD6vWY9x20OnO/9zLS886x6uU0Yr5m+OvCuN3pyBw132hrIPm9n+MF
rKwDGYj714hxIu12kjdTUtwbapOJNk2PvtbWQPJ4WQasV7u9MtGO4kXNDVIk
X/f9mlrfu7gMZHDu2wl9BsnXGd1i+PdUC5DpvItRLBOSrysd0KrXc0hDRyoZ
d7SDSI7O6seoZN70FGR/uLhHvZzk5faHRGxeEBWLXCX0ZZmDJBe3T1ntqeXw
UHS2ViFTIEPyby0/CnsnDfgi34RX2gwmyb/ZdBlc9BtyQLbzBmpFAjbOEd2u
t9U5qclCvgHM7EH1PMy3fI567R4cid6Xvncz6SV5tuvyTzNf30pFchqbVDTK
SW5tymE5k4ezs1HCk+2vpEQkn9Y35aTjTlchyqTf38E5K/rcuVLheHYvh+TQ
nrzY+dvlUD6qe69Z0NZA8mbf32goJxkWIEfZPB9xAsmVxXp8+67jWYDO5G25
2tZA8mNhqfywo11//w6amWGjzyB5MGfrsph/zuni39KOZJmQ3NeKSnNl+bar
KOlAA9IOIvmu86pLxjTNE6Cs70ffqJeTHNe7n1HPa8rjUUHULxnmIMlr7Ti1
WU5Hnof22UTx/cQJON/CGq+0XtHfC/0yGNpGBQkx/3psS9TvM2FovsigX5Fd
jPnSCwO5mV6xKDPZsNpNkeSvpk6M6e59noxQ+9mZx3h3SY7rL2dGQ0oaqlfI
5pr0PsA82nvPRNHITPTa6MldlgnJX51MndvQOeYK+lnleUGRTfJXttrBCpOv
5aDR1lOvy/BJ/qp89qnxwr/nUWbklU4pURPmS05um2Nlm4um0+9h4dwRfa7d
3A1Plw+qk/yVr8GzQJf7eWhJ53HTXg7JX4mKt7U8Y+YjrTOSfw8byV+JMs+t
vXc4H6WMrzbu5fxv/krQxn/P4ZH81aQdB7W2rc9HV7LZXuIEkr9aMfCt4WV3
Hsp1ZU5lF5P8lfdCUy+pQ3nouu5gVlsDyV+5hfpvKM3IRWXdFxobpEjOqsJd
QiLO+Bq6e92Yo88gOauLSWv9jKuvoIe+Kr8eapOcVdiQzO6lLzNRreGHMJYJ
yVk9KDuetSAmHTUybqiWc0nO6t5a3d8T+1JQc793qXYQyVl9Po02mD+JRx13
duwuFpCcVaWxgk7h6EjUFSL/Wr2c5Kyk3HiGY/v9UM/BLldhG8lZPeeHsY5q
7kUbQp8oJLOicV5l9pHNar9u2KCUCJVwdnER5q4LJWqjdwehI36lSomsMsxt
LH9k/0oKR67l3XZBwkrMLcfEH1VaGI0u/ppc4ab4APO7fcFbOjbFodTV1NRj
vBqSy6o57/f9QyI6UFKgzhysw7ykN3fmzohkZLVPz5zBJLmpgYyPGu3fU5Dd
YKe/IrsJ86HjjNlZqpeRzwrpVilRM+YSnV3LfrWmoSD6fUDgT+nz6KLsVi4e
VCf5qEJVLXe93HT0eNRrtUF1ko+KpfNRT5qEZVx9ko9asXSNRLAgHbVedjPq
5ZB8lKq4zXiCfjp67sjq4fBIPmrrrbe3ROjv39EbZc6KE0g+amzVgeX3v15G
H5+nZ7Q1kHxU+fvVh5xvp6DvHmvrG6RI3klTGa3RMUhEv3aMttZnkLzTwndd
I8oiYtHwGfU/HmqTvFO1fq6cjHUUknofF8IyIXknk/luHJ4oDI0vsZ5bziV5
p6DWhm8zzp5HkwOX39QOInmnuxEjlp729UQK+37uLBaQvNO9eJVxv5It0IKi
fxbKoTg3It5T8tySt4ZSMu9fkSFzHXNTJ9u0LU7b0CqBfpmwrQJzpcV1z+U2
HkLbulynJLKqMD823CA4x9oSHZqZfiRIWE1ySslKL5LmHEU3r75p0w6qw5yy
Pi61wMMGVW7zGKVRXo/5uNTCOX6OtujR2ylLmYONJHdkNmCm622PXs5d56PI
bib5pbLcL1/duegr+9gTKVE7uU9JP8S45ogk/v2P5I7e0LmjkbUPI9wUSe4o
w3DrzVr5k0g6IXLBoDrJHal83GjjJHkSTTxxCHH1Se7Iddy3N38VOyLZtWp7
ejkkd8RJXLTi0DpHpNxS5i5OILmj7UMvFonyHdB8573pbQ0kX9Rxwuyb9W1b
tHzq+9oGKZIX6tWuXuLlfRRpiq9b6jNIXujwvniWqM4SrS3w+v5Qm+SFppZf
a/tafQht8Nl+kWVC8kJSIxzlzZ6aoC0G0xjlXJIXanqVe1W6Xx/Nupm5/oqM
H85dWD5v8NG9s4fiq5Y39nIKMHexVFgmHu9BfT5fNKlRqoLkWzwYMopBAdSM
EROKhG0izJnH2h3OTQmlFJKUfPUZdSSHM2n2yC9//15WofJyWCb1mKvtXKU2
yj6CYrZteaYd1Ij5p8fDxFUVkdR6eUc15iDJ85yQrHUyuh5FGRomeCiy20me
5N60pVFF0ZRG1aujPDHJ52inX51y8X40tRrO06D5sF3/nZO27ohrmJsiyeFY
SIXNWv06itLR2Kw6qE5yOG8fv5STnR5F7Wxo2dXLITmc90MHgmtrIygTB3tX
cQLJ22yalXJzU3godXjiqMttDSRXc8xQtmKzKJA6fjW2pkGK5GTmdx29tTjA
k3JwP3JYn0FyMqZP7m54s9uJOrVt2eBDbZKTmSzKMqlRZFNN0rsulgsccN7A
ePxXoQ97DjWxL9RJozwP8zHXZzz7Pvc0lWs/kz2oXo556f1nU4WSvlTLG6fR
jVIizP3f67Eul12gvJa+3mvSS3IscqwRvhzbUOr8IzdPfUYj5u1vJneUpIdR
iWMFDdpBJK+yIuJB5XOXCCqfVT+POUhyKVNUyt5Ku0VSlnd+rQ0SkvzJNePs
kdpZkZTtwYgjPDHJmcjfdZU/OTqScqTf+8Y5DfocsDPVn+cMqpM8yUmtZ6Wh
AWGU/7HAnb0ckhtRYy1adjs/mAqVmuUsTiD5kPmqGd/7r52jYtMLk9saSA7k
Qd+xbe9He1JpOttEDVIk1zHzeStabHWEyuFNfU4FJeH9cbTyVXaHghHyusme
6q5I8hutA6WdyoGWKHP5jVKT3mLME4pWHWS+PYE4Rv65imyS31DKD93ttcUR
eYTmjRgjuou5+ds+mzHrT6OwmnbjQXWS37iTrMaxrHZF6WPGZIsTSH5DwExU
if98BrWrKP7m8Eh+4/W6jHGCA56ou+zafHYxyW/o75jqLhnohfrMNxuY9DZh
fq5kJC/M1xv9NdTips8g+Q1b1Gauu9MHjYy1T2OZkPxGrumC1/Nf+aCJWqNq
tYNIfmOVquqoZVv+/t39NPabejnJbygvWl/KPs1DYTflZfhu/5vfiAroSpPh
k/zGLWf++7XreCjOJGd1kJDkN/TmrT7S/cQHJau61EqJSH7jid+lUzfX+KD0
r5sseWKS3zAsjdt+/YQ3yqbPDQDeT59vJoxoDnJTJPmNKVFjxUu1PFGhxWWV
QXWS3/hQ1Hx1WtoZdHO5XRFXn+Q3bjiquszluqLbw1Zv7+WQ/EZxycfOiNZT
qLJuxAsOj+Q3rq/3zF7zjIseJNY6iRNIfsPzNKtRt/84emR7aSy7mOQ38vdk
NSxytUAN2laJbQ0kv2GmFbhRrsgAtYxbqm7SS/Ibnn1Pp+1ly1JjlxzfFO12
Ce+DT1g36tn+yaeQ7JC/WSLrBuZtce7t0s9C0azVH4dRQWUkd/HC8NqXHVFI
/ZSiEXOwkuQNPi8Pytoah7bkbc5QZD/AvFZzmmzp4SRk2mv/Q0pUg3n6/hrr
wMMpSFNup8BNkeQx7hj3DZYxLqON+V11XH2Sx/g4Lb1mY3oa2r7b5S8Orwnz
xmEdsTN60tGhoMs7THqbMZdYPeJjc2EGOqa2+rQ+g+QuCvztx5doZ6KTD2qT
WCYkdxG4rM9nwC8T3c5fLk5g/W/uotL7p4sim+QuHtSXuBwzy0QPdldN4LuR
3MUe7dZvGT0Z6NGs8FQZPsld8LvX1FFaGajxo5lmkJDkLo4+GpjE1BWg9qAB
Nk9Mchdraz6dn3j1MupWCzjvpkhyFA+3XZbXmpqM3v+1Z9agOslRLLg4LZPZ
Eo/6HigXcvVJjuK8qbSSx5gY9DX6rW4vh+QoYoyDDYdKw9EP64IODo/kKLrK
lkWFvj6PJFaddRQnkBxFvZ+W4NsdDzR6lJ4Uu5jkKF6LXny4kLsbFRtm38tr
C8f70Y5Xl2VPeOmMPO8a/xInXMdcpjPwaP1fMejtfu80fUYl5smjtki7WKWh
If7Vb9pBVZj/Gq1hUPb37+XJDc+2MQeryb555F0xa9MVFD7aWz9IWIe5d1f1
rO3K11B82jQXnrieXKfT22ObSIgEm66muCk2kf16hnu2wpNcVHL22RcOrxlz
K+ulEdeN81FtyXBdk952zNfP/l73Y0oB+nBle7FA5n/zDP1u03YymCTPwM0o
jHo7tgAN6r18mcAieYZp3wtyDpbmoyGFq6cV2STPsNZU4s3Ztflo2NvT4/hu
JM9wZuwWfb3zeUjaf/zKICHJMwR7ZYs6IoRIbm7qQZ6Y5Baqp334pJyXjWZW
aAa4KZIcQm+T4qwRwstoTthw5UF1kkOYPH6kxqLYJLSA/SiPq09yCJm7j1mp
bolGi5fGbOnlkBxCmHvE3oKFQUj9t0Ubh0dyCCmNMsU5sx3Qo8+N4ZfcAvF+
7t5fz1wKe4+h9xdVE5mDBZgvsxu2ZmcQHyWu6/nC1a/AfGHaO7dlnqmoqmh9
nD6jGnPNv8JSetZnod7vhYMJrDrMl0ytkemZchV9i9o2m+9Wj/lyKwcD3rlr
aPjKF3pBwkbMKT/XkkO1QjSVOy7BTbGZ5Ark+wdUTPLQwpxVfRxeO+afWSeb
Vs/JRzOdlqkwB8m+f4GZ8+OMFflojs7QdYEM2d+f4fREIelzHlow5f42BpPs
78tPMOs+7peHFr8MfZ7AIvv7PZvjjSa+zUWanqpj+W5kf5+1ap960ywh2qh8
a0WQkOzjVwucJetWZaPtpQZmPDHZr+/y455+XnAZ7d3/xs9Nkey/L2NoSVhz
Y9CBBfnTB9XJ/vt17dwRWuYhiP3tjJCrT/bfT2zWLai87IoMPdPVE91c8T7m
ArfITJXbOsjYZHCdo34+5rN3zPrlqnEOGc0xYPHdyjGX2ena3T+OjzziMt5z
9UWYj3y1taBtYwLaE3j2gUCmHvMxghPrY01TkPl8uYEEViPZF37Z08BIT0UO
lutZQUKyD76jL+eccWga8k2yiXFTbMf89tuTKclx6WiH7bav6uVkX/sJq0h+
RFU6Mh73YiZzkOxfx+4M/OYxJR2ZtmYXCGTIPvVkuYmlm//+XjrisqEjgUX2
qbnzXs58dSgV2U97OprvRvajpyydnRThnoRcC48vCxKSfWf7bTM+L3OIQbw9
kgd4YrK/vP0od/DSwhB0sS+K56ZI9os3HjiQbvn+JNLSzeAL257ifT3VEt/z
SuIo6qGNk5+wTYz5uGlNsdS3SKqTU6NzUXgF7+8omSy3HudsT0WtaaPKuU8x
f/xTLf2HSTiVfXp0mLCtFXNBTuRx28AI6rtl8P5igRjzZJMPN4Ptw6jhw+fy
hG3knBC1/Vs3lUuHUPVDx/2mszPJuRm7jrYIb1iiUtuuiVtMEOZaUpzqmHuO
6MuiSd0NUk/JeRfe/W+GunzQmGNrVpdzWzFXOuBV+vg9Dyn/U2Zo68R8N32+
xHzzzMXlXDG5fmeHl84Cb7R8iDIpFpDzH0Y1hUlR8mfR2kuNXsI2cs6DMtNf
oZlyRveCx1VlyKTj+nz6dkvNIz5eSEMzXxgkLMU8UDHZQT4nAm2SFXowmPcx
35jsoq6UkIAMZ+kEixPIeQVNtdydb5wE6Kip3csGqVZy3oJ9QMJLyUzkHn1J
o5zb+T/nD2ztOaxj0kvOGQhve3HTYnEmMjaukBRpi8m+A+O++0GUjthfTJjl
XHI+wOH0pIAr4lRkE95rVCwg5wCEGUvINkxOQqeW8c4K28j7/h+RDl/yAh8V
q1wZs7I8BdfPf11xmVla44euDfPZ3ShVgnmp45n58z8koGHfp9WyTMh79Ghs
5naJFAFa4GDrxGDWkv2FjT2De7RzUN5k51WD6uT99+0Xrp5aGZuH7u1MDRQn
kPfcxQPzVsUP5KOWwEftDVKd//M+u3OXuzy7mLy3bjTzSu9rvQLk7TV5o0kv
eT+9WeKG+IFuPvLf1f6kQUqMueDMxDdjPfJQaC9XQqRN3kOfWfn0u9ouIYq9
ILWwnEveN582d2VRVH4WSluYsKdYQN4rfzfs94wnGqnoWtWKM8I28v54z8/F
k1L0IlCJfPk6k14xrvduk7CT/XVHiD5qRjePEV3F9braVhlNLQ9v5BrplCvD
f4q5lYqJSuGMNNQj0zaFXSzGXCFyXKHEYCr6fM1B26SXvKe54UywxKJdyeiV
aNX0KLcsXP/5pHHts/KuhYj1ZGsLT4wwv/GlxDnHxRg988/cx2A+JfWo5ct0
hNEO6H1F4xUZfivmijXIccYSR6Qg/bWbwxNjLplruzUtjIvmZJ6XYReT9+xS
lvy17F6KPVq0ZfYak17yPp29867Ur002qNn8qekcpgDXN+zjgscuHsulyhLl
3UTatzAv+eEzKSOAR0lVvbQo597HvOrir+8r5S5Sq1zbh2mUk/fClixad06z
lU/pXZcyYjBbMf/dUXV1plE0dfCf8ie/E/NJ9PtcuiMmlXL1xZjfOG9jHjuF
T+1JSRNzeOR9K8nsMbvy9cMps/VrJrKLyXtV98L33L6tHkxZd9RpmvSS96cK
iyRzOt/6UjV9pxJy21JxPUGyQ2P+t/tHKS3Om+mT+SWYfwntCjHz8aTuXdEr
ECeQ95I6DLN8rWUDqN45yfvLubWkbmP23SBlWAgVeVwmi2VC3ieSTN1zNCgr
nMrMWPtTvZy8NxT6gxNdKBtJ3XplvYvB7MQ8i34PiBPy4LGUiLwHVOa4pG6a
YyTl/HNBiJuiGPOm1J6luWHhlHfs7WKuPnl/RyP+iNnAtlDqgpZRF4dH3tOJ
RKy9VkcuUPynPePYxeR9HFmj+/bHwnlUkpPnSpNe8t7NqKnS1VJTT1Ftoy1s
fcU5+HfHkoqgtAkif2T0ccIcdvFTzJvGGyza9VGAmtH8GimRGPNve0zq7RTT
Ud4lSeFkfjZer/ZMPT5/x/EQdFU753I59zbmlbrdlcmHk5HwxcZqrv5TksdW
2LEk/FoeqpxhO5Nd3Iq5/mnObN6jfDTqxsZkGb4Y834zlhXKyEWT9j57KCUi
eePWdmPlbYk5SIE+hxD/bqLP4z23KKUvkZWB12NvLE5x8l0C0bTRHpvHiG5h
zuSN0N08NxHlucnpsovvY35pzlz/zokCJN146iRPTPKxpbGfLI2zc9GsSSn3
ufqtmLcfHKlS2ZSH1LfXKLKLOzG3oHOt6rmmTopsMcmdBnTe81PKRZR+f4IM
n+ROA0akqPW9u4q2fPCvkhKRfGnPj68K3nMz0G76fEXgi+hzWc3LNqxYNHgZ
r3+iZI6fM5VyRd51O17rM0pJHnLNl/Wy20IR59CZGJ6Y5DM3jNSwdD10CYU9
a1jHLq7F3G612mPp1iRkfS9Lie9GcpWXFA5tLy26jNwkn9jxxCQ/KVV+OOj7
8nQUTA2r4Op3Yv6YzkMaaE89L2wjecihgFVnUcDf///NOqXLYIox/yVet27y
2cvIZus4R0U2yTG29Z1zqhibgpxeJ8fJ8EleUSWqIKX7eDw6y1t1T0pEcolx
aK5l9IhIFADnXdNcMuq/cz7hPE9YB776vTnhoR/powHc+0DRwF410q8EeLWf
pqKMSjjuO4DzY4H7JkW+icR9HPC5jsLMyjMKMbiPA/AUOqcH53YCF9337u+e
EIP7C+B/b1cR+PA56RcMXHHF5ZsjfpK+GMBPHZ8QMrn6Iu7XAHzCqLWD+yb7
4T4CwMcbsj50xZzG4wDrVd8NTy9UaQTgcQDOmf5UzX1LMB4H4Fs4Ewf8fpN+
N3/myuB5gccd19wwlBKBnxe49yPJFNnMcPxcwG3UnEfrvgrAzwXcxzrcaSjB
Gz8X8BQ3HvO3JOmrC+vYkbO3X5KkPPG5rMAXjx317h3ljc9TxXmnhwLup2we
Pk8V95M1VtK8eN0Hn4MKfCiKnWRy2B6fg4r/faW72ZrhbPy5sJ58EdSezxiZ
jq+Pzx/brBuT/0VA+tPR/IJvd9DAkB++zp+5FDjPFtZRowU53z3FpD8g8F9M
depmJ+l3CVwjf+EhRiQ5Bxt4wroPig5y5Bxs4LeyVn/VEJJz3f/MUcDfBfC5
rg/S9aaT/oDAf9C5CBh/4Cp5Z22DlMg52MBv3LzUvkiDnN8OfHbSV18dZdIH
EPgHQ6sO9yQBni/gTIlMx+gP5Lxr4FkZ9R+dRpFz2mHd+H6q1LDEg6QPHfAc
p37ZsBOkvwM+F+WGtJ69ZDIeN+DqD2a8rA8j/eb+3N/H597TPI7ex4fxwZ+7
U2fmfS7xB+cimvnn+thpeByAr8pcrvz6dyweB7wPnr2m7PDkCDwOwM/Jqa81
NfXFzwvr0lk/rRR10y3x8wJPF18S+a8/jp8XeLnlMIbohz1+rj/3neG58D77
cFmJ5A+O+LnwPm9dvN+E91x8/8DrM2edjV9pie8f+DyHxo/ZK43wfcI6877/
Mc6bMtJ/Cu/PzmRvkbGJxN9XeB276//3jQLu72I6WX9XFP7+AZ5dM3JULuM0
vj6s04aPKlowPYn06/lznw7+fmE/gmtTYXp8pgX2ELjlwU0SH8sc8LwA911R
79AhcsbPCzxJNTPpSyjpHwc8K049vve8F/77BW4xKilh5Hof7CfwxZy9ZzMX
8vA8Ah9Lv18M4wacNUxn1Wpl8v0JvEU2b6Kqqg8+jxr45z/65gCfvGjHz7er
PbDPwPc94u77fsAZ+wCcV6+ry9R0wD7g96N3KucXt7LxeMK693Z2+f3ZwXw8
nsAdakWn+6hEPJ7Ac05u3h+/lPRZBn4h+EWm0Y80PG7AGexoapxGJh434Gr0
vgmMG34/d1tlkr0q6aeM92tqHdQavwrwOADfVGrgcqYyAY8D3g8a3Czt/D0S
jwPwSUPZ18p0ST8gWFd/GlKwGQohfT2As/YYGc1dQ/rDAn/LeGaz05D0Nfiz
zg/PBdxzyZoJRk/I9zlwU61i2bmv8/D94/cin9+MXeRA+msAl304hhnjH4bv
E9bJdQ2C860PruD7xO+d6eRu3RhE+rMArxlEi3u+5+H7Ad69K+/dwSl5+HOB
6x+8vVnleyi+PqwzrUXzXs0LTcXXAb7J/mV81ok0/PeF3+/QH0zp7o3CfaOA
1zG0XpR3RuLvAVjPnLffdGznKEfc3wr4xSvqwapxpP8g8MbK628bwkj/L3we
tV2dcuxo0jcQ+FSBWc5gcjD+XFi3SLEkNp9RtsJ/L8DlZ1a/bm52xM8F3EZn
acCh9+R7A3hyloTJqo/ke+PP+iTcJ/BaqX3OW2d44+8B4F9fb5HYPJycSw/8
Tmfaq4nqznj9A+ulHuZ15UefSX8K4EGFHm/mniF/78B1ahfLVxxIxM8FvKJG
p89CkvSbwLluscGr8erk7/rPc1DBN+CUufEFs7//ruF5gbuvfO6u8ZP0lcDn
hc6+7/R7FumvBLy2qH5YyFvy9w48/vlfFRl9kXgcYH0479DqwIyxpL8P8N2s
Oe2dz0nfGeBOG8zawgbI9wBw2/H96rFlOXh8gM+9c9H2tjbpLwP85e3FWbOW
k/4ywAvp+iSMD66L1jgFiZeR/jLArZuUNHS1SX8Z4EvW2TZRqaS/DD7HMlmb
8xOR/jLAXZfFDnr0kT4+wNeOscjZ20G+Z4AfKK38kTUiHH8uPvdPqsPuQa4Q
jzOsl8xcBtjXzXh4fIAXfGuR+2SYhq8DvG5l/YOBS6n4/vF5cVuzNb8sScbX
h/VM6bhNnw036eF5xOdlbX7Zu712P/5cfF5WYUfgYW8unhfgC23ZIwM5jvh+
gK+t3ZX0RNsB3w/wuhfmLlpz7PB4Ao9IfaVWNc8G3yesf27XDB29W3Ia91UE
PraI6SAeTX534/XShBP3Z4RdxN9vwNd4xUyYYBKFv9+AWxl9WFLqQfpR4twX
XZ+E58LnJt08/U7rSCT+3sP5vZalW6vTyO9o4EPhp+b0rya/o4G/UJMddiLe
F39PwvrtVpnBouFc0n8W+EfGpsXLBr3x8wK/OstacoJRIP59is8pkk386rwi
BI8D8L4oXxMHowg8Dvhz95tOEhlG4nHAOTG6Pgl/X8D3ZXYYlJhF4vHB50TV
lXlvySb/XwB+W3qhWrlBCB4f4GNtqQ3uaYF4fIDPujAtxXOfD14P43rmsrIH
4fud8LjhnMb6O0tO7SH9i4GzSpKr7EZkYD+BCz3OWjT2p2HfYD3gvyr4hdId
8nsNn4ewSGDbkpyMrw9cXa7UXP4t+X2Kz1WQqlAb2UK+Z4CHo779pwzI9wzw
03duyHrMI98zwI/T9Um4T1g/bOEsXjz1Kvk9DjzX88Xd5jTyexz4q40xS5ds
FeD7B+4ctcjRYyK5f+BhXIHppC95+Pv2z/okPBc+l0BHjXktWIifC3j9Q+fB
keIr+LlwHTX50oxwd/I7GrgyXZ+E54X1z5dcB6c5xTz8vMDnzjj/coBPfkcD
/9an+8PWkfyOBn7X9/SV6i+knzjwkoOz3rw4SNbbwE+MditQtie/o4HX0vVJ
+LsAnursoOHkSvoQAf9dbrOhMoZ8PwOfsb3l9g+FZDw+uD6pLlfmXEd+XwM/
IDq9KV2K/L4G/pDuQ/R/cs9+5g==
   "], {{
     {EdgeForm[None], GraphicsGroup3DBox[{Polygon3DBox[CompressedData["
1:eJxNnHe41cT39XPOSTK5iYhiRaSrgNh7p9uVDioIdrChgogNFVBArIAFRcAu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         "]], Polygon3DBox[CompressedData["
1:eJwtnHngFtMXxud9Z+ad5aVCIkm7kJRWS9kSQmhfLUVItNhK2ZIlyb4vEQnZ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         "]], Polygon3DBox[CompressedData["
1:eJwt13m4j2UaB/DfOZaKmVLZd0mWEbJzjn1fsu/72sia/cQRQiNTyVSmEdka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         "]]}]}, {}, {}, {}, {}}, {
     {GrayLevel[0], Line3DBox[CompressedData["
1:eJwl0slL1GEAx+HXpsVyKzWz3PCaRXRNpWsZUWqZOtqhg5prqzraXlhWlods
soWIFJGIKB3EY4p0Nf0HjOja8g+Uj3T4zPM9zMD7e39TfKarqjMphPBZo5EQ
1vYIB1RkZ20KoZxR7bdjjOuYneCyOuw/zPDjB/ZeTvIIz+qLfZfj+mHP85si
ySH8Y8G6EIrtUh5kHXvUaI9wSv32V/7SqJ3mfCWasQ/zvl6oWXE9VouOb3AG
tqrSbmO7quwOdqra7uI5nbDP8yQv8KJq7Eu8rFN2N3tUa/cypjq7j/Xs5xVF
7au8pgb7Om+o0b7JWzpt3+ZDvdQdPdOwmrTs+Q5xtxJ2Kn+6g7i9yE+K2U/Y
rahdy3IeYL6K7L/ueUVJ9hzH9N27GGCLFuwKTnAP0zVo//Zel9RmT/Opjtq9
rNc+u4z3nOu5Cte+w0cqsGeZzzzN2Lu4Uwk7lzs0Zedwuz7a2fzALGbqvb2N
W/XOzmC6Ju00pmrCTuE4t3Cz3toeNzhieGNvpOsOr+31RHjlwxWFocj///8q
vl5WFw==
       "]]}, {
      Line3DBox[{1811, 2260, 1810, 1390, 1812, 2261, 1813, 2690, 2262, 1814, 
       2263, 1815, 2691, 2264, 1816, 2265, 1817, 2692, 2266, 1818, 2267, 1819,
        2693, 2268, 1820, 2582, 2802, 1821, 2269, 1822, 2694, 2270, 1823, 
       2271, 1824, 2695, 2272, 1825, 2273, 1826, 2696, 2274, 1827, 2275, 1828,
        2697, 2276, 1829, 2583, 2803, 1830, 2277, 1831, 2698, 2278, 1832, 
       2279, 1833, 2699, 2280, 1834, 2281, 1835, 2700, 2282, 1836, 2283, 1837,
        2701, 2284, 1838, 2285, 1839}], 
      Line3DBox[{1841, 2286, 1840, 2584, 2804, 1842, 2287, 1843, 1421, 1844, 
       2288, 1845, 2702, 2289, 1846, 2290, 1847, 2703, 2291, 1848, 2292, 1849,
        2704, 2293, 1850, 2585, 2805, 1851, 2294, 1852, 2586, 2806, 1853, 
       2295, 1854, 2705, 2296, 1855, 2297, 1856, 2706, 2298, 1857, 2299, 1858,
        2707, 2300, 1859, 2587, 2807, 1860, 2301, 1861, 2588, 2808, 1862, 
       2302, 1863, 2708, 2303, 1864, 2304, 1865, 2709, 2305, 1866, 2306, 1867,
        2710, 2307, 1868, 2308, 1869}], 
      Line3DBox[{1871, 2309, 1870, 2589, 2809, 1872, 2310, 1873, 2590, 2810, 
       1874, 2311, 1875, 1452, 1876, 2312, 1877, 2711, 2313, 1878, 2314, 1879,
        2712, 2315, 1880, 2591, 2811, 1881, 2316, 1882, 2592, 2812, 1883, 
       2317, 1884, 2593, 2813, 1885, 2318, 1886, 2713, 2319, 1887, 2320, 1888,
        2714, 2321, 1889, 2594, 2814, 1890, 2322, 1891, 2595, 2815, 1892, 
       2323, 1893, 2596, 2816, 1894, 2324, 1895, 2715, 2325, 1896, 2326, 1897,
        2716, 2327, 1898, 2328, 1899}], 
      Line3DBox[{1901, 2329, 1900, 2597, 2817, 1902, 2330, 1903, 2598, 2818, 
       1904, 2331, 1905, 2599, 2819, 1906, 2332, 1907, 1483, 1908, 2333, 1909,
        2717, 2334, 1910, 2600, 2820, 1911, 2335, 1912, 2601, 2821, 1913, 
       2336, 1914, 2602, 2822, 1915, 2337, 1916, 2603, 2823, 1917, 2338, 1918,
        2718, 2339, 1919, 2604, 2824, 1920, 2340, 1921, 2605, 2825, 1922, 
       2341, 1923, 2606, 2826, 1924, 2342, 1925, 2607, 2827, 1926, 2343, 1927,
        2719, 2344, 1928, 2345, 1929}], 
      Line3DBox[{1931, 2346, 1930, 2608, 2828, 1932, 2347, 1933, 2609, 2829, 
       1934, 2348, 1935, 2610, 2830, 1936, 2349, 1937, 2611, 2831, 1938, 2350,
        1939, 2720, 2351, 1940, 2612, 2832, 1941, 2352, 1942, 2613, 2833, 
       1943, 2353, 1944, 2614, 2834, 1945, 2354, 1946, 2615, 2835, 1947, 2355,
        1948, 2616, 2836, 1949, 2617, 2837, 1950, 2356, 1951, 2618, 2838, 
       1952, 2357, 1953, 2619, 2839, 1954, 2358, 1955, 2620, 2840, 1956, 2359,
        1957, 2621, 2841, 1958, 2360, 1959}], 
      Line3DBox[{1961, 2361, 1960, 2721, 2362, 1962, 2363, 1963, 2722, 2364, 
       1964, 2365, 1965, 2723, 2366, 1966, 2367, 1967, 2724, 2368, 1968, 2369,
        1969, 2725, 2370, 1970, 2726, 2371, 1971, 2372, 1972, 2727, 2373, 
       1973, 2374, 1974, 2728, 2375, 1975, 2376, 1976, 2729, 2377, 1977, 2378,
        1978, 2730, 2379, 1979, 2622, 2842, 1980, 2380, 1981, 2731, 2381, 
       1982, 2382, 1983, 2732, 2383, 1984, 2384, 1985, 2733, 2385, 1986, 2386,
        1987, 2734, 2387, 1988, 2388, 1989}], 
      Line3DBox[{1991, 2389, 1990, 2623, 2843, 1992, 2390, 1993, 2735, 2391, 
       1994, 2392, 1995, 2736, 2393, 1996, 2394, 1997, 2737, 2395, 1998, 2396,
        1999, 2738, 2397, 2000, 2624, 2844, 2001, 2398, 2002, 2739, 2399, 
       2003, 2400, 2004, 2740, 2401, 2005, 2402, 2006, 2741, 2403, 2007, 2404,
        2008, 2742, 2405, 2009, 2625, 2845, 2010, 2406, 2011, 2626, 2846, 
       2012, 2407, 2013, 2743, 2408, 2014, 2409, 2015, 2744, 2410, 2016, 2411,
        2017, 2745, 2412, 2018, 2413, 2019}], 
      Line3DBox[{2021, 2414, 2020, 2627, 2847, 2022, 2415, 2023, 2628, 2848, 
       2024, 2416, 2025, 2746, 2417, 2026, 2418, 2027, 2747, 2419, 2028, 2420,
        2029, 2748, 2421, 2030, 2629, 2849, 2031, 2422, 2032, 2630, 2850, 
       2033, 2423, 2034, 2749, 2424, 2035, 2425, 2036, 2750, 2426, 2037, 2427,
        2038, 2751, 2428, 2039, 2631, 2851, 2040, 2429, 2041, 2632, 2852, 
       2042, 2430, 2043, 2633, 2853, 2044, 2431, 2045, 2752, 2432, 2046, 2433,
        2047, 2753, 2434, 2048, 2435, 2049}], 
      Line3DBox[{2051, 2436, 2050, 2634, 2854, 2052, 2437, 2053, 2635, 2855, 
       2054, 2438, 2055, 2636, 2856, 2056, 2439, 2057, 2754, 2440, 2058, 2441,
        2059, 2755, 2442, 2060, 2637, 2857, 2061, 2443, 2062, 2638, 2858, 
       2063, 2444, 2064, 2639, 2859, 2065, 2445, 2066, 2756, 2446, 2067, 2447,
        2068, 2757, 2448, 2069, 2640, 2860, 2070, 2449, 2071, 2641, 2861, 
       2072, 2450, 2073, 2642, 2862, 2074, 2451, 2075, 2643, 2863, 2076, 2452,
        2077, 2758, 2453, 2078, 2454, 2079}], 
      Line3DBox[{2081, 2455, 2080, 2644, 2864, 2082, 2456, 2083, 2645, 2865, 
       2084, 2457, 2085, 2646, 2866, 2086, 2458, 2087, 2647, 2867, 2088, 2459,
        2089, 2759, 2460, 2090, 2648, 2868, 2091, 2461, 2092, 2649, 2869, 
       2093, 2462, 2094, 2650, 2870, 2095, 2463, 2096, 2651, 2871, 2097, 2464,
        2098, 2760, 2465, 2099, 2652, 2872, 2100, 2466, 2101, 2653, 2873, 
       2102, 2467, 2103, 2654, 2874, 2104, 2468, 2105, 2655, 2875, 2106, 2469,
        2107, 2656, 2876, 2108, 2470, 2109}], 
      Line3DBox[{2111, 2471, 2110, 2761, 2472, 2112, 2473, 2113, 2762, 2474, 
       2114, 2475, 2115, 2763, 2476, 2116, 2477, 2117, 2764, 2478, 2118, 2479,
        2119, 2765, 2480, 2120, 2766, 2481, 2121, 2482, 2122, 2767, 2483, 
       2123, 2484, 2124, 2768, 2485, 2125, 2486, 2126, 2769, 2487, 2127, 2488,
        2128, 2770, 2489, 2129, 2771, 2490, 2130, 2491, 2131, 2772, 2492, 
       2132, 2493, 2133, 2773, 2494, 2134, 2495, 2135, 2774, 2496, 2136, 2497,
        2137, 2775, 2498, 2138, 2499, 2139}], 
      Line3DBox[{2141, 2500, 2140, 2657, 2877, 2142, 2501, 2143, 2776, 2502, 
       2144, 2503, 2145, 2777, 2504, 2146, 2505, 2147, 2778, 2506, 2148, 2507,
        2149, 2779, 2508, 2150, 2658, 2878, 2151, 2509, 2152, 2780, 2510, 
       2153, 2511, 2154, 2781, 2512, 2155, 2513, 2156, 2782, 2514, 2157, 2515,
        2158, 2783, 2516, 2159, 2659, 2879, 2160, 2517, 2161, 1701, 2162, 
       2518, 2163, 2784, 2519, 2164, 2520, 2165, 2785, 2521, 2166, 2522, 2167,
        2786, 2523, 2168, 2524, 2169}], 
      Line3DBox[{2171, 2525, 2170, 2660, 2880, 2172, 2526, 2173, 2661, 2881, 
       2174, 2527, 2175, 2787, 2528, 2176, 2529, 2177, 2788, 2530, 2178, 2531,
        2179, 2789, 2532, 2180, 2662, 2882, 2181, 2533, 2182, 2663, 2883, 
       2183, 2534, 2184, 2790, 2535, 2185, 2536, 2186, 2791, 2537, 2187, 2538,
        2188, 2792, 2539, 2189, 2664, 2884, 2190, 2540, 2191, 2665, 2885, 
       2192, 2541, 2193, 2666, 2886, 2194, 2542, 2195, 2793, 2543, 2196, 2544,
        2197, 2794, 2545, 2198, 2546, 2199}], 
      Line3DBox[{2201, 2547, 2200, 2667, 2887, 2202, 2548, 2203, 2668, 2888, 
       2204, 2549, 2205, 2669, 2889, 2206, 2550, 2207, 2795, 2551, 2208, 2552,
        2209, 2796, 2553, 2210, 2670, 2890, 2211, 2554, 2212, 2671, 2891, 
       2213, 2555, 2214, 2672, 2892, 2215, 2556, 2216, 2797, 2557, 2217, 2558,
        2218, 2798, 2559, 2219, 2673, 2893, 2220, 2560, 2221, 2674, 2894, 
       2222, 2561, 2223, 2675, 2895, 2224, 2562, 2225, 2676, 2896, 2226, 2563,
        2227, 2799, 2564, 2228, 2565, 2229}], 
      Line3DBox[{2231, 2566, 2230, 2677, 2897, 2232, 2567, 2233, 2678, 2898, 
       2234, 2568, 2235, 2679, 2899, 2236, 2569, 2237, 2680, 2900, 2238, 2570,
        2239, 2800, 2571, 2240, 2681, 2901, 2241, 2572, 2242, 2682, 2902, 
       2243, 2573, 2244, 2683, 2903, 2245, 2574, 2246, 2684, 2904, 2247, 2575,
        2248, 2801, 2576, 2249, 2685, 2905, 2250, 2577, 2251, 2686, 2906, 
       2252, 2578, 2253, 2687, 2907, 2254, 2579, 2255, 2688, 2908, 2256, 2580,
        2257, 2689, 2909, 2258, 2581, 2259}]}, {
      Line3DBox[{925, 1375, 926, 1390, 955, 1405, 970, 2804, 1420, 985, 1435, 
       1000, 2809, 1450, 1015, 1465, 1030, 2817, 1480, 1045, 1495, 1060, 2828,
        1510, 1075, 1525, 2721, 1090, 1540, 1105, 2843, 1555, 1120, 1570, 
       1135, 2847, 1585, 1150, 1600, 1165, 2854, 1615, 1180, 1630, 1195, 2864,
        1645, 1210, 1660, 2761, 1225, 1675, 1240, 2877, 1690, 1255, 1705, 
       1270, 2880, 1720, 1285, 1735, 1300, 2887, 1750, 1315, 1765, 1330, 2897,
        1780, 1345, 1795, 1360}], 
      Line3DBox[{927, 1376, 928, 1391, 2690, 956, 1406, 971, 1421, 986, 1436, 
       1001, 2810, 1451, 1016, 1466, 1031, 2818, 1481, 1046, 1496, 1061, 2829,
        1511, 1076, 1526, 2722, 1091, 1541, 1106, 1556, 2735, 1121, 1571, 
       1136, 2848, 1586, 1151, 1601, 1166, 2855, 1616, 1181, 1631, 1196, 2865,
        1646, 1211, 1661, 2762, 1226, 1676, 1241, 1691, 2776, 1256, 1706, 
       1271, 2881, 1721, 1286, 1736, 1301, 2888, 1751, 1316, 1766, 1331, 2898,
        1781, 1346, 1796, 1361}], 
      Line3DBox[{929, 1377, 930, 1392, 2691, 957, 1407, 972, 1422, 2702, 987, 
       1437, 1002, 1452, 1017, 1467, 1032, 2819, 1482, 1047, 1497, 1062, 2830,
        1512, 1077, 1527, 2723, 1092, 1542, 1107, 1557, 2736, 1122, 1572, 
       1137, 1587, 2746, 1152, 1602, 1167, 2856, 1617, 1182, 1632, 1197, 2866,
        1647, 1212, 1662, 2763, 1227, 1677, 1242, 1692, 2777, 1257, 1707, 
       1272, 1722, 2787, 1287, 1737, 1302, 2889, 1752, 1317, 1767, 1332, 2899,
        1782, 1347, 1797, 1362}], 
      Line3DBox[{931, 1378, 932, 1393, 2692, 958, 1408, 973, 1423, 2703, 988, 
       1438, 1003, 1453, 2711, 1018, 1468, 1033, 1483, 1048, 1498, 1063, 2831,
        1513, 1078, 1528, 2724, 1093, 1543, 1108, 1558, 2737, 1123, 1573, 
       1138, 1588, 2747, 1153, 1603, 1168, 1618, 2754, 1183, 1633, 1198, 2867,
        1648, 1213, 1663, 2764, 1228, 1678, 1243, 1693, 2778, 1258, 1708, 
       1273, 1723, 2788, 1288, 1738, 1303, 1753, 2795, 1318, 1768, 1333, 2900,
        1783, 1348, 1798, 1363}], 
      Line3DBox[{933, 1379, 934, 1394, 2693, 959, 1409, 974, 1424, 2704, 989, 
       1439, 1004, 1454, 2712, 1019, 1469, 1034, 1484, 2717, 1049, 1499, 1064,
        1514, 2720, 1079, 1529, 2725, 1094, 1544, 1109, 1559, 2738, 1124, 
       1574, 1139, 1589, 2748, 1154, 1604, 1169, 1619, 2755, 1184, 1634, 1199,
        1649, 2759, 1214, 1664, 2765, 1229, 1679, 1244, 1694, 2779, 1259, 
       1709, 1274, 1724, 2789, 1289, 1739, 1304, 1754, 2796, 1319, 1769, 1334,
        1784, 2800, 1349, 1799, 1364}], 
      Line3DBox[{935, 1380, 936, 2802, 1395, 960, 1410, 975, 2805, 1425, 990, 
       1440, 1005, 2811, 1455, 1020, 1470, 1035, 2820, 1485, 1050, 1500, 1065,
        2832, 1515, 1080, 1530, 2726, 1095, 1545, 1110, 2844, 1560, 1125, 
       1575, 1140, 2849, 1590, 1155, 1605, 1170, 2857, 1620, 1185, 1635, 1200,
        2868, 1650, 1215, 1665, 2766, 1230, 1680, 1245, 2878, 1695, 1260, 
       1710, 1275, 2882, 1725, 1290, 1740, 1305, 2890, 1755, 1320, 1770, 1335,
        2901, 1785, 1350, 1800, 1365}], 
      Line3DBox[{937, 1381, 938, 1396, 2694, 961, 1411, 976, 2806, 1426, 991, 
       1441, 1006, 2812, 1456, 1021, 1471, 1036, 2821, 1486, 1051, 1501, 1066,
        2833, 1516, 1081, 1531, 2727, 1096, 1546, 1111, 1561, 2739, 1126, 
       1576, 1141, 2850, 1591, 1156, 1606, 1171, 2858, 1621, 1186, 1636, 1201,
        2869, 1651, 1216, 1666, 2767, 1231, 1681, 1246, 1696, 2780, 1261, 
       1711, 1276, 2883, 1726, 1291, 1741, 1306, 2891, 1756, 1321, 1771, 1336,
        2902, 1786, 1351, 1801, 1366}], 
      Line3DBox[{939, 1382, 940, 1397, 2695, 962, 1412, 977, 1427, 2705, 992, 
       1442, 1007, 2813, 1457, 1022, 1472, 1037, 2822, 1487, 1052, 1502, 1067,
        2834, 1517, 1082, 1532, 2728, 1097, 1547, 1112, 1562, 2740, 1127, 
       1577, 1142, 1592, 2749, 1157, 1607, 1172, 2859, 1622, 1187, 1637, 1202,
        2870, 1652, 1217, 1667, 2768, 1232, 1682, 1247, 1697, 2781, 1262, 
       1712, 1277, 1727, 2790, 1292, 1742, 1307, 2892, 1757, 1322, 1772, 1337,
        2903, 1787, 1352, 1802, 1367}], 
      Line3DBox[{941, 1383, 942, 1398, 2696, 963, 1413, 978, 1428, 2706, 993, 
       1443, 1008, 1458, 2713, 1023, 1473, 1038, 2823, 1488, 1053, 1503, 1068,
        2835, 1518, 1083, 1533, 2729, 1098, 1548, 1113, 1563, 2741, 1128, 
       1578, 1143, 1593, 2750, 1158, 1608, 1173, 1623, 2756, 1188, 1638, 1203,
        2871, 1653, 1218, 1668, 2769, 1233, 1683, 1248, 1698, 2782, 1263, 
       1713, 1278, 1728, 2791, 1293, 1743, 1308, 1758, 2797, 1323, 1773, 1338,
        2904, 1788, 1353, 1803, 1368}], 
      Line3DBox[{943, 1384, 944, 1399, 2697, 964, 1414, 979, 1429, 2707, 994, 
       1444, 1009, 1459, 2714, 1024, 1474, 1039, 1489, 2718, 1054, 1504, 1069,
        2836, 1519, 1084, 1534, 2730, 1099, 1549, 1114, 1564, 2742, 1129, 
       1579, 1144, 1594, 2751, 1159, 1609, 1174, 1624, 2757, 1189, 1639, 1204,
        1654, 2760, 1219, 1669, 2770, 1234, 1684, 1249, 1699, 2783, 1264, 
       1714, 1279, 1729, 2792, 1294, 1744, 1309, 1759, 2798, 1324, 1774, 1339,
        1789, 2801, 1354, 1804, 1369}], 
      Line3DBox[{945, 1385, 946, 2803, 1400, 965, 1415, 980, 2807, 1430, 995, 
       1445, 1010, 2814, 1460, 1025, 1475, 1040, 2824, 1490, 1055, 1505, 1070,
        2837, 1520, 1085, 2842, 1535, 1100, 1550, 1115, 2845, 1565, 1130, 
       1580, 1145, 2851, 1595, 1160, 1610, 1175, 2860, 1625, 1190, 1640, 1205,
        2872, 1655, 1220, 1670, 2771, 1235, 1685, 1250, 2879, 1700, 1265, 
       1715, 1280, 2884, 1730, 1295, 1745, 1310, 2893, 1760, 1325, 1775, 1340,
        2905, 1790, 1355, 1805, 1370}], 
      Line3DBox[{947, 1386, 948, 1401, 2698, 966, 1416, 981, 2808, 1431, 996, 
       1446, 1011, 2815, 1461, 1026, 1476, 1041, 2825, 1491, 1056, 1506, 1071,
        2838, 1521, 1086, 1536, 2731, 1101, 1551, 1116, 2846, 1566, 1131, 
       1581, 1146, 2852, 1596, 1161, 1611, 1176, 2861, 1626, 1191, 1641, 1206,
        2873, 1656, 1221, 1671, 2772, 1236, 1686, 1251, 1701, 1266, 1716, 
       1281, 2885, 1731, 1296, 1746, 1311, 2894, 1761, 1326, 1776, 1341, 2906,
        1791, 1356, 1806, 1371}], 
      Line3DBox[{949, 1387, 950, 1402, 2699, 967, 1417, 982, 1432, 2708, 997, 
       1447, 1012, 2816, 1462, 1027, 1477, 1042, 2826, 1492, 1057, 1507, 1072,
        2839, 1522, 1087, 1537, 2732, 1102, 1552, 1117, 1567, 2743, 1132, 
       1582, 1147, 2853, 1597, 1162, 1612, 1177, 2862, 1627, 1192, 1642, 1207,
        2874, 1657, 1222, 1672, 2773, 1237, 1687, 1252, 1702, 2784, 1267, 
       1717, 1282, 2886, 1732, 1297, 1747, 1312, 2895, 1762, 1327, 1777, 1342,
        2907, 1792, 1357, 1807, 1372}], 
      Line3DBox[{951, 1388, 952, 1403, 2700, 968, 1418, 983, 1433, 2709, 998, 
       1448, 1013, 1463, 2715, 1028, 1478, 1043, 2827, 1493, 1058, 1508, 1073,
        2840, 1523, 1088, 1538, 2733, 1103, 1553, 1118, 1568, 2744, 1133, 
       1583, 1148, 1598, 2752, 1163, 1613, 1178, 2863, 1628, 1193, 1643, 1208,
        2875, 1658, 1223, 1673, 2774, 1238, 1688, 1253, 1703, 2785, 1268, 
       1718, 1283, 1733, 2793, 1298, 1748, 1313, 2896, 1763, 1328, 1778, 1343,
        2908, 1793, 1358, 1808, 1373}], 
      Line3DBox[{953, 1389, 954, 1404, 2701, 969, 1419, 984, 1434, 2710, 999, 
       1449, 1014, 1464, 2716, 1029, 1479, 1044, 1494, 2719, 1059, 1509, 1074,
        2841, 1524, 1089, 1539, 2734, 1104, 1554, 1119, 1569, 2745, 1134, 
       1584, 1149, 1599, 2753, 1164, 1614, 1179, 1629, 2758, 1194, 1644, 1209,
        2876, 1659, 1224, 1674, 2775, 1239, 1689, 1254, 1704, 2786, 1269, 
       1719, 1284, 1734, 2794, 1299, 1749, 1314, 1764, 2799, 1329, 1779, 1344,
        2909, 1794, 1359, 1809, 1374}]}, {}, {}}},
   VertexNormals->CompressedData["
1:eJxknXVcVNvXxrG7A0zEFgM7QBZ2dwsqdgsqgoBxFBQQUJAQle5WAQVRWYNg
K6HYItiJgtLMwH7X785Wz5z3/nHv9fmcu/Za3+eZU3PmXK21pgs21FZTU1vZ
RE2tjtp/f9XKGLo7hf6Zd6P/qBSlVGTwi/m3OfxrZ8qPWVZ+Xxeb4wf2v78K
DU4zNmPratOUzus9zJ+5HcFTXNdlwo5Hr7enXGxadi4i6Tj25PrTGnZC12hr
ypZtWmMvNnXHUzVKfV8Niwt6vimlie7MzU1yT2FZtVIfXsNyGi/ZkDK94eXX
L6afxTlcr1/DSnfnrE2ZVbXOR3OJL4YolDr9dxqv5q1OKWqeMM9ELQDVuN5I
wczsfIxStBPr723YKxA3y5X6OgVLWuK1JEXvs+OEPI0gfFel1IsVTN7bbX7K
2d9Z8YWvgnA311fLmfCzw/SU7yua3xprEowdua5bxTS7akLKns3vDtzMCsa8
SqXeVsGMsW3PlNHefi+OqYVg6j9dkLXtqS/Vqc55qqMvrUPrZtG6+k1Wqq5L
fWr2cZuvL+2T5npFc+lL5yIOZ4iDvuOYhiociJs2cdOfNyFChRtxbmCWs1Z/
wCs/Fc7ky0fyRT8y8WKe2BfyMZ181I9evUvFR/I9gHzXj3zcXMV3XcYOUk70
h6spVHJCuVpBudIfu8JFJVe/WH5nyqF+Rg9blRw+bPSsEeVWP8C+U644t6Xl
/pOHNLiAz8toM4OhKb8Llds/+81efv4Ziy4VbJT2j53485dSNyoViuKvReOV
Sva10/JDeLlYqe8pZ0t6HYnE9hXs/dxAe5xWqtQHVgpHe84KR81yZv5p9gkM
KFPq7lVsqWbbUFwgZ74+Om54o1ypX5Yzo865QThOznK8v3ngtQqlHqpgbzVC
AnCmnJkVLfVCZ+77vSrWpf9zH9woZ/vO7j2Do7mPtRXMqufm03hMzorPTPfG
G3/0apbTpcIdz8vZs58ZPjic+xstZ8aDWrrgQznrf6auHzpyvU01U9cabIcF
cvbx9A8/vMP1AAXz7xNgjbUUrMlPB3/8zfX75GeH1DXYRMG8Tz/1x/qKv7pm
p9Q1INWpjmbfAGugOo3EdWjdpbQu0LrvxetSn/7UJ1Cf/cR90lylNBdI5yIO
Z4gDSDkQN33iBsTtgJgbcf5FnIE47xJzJl+2ky9AvjwU+0I+biYfQeoj+e5J
voPU9z3lwkbKCUhzYlTK1BKuRQPl6rs4V89+C98oh0A5HCHO4bYgrdmUW8gq
Y6/iF/zLbftnrOOkk1fR9jP9UeiWYpOt1KPy/I8cwmTs95zNrXdjFbo+Veqm
Hw0m1s9Nwlb5bKmb+w5clavUJ31nhWeKL+HT70zmu8wcb71V6v2KhJmfGl/E
1d8Ys165DxM/KfURJWzpqO7xuLCUuTzeeggHf1fq+8vZJNcxF1C9jLn8fGOD
w3mffUpYg4eBMTitnBnXa3UU034r9Z4V7PPh7AhMrmBJHeR2mMf5aMjZk6Es
BA2qWIP+/g5ox/kPqGbp7wcGYrKcLR1TfQyvcR9bV7N1/ZLPYsNq9nlSOyc8
yPOWUMMMnNq7Y4catnf2Zyd8xPc/rRgb9fKzHT6rYeoLzZwxnu9/BjHmv9fR
BPUYa7Ek2fnv/od0YytHEyC9j1inOv5UB6iOjrgOrbuX1gVad654XerTm/oE
aZ8012uaC6RzEYdfxAGIA9MWcSButWyyI4C43RZzI849iDMQZ0HMmXxZQL4A
+eIl9oV83EA+gtRH8n05+Q7ku/o+ke+TvgvVlBOgnBSKc2L6UTaPcgWUK3tx
rqLy2EnKIVAODcQ5bD2+bV/KLdT5zIy3PP2XW8enBlOOX7iKHr1HzR+n10W/
PdfleSz8RGQynhkUt//giBXwmNe5/ZEN1E5LwlpuC3+pn94G5/i61t/ZkVpv
L+GoQ4+Ydt09oOB9Lilicz0rE7Dx83PNH8dZwRc+17ISocq0dTz65xdUtH19
EFZwDqfK2a3d/S/g15qIxqXXD4Mh5za/hIV+dojB7V2sV4zKsYVPnPOkCub9
7UoEnrY3M54fdBRquC86tF/7URCCNW0/aE7UsYcg7qN+Nev/q2sgtm4/6GhT
awd4yn3Xpnx8CTyL7mWWnrE2x+A0z0k65aqwnju66seZ957uCN94rnowpl6Q
Y4frw1e32ZvhCPd4Dicxlv/B1AQbDrc38W/hBLrsr+7/ydQEZE2eWot1qiNQ
HYhJ6zVUXIfWPU/rgtbhPg7idalPza+BZ8F0bYC3uE+aazLNBdK5iEM1cQAp
B+KWRNzg3fmeC8XciLOMOMOlyf3niTmTL4/JF1hybkoPsS/kY8OdreNhcZJe
vXYiH8n3leQ76Gy3byj2nXLiRjmBu+nTWvcX5eT2R5ke5QpeFp3oriHKlTzP
IJFyCBbhN5aKc/h8Li6m3ELByLcs4fS/3B4sZbUCjsZhg0W375Q2GqafXaDU
jxTJtPXOnsf0l0UBmt93wYIipR5WzB7r9ozFhpM+zo41OQw7+bzFpcL3HwVR
+DNgZ6MO445B8xKlXl7O4k+7R+CoBUMHjxzmCo6cm3clu5iiF4aTx0U+fWTm
Dg/48aioijkHfAhGwxHDP/ZYcwpy+fGLjs9n9x8PxLb3r/QYJj8NqdyXzEom
XNzuhxe6rd+oNsEb9vPj41g5m7sLz6BVSudHTiN8oS33d6uC9RnU0hOrrnsu
fvLED05wfWM1k39b44rNFo00M2kVAAVc36dg4XM32WP3YZYL5p8IgMH8OP5D
zs67tduPd/3Gj3J/GwAruL6E8tY0eS0+u5yhPbxJIOwW6c2S10LrLqX9xTrV
0XFvtx9O6HYcKa5D636mdaFaP2GWeF3qU/P7Gld4VNh8t7hPmmsqzQXSuYjD
LuIAUg7ELZi4gZQbcY4mziDlTL74ki8g9YV8vEk+guH5Jo/EPpLv6eQ7tFq5
Q1vsO+VETjmBO9HRdcQ5CSsWPlKu4EDT4fPEuTpSZGBAOQQHi7v+4hw6rLVu
RbmFvMdRm7yb/8utmtqhgb3aTEX9hUdv9j2hq//nvPoxY10S1bfDum2ez+CL
JWTy/clmZqBlsdcErGsvXdFqhAOs5nozxpz9wzdD55Dk7Nd2J+EG38+41wjV
V69sBMP6w9M/7D8FNXw/06uG3X0ftB52/LDzADVv6Mb17Gq2eJXFWvAe615V
t6U/jOT7n7PVLNBuxmro0SfysdaSQJjB/W0hZ6XN9VdAg1rVow98C4KN3K9h
ctbj04el0HbdvottJ4eAG/crUM5mXnNeCCNbmU35siEUnnO/fOl8rueWOTB+
57ai8llhoMt1qtf/4eXJ4PM2Om5iVRikch/rVLLPVS114eqIvCP3d4TDdq6P
l7PCsNVa4DPrgYlLeDhM+Kfnh6/WQp3ZA0zFOtXZJG+piw3wla24Dq27jdbF
99oa58TrUp89em2ZgwOa1VXpk+baRnPh+F7nVOYiDhOJA3aJD1fhQNzUW+iv
QKPnvVW4Eec44oyGswxyxJzJlw3kC3rGm6v4Qj6+IB+xTcST42IfyffG165s
xIf+zqli35sxIY5ygnceuDwU52Qzk02gXOG5tXmG4lw9Zvkpl9S340eNfk/E
OZyUYFVnQJupsFHna+P2otwu/eH/YcToS5CzNWun62d9/dz3yu3jCgz6/txy
CXp3Xj0qpe5+6M31u4WyTEXzizA3b3CPoWOcoDs/jgwsZi7zZ8aDj+xz7MFL
7uD2Val7lLKQ+MQLUH9DU9mh6WegKf8ctStkjTuOOweZlydtcljhBx1/KvUZ
v9nQjy2jIcbSNy/TIhDu8eNaQQlLkb0Nh6Cyxr4bDwZDX35d0LGcvTgVHwLn
yrxXNpkcCsA/10UVTL7NNhD6OMzTTrkXBhr8+qJBKethE+EDbTs61exrEQGp
XM8sZ3MHzDgFP8+0fDW1TSSM5fuNoBJWHvPMBYaWhqZ2exoJHlyfX8nm1upk
C6s6tLxQf1kUZHK9fznzX2K1BQo1HCMqT0fBl3+65jKrLViirxYu1qlOONXB
t/1nnhfXoXXnxj5zwYHZOmnidanPfdQnSvukuebSXHhqwK1q8VzEoc1220CM
POvUT8yBuBUSN5RyI845xBm7fchS4Uy+TCdfUOoL+diNfESpjx6lwgXyHR32
TkWx75QTb8oJSnNCuXpJucJFdcK1xLmiHA6iHKI0h9lDX7+g3GL9xtcUPh/+
5XbKef+pH2/fhLXXsnIUtfX1Nx5T6q0TNDfpbL8J7PjRG2fH7YP2x5V6++uy
+wEsHXw63Ilusc8RFnkr9dVZTE2YkQanXzl2LOzvDj+jlPril8yv3aVU8J9z
tVfjM6fhZZJSv3eLrgfGIlT/clp5wcEX9qQr9SNP2Lp7za6C6ZgIjXJFAKRm
KHV4y56p5SdBQOKu35vKguAGP49aS9cbIy5chJ/li6KiLoSAa55SX/iL1dt8
OA6WLPwwTdY/DAZ8VOp5BezZiNAYcLqjmRm6KRwCvin17iUs2HtqGMxb2kB3
1foIKOG+GPxmz2o/9oehD8uPfdGKhAHc94aVzDRTwx2GZ0yQTQqIhAU8V8cp
t5strGD5uzGvdudHwtrSv7r/FgsrlOpUJ4vq4OL1HqniOrTuqDqP/XHh5ulO
4nWpzyzqE6V90lx1RobGoHQu4tCFOKCUA3HTIW6YsbpOpJgbcS4kzijlTL5Y
ky+Yt4Opi30hH+v7jUWU+ki+R5LvKPWdctKUcoJ7J43pIM5J++vsGeUK99tY
RIlz1Toh34RyiCnG766Lczh5b/JEyi1mlR/oNbj1v9zq1pHlWrzOgtkamXXG
6I3W71tbqae1ZXOrO2ZB04POu555W0BNM6X+Zhx72bp2BkQvUXyLrDoK2gOV
+tft7M614/dg3O6eXVc9dgGco9TnuQiW2ePugPe5eoWHtnnAgm388xXNrIb+
vgkF8wq2JB45DXBUqf9OY3XuB6VDt99+M8qG+8AhH/65e8JCtyy8Dvd6NPCY
ud8f2scp9Vu32PtmDRFmyca0M6Lr+/qcZ+or9mLKlmRoYJjXrNPmIDB8pNR9
v7Gbwr2LMKH6bvwGk2Bon6/UD5ewuMt0vYNNe9bTGxcC4/h+o3UpM3jfIRw2
GlnU8n4dArn8/G1qOdOJuuwNoe1GRR+dEgo/eT5D5UzWaZ8NNHsGteTWoWBR
8VfP77zPBjWmBCqqRDrVkVEd7D/7S4S4Dq1rT+uidF3qM4f6RMXOmfXFfdJc
X2kulM5FHOTEAaUciFu95g0RpdyI8yXijJMLFp8ScyZf2pAvKPWFfDxGPuLG
DnrbxT6S78fId3zeemCR2HfKyUvKCUpz8macUEC5wt6aM3+Ic5XWVmZEOUS7
Ka/MxDkcGVT9gnKLhR07ncxq/y+3eu2M4alnDjS5Umvaovy++lsP1fynD+lj
bGnWOgci7r+fG3piE+h6KPUp8wzkKbcfQl9oNT3tpwVcS1fq9ayE/OtTs6Gx
2roW33wOwYUypd5pKNs6KSUDtk/Mi6i34Cjs6a5cd/QmNr7myz2o7Z78I/Hs
MVgwQ6nPd2PdstrcgbX3wqzszY+DrolSX3eRGUfDTSh6OeGB0S5X6HxCqdtm
MvUjW9Jg8JLLTlq/TkJNpFK3SWfDLveVgYHawi9tdN3hzXWlviKP9dl8MBmW
918Lw2Z5wK0nSj2ukHXSeJwAaVPijgp9POEc349NLGbqrgtj4Pv1JokV9z3B
hx9/Pen8sbAmAKYOCHvmN+YUuPLz0nE1zN8g0g6OHD30bdfOU+BQ/VfPHxdp
h1Kd6swtqglAaR1adxOti9J1qc+J1Cc+Ttx/QNwnzTWT5kLpXMTBiDiglANx
60/cUMqNOJsRZ5RyJl+Gky+4R3f3LrEv5ONi8hGlPpLvAvmO5vL0ELHv9awM
vlFOsEXu4mbinFCu6uPthyjN1ZA++QLlEONs784U5/D3qVn6lFvsPcZoy+a6
/f7m1q4KQgfNfgzfy0JW7evTMuXlOqVu2ly4ijdzYI5+kw3JTediUyulrjdW
eDzA9BG8ODCmw4gWq1A7RqnHbmGbVr7NhujHU3dtubwBG75X6jkdWZ/Up5mw
JnqwVctH23Boa+VcQ5ewErvP9+Hp5bz5U2N34hR9pW5kx7SNy++AicvtXjX9
zbD9eqW+MYa9c2twC5psGH/Ac505utop9eN3mZOfejo0t03+OnDRXsQQpa7I
Y7GxfVLB/nLPSy+qLfEsKvU7r9hUK9MrgEutDdxXW2Pfx0r9y082zMvlIlSZ
uD8y3L8PN/KcmBWzUVuNY+FgnSqnwfP34yJ+3B9VzVqE+QeCU6uvK9rm78ff
/HpqD2P+9oI9nPX0Hlm/9wGcwP7qzEGwR6lOdTZRHZTWoXW9aF2Urkt9GlOf
KO2T5jKluTBy0aXB4rmIQzpxQJ+rX9PFHIibP3HDSqHkpZgbca4gzrj9TYdN
Ys7kyzjyBQ2da6uLfSEfG9l/vo9SH8l3ffIdzc+V2ot9p5zsppzgqYc2a8U5
0Rsry6dcofeebwXDRbkyba6ZTjlEaQ4PPFMPodyiYe6jQP24f7ntPt54kd3U
R3Dk97vl5u8Hp+TFKfXjc2Q1358+hIrIgeZWhqYYf12p/zIVru8KzoYHsslH
C3YfxKJvSv1od7bktCXltu7QNT4N7XCzurL/pCXs7sFn9+FE/R0Zj8Y5owmf
d4wNu/Vr8F0ImzThW36xK+quVupHQ1mO47FbsC9UI8hacEcHQalvus58tN6n
Q/jnA8v90zxxCj+/eviU9Zwy9jpcirl7yzDFCx0TlPrYDOb/QzsF+va9p37R
9AzOucP3Y+9Zkzmvk+D1fotGkS/O4ukXSj3lF9t7ziUedj6wfThG7o1bPyv1
4SXsdpcjUWC0r5/xxsc+eIPvJ5MqmE7KQ39IevhYNmiDL8bw8weTaiY7MPIo
PNbOKnCL9cVuir96/sGRR1GqU50sqoMugtU1cR1at0XXI1EoXZf69Kc+sVvf
jHviPmmuYTQXSuciDreJA0o5ELdRxA0D63S+KeZGnC8QZ5RyJl8+kS8YXG4W
KvaFfHxBPqKbt8cXsY/key75jlLfKSdbKSdoHpu/VpwTytV9yhWG7Ph2WJyr
43OEegVPHxIvB0txDo+Uf1lAuUXbiKgYtZR/uQ2czjas93gAYwc3KF4zZExK
5jBl/WcLDVYeaPAANK5o1/fz3ot79JR6iBlrO0T7Hkyav+vy7EI7XLJIqT9w
Zw/CSm5DXHZigzlnXNHClM8Vw4wvf7oJMb5nh5pN98R5/PMedp2FbMtOh5Ud
NqXNcSbOnFvQI3Zwe/J16OPb6HTsWl/UOKfUO6Qyb9dpMlgddED964YADOL7
meeP2Ygzna/CsptTB3x6H4gt+XXKnA/sxcOiRNhguuTogv7BuIr7u7iQ3W54
Mx480T1pwNgQPMWvi21+sE3C0Fh4qF3wek/7ULzGvxe4UcYm/ngZAhOWjlZo
XwnFxzxXGhVsVGL9MxAz0bL13D5h+IGf996Vs6we5w9Boe2Rjm9XhuG38r+6
rOf5Q7jrlKyDWKc656kOntv8s6W4Dq0r0Lp4fVK1yrrUZzD1idI+aa73NBdK
5yIO5cQBpRyI20LihlJuxDmZOKOUM/niTL6g1BfyMYF8RMOSonSxj+S7CfmO
59JaDhH7TjnJpZygNCchZkJPyhWOHyBPFufq2ULjTZRD7NbveC1xDr1+1l9L
ucW0Jf3O5+v8y+2LbNm85iPSIPDixNMnT+indIvl+4GHgmlJmzQ4Nbdlo6sx
+7Az7//ZC1a0/GsqsN6/Gu1474gP+HVrwA1h6dsSBJecy/FNLdwxIE2pr3vI
SqYvvQZmdwebG5eexlX3lfqsXFY6ISgZtswPXetX4osmOUq9z0fWQ78gEczM
zwyZpRuIdi+VunYBMy3UuwjmLmuLQDcYg94o9Yu/2PQGx+Lg+9dlXQdXheAX
fvz98Z0lPImJhX6uMyJ7WoehIb/eX/KbOXlNjYCqvX1qd7oSjjU/lHqbcrZt
+bsgcDQumd7mSgS+4ddfzUuZy8iqsxCdNFloZh2Jdfn9rj5VbOoVHVeYfKhT
UKOqSNzJ70vE0v613MMclk97m9BANwp7lv7VNSs9zFGqUx0vqoMZUx+q1KF1
82ldlK5LfbpTnyjtk+ZKoLlQOhdxeEYcUMqBuK0gbijlRpxtiDNKOZMvI8kX
lPpCPjacGJSMy9LGrBH7SL43mLH0Gq7RvWkm9p1ysp1yggcnzY4T54RyVUW5
wtyGHRuIc0U5NKcc4uCwIU3EOayfsngm5Ra33734ruDIv9yuLJXlZv+MBudr
pr7eV/VTsjm3oGL/kS316Lxx5fx77m/2oQU/f+tRKvg99YyGIXXVBz9u54Qb
+fasjMXXGhkJi7ftGuB41h3duC+dKljI7xHhkLvARXtQzzPYlfuoXcly1SpD
4OzhvnczB/ihG9cbVbGMH1eCYNy62CO+hoGYzfXrVczExjkAHK6Xj5i/Khhz
uZ5fxp58jvWBNBM2zEkr9O/2gyrYkx2TTsNhw1Vm80LC8ALXbSqZ1ceX7tA6
LHet/6dw/PO9layULbzy7gQYt/PvbvklAldz3aOC+Ue2sIPFr7LiX0ZG4liu
1y5nz4ZYWUNz+Z1Wt7WjsDvXqypZfrewNdBQ/8V4/W1R2Faka4WtwYdBAyeI
dapjPNTKGq+4T20trkPrvqd1cVdEqMq61Kc79Yn73u1R6ZPmOkNz4SCzeJW5
iEMpcUDfPsNVOBC3YuKGTo8XDhdzI84HiTOOMLQYKeZMvuSSL3jeq66KL+Tj
D/IRH3Z6fEfsI/meQL5j6tFkFd8pJ+mUE9w1eqpKTnqUsnOUK2w3arxKroKK
DfQohyjNoWYP9euUW9w66eWFPtf+5XZEtZCmttkH07Pmd36RMyblJT+vc6hh
VpvWnyKO2jP7jrLET/x6/EKNLFqrjgdOb9NphK2d/V/ds4ZdlO9xwyTDdftv
1T+Jjly3rRG0Jq13xVszzQ3zn3iiBtfjFcw+Ifs4Pqn9pSp/+Fncw9c1VTCT
Pi8dcXDtps6ePf0wlX8/tUzBxt/wsMfl1se/az4KwMZcX61g9w3NjuDmw1Fm
5cuDcBG/nvJQsJz7sw/jx44fvj6JDMYYft/gTSUrvj5vP4Z1N8tLvh6Cbbn+
vorVKahngVXxnU2DA0PRjZ/HzqtgwgALU3yTFOrtNj0MB3FdT85aHH6zFi+9
01pvn/zv/MGhkhks6T8dNzTpdOfwrzC89U/3X9p/OuC1QSo61dlEdUBah9bN
p3VBui71OYz6hNh2k1T6pLl6pM3bD9K5iMNX4gBSDsTtLXEDKTfivJQ4g9pd
KxXO5Isd+QJSX8hHb/IRpD6S7zrkO1id81HxnXKSSjmBrSmOKjm5UGOQRLmC
UxeKh4tzRTl0pxzCU53cGeIcbvJpVK/WZh94+mXKNtcn/3LLPuanvUlIwsn6
H+c1ODAk5QN/DuRQgWbLVkcuYfbRz583bNqJavx87FyRbOyWjAT0tplwveVr
AYFfjyiKWYcmA+IxJO1dzp3m9vicH9delbGcJPML+OFgvzsdTx7H0fz+/4df
bHL7J7F4f0t06OWUk5jHj5tzSlngVozCG2szTKI3eeBw/rnrWsHUD7uG4wH3
jh9v3zyFs/jnfXYV+zFsRwg+GNOkR+fnp7E1z4NCzm7HTAvENS3cDp33O4uu
3PcjVcxl9TQfvL5RfYvQwQcfcH83Kdi+TcwTi+x69XSe5vv3ucqTcvY5d7sL
jlFvd/lJfz/cz330p+u7by9t0E0rt9WKdD8s43qdamb8vscWTB61cqJmC38c
qvir53/osQXOHr07QaxTnVHfX9pAXI5pa3EdWtfg9XYXkK5LfYZTnyDt07aK
XaW5QMbnulf5l0M+cQApB+JWb/iOEJByI879iTNIOZMvl8kXkPpCPq4gH+Gq
6xoVH8n3fPIdpL5TTnpRTiB9j8VjcU7OFRlMo1yBxsyT6eJcHSow7kI5hJNa
qZ/EOYT4L08otzCm0aRFv23+5VZ2Xwb4JQWbOI55aro5c6wGv/51emZgHWFx
Fev2S/XZf74Z5PLnl6a9MThatSAZzW2/uvzY2wUKnil1x8+scPSYJMxrb3am
qnFvmMW/b0r9wWbWbXkJ+9XVSSxrOxCmfFDqJr9ZsnW7BMz4amxndn0IAP9e
QK+MXTLsGIcdrY0WjDk9HC7z88DA3+yMouc5PKjuedOh9yjI5NdHM8vZq9Va
UTh13ng327VjYAnnn1zFRml3DsPxvkcP7pmpByu4j12qmXsT9SCc4fMiYc/7
sfCB52FaNVv4oocP6j5NmpneD+ALz1ttxnp4d/DAVt3aCEJXA9jOnzdwY0zz
SlcHrCMPN4y4bgD/3Y4lnZaR7Wu7Ex32aAz2azQOiv7p5/e33QlSneq4UB0Y
uu/zKHEdWteY1oW3/jmB4nWpTxfqE7YuKe8r7pPmOk9zgXQu4rCYOICUA3Gr
JG6gnl3rkpgbcU4iziDlTL6kky9gZLXytdgX8vE2+Qg7vr65L/Yx9YdgSL6D
xtHtDcW+U05qKCcw4LROWKUoJ5QrD8oV1K0b0UecK6dngiPlEKQ5LJyduoBy
C79bzvHNaZH9N7e33/vH2RhdxtILy5zq3OuvX8DP89O/sbKOvRJxeZcNrU6q
bYV5/Lm+bYVCjdOKi+jbcqnd/slWUMSvIzSLWcTniHgc0nObQ+QcG/jG55pZ
xkzmf7yArzf32mEm2IMf5zDmF+uRHXgOTydsuT15lDO48s91rVL2fKdFNJr3
Dh3RR88VBvP9gGYF+/VmcASuTdGabN7VDTw4f6GKudem8zfXDZd0Ftx0h7N8
PzOb9rc5GIgx/Z8dQx1PWMT3VyBnS5Mb+WLoBfVRt1eegjTue0c6jt31PIXd
K+912TTXCz7w/aFRDdN5oeWKzPBGa/+6p+Eaz8/KGrb3oZEtwpSsZqYHTsMs
fhxsXMOE61lbMK/u8ybPkk+D2z+dpWVtgdz8Nc3EOtV5RnVgrNbyFuI6tK4x
rQs1wVPbiNelPofd8zwF0j5pLnuaC6RzEQd34gCx7xaqcCBuscQNXM+NHizm
RpwbvR0cAev6d5ok5ky+FJEvsC/PcYjYF/JRl3wEL0WBio/kuzX5Dq+q+puI
fdcsFi5RTmCo23p7cU4oV42dV1wEn+UvVXJFOazbqVciGE141UKcw6uTD9yg
3ILRAbXf6jf/5fan3NjAb2oI1rrsYmazbpS+B5/3aLXBhJwmgajItHiw5LM5
LOPcmimEbYXn/bDe94mv3007Cu+4LijYuJuNfPCsbkqLC49PwJ/f77xXsMm9
Wp5B28Om1Vp33OHP7zIUdP5m/OAU3gpe79M11Qtu8DrtqtnPasEDf2e+tQxf
4P33uUqDauZdT80Ns5NaHL4r+EFHrr+sYsXb9V1widHPLn7BAXCF+7hEzr4n
73DEOWZXFx9+HAiGf36vJGdNAv2PosX0QZtPPQqC2lyn88B1hx8ewtlZjRq/
9A2GRM7hf+sk1rfEVs/a3ps1MgSsuU7Xd/65j7djO52ZAT+9Q2Ae14vkzN9t
9ELUN27lLMsMgbH/9Hz30QtBqlMdndePt0PnqVtV6tC6o5LqW4J0XerTifoE
aZ80lw7NBTuHtFCZizg0u7LDEWZ+jlbhQNza7dB3geWfq1W4EecY4gzp9g8P
iTmTL7VqBA9Iaf51r9gX8vEX+QjJZr1VfCTfl5PvEFzZuEbsu6AQFlFO4Enr
Jy3FOWmmYAcpV/Dd8XauOFdHq4UFlEP4YtdBJYfyletWU27hWZpBcrEotwcU
wgeL2cHwYP5vr6C0sfqD+Fy75MYvH78JAc38wsRjRdZQ9w9PucHG85XBUP/G
o6CVAx2hI9f7KphWwIYgKG5Z66pmqdtfXwwVQlFO40AYnXEpee3C09Cb65Mq
Wdv0RD+ov2LZb8vhvqDgx8HLlcx4/3pvcNr47enOBwEQxXWNKjbdbeJp2NU6
bdPM1CAYyXXPKtYhTM0T6pQ11AgxDwHk+5ledP584NZJsOh2qt2BgtC/z2eG
lDPZsPbH4fOYaxPze4ZDJn9ed0wlu2/hbweheo0Kb3WNgK1cZ3SdeKPvIQgR
QpOGv4wADa6/rmSbuqw3A1mjWe59l0bCG74fu1rOjB++XA5p7PehIM9IuPFP
z3/0cjlKdapzm+qgtA6tO4zWxahG6SrrUp/l1CdK+6S5CmkulM5FHPKJA+48
ZanCgbjpEDdsdKi3CjfibEycUcqZfLEgX/BE/0oVX8jHgeQjSn0k3+XkO0p9
76sQBlJO8LPi5hVxTuLlbCflCjO/3gkU52qX3P9/OcTJnQKTxDn09+h2j3KL
4Ybbp1jc+Jdb81QZ21cgg2/m21cMUgP9OalKvdt1gw6rb8sgM8BnydtO++EC
1xfeZ5Ytc1Pg0ZxY30HznMD5tlJf8ZSZ2phehfMVKR+ib7uDSZZS/57HjPz6
JoMh9Cvdt+YMFPDnCvZ/YssHXk2E940yCuMs/aAtP58/WcBm/J5/EZbEZhZ9
swuEjfz4suwX67i0JA76TrvsZ+IaDG/48WjdN9bvVsfzMPdSl6ZXl4XCDX78
Mi5iSSYLomBU6ynHH+WHgRo/3lWXsDFwLBQcd5/RxV4REMKfe7SrYE6tUgOg
9GjuNGvtSLjMzxutylhh9g8vGHrzgVGDn5EwgR9nrUtZYWWiM3TY+3rzhp1R
MIXfd5pBn8ewnmbwrY2fqUdcFNwR6eE9zVCqUx2hKtEZpXVo3VEPf3ihdF3q
8zz1idI+aa6VNBdK5yIOL4gDSjkQt9nEDffs+thEzI049yfOKOVMvhiRLyj1
hXzcRj7ivA7nisQ+ku/byHeU+k45OUw5QWlOKFfHKFcIq074iXPV7bqsO+UQ
NToMUMnh4pYjyyi32LR7t+Q2df/lFrew61/u3YOEdzmpCV309B1nKfWZu1kP
vUn34NGRAX4rt1jBioW8jpNB9y9ed6C9a3Xa4ji6jtms1DuGsre9Tt2Cu9k7
9yvenoTRglI/lyy89Yi+Qfsrq5Adv+m8z12pz77P9jufT4P4V00c7zp7Q2qo
Uj/wgjn2TEwFp51d6h6J84cJiUp94l32atuRFDjgo7lqzoVAiLih1ONeMvlK
t2QQmp8sejcrGOY95Ppn5hQbfAlmXtiScPhcCDTnnBv/YmZmF+PAzHnwxGFP
QqGMX6c8+8m89jpGw6fxN5uWpIZBS/68bq1y9r1pTDAEtmoXe2NXOKzi+ckq
ZzoTvL3gudFqjdDP4fCJ5zCL9osxVgK8mJk927N7BESU/dVl56wE/H96OfOn
OiitQ+v2aBYTjJ/3HVJZl/rMoj5R2ifN5UJzoXQu4hBJHLDelJp4MQfi1mGV
WzJKuRHncuKMUs7kyxnyBaW+kI+O5CNKfSTfC8l3bLD1o4rvHUOFIsoJSnOy
2InpUK7QqGpzujhXM3cbD6QcYlC6ib84h2P3tJdRbjFQc2HvB93/5XbYbBne
evcQTst6ObTvOly/Y6rye/Clhqx8hulD+OVX26fm+W74naXUd1gKo0/MzgaP
H2265MyzgQ+lSj1yoKD2tSgDHEOS2/ZwcIShmsr6MatYs/lr7sOATdNyRtU/
CXsmKvXhDmyL1/U7sHVD3D3ZTg/ovYFvH8n0Knvegg3WX3sU2HrBOFulXpLO
xvocT4dd5oOMnhichSu+/HP9nHldK0oFdzWTwFEhPtD8Eq+TyVr4R1+DzY01
u7eL84Pf/Pr37nvWQ8s8CZxg1wYYFgA2/PvfM7+YZhjEg+W05lOGvwsA5M+T
Hy5mWUYto6BfmWPi9g3kL7/e2UvH95wp/pC/LSr687VAmMSP1+YKZvDuxRFY
G7m9V+iXQHCt+qsbv39xBG/11u0t1qmO8HiKP+7/mRslrkPrtljRMgql61Kf
E6lPlPZJc02kuVA6F3EYRhxQyoG4RRI3lHIjznOJM0o5ky+zyRe8U57YU+wL
+biffMSMdwfvq/i4inUj39HlQ7vHYt8jB7I2lBP8oWXfTpyTHZay8ZQrLN/6
ViVXSw2FGsohntAa4S3OYU5QRQrlFhePmuTg3+1fbidW5xlW6z4Gva5P/JN8
m+lf26jUs1oJZe3O5cC4Kt+Lrs9nQvx+pW6ubxC0YMMj2H4rLHhSGyM4FavU
l2wRZgd/yIbJ1gUFe0PXwdl3Sj2pA6t2eJ8Ji+vfv79i3BYwaaXs/+pitl7z
533YUKGY0X6ZCRSMVeoadqx0gOIODPnxxDzeYhfkrVPqLWNYS7MWt0CuvaXb
pUNmAPx5gPV3WeiTzumg+fKu4azp5uDGnxN7l8fqbRyQCi9nG9/yyLYAa/4c
wrlXzH3A3itwdfWHJ1faW0J7/hxa3k9m4OZ5EUKvzTH262QFq/hxdmcxyy/b
FAsRbVs7zsi3gj/PuelWM9mtkEAwPqE+M2WNNVTwfFozlr/Szh52zG95qizI
Gv57fFKpGxjb2aNUpzrqt0MCUVqH1tUp3xSL0nWpz23UJ/r1tdgg7pPmktFc
ePFBk1zxXMShA3FAKQfidpW4YYcpv1aLuRHn3sQZ2Z7FXcScyZdGAxV3cNTh
c6ZiX8hHK/IRpT6S762Pvc/Eubt/PxT7TjlZRjlB+NSmWJwTc30WQ7nCQzaD
T4pzldWKVVMOsVeUXoY4hzIHu//lFnd2qVkw7/G/3LpqCPPqHcyBy5sOvPB/
0yul+RGlnqDtv69WxSP4/uSUbsfD61H7tFJ3mS9cfHDtIXxqlFs58bsZzrip
1K9ZylLYjGzo46CIL3u4H5fw51pbDmERC+9nwNfxEz03W9kgainnerWRPT9Y
dA9cr33/bdjfDtvz52Z13Jj2lA534NyFk/6vDh7DQfw52+EXWeCaqTdheMj5
FWfMnLEufy73SCbbMcc0DfTqH/F83sgFO/LfOwSks00Thsng/awm+bIAV2zL
nxM4nsfM5HbJoLnhi7XB8ZPYmv/+4nMhe5X6MgHKE3JszWe4YXO+3wuiPLdf
GQPbTbbNW/ncDZvyXOUoWH5o3UDoNCT2bflId2zIc+hNY+desIPa57SHTd5I
es1f3SDvgh1KdaqjE1Y3EAvXB34Q16F1+6ivjEHputRng+svE7DZ2eU24j5p
Lm+aC6VzEQcX4oAZG4++EXMgboeJG0q5EedE4oxSzuQLkC8o9YV8LCAfMSxo
1y+xj+T7NfIdpb5fszS4QzlBfRObOHFOKFdIuUJprhK0ZTaUQ5TmcNjbzv/L
LTaoW7f75Rf/cjvegn0235ANgw851O60fkSKdrFSb6cmrG1TkwXbDJbtsO+6
B+urKfu5MVCwH1mcATaWDbJbONvian68WLNCaPLI7j4MdT+qVzTDGe+NV+pT
bZhP5sC7MOyKb8nCnm44mj9PeCyIzd2RfgvuBz4xHHPLE332K/UD11iD4BU3
QGDrbMY3OYOfPJV6bjazXSe/DhgQ5D2u2Bs7xyj1LddZpXkfGWin21+bfdAP
E2VK/dZz1mDlyivg/l674YAlAbie34ef9JW96up2CYzS6lXGQCBO4ffzu5ew
YRW3LsDZnYdTzlcE4ip+fTS5lKnHl4dDve+7lg45EoQx/56v08xO84EoD7Z9
6NsgHM7PE9YpGHMcYAuy9o0U8S2CsaLyr67pPMAWR85dKBfr/3u+juqgtA6t
u5TWxf09ri0Rr0t9LqU+scfoUSjuk+ZiNBdK5yIO/YkDSjkQtw4WfWQYKH94
VcyNOHsQZ5RyJl80yBeU+kI+GpOPKPWRfI8l3zHq9+dise+Uky6UE4y8n6Ur
zgnl6jTlCnd+9c4U54pyaEI5xHd7g7aLc3hxy8T/5Rb7tpo4Dvb8y62tt8GO
jia3oV1Wge2FZ3opaRbK7WUBsoTIWrchJVXvYW5Xa7TZp9Q/XhC6m56+CRcP
Yu6b1cfwjqNSz7vOvNflp4P8l+nccavcsIQ/NxifJfQfPzQNHvZuuyLnhBc2
j1bqYa/Ykpa7U2F3w7wnAVN8cFIy53aPTY7amgKHPsSN+TwhAO/dVOrOL1jx
S0UyXNrYU0+9dxCGcV92fGTCq8OJMC9x5OkvD4JxNL+vPu8nsz3QNAEOtjaL
nj8qFGe8U+qeX9mm3f3Pg8ZA10XzNoSh4otSP/2bLR0OETA8xa/n9yXhOOfP
7zorWHnj+YHQ5JtpfNemETiN7yczK1i+720PiLw8Lf37kQgs+Pf7QZZzcR8o
tOVzF1yPQCj7q/s/ubgPpTrVmep32wMjh/5KE9ehdfs0mR+ITXbeVlmX+nSi
PnH4xDKVPmkub5oLNRI+q8xFHHyJAx44fU+FA3HzIm44b+wJFW7EuckrRTJe
Ktinwpl8WUm+oNSXsFfCOvIRpT7GZ7FR5DtmX+64Uux73nUhgnKCVbYW88Q5
oVwNolxhwqnOeeJcyQKMr1IOUZpDtcV7tlJuMbyitavPq3+5/frWYHKvd5ch
bGDOlDXakDKHX0f4vmW5PQsuwzOjkgXHx+9HxXOl/vIjM9vmkQTyZp8Ht9vj
hEf49fKdb0Jl/K1L4HR7/4ynee74iD9neP8nm/aRJUDknCLnofvPoCW/7jb9
zRQdW8SD4aURpe9P+WEZ/75+WSnTyu15AfovsFzq6BWIb/j3+xMLWauHx2Og
W7xZ75lBwQj8vpNGMfP8kBgBofdDja5uI7/4fareZSy/cUEIWBvYvs0uDsOf
/HoqtILFvegSCLlGq58d043AcTwnW0rZ+e4BZ6Hej7bVBQaROIXfH3tbwbxu
13WHEHmTm2V1orAuz9uDctZn5yM7+DX2qTzcLgoPcX1mKTMo2mECva4c9lG7
E4X4T2e/dphg4x/RKjrV8aI6eCVIWyGuQ+vep3VRui71+Zn6xMwFW1T6pLmy
aC68fsJRZS7iICcO6Nl0uQoH4hZH3FDKjTj3J84o5Uy+DCJfUOoL+di4U4t4
PDn3bYnYx/s/hSXkO97odEvF9zvfWP2EW5dQmpOXH4VDlCuU5sr3reZ7yiEW
972nksPbo+rpU26xW+6hRuXd/+X2HGMxjUqPwr0ZS+89mjE2xYEpdTp9twjc
chycT0/7ctrOGhX8fM+mRlb6wOsE1L59XxZz8xju5HpVtVDssuE4TBUO19cN
d8MH/Hvb9dXMP/SdE6weJdu3q8ALa3O9bjWbFlrkAGbnSmJqJ/ngAP49UaKC
bSjTsYOAi2faOtoG4AT+fZCVgpnee2oLfVoFNxxrEoTz/r3v5Xll88Pw3de5
m3+nENzIj+PjK1mrjaX7oVEf86BIp1B05vf5v1ey92mxe0G35XGr5RhG1+tK
/XMV27R8625Y9HO1waWEcOzJ9TkVbG/h3K1QeGf40eRtERjC96s7yph/Fzdj
OH3OpsWmTxE4i+uHK5kwtOlkuFNk+iKlRyR2+6fLhjWdjFKd6uh0dTNGNcFS
pQ6te5vWRem61KcL9Ylzct1V+qS5mqTH7sVHBl4qcxGHUcQB9VvsVOFA3L4T
N5RyI862xJnyE6HCmXyxIF/wsY+Hii/k4yryEVsX3VfxcX21cJ58x+4XW+4X
+15VzWooJzjG6LNKTmxqhErKFUpz1YoJKymH6B7VTiWHFg97LaTcorqxfuhs
UW6r5cx4Wqk/7q1mM8cNW48K3ueDas2rl+wCsPv/1hNGpFyT/93elLYH6fYR
l2ql0/agRdf9A+3/bd+8lHX71DcGHnpvG9JWezu68v2JepmBy6Rp0RDf/9nC
0Vf0U1b/fY5d6EjbY/unJ3TE269hpmPX33PEiWntD47L2Pr393fVzKVxH7dd
KSsG9LhvlrQBq/7pbUjXz22zWkVfw/x3Uh04mhl9QFxnebXlPuoHdxktyA4S
9bOLaXYad9wVZ9PudfC1RVhQ80ef24N0mM2Er2I9vFqoycoLgLBXj03aJRqh
s/yPvrSQdNSZnLdDrG9nsjtWT1zR4L8/jkj5xOswJmtu/W6Xvuzc++Z6XxZj
De/zGGNjD8U7gHGXZ+mnPxviRq7vKcluMnVcAN6SjTe07KGf8kb+p05+PaqT
Iky1UqlzzvBRNq0LtEFGxvd/636pzu9GdWC+bsRq157/6hxjc8uFeAfU1S28
IV43is288em5acqJonVlK5JsMJLrn0v25nbuHYMmJbIpk1MO4OY/z8nXmNoM
m7Ut5Wi9dVNWW5/ELL7u8YoWj3tqReDhcgM2MMMJe/PP78qa/HGHZBtTpj2O
utpuxWk8z/OvIZc18qPP4Ry5/+Tta9xxFP+c1q6R1TwYujZlmG3I60w1P9zP
P19PFQbNNNoH4GI5K32Z74VX+ee3ucLActgsoxS9SsyZPDwQV/N5Wyv8W/TU
Oo3H5QYT8td44wP+uX6jEIofDF2QMmj+7SPH04PwENevVgt1Ndq7YpZceJv+
2hcP/3lOUsHePRg6IeVFz503ZsQF4y++7s9qoUy9/SGskWvuXLfMH7/y7dXU
3hCRh3rS99DWUfvfhUMr/Zb8fZ5N+FzHFcLAjKET9N9L6n+rFkZqtD8ETK5p
Iq6fpxDUM4Yu0NeR9H+lWtaT+ocsuSxf3H9ThaYf8dHfuD5VhU9LhUyH+ICU
T60aWcuMoWv1nSffl/LvQvxhiZyViPmvqMlfQP7qz3066JrY3/ZyWUfyF+bJ
ZZPE/lbXGHhQfvQrjyxTyY9TRf57yg/YS/ITwdY9pXzqL7m1WiWfH0tuF1A+
YX+J/3RxPod+OKxzYORlPPaWbZz6bSvOf8X7/KkT2S/tIpZ/Yw0iOlnhN36+
EVN63sBkVtz/fldQKBw8jH++r9Sh87QDsdEYU87MHZ2OogevryfP/9AlLQSX
V7GCJpcc/v6+MlUh9D0Q640fFMx84m9HnM25edYIzQ/EOmF4DVt8cqozWvF5
m6qNo3/rpD+N/va/92EO5XO51DBL2h5o++Xi7a8pmDHVh4+S+mPkMrWuaSFg
WCV8FPczqFQwov4htpydFPcfXXp+Ns0LCaVCsXheo58skfiA4hvrK+Yz+IN8
LPGEU28FZzFPhw/5dY93uYz1bG/M9Wq5Bfy4fvxn/vuVFy5iz1GdIy+67oUu
/P7t/dLyYWv043DXiZiOjcwOQT++7pJSYd1mz2is3jv6dfWUI5DI+1wgFzSa
XwjB1pdGJxZOtIe7fK7nCtZus6c3Opw1NTuz5hhs5BxiagT5Jk8nXPm0w7su
IY5wknNrxjkX+Z/b87/3NE7nnENr2IbNnk4wdk79avH2TxTCbKoPXzUeWYrr
z5cLQ6kfaCPpZ1EpO0D9w7SAr9ni/u+Vlo+neSEv6XNf8byOP/N/ER9Q/6ET
I+Zj9yGpNfGEve5z9oh5ti9u89HwbCx6JV13LjwvQEt+3j62XCdCwzwSe/W4
q9ns8nGow59LGVklFAeMCEXbJvVnh131gJl/zosUBnUvlgfgoW4b9nxyPgMl
vP+5cqHLcbMzmDZ70VbXub7Qhe8HplYLaxLKXXHZ/fklepX+8Od914er2byE
8kPYJzbN/8TtgP+9x/c/va5aKn3yW+iXbV3z3/sDLbh+oJq50vYQ3ETbV7z9
5Gp2hOrDr1ezfovrz5YbG1A/kC7pZ5xCaEf9w2FJ/8OqhLqBI0Kh1tYdM8Tz
6pZnXSY+kNF2S3sxn7bFC8uIJ5wxnOEq5nmIBXezqWcC6hfHsvdqdmDFc3Kz
Zu7Ck2abwE5rSt+gAA+Yw3NSu8Zg05bz66DtvAFret32AfzzHlq5cKGZYAy+
XTB29NVAaMPn1ZULduv8l0L567M/tJaGgD3ff+6sEAx1hLmwev0AebvBYTCH
zxVXznR1BAPYvS+vddz0cNovKnU1NTXqIOPax1kKlffdRZWzK7Q9Ngto3kq8
/Y4K4SzVR515L6rE9UfLhTDqB+d3uKPSj7acZVP/uELHKkbcv1qNwV6aFxNi
jFaK502v0dxCfDAx+0dvMR8b9qQf8URXx+xqMU+9QvsWjeddhFlJd6y+oQP4
8vwnlmjqm8yJg8bhfhVsiBcM4r/bdSoSCna/ioGM0Tvz1AYFwCd+f+ZAKTtS
2i4cokbqZLQoCgYLfn+ycaXxbKt5gTB1iId6o/ww6MU/j5blQuPydl5Q/lUw
zvwdAUP5+eGbcqGkrJ09qP+EJyY6UXCD6w3V/veCDvWUff1v/ve+tWKuvywX
ZpW3s8dx/kNVtrcoF0ZSfZw2a5NK/YaVBhuoH7w3Mau9uJ99pews9Y/3vqSp
9O9QVFjb7FUMZknmvVSSNY34YIBbDxU+Ywo3dSSeuO2Sg6WYpx2+dZBPvAFD
OzL9Jq0dIP003489lfXoMvs6+PQ4Vqub6ykYxH+nvyFDtlbr+TVw+jZkq561
P3Tn3wv7vWefZ7dJgob2WwMq1gfDc359HfnLePg+8utC49FxBwzCwJmvO7lY
+DanTTgc2eA44PakCLDm/dcqF7LntPECl1XeP29bRsLdP891/8e5T4o1fw+Y
E/+cKsqEwXPbeGFcaUGhePsJxUL7uW3CUVo/4pfBLOoHpf34vmeM+sdxWu1V
+l+bIbOieXHnaL8t4nnnPdXUIT5Y7NhYhc9RnO5BPLGLbexYMc8bowuzcWMG
LB/qNn5KlS0c6qPUY2zOt4/schdwbWO92lfd4Ce//9wv0XikeeENuLJXd8Uj
rbOQ7qLUC5+zCldZKqzu8rBzcYcAyOHfv1/LlW021EyGKW0HXhYsg2AM/73t
0mLB46TsAny699xQrXcIdOP3J69VCkdOygIg8JX2kmu9QiGQ53Dwf+elQ1Ie
NC+q+d/7qe7z/UBSpfCAtsfMOI9F4u0XF8sSqT76THhlJK5/JTffkfpBaT8/
nxs0OilLRZeIc13E/fdJNJ5C86LNHbuV4nkjbVr0JT64uVa6Cp/00UZviSe2
Oh05Ucwzadql2qn1HkH6yleGK5/tgfZXlffbHToK2p0fZMLOxvPmdjphCzb8
PSfW1i7BydF3IcLol/buGU5gb6jU+15lx9ccuwG/x3QbO/uhK5jz7xFm3zQY
1iYToW5xwusRM91Bn78vK+qH0GXtsYtgve62ol1TT/jKfx/0q1JosPZYCCz+
3uuHofopOMz3t/PVAqixYSl5/L1Jjfj+sKBSWErbo3T78B9sEtVHxw1nSsX1
Z9xkhtQPSvvpc5UFUv9YLOl/r7VLEs2LCSsM+4jnPdrxvAHxQfn5qpliPonT
mjUjntj8s6UKz8xhWTqbzz8CvRvlR50XG+HLIP6eIjXWGwqzYILRmKe7HLZg
7VrKOhe3+Tub+92DOl4ec5Ju7MI7/H1fJQkGGZ4zb8Kj7canr+aboy3/XrJE
JtNd+UsGHq3vza7X1grb8OfoogsEC/eZl2DKrMFv3i7bh9acg2WVsMJ9Ziic
XOnXPyV+Pybx3K76j/OIFPVTyvf5/Pdzc9LNqlgibY/S7SMLWCDVx/fRS/PE
9X/JhI3UD041TzQU91OcIHtH/aOXQ8sj4v7jt7UIonkxdkPXaeJ5bdXYWOKD
TX2+vRDzyRi2Rpd44i3n8jVinhlb5DEar7OhrHiSy6vYfWjC38NjOzF/1Zec
B9Dm09P1+P0YntJR1lFzO3/tYoM7MLHFhbPFLd1wJf8+t+QWw61j0qH3i+zh
c8afwphA7kumLKzN02vg8OPDxoV2Z3D/XaXerEjYunZMAkR0t7nc4Jk3/nne
smEVW7J2TDC0nuqvVTTKFz/w6y9QS/1vv6HXX/meGRd+3K9bJYTQ9uh1cJ6m
ePsmRYIb1cd3C4LixfXjM2WZ1A9K+ym+JXtE/eM7kw0q/VefPJ9F82KnRSO9
xfMenmiwm/jgoXqWG8R8HmwxTiSeWD7vlbOYZ+YOp7Xnbe+BW5udZfVeHMGc
ucrtXYPz7/yKvgUVg49O2GDvjnUOKvVxd43rrviUBhOG5Rlo6HpjZjDfn9wU
0tz0EXT7X1ix+WYAmvHv5Rt9zJ/W7lwirJ1k3Xf12GBs/ef3U99ZzC79c7Cq
i9aL/vIQfMrvh9cuZa679P2gZPqR+8PqheFLvr8d/9953cCU1c26//deFB2e
26oS1nC3vh/6Nku4J95e9l34QvVRWr/BR9lG6gfXSfqxvCm8of5RT9I/3C1s
TfPiHrw6TjzviWCD58QHuzR0GS/m82BHo13EE3/PHV8u5rniedKXJVrXYfje
H92qdjpgc/584+UHhclrF6TA4oyJ2wM+nsLR/Dg75Y3m1oDdlyFu0vs07wJ/
jOLPP3j/EDaOcEmA7r3f6OlFBWNT/v3a8gLh4eElsRC16nnznifC8Cyf17aM
6dRyCYagtKpxbc9G4En+/YVvhdC1los7RMaNftb4USSqc24t/8uzVsou/l6O
8fx840yFYELb47OoSyrbHypjS6k+BkvqLymQlVI/GC3p5+wPwYr6xx6S/ie+
0TxA86LejfYq8yY+OJ9BfHAaPN8q5mP0vPwX8cS3mQ+7inm+Lam37eGHaBi8
qPGEe34OOI6fFyWXG8yoKA2HVp0nRbu29MIS3r9bpand8+pg+GDg39qgbQAm
8XnzSpm3fo0/vIqxuqSZFYz5XJ9YYTDvSbUX6BksWWt++d/7FraUsk2dq13A
8nZYY/07EbiZ60NKhWmdqwXoo9Vp+IHaUTiI63X/y3OLlELTOv+9L0KD6/1K
hWzaHkdWrVfZfmMpC6f66OGxX6X++AqDndQPLms6QKWf3FLhKvWP2Zd/qPTv
WulyiubFkVH6KvMmlrPlxAczI+ao8MkvmWlFPNHTd4AKz5iabWmrzD0wuv7Q
tRZrj+J3fl/reE1WhYP2SVx3clCDkQ09cBrXzyha6D894owuaZu2yn54Yz++
nzRUCB+2PLDDrtc8MtoND8S8qj/bG/c273QY1zQZ2G/R1WAM4tdf6VXs+pQs
C/x1qIF+2NFQDOb7gflVLGhK1kZc0G7fR8dTYcj4+UOt/86fS8e2/tDzv/cY
3Ob6zCqhmraHhZLtU6vYL6oPc8r7qdQ/rRDGUj+wVtLPcoVQRf1D5/KjKv2f
UmQtoHnBXTKvU02L+se0T0LHksUqfCJrgrOJJ9QJaazC83vhmosRmhdR3+zw
ZbXy/bifPx+VVWrQXL1jHC6tONF0bDcnrMXvn2wvNhjUf18M4pSo162/uP39
//ucrxAyYm+HoXrKqZIVM7zw1p/3rFJf69sH4sv1HYUViWcx/M//B0ch+Nnd
OYU/0tKdo7r7YgSfiykEG7s7drjyZ0a72h5++Ixf/zZQXg/qX1zV5r/f3Y/l
81YqhJe0PeRYDmsv3r6fQrhH9eGnpH5LRb76hvaB8ErSz7kK4R31DxqS/rcU
G0ymeSH82iGVeTNKDToSH+hrdEuFz7fCEanEEza00b4i5nkuT6dHdHIyXkD/
hA/JHSGE738svwuNLPMvoa7T5v6jd2lDB76/0ioxuOwzKh7LK3xbbGVDYQK/
3nxSLES16xmLyb1SLe0vjYKr/P7JuyrZ7OevQnHE65eHS9brwbE/3z8qhOZa
vXyxTotrlpVqAOc5t+5MKOjW6ziGWTQ6FX3CAAYwpd7iv/1GF31X/rvvP++Z
78TYKq1ex+HylFrHxNt/UbDpVB8G+S80FNd/U+W/jfqBkZJ+coqFO9Q/nJu8
87C4f80Sg1s0L+zcbG8mntfiu44G8YGFMZ7rRon4xORtG0o8YYj9t1Vinid/
qmf0jr+IU0bfuWVTYQEd+flPj1LZjcgTcdjLxTipz/GjMI3/7uD7bx2zpxCL
l8o6ubxofQKuc3+vVgiGX9eG4+7wW8IABzfows+v1ilY8+FOgVg9LLqt/wRP
2PHnPSoK9m3qei9s61rSbdgQL0j/831BtZA6db09puYatTi39DT04Z87fn9D
f8Nvn6b/+z2yL9efVwvdpq23B80o95bi7V8rhK7T1ntBO0n9NQrWm/qBE5qD
Vfq5UsF2U/8wzLm7Sv9ffvs70ryQmZ3pJJ63W2lhNvGByGGBKnxcfu59QTxB
o7zZbTHPt3Kd1DUL/dF4wW+LL8tsIYP3k67QnHR94Fn81X/5+LKebtCY56Fx
9fkGpfc8MXbjq/26885AKN9+ZrWQE7fpJDqWp+mEDfGHun/eYyNnK593c8T4
gHdhaz8EwuI/z4sq2LLJ2w6j+6pMz11HguH6v/d71J+8bRd6DjNsNmB/CBhz
Xfl9UB196e9k11JuaXvo6GGqsj3thw9RfXDfd0+l/iq55iHqBwo7PVLpZ0a1
8IH6B9sOPir9N6xmGjQvnPSaqTJvqqJwKfEBj6yfKnzy5ZpPiSecPHpEhWek
vN72+r1CYPi1XdWb79tDJ97PTEUL2zfOgRBSf+jZRvNOAfz5vWplVq8bE3zB
NmPVjY3d/CH/z/3GKqb/bLcXLLuf4x44MBg6cV1HLhy77XYSmtlYjq6jFgZ6
/DjVoFLYOsfEHky8/SuPsXDY++f7oAqWPMdkL5ypCV/VeXAklPz5ffp/eW6Q
coP/fvPP/pOObx3mmuzFq2PiVLavW8n+j6vrjqf6//7amtramh9S0VbKuWnR
pLIaaFoNCZWka49kb+HaM9krnGtHGYWiRUNJkWRc+/17/75e6l7/Ph/vx3md
8zzP92uc9+v1envS9lF3hH2xPmYQ7Q9GvjjD449EL3WC9h/frnvH4/+dnlYp
Ol78kXGZJ96D/QxHmh9cWb+Qh5/IvjIDmk/0UInu5+bTqGSypvg2BFHmDr78
Kls4UTSEl75jftk05gkcHTuqtUzGC7xJvWV7k67FitgUiJlbWt29MxAsyX5L
lT/M+b6nEuBeyIwnZqNDoZn0/7G/heLfjYuGXbILZTd0hMN6Ml4s6GYvkzgZ
BC4rZj/9PDEKzMj7eKOHuUXipAu4MIrHRspEw0QyX5r7vzq/UHY/OVdYR/Br
PUwT+nkc+fy8bvY+2j6OtB/zm1FJ+4PSI/xR/sMWpf1HW9cxPP5vbaLc6Xhx
7IXJr7jjffaO0UHzg8dH8HOrJOQmzSeOrWjk4TPb2i1R4nsx+G3YbdilZw2X
yT26Qolx0vYXCuGQ480te6Z4wDf7ITz8pdAY3cpcmOKgL/TujD9IknvnnpVR
F77bZMGCnkxzfcFgGEPm7XLfmT8yLqaA4BKN0uacUIgh+5SUWiizfdaP4FCM
a7txSDjIkvGluYPpvs/aD8qra7vK8yKAj/C2lW8prec12fyHh867fSP6/NrB
HLvf2g/HavTyPH+8hcqg7eNI+0e+q/M/uZiCN3VG8fhTXMY0pf3HhSP8D33p
NIOOF6ePiHdxYr0czQ9mxmfw8JNlbcam+cTPsWk8fDbc0PT7ZPECJl7fpTEm
3BT6fg2tx8MOt/KLKpfCNKGPrZWSTiC9deh5Ua/6LTP9n8LnXxkbVpR4APvG
EL6zhH3iIr0eN1XB5pZaX/hM1qezXzA2SKhkwSPpGL/LpQEw59kQ3tvKNDX8
mggnInrtFEsDYT8ZL872MO0NvwbDQa/pDJcgWu+kH5Ai9Y1jWlX/O581QPrV
Mz3UC/p5nHvMArif726lQmj7qDDC/owXlALtD8aO8GdHCVOD9h/NRvgv4qUr
S8eLsldsNnLHG3JYaBHND76eJNbGzc+XGyvCaD5xw/JqHj4vb5m8mxNcCfXy
3xQ7H6pATOgQ7krVzYvvqYA1rhLd+//TBFWyb1nxsq7CvtBn8C07VCV57XW4
R+pXUUmM1OfHC2Gc8qjWt3/0YQepd+WzmbMTe9mwlKUszGm4CZ3sIZzVzLxf
eCwFlPWW/RrVdxv0SD3NqJcqKTwWBmm1hdd6tt2BTNIfqpN63UdyPuh/x3do
3KCXKVR0LAxHPu/fzEyl7aP8B9kObvs5bPZO2h/8OOcJjz+RSYxS2n+01d75
i9v/E5cpLTpejLnXrsgdrxMFYjQ/KDKoNsjNj84W8cM0n7ht9JYD3HxqHnzl
843zErY3m8ZLL7yBAtnknOP8VkGFmnLoPv8mgNFuii3kHJDEnfopSoklkKls
AF9YNniW1GPHZVLVZ1wKYGp2g+jq+Q6oQ+q3VwrZ3Sa1CLeWlNTaxDmjPqn3
1rdQYrLOybDzYGpe+UZXlCHf5SV7KfEDzqFgHSrrrjnfDbuH76kj9Wd5cm7F
ltSft/QyTejnUcRW3pP7+Q8tzFO0fXTWv5zLbV+7kL30Xi1ivueat9z+jM1k
N9H+0/Hz+r/5Tv1SOl4UjWJJcccbMV9uLc0PCt1z5eFH4+ChEJpP3D2CT9VV
Tr8ZiuXQrrzfPqrADGPmDz2vYqD7TVzgGfwXONkyN9QZ/1Mcwlc8Zr4wSC2E
KT9XNF/Z7IUTbcl7Ws04b3QuF3ya3n0Z4+mHB8h/LureMFZFTX8C9i7bBJMv
BqIyObf77g/Fr3o2Ab73tl3U/RSEy8n3DsFe5kb1s0FQLbdn7vKCYCwm/cAm
8j1lw6bH/ztPcYL0G7N6qVv083jHbBLP82/+UGtp+2g60eUSt/33bxgHaH9w
pD9d1dQN2n9Mu/WYx/9lj1s/0vGiwIh4lQwqODQ/OOnXLQtufk6vYvHtUixH
/qap97n5bI3NXCz6vhDmnuvWeDjDBscSO4HP4uaIVeXBMjclCT8/D/Qg55Eb
2MyP/WpsqH9Q/Gzv8gD8Q87ZBb6n5i5ckgEJvVquz52CcT0Zf/EXBTNeJcL6
hrGeGw6GYS5ZN9m0UfPfL4yCXT/9nqVti8CM4X0RXdTFLwt9QKJ77OM16pG4
m4xr//GdpXlenb10zdA+/6tkHLToYj6jn0fOqoZY7uct26gjtH3cpdfBYz/7
F6VC+4PiOmd4/GG9p8Ro/zHRNIfH/09sgR46XvwyIt6AZ+LLaX5w1SrVbdz8
/IptEqH5xMDq2VrcfM77GidRV50Go0LNb93ssMVvZF+HUov45RvRyfT8e2yH
+DkvXDvcv7WLm7C2JcAg7gjJOhyI8uR8ze7f1J853jFwf1vOpojZoVhO4pLv
EioTjguFPTM+Xd/JH4ETyPyqqYNZ5O72EL6eUvPeJRSFa0hd608n822Umz24
8af5vlCNxkuEt8lD+2Syg6s8/7f//DnBf3ZSMtFu9ugwrY3n+W8d1CBtH4/f
ieWxL9fFaKL9wayVWTz+SP9mTp3rHYMj/We3s+/T8aL66JU88Sq0xN2m+cFd
fj/aufmZ83VgN80nysTd4+EzZLCvbKW6I4w+65cgedUGnUm/FzQgx8zWfwCn
ZhbH3f3jgQpkPfutP65QJcsGNiyVPzHJNwCfk/XOnX7GwdcrLeCkgX+5+5tg
FCTv9aEeofqfgXfBL+wbqzogDE3JOFXcy/QqmqkPrjfCiyZ6ROD24X3Uvcyx
W2ZdgGqlg9XTcyJRi+iW73/zjfaskfuiD/RSR+nncZHSHp7ni3qZbNo+5shW
89iX7WGMaw68izLmn3n8MeqnVGn/cdP+IB7/G/qZb+h48XDOZp54AwfkHGh+
sGrjsnhufkIHGaU0n4g+Xjx8LqCmlxyzC8e+lK7VTc738DXx59LrfaPEhfxx
jvSZQ05zHLGc2De4mmnia+qMlnI6XjqjPXEKsZ8keGjdxtq7uKTvoMI9NT+M
IOvQiZMwVaL7BCYcVNIQ7gnEe8TOZmXVXyJi9rgndbmX1LMAdCd45tEx2xcd
vYEpxmMrLZsCUZ/gZYLJdfNzjkH04YpZPzuDsJPwoMt6tHdt1mWQjVgTzdEP
xmCCFy9oC1vVfQGWd3RGyR8JRiT4mhMcjeBPnvBRZcbiRbUPsYXgX6utW1Z1
eYPSkmqTNeY+OJ60G+1WbRqa6gXm0+R0BDM9/t63edOJb9GSFW6QuPdAoLiS
M9oQHpa7Gspt1rcGS2P3sfZHzPF/n7NoPLlpTZXohlRc84WZ9frsNRQl95/8
6mC2esolYFoX81Kythn2kjpJR2f9h7ip0djcxXbuTnuAXuQ9TepjrtgUF4zZ
fZSD8jl3bCY64fTVR6tN8MHMPqbQj4u++Orff5PbJnzywav9FN+8b45/74/1
H6RUrz+2xtuDQioNem44nujh/Wi+HHQ/AHMGqZqg+V44/F/jHYNU58o5ViA3
oJ4pM8kXfw7fQzvAVHX47AKn+hm+b748xDTCz4U+p0Q+uVCg3wPRrsf38T3x
cwyHvfv87Cj4waHUXGwf4Dkyng626eY9C38EUzns7+p29qhL6nhpLU6nD46P
gyYOO/xImzXqk+81s7qeVp2dFw8SncyAgVF3MYCcZzFpkFK7sywdL/1w69ho
dwE8/+5jpCYrpyUj+J/Kq1x4FkTJPL++00lFen8CikSeLSzUl8GTpB8z66Su
CEbG4CHx/WfViw3wD+kPT/SpZ4rlhuLh+eucvBys8CWJa9YAlbnS5yHeqy1J
i59pAY+G949RTJUSlj0+bQyVa9fWB1Gih8fj+fj4XN5mT5NkHdd+KInDddEV
dKe9KMQeNI82Hn4bf3Po2O7/9zMDVEZO1EPokjz15FSIJfoQ+5f6qNMD8aHw
q+qSivEiS/g5fE9XJ1O+3DcG1jfvmr2fcQPGEP00dAqudtyTALLtm/Bcmyic
JfFa/hJwWp+ZDPePH3DO2HABlxB+djc8/eK0MR0yDPdt/XL+Ep4jfF7unBBu
Hh6PNR+uPDgdbgI3yb6dSS0sN77COGxU31r6nM8WYkhenrcxJQr4YzH4qPPR
dXsewFSS3wkc5uG9m6NwXoRDujbzAcgSPdzto24G7g/FBQ+8vSd62cHv4f2B
A8xGbX9XzOtom7E83B8kiN5WDDIFl9pb4Zlm1Wvexx5CMOHn7Fg+07irMrQe
PCcsqvCCEqLn+4NM575RNlA5al2Jm5MbDBB8ywBVkNDqA/FFLlJlExxh+H/0
Mn0sC639vnD6/EqjMf/5wdbhe1P7KLFalRAwfLzeKv66B5wmfpp0srezIqKh
fUbWZZEIB5g8/P52NPZo2yaAfeKk0IdMMzAh73tck1GdxN5UiIynbrFXXIUu
ck5qTNfRc1oWZnhCdvHM1SetYPh8hGLvy5yFl12xOaQwZtYz17/3TAb3/tyd
xeeNZwPVi0RsvUFj+D663ohH+7/44Eufg5zQDX4gQ/xP6Eu6NzDNGwdPlCz+
PS3gb1wr+hlrz1SeQXu1NJnU62FQTuLS7hcY/XjMZVykuESxUyYMPhF83QDl
P7fiBC4ZM1B67iS9jhm+H3vg6Wh/wxvA9vA5fbAkGDSJ/Zw+OWsR1Qfg8Tr4
0UBmINQQfN4XythHYw6tv4mzb3BCoIjYie5jLMuTvw15Azsuv9EKhPDh+417
aiZuaHICqQkCDcG93uBK8nW7O/Z2iLM/7JZdMNEj0RmYw+OLMmSInIyAmFX/
pSQyTWHb8D11HSI98jfj4VJGWSAY2IIx0fOdTofJR26HwXH12DCLs55QO1y3
6axy3rncBwITFLfOux0A34frvRz1ec45NpD87uvW98eCYQuJy7G7/s8DG20I
UVu0OtMsFC4O37vY7QV8kW4wuunu94f+kTCe6D++K63n5BJjmFDsnJNxMAqq
CW7AoeKPXFBB+X3f7u9dGgXLiD/+3beEbMYZ4ocxSsIaYpGQR/CwnlaJ3Ag9
VDiWpSdrFQ58JF83ezrj+wwC0Txf9Z1ucjikkf7tVrf4QMmyYFwcfGnvlZMh
MJa0u7T7pMwhqyDcsjq6cVpMANgS3lx/v1zgIuGPJeWORktueEA9iddD/1aY
u7AbhqSMq3E6ZP3/48n/8K7SYz2B0nnQ7pN/+9pKWxg+Dz6+gu1Hj15wse95
bUq+J9SR/7NM+VFTJ6CSDBrvo1ovtrHgPzLPT6DXuTrSj8Dilmog51kIaJF+
bHc328d2SzDsvuuQbF8dDrGknxnVyT62/kAYYIXXn9yTkRBJ+qXrPez2nAWu
kFySwJyfEAVa5D39wKFYd/VPYvrAJ+mtO6NBavg/CD0MNzsLZ1zMmrR3MScK
NMnzWh3Mq5ujfXGt6Q2fqg+RMHxOatcf9bD2d/G4QW/j7L4D4WBE6p+rmygX
N5Nk7JLZWTb9fgg8rx/C6+qFpjxvScXx1loStQ0sWEP625NvBLqniaajm8j5
pTqDnqA3fP7xjdwOtkI6OrVaStk8sgUtsj9EXGXflm6P57Dc4aRLurYlnBo+
Fx8Z91NvbBEUBSozotvdQJr8/7HuFUNq37xcWL9nb+e0Dj+IIfskB99SC/Zq
Z4BAxorMlZbBcID8j/LXb8qsJyUB+mPN45qoMHhN6gy2Tcw/qz/FgZTlHjWR
sFC4Seb/+Z3Mhi2j/OGwfJXzbONweDl8Tx1FMUIoJTR0b/m5NTYCdg6fB+yg
Lux0eYizRr9L1l0RCb8In+zfTHnZhEh0fSS0mlUYAWEk77kf1He+T0vH7Xqf
M2alB4MyuU8mL4t6v2Y1GwVmBo1+2hsIFWTd96HEJn3Xnjy8lvfx5WCEH2iT
/w+2JqufUdAowMs/dgzcUvYAcU+in9Ck9Xmzi3Dd+zMt3sE24Ex4cz8dsrDy
zEt4fCpy19b6m6BTOVT3SJFlOOrZl4KRR231t9128Jj8r6c5UGBM48ci4NfZ
AGd2uoM9Oa8dX8Xc/ds7F+5fb59hNt8PTOPI+/Ku/pe3TgYUW7V39X4JgkDC
/8pWxoyvf5LguH/sqNVqXkAR/pm91JgzjcHQIbF2zpLjfnCA8Gk9ic/UPV0e
lRwYfT4nA6GS9Ie+PcxKr3PB2GPvknOKPxhCic6X/aHypikl4JT/tN509QeD
Bznne6GovrraHJExXfgsw8AdxMl9aOdz2cqj4/NRalzFhcSf7nCR3CvV5CLU
JPPkKepnm22Ku+8GeXpD+CdlVuEJted42HFb27ZcJ8gj90fdmrsw3je9HPVM
Tr042WUOybOGcIVt22c9c6iECreZR56sk8OciCGeqyezTCferQARBZV1J5Ye
BTH+oef3G7ZGyAo8g3G3mnzLdQxASGkIn/qEEv2eXADn5q3rtGBbwUl38p4W
Mvat/IDQ863izG8/F5Ae3p/Zwjyuty4FztcIJV4uu4zNZN36spe5sZ4TCrvf
Zjhe8FSFJaQ//76Sj29tiShGSCdlfDxyD/53DeH/zyd7mdZzP4Si4dWwyvvL
74Pt8D6NFqa2ZUQyZhvKdNyPc4ElJI9yOQyFw5/Z2OM+U6X11A08T/YxeqSw
9wksLcTOz0e/CWoCXHMm9vUq/L5JPsPxj7ZeUrt0HX6Re+FCBBjf5BkV2KN/
91C72014OnkIl90btVpNuBIt2JR5QqMeqKYO8Wmspr7+4/aXYPw73PLRLSNc
WEP+DyjMOJwiUA6qn0aHlCVYYNJiorc7TuFajiWweOv7MzI5Vrj7DHm/0phJ
7OoCWKCqemNcgwUO33cXmUNZSxaz4eGU9Wc0Vt7DcBKXWiv1MsI+CZb8J7eh
5qgPssj8U6KX2v5jcSiIvXn5q/GyJ6YRPavN4OPbL7sbIvl3SN03dsVoMr6U
9TJLJ2uGov9knb5rbfaYRXgOaGFKHu1Jxkqhe4Mvs8xRlPC8o5xpvpXKQr7T
01fs2O2NwmQfo2s+u3kXreeXKWVnJZ+64Dui51WWAmm5giWYmx13p2+PDQqc
J/3q4vqjeknl6GwbarBgmxFumT2EJzOqUgOPVyLrV+3+lYLncXc8uT/qqNfZ
j3+eg9i2UzWPFljiCXIP1am7rDNXFpdA/ri3x6x0XXDpuSH8fQTzVkRzIXww
OfDt5EVPrCf9T0Up80zzkTwYd3y3z489Psgm/VhuBfO4k2UW1A4wrsJZXzQg
3y+ON1ED5hZxkDy1qHLXslAUJvvcpvSy27y+BIKCqMvprVkhaEj6gTUT+Pgu
Lj4O0p6zZBV9g9GLjO9ZvcxbFgZBqN9Uy+xsCMRiMt8wamN+P+mZiCU3VNgf
7vsjH+k39jWwM32oVFTOOhymUxGMOmT8ev2BXSUzKQcDDCwUNtsG4KSsITw2
Re6U9qhCFNrv25XwzRPDyD5ztWvU+6vnn6Ge9Lr99xY64pxjhDdjfgnTVS+w
qK22xEHUBOf2DfFsl3/Ig4/Kg8SOCC11AVvcTup740p1o8bV5AL/9BXNtZUe
6Eb+S7X3TVxzk0gOTDmQ0/1Lzx8VMofwm+VMmce1mWBhuPlN7/0gfEL4bPrK
vj2KnrdvNl0xlWEQggvIeK3bwbwuLxEG3w5F3lISjcRaMt+I6qJOh672hp8W
e6fNDo9ESTIOitLu+rkqw/FvGzU7DkViIeFzLYfC8mAfPJ+g7Sa6IQL5SV7W
/qLClns8wnvu+sFNOmE4k6wj1vykPKNEH+O8FeKi+5TCsZ+Mv9nfGJz5HSm4
+8NpdmRDMB4h3w2DC3XjLVuy8UbS5omFyf7oRvpz+bw0u8X38rHZQDh3ra87
nmIN4WATlz8uvBgls0XiAyWt8JHmEN7avOntqf4EeADNrS0+triBfK+0/qGu
EP8+EeY2Bvh/Gu2FiUQPA826castE0H1zDNDvbGB6EzmRQ/b1GdUcuLBuvjA
qJnJIdhGnpdtcbKsv/4IihO+KDQ7h6MWsa/WzdYU9HADgeXO9x7l/bsfRqmL
sXNylx3IdFGzHNqjsJLgNhxKqNziJAQZTjAOPh6NooTPx52MSKv/HHBseD6n
92MUppDnP3OEMrPyg3Dh8illoaxI9CH1z2UcoakLSnww+8yKRbEp4agyvD+h
k+3wdV0YFgxe+y1bGIKfyfxzSSM1p+htHOqUit1bOD4Ql5N8PfvC9nl8PRUP
9nfelmv3RCPyHXxnwdXszG2Iqc+yrr82tEVF8r07bvquRR4bDPFX8OKbKk+s
cPh/Gb5drPOxJ8zg4NtN2izKHfvJejCvV1lFK90FQqdcoefuAbidjPvmPdRh
lb2ecOLGxULJxSE4vG5t7K74/eWoJ6yLEJgkbB2Ow+uLqgHqwa248+iU4N6y
+0cY3iHPz++gfG5uVAXbXelXgkIjUJr0z5e7qaddv5WhpX+MlfrjSDQidk50
UVJpLjq4ktocq9FB65/gyRyGkLK0HSZFd5wMvBCJcwg+r4/xe6WxMTzg0zML
bglBfzLOtkzl29VbcAp8D8dn934Nwn7SL83poSQzR5livW34iwkt/ihN1oMu
PaxuZ0FPPDWgeUB4vieuJ3hmj1y6gnwoTgjdLvZ9vy32Dv/3p2PWad8VCdgy
f8mazqv3UIfMM2s6W3tnT4zEU4YXfQsZTjiO+LmSQz2XK2HhF1W/gXkxXlhH
/Nzcz3a6MM0NWeMFf2zVY2F6719cpC/Xgn5/Ha3Hyofgc/J8Qb+QH99yd/wU
ICXYVBGAqeT55D6q0ajmHs43fHpzFd3/dBE8ZZCSE3hzHKCRnWy7MwQlCJ7f
x87fuuwOpHv5GmkoheLwfiTDfrZVXLIp+E9s4YyPC8XJBN/fL+OZfyUQ+o4r
F/Q9eIiVw3WMXiEnz/ZgOLw+KuyYtC8mkvx2dc9qTE8LAb6Vhw9miHphNcE3
dCvHqOYEQ8TK27v0ul2QQeyf6zFcXLoxENTGRor0h1v+/T/R488H2GJ+6Wjk
IpX5w28friLrF6nfjDfWvUk4Sfh0WWzGdewn/cPXVta3nxiHi71y2k7FWuBH
0q9u76b4MzZHommstFZ7rzOmk/fxv352sqtiEC7rPh1j3+KNw/UKqQHmDh0R
PzQ5VDHlV6kW1hE99A4yB1dq3sfpbgsMs9aaI0XmFVun8PGpzN4JSwzfH6t0
dERB8t5dG2RWmlvbQYzP8nXa9HsXSt47vX4qQKrQC5Ka9n/ld/FBGN532sdM
jfYLgzWC1xe+SFLEROLP6k6m/aS0GLCUKs44kncL3w+fK+ziaGV5xEPr7rpb
FffN0PzXcD/JOsRPJYJZZOD+wJPmuIT088rNMStXSaXAg31rXhjXGmEYma/K
/kxS1EtIwY9Wn/o83QzgLllHb2hTZxTvTUK+xTu26QWZgMf34fdUMH0gOx4X
XPCNPTbBBGSG63udzHmDb2Jw1oVu76XvDKCI+Dmmj6GeEhyGX0axLW/mn4FY
EldXPxVaJeuNfDaXO37qu8P04XtyBqnupfV2aK7y4fbyAWfYRni24efjq7y4
HTtCPg+ukLSDc4RnAYpaIht9H1yYpjPnX2DCDIJvGaAcPXb5wcdsVyeVaG2o
Jfa1+tlzlAuCoNn3p0nfF7e/9agF3dS4UbGR8LLAtcXgrD3kEp0kcJT3T5of
DzJz+ietFTYFB6Krj60sv5Ork+HyvMuNFd5X4AHRoeLnC1Fnn6TDD7Ofn3zv
7YdiMp9hcw6dvVAYiqYtXksZFubQQnjo62JdzKgKw6cu7QLRXk7gQd6XPd02
gWPTwnCFdXdDMu2nIMFP9bItmfNCUe3ui9ER3z3gJcFd+nWLL/YE4n5zxrU5
Ep7gSuJa1M90YPdYod90yZ19TsGwivQDEv3UceNZ97BMbXlT888gyB+uW/Lx
Od/aJI998YO2rzwCIWn4vzODjK9rp5vB9SNvVdbe9ocThE/FASbf5MUecE1j
TrXQAh8oJc9v6BMKmKP1AC5+m3hHWCcIjIj9wD62t1W/F9Qfi3m05uVDyCT4
YC/z0uGrwTDrgrnqH0N3ECD+3+rwenPnbDSMvrRmjQ7jPhiS8VewfY/3kZWJ
sHLTa/1XIbf/7oPy75crOzLDF2Zeuinx4LgNvCR+NvUxv2e7WYH/4nFpg33u
UE3ex/cr+UJ/1x/EyenjOtqn+UEzeV6Ios6kME1x2gotTwWHQDAgce3uZ8ww
7rTG18yHm21WB//dn5nVS71wEzQD5w/r6nYZRsASkhfdTmpx80FlmPpMp+FL
VgSsJ/iXHoqdaKeEjuLm4zdsjABPgn++QlGHhPlx3NhUm4utYXB3eN94P5U+
Z/VNKFy0K+HJtFDwJvxs4lC/N/Q64S6+4Oi6J2EQOKyfHuZBPs8HqMh/bM7S
7cEwlvjZ10cd8/c3xRuPnh6OPecHniRehTl859s/qMLgopcrRxm5gTl573T4
NhcGL3CBi1I+OwtfWsDfeypqipU+STyBHLk9JYlptqBH6irvm+up62uTgH/9
KfU33Z7AIe/Fqlab+gWXo6HRYfxDl3wWiJD5EqebocH/MRBe9NXKa2qEwCPy
3on3shOlTrtBkuI34RnTw6GVjKdOf6jfZstY4H532/eipkiw/HtPAmOu3TNb
KOsx3nCzLQo+E51EdlEC306fxHo72dsPV0TDMWJ/RjebmsKyQpe9HRuOWkeB
KsFfdVAyws6O+Gq3cW2YUCRQBNdtE8oKXBaFrQaxKisawuEPGffH/aRsvBxj
8XDNrIHMkhDYSeZvUV9tTjg6x6Fkt3FV0WsWGBHc/EucmoZkHO76VLt6MMAT
Ckj/WfS9xjt41SPMuWCzyajRBqaT/vOS/4aAxV1FsDn1QXliojUkkLpQbVmr
2arpeTCR6dZ/Mc8DPEi9VP8l426UViaYbYuvdRjFgkOkXrqomVFV+y4JRO6I
JdkzQ0CHfGek+zPJ11+ioSkj1FukIhzciJ/RrYwr8s+iYXwx87hDyz9cg57P
TEvxgqKdN8pC7CJBg/Dc10uxp0er4IT1aXWzdaLgG+FtHod5/JqoJ07Wlher
Mo2CnySuyV2U6to5ISg9QVjrJTsSkHy/W9Ykl5fVmYwLem4Zd34NhfQPQ/j8
1+z8qPFPUHCWi522bzDsJvcrXshhrVRpysZAm9O/4VUAqJF1ivPr1kxKIQdv
zW8QfuTiCcPrtYBKlxcbpuUiziyKGO9mC/HkvFXgJKeNlToVIKdmcPTBHjNo
J/UikTvMD0s9SsDMKc01SMUFtp4ewgWynaY3byyArJdnYr8X+4CW1xB+Jp9a
H/cQwdWw8ElubSCMyR3CbzcyCwtyUmDj6vv3yjRCoXn4+2Mb85n6ukQYcE5c
5W4aBMPrHeVeRsOib4FQyF6YdcUqBDwJnzvG8pluMlDA4O3jJP3HhYEg6Qdi
eqgY492BGPaozKi9LgyG9284/qD+0+uKxb7ct8pSdH9iSNb1Ei/ZRmv7M/Hl
mgvbok1ZsI78x9m+gkGZvs/Fa+di7h5T8ofPRFe3Hsdt99hZiPP37g2do+oD
2Q+G8NF24ibuq4qRnTlv4eRjbvD0Cuk3NHSLRKye4bkDxx2uVltBCjk/2LH7
xMYNEpVwOKv/zKYZ52FtMrl3fVnr4APbcrCKlZSTeGYMOHfo+Ts2jJpt74ph
q1p5WfmL+1BD9p1aFjK8dPTy4YehwDODsR5QyBrCgyoY35Vts+BSjEKm2n/+
UEbqNiktzEWWbcnQO+Py3eQ5FrCD1HnocU/h0v5QYJYNdJ594QjD53T05vHx
fb+wDw2TxbrHSHmAFOn32nuog69/h2DCxgzV9dq+MH34PHgrc1baviQcr2Z0
zOVwAGwidSrXHMrS5RkbW7sTHomamACL1LXE0tk2hU8LUHNqWqZ6sBV4kTqY
2l120RKNEsTYmLyXNbYgpEbsrKW2HikuQ2mprxMOCNlAJrm3eZHG5JSI1hfo
m6JqqKNzD9o+DvHZtq/++qQFlfBLxDFWeLou7ksn9edp7HzHgxUwP0sYsrT0
cSmp+y3XY53mk34GF6Onl+k/uIwhpE4om8L4ri1cCCfULx51fLAWl5G64oIc
5ui4n2woZTAe7uDTAwaJ60kLdfzo42S4vkWh55OpI54hPHv1UuJxX0Jh2rHM
9Qlnrf/Ob7OF+Pg64kThv81HFgoYG+H/rm2g8Re91KKzg6GofdZ7zKRYRRze
Pz+3hXJhb0rB9PPhqXMu6MAHMo+VL6Q2mjUi6ubN/5VwxRG1SJ32RQYjHbMK
0NX1kpFdrDkKk7pug0Hc/IdznqHVvXyoPayH1WQf3edJAuaG1hW4YG3UhH4F
Gbw/YQjv2T7LsMq0EpcmD7CNAw5DUNQQn/4T9N/73aiAnasKZ72tMcW7pN/4
fFT398eO57DRSmHT09kPsGYH6QccnWLLBYpBaZqa1JINLrjw2nA/xu6+9TYf
VCu+tDUfdEURP6KHIob4enqZECC/w9QOXVCa9G+lbdTD7roE2FTCzL5aGYgB
pB7S00PFT6PXWfUUH3P3GxY+IOPmlFl8fDbLD8Pn8O/ur/L8sICM+ym9zH6f
9SFYZ39xj3axN74hehZupYoezUhG3Rq56ZXy7ihB9LzuDTWTI/cEJ7YNWms8
YWEp6YdVXjDk1ebloaaRjk1MjTdmkntrrR46SferPMWsiXxHd1W5oDG5b9ZP
WnxZSFsp5ncq6/cJW+NcsSHc9tSKddu0X2IFnGN97NDH/BdDPD93Zf4ysX8K
FQIPL7mZWeMPg6HnuyOYTE5CISyMSFl5bII7FpD9eBvy5LJ2S+WD4ms3j0l3
fPFJ4BCu/5aaWXQ4B+oUX+U0vA/A9+Te3U9v2c8+x2eA9ra2w0vSAvH83+8p
lEWnbzQoBKxR/+IW/ncfzthOqnbyXn9o9vYwSwgNxzDS37aP5ssxlVWEpctG
h5t/D0Mm0fmELkrP0zsAD0ws3+13L/TvflGpDvbNF4HxaCUz9eUe62A8Q9Zr
438JJddsTsIlhwLOPuWE4iyyLquoYlaYyWSiyAbBlaevBCG7dAh3KW90jRfJ
w+NhKssi3vsim9wbr/yw1V5j/VOcr+PvOUXSFffdHsL59k0Ubw4rxReyd+0T
FMzx3sYhfNvziLatJZkgcvLkzy25tvgf+Y+S+3PW6DuamTB6/ccUzgtP5Cf4
71fs+BvOGdC0/rXlicMsVCD7Kud9YZeYuqeCdO7ePaacYLQk6/fLrXJGoRcT
4XTjBjErzTBMIu9vZBvV3juXBTcVx2r5NESiPZnXVXSztQaiXUFnz7fZqjlR
KEN4nkHPZ1P6VGDRgxM3owqiMIDw+bqbIZ0p6Y5GLj6bWP2RGE6e121nbl59
KgJTS2X71PQj8AuZdxl2UoajnMNQgONS+/1HONqSeYh5O1MpTDEeVyv2mv95
FIIyJC9XPsuxV09Iw3ANyQc6uiykSFxsZEUqNCHamArdrF7riWfIufuvOPP5
wKd8DFsv2fFurw2Gkvc6t9mjqWgJC26Y+D3M9bTBWLK+eP9HaNH1+FD4JL//
gLKmJ54i72Pnn6dyUhgOAWkdk3siWDiKxHW5Q+DyYeNwWPmrZ2VgTgiOHj6n
2fU0Law0BLLej7ls9DscI8h8e3cvs0vf3xQOvz9b6VQQgd9J/xDVyfSYu8kE
6jylukMYUfiK8MnHoeS+iJ4Ek1fdkvWdUXhzeJ7cI7SyGc0ws3zgplRdFA5/
B8/qUg95MNEbPae3PnjSGokTiJ/b+xhq996aoWJabphXahieIO/FVHqdMvjc
DRVdNT88XBeCGQR/zjH+IRgchC6jshzu27P+1g+rWiasvZgbg9qerqcUmz2x
icQl0uK9dMabJDxZZOLQ+swWi4f/49NwQEQsIw1jW5gDLrXnsZzUt6XrBlzP
amag0f/nlbEyO4b8V3fWD/EPhv0p+OI386fqqhuYQubJn34Ju8lLJqNiC3PZ
vc13cA+x/+3PO7vBW4n4q1NIzKPUFLXI/Gp7F7sxLiUeOzsZ1yNELFGY6O11
m3puxbdYvN/F3JslZoPD56QWdtWbwvloNOcw7crr7NCI8HaxR84r9kM4JnRT
VXXbHuA0wkN1n1zGopMhSM9HEpp3OuJuMj4u7GOkCkaxcF0fU6T7hxMKEl1d
GmD0drK8ccUgM9U0yBkdSP9fPMiAak8XdB2sX2G53AXDyLp4KsUce2mhFX4Z
pC5Y33bBs2T+M5uiZlivvIJTKLabTYgLZv/Dk2xWXoEpFNOfG59KURdpO/Bl
UP0qt53iQbYe3S64DjJmcbd7aYC9rovlDSsGhXj8XNhX/42OC0bGVd0nUEXz
AO09zBhuHi726MbRvEFCN/sTN28Lu1i+NM9gzmEHc/P8uk3uHZ0XuN/FOMid
l+1daR10HmFkHr/9yfSk8w6/OusluPP+6Zcbi9YJ0DqR5dbJrB9JTbSu4MVv
NsWtK7OGh5tpfUJsC6OLW58nCsazaH3CjCZm/DaHf/qMaD3d/5SZhFcPOe5q
jbsMG0hd7usPr750xRQMM9t00ElmnZQD6VfHtVdsWj42EY2kA5Z86LoD90md
JLPz1k+dgHiU/fAhpcbWAtRIXCt+11/WVX6M4+Kpe6dn2MEowkN/O/VAVD8G
J/dRd3YscAQVso6bx1G/escpEu2O7To3+5gLDN/n4NYjxC6ICcPq0BhlXwU3
GP7fhGkf8/z04mDcAQ1mcYIekEPe99YeamdGMQsznhzuOeHrCQKkXjG7n8o4
NsoXM6RuPrZ57wUrSN69Bpibf2x3xyCvSX4H67xh4N//ds+P+/oAi42FP/ix
fIBF9MMapNS3Kpmh2H/JKveW+sIkojeVQUrTf7EmCplJLmg96wu7/uFxAYs1
4a1172JunLbzmLYDo+smqHLbodtNptuF8Tc133C36zVAqdN+ggvmPOT2c3Y/
8xMdF4yMq7WHfYnmAUbyYNrHuE3zBiWGHkxu3tx6mFU0z3D+/RlFbp7pdbc5
nRe49vnDJe689LcLBdN5hJPldre487jiN2VK5x1Ozw++yZ33zM60TlonkPU7
nUcn49qFgNYVVH/IFOXWVUTrQv5iZhKUJq/fxq1Pu/ezJmcopkB+odOoBrV/
+pzbvu+ZVUYITF5yb1nq3jt/z0Gnul2avVc1GDLyDZfuH7dTarhOOG3LrDPy
rGBYpqyUVG9tB3/I8zs5HT3P6wOhvtJkw15jV9hGnjdoc619UxsACYnnR2mn
esFcgn9pryq7//MhHOjJ+Bhw2w+eETt1nTFiC/u8YY1cXaPx2cC/57WtOSFS
hZM8YWb7iWa2TDB8Jvy3d1+y0l7gBgYOo7UX/gn5+x/5zb35bpNEnWFiKL+W
o3oY1JK8JHfVLFLWvw8BHgPf5jmHgyrB67rHzPRxtYRXibMan1hEQDsZlxs6
BaelXjAB9YPbtQwkIyGA4Jwe4e7twXqgNbFAc19yJFwcxjn1thxzZZioJPB9
XVsk7P+Ls5u6zZXRcbxPIw/eE3FAMlgP1957r8Ftp6HTS51uFy9afNbgbreu
O1+S9hPn27/5xu1ncpfXPjouHIgs5olrc++XKJoH9NJ6rsnNQ3t3jQ/NG7rN
va/FzZs1Z8xxmmdscqr7yc1zXefPPXRe8CTfa568fGnf9JnOI8rs7nrPnUeD
Nr8WOu+4+JwjpcWV9523sseV1gdizoEuHp1MS8nRpHWF19e9TuDW1dyqlaW0
PjFUfNlSbn3Gok/fHtVg3GqYMrttzD99Fjoqf/pc8xS8jjxt1Ra8AylkX9MX
m8ZHB44Ug5lyRf3klzukTpM6SUKIk5zUriJoWOOxo+uUHfiQ/+uVpVM3jp4u
gBfJjwSZp11hLqkvrSxRVxzrnQde36fWRjh4gWbEEB79mlkrU5UDMZNDPybI
+MFCUtc6kE8dzl6IAJMqF6rsDYStZF2cWU0ZdDo/gZ1iSlrKIsGQXU76sc/U
wTXj0+Cq6LTC1xX0/JHco6jVTD1RN04Cq1fLJV9LhoEUGb+YjdRekU9xME/p
4FNF7XDYT953Vhs1y+V5JPy0LL+ieDoC6km9VLKb+tiTEgTf9GuEX02P/Lvf
O6abUi/c5QGX6hm91XaRUE3G5QccinNa6S64CGU2KBRFgkTXXzxCVekuKmS6
feHGaTvPaTvIUovisUO3O7c3JQgZYdUi3O3Sfu6j/cRe1XlXuf2k47pFx4Uj
49JqZr6iecCRPDA+My/RvOHsnukF3LzRPDvSPOOhCYE8PB/IZ2jQeUEXvRM8
eYl+LfSVziM+y5b4xJ3HlSX15+i8Y0SuMk/ey9KZprRO8JZF3FxunSSECKnS
usKYR2t4dFXoKPiD1ieO9T/7i1ufwVYHo2h9YtbeS3wqVf/0Gb3KZW3k4ipo
P3dsjq3PJXByHVqPe8wqKzgUVAWPbz4QWfHiP6moe0P4FLmq75srX8KhvQvl
fSYYwpG8IXzu7Qnep4+9AJ1zci76t++BGfnPY8r6iv/el5eBrd/lKf4OFsAk
dS1JDfGyb93PQGCs3N4gYxvwPDCEh7qwlvEvLwbZZXXTK8baQ/xV0o8liddu
P1QIWnKz9HVXO0KuwxAuW85gXzLIg+c/FDPRwBnKyD4o+XymxvIdbNCQ6tlt
HOwCVaROq1hHbTdyyABFoXvZLf6uUEP+L5zXypz6oj4JYhsmL5+r6Qa1pB6i
105lHLn4CKoWG2t1DNA4GTef9FNn+/iD4MSqdG/b8+5QO3z/wyAlFJpqDS3T
BhMr3Wl84C9+LizVGkfiT/qZCbQdHGmHbnfS0YuPcGS7ea3sLbSfiP6nFnD7
qVjHUKPjwnObMnjiks9nO9I84MnVyMMDzVsVzRvWDDrz8MZJkmumecYH9gU8
PIe6sLfQeUG90SETufMiqcH4ROcRR+YxZX39DjrvOParMj933ufefh5M6wSn
fGt24NbJFLmadlpXeN20lEdX0atmbab1iXfx9gxuffIdysin9YmPfqV2ev36
p8/8/cpKRbMrYbJc/AxnzSs4PoP8526bsdoO20o4eltilpWzWLZT5BAeo12/
oun9C1hSreHP72GMhuS+wV/zhMLffyqH1NGeSw93WqA4Oe9sLMfu1JAoBbWf
thxZLzs8vm0I/3WXfaXApgSoLzPk/FIccRnZD1kaVK+2r6YIbpSNYfyMdMHT
5L9mLcgujBMuAP6t2xZopbhhC7mHVvZV/YaEW7mguQc+yJt64E9yXtj6OVPZ
2Ckb5k+8c/7RRC+UJ/+5dv3M1HcTT4ctpnvMbx/zxuXke7RZG9MppiIRnH41
Xk1R9sGzpH54oINStKmPhr2LQgUvLPLFaaSfdO2nrNOEAmG/ae59M5YvriU6
rByg+gKYVqC+/EfO9E+++KT/L74ikGmFI3HaTg1tBy94v7ThtkO3G0i3iyPb
pddhabSfWLKEX4vbTzquh3RcuEilzIw7LuvnFJPmATds+M3Dg+wrai/NG6oK
y7/j5q0FqTc0z9jQYz2fm+fSIMYNOi8o5WAizZ2XX3cpJp1HXNS/7DB3Ho3l
hCZqSpTirVkUb97nqT+hdYLO5V7LuHUSoz1BjNYVtunP9uHWVf7+Taq0PrF1
a+Bsbn3mV01TpfWJy1/J8L9S/KfPhtjn2wXWF8I+D5Huc5p30Jfsh9SNviDx
5kYhnH4RmHxjw87sAfK95kkWY61/WT40ShjtWhFhh8fI/tU/z1d4Bi3Ngx+b
ZRfPcHFFM/Ldx6dGYtJCzxxYW3cuMKzCC0eTemlLHkP+5SiEfZ9dTMe5+6Ed
qUv/rhSqPfL6CWiMfmfG1A3EAjLe+dSzyz7FpYHi+IeLGpSDMZasZ283sb+s
tEmGA05Jo7ePCUWt+iG8+Tc1MUYtAez3Txs01wvDruH7w5sZsapXHgHz6Jv7
OcHhqE7WHQod7IOXFoaDWsWG4jbPCBw+X9bwh1n2xp0FT+yOpc49Gokfia4c
eqjRTX9c4ZrJNkXx4kgcRdZHyt3Up497jGDcoY6QHeOicHrXX1zq8x4jLM9J
5cEdepjqtB1ce16Sx07DH2r1W3cWts1y4mlXoYO6TfuJI/2k43pLx4Uj42r+
zRaiecCRPNxuEu+lecORvPnUizfQPONInn9XtrbQecGReWnJi9Og84gnx87i
yaNPje4cOu94rqY5gDvvf56fDqZ1go67jy7i1smTLI4ErSsM0ORjcOuqIXaO
NK1PNN8jxqPP00uvbqT1ifGSPnkqov/0mcBhGb3ndwUHMZxUN/kODv+v4csf
qivQ0B5Wl3488+Tpjuy91BDu3M0q3ufuAoLTfRLXHLXDNeR513YqfgLHCWIu
6ShEyrtiAhlPv3YwRYImOMKK4+Z54028kEP6JXo91Bkx0R6ovfzna9b7oTjB
dTjMhqf8tmCQdHKVwdZAVCDrdHq9khV81AqmsfKct80LRj0y/z/QQ+lKGpjD
qJ7qE7nZIehO+rdLHVSNwA4maO8IEpslHIZFZF1ztIvq0XYwgrqGiMC1CuE4
dfh/Dd3UsYJ6fTBv+FA8dV8E3hiuf9Lz2Z0Xr8CzEsmI1J4I7CY6lOih5Nr4
z0HXtU5J4RuRGEbwb10UyzN1P8DKXsv/329p/A9v9UrdjxXiYlbcOG0nhraD
hzM37+C2Q7erLHXxCqrEr+Jpl/bTiPYTte++5/GTjmuZjoMRXnnuyhMXzcOo
6TuYyFn2gIcHmjdzmjf8uobi4Y3m+SXNM6bP7Obhmc5LF50XfHRkHE9e6DxO
jZxojwtn1p3jziOd92103rF1UQxP3mmdFNE6QdcBLR6dOHerV9G6QvHbvjy6
SuAw9Gh94tvnnjz6lIhbaULrE4P9pk97X/xPn0rfDpz7qJ6GfFoL8qdra2AV
2c+ws86j51JoBrpc0bVo/Cqc/Z3cK9jwUzPkP5sUnPO66eGqfEP8Sb77aPyu
v7I6JwnXrK2N32bCxHNkHDzUwcxo/ZqAoaXbtmiJW6IH6TfEOOKjuyTi8Wdu
3+4722xxgNRtZrQLjTo/KxYvW0xZLfDOHieSful7Fyu+MSAKDTznWs2c64Rl
ZN30qke922xLOCp+C9xU2+GMa0l+x/VTvfnPgrFmT5FSr6grbiT5Wt3HZK3O
CcCO/er7L69zw+Fzf7IDTIHnP7xQSThz5dp+N9xC+PcbpHSuzHFB/Ujxip1e
7riZ8P90kApZaGqJluNeb/cfdMc6gscMUlFGipfR503NjSMbPXDT4F9cxljx
MqyUu8GDPx1kjllkagk+fJqS3Hbodh/S7UKVxFiedmk/d9F+QpfXNx4/RfsY
FXRc0D4irnH99bMLngXDSB5e9TBmmm8JhxRDQx7evnexn9I8w0ieZ7THzafz
AlcH44W58yLGuTWNziN0GXyX5s7joQ6ZIjrvkE/N2Mqdd43fFUa0TuCl9phk
bp00/KTiaF3B82OjA7h1pfTNSJfWJ4iCZS63PpVmNU/RCM2A3APVwV9//tPn
mF97SjfrJWOQmFKwguQVeE3Go67Gc4wH7qkoef9lashqManl5JxyZ9vkXqOi
RDwu+uHROF1jKCHf0WZ3Nn6YtzkBQzQVT+rUW8ASsu42bWW9ll8eh7V+7+85
mNnBNvI97nw7a/EZyUf4Mtwj5WKgIwQTfpy6KvyC5aLwY+YUEAxwgafD/0Ho
Ya4rPBiO401YpaxoN3hC+qsNfUJRZSdCcIy8pJ6ToQeokf4nvb/+ncapQDy+
YvK0xkFPyCN5TOpjS93N80WxI7t+JO33hkaS9+MDjNciL9xx0jT3rN+HfaCC
9D/1/ZRFRKYDeo1rOx8wwxeG/6ulMUitG3xthpdXi1RnufvCL4JPHaSMjpdo
4q4z56Yefu379x5OGv9wokQT6voypnHjGoNMa9oOTHayfcVtp76f+Y5uF259
vXCBu13az/GrX7jDSD+T+ihtOi5Ya7ONJ670/tY2mge4cdZ9KjcPG/pac2je
oGFmAg9v63uc9tA8wz5OwnNunp26qEQ6L1AfqiTJnZfz7eyNdB4htrebJ4+m
rfXNdN4hQLKJyZ332Z36TbRO4Gewqwq3TjrbhMfdKUoE0T/rY7l1NeaXzRta
nzCw81sgtz5Lq9qP0fqEYvXpn/VW/dNnfL+HyiTzYNgqJ2vbxboDd4b3yQ9I
u66qDoRbqx95xF/ZKeVGeMvrZ3a4FwTBhRqjrjn1dqBDnp80UNPJUQuEgz/K
GfpZrjA8Tm3sdZp26EIALNBui308yRtWDP9fqdfpq7PaQ1i8rOfwpg9+UEl4
ZvcKZG7W8IbP5bvHMXwDQY3gnF7WcxWWB8joHh3YaxsMFcPzhz62fHyqKzw4
rJlusS0UGMP78zmMbfKxTlBu6H1yIDoM4kj/87Cbof/6hx1Qp8akPqkPhzUE
5/RQspoiltC5N2Np+uuIv3mczGEKji29C6sNS7d1OUWCOsHv9TIfbZbRgyX9
CzsMJv87b+7aTQk9nKgMOV9Dj20+EAWj/uH6fhOVcSR+r5catUVGDwNaFvPY
mcyhrtLtotN/33na5fSwdWk/caSfD7spfzouZGqP4onLhCN0geYBI58b8/Bw
tE/uIs0bJnZZ8PDG6RWvp3nGpyaHeXhm9+pW0HlBt0+yPHkx66X66DziIujk
yePG3tZldN7Rb2kfT94nDYzh61YLxF37A3l0ktfPGaB1hWXVtzu5dRXfX6ZM
6xPnhXzn0edupdu3aH3iDVefxdeu/dOng4uw2rxHT+GPk+yDwTl3APWHcAP7
WzNwTjEcmfJE8/jrHVJ9ZN/R99AKkevrimCXRVTP5JN0u5ZDeEs6M+2BWgF8
XmSppHXaFTrJeeePxSyD/LA8ePwybNsGRy9oDB/C3V9T/ALvcsB49d2QfBk/
eEP+CyORz7iQtArBLRWlDu8NhOmkzmlfzY7RCHwCcsX7rimJBMN9sh5Z9pmx
W2hGGrRtM+DUVoSAP6mjHm6mKAGrJDhV8rHplWQYrCJ11+ONzKz+33FwoWjS
KCXtcNhK6rQmbdTsuppIEJ/1/OH/13VfkX5jeTdVno9BEDuYp/L/dWD+4fUg
ve6TP+QBT4KZa1/ZRcLwuTANDqV8+eJd+Jq9Z64iV52ZxhuvXLyLI3Hajsyx
Qx440g7d7qgCDMLzjrNOcrdL+ylD+4kj/aTjaqXjwpFxHW5mL5hulYRh2515
eKB5U6V5wz5hDR7e7KupAppnHMmzRD5lQucFR+bF/TV7Dp1HVLqazJPHj8VC
ZnTe8fy5Lp68t6SzCmid4EidfA9lbKF1hRVKG3u5deXgoq5B6xOXLV7iwK1P
OX/BabQ+ceKl8ZOXvPunT+mNwsL+iZVwzuL7shNaF0Gd/Fdl3DKXm5c2V8Gq
UQ/tzApWSYk5DeFvlfuSmu+8hJIGg7PXXunDyfIhPNMkqero1BeQ2l5wJTL7
LiwfHMJTt1GWzqfKYKDR5qvJDXPYLTLUruUV8caQ+8+AVfqtfZKwNWiR/avS
niyF8fgUPtx0fvHirh3okfs8+dMYs8O6CmA8Pe5MNXgAKi5DuOqL+rj7q/Ng
8YSS/45OcQJvsl5uLGSr8mcjrO2vFC0PdoY6wv+respV5r8MmLSlpo7f2QX2
kvW73W+q7b5TEjx2TRr94ogrPB3eV99B8Ye0xcD0FSsfrnrvCtpEV339TBGx
gkDYqFugMHGHG4iSfiNpkCppPGUNBmffrDPWcYNJg3/xqU2nrHGNmIMYN07b
MaLtoHHQdB47dLvH6HZxZLt2v5kL7J2S8MNilzHcfr6qZ2fQcaFkTnI9d1yN
hZQFzQOO5EH1hVABzRveWWwpws0bf1qrCM0z1sTz8/As7cnWpPOCW8XsKrjz
YnlFro/OIyr6+nZw5zF1m5APnXf8smt+I3feM02E62id4LOaTbrcOnmrPAtp
XWH7dGc1bl1Jb5QQo/WJGp+jV3Lrs82A///1ieVXGz9rlP/T5/dDmU6hb19C
/s3ALo/GyyieO4TzS8nZVShUQkZe9erbaeuyOXFDuP0VCVHfpBdQukxcZe4i
Y/z0fQhfupCpdzS+HO6MlhZL87fAdeRcOVueWSA9vRR8FXMUlgrb4T3JIXzj
PdY+b/USaHFqf5cv7oiryb7ikuD6AdvEIjg5IX/jh9MuyE/+/2LOZit9nlQA
H+pPCKuou+Ei3yE89xVrBedMLpxac+XV9eUe+CVxCBctpS5MuZANXyVt2uaF
eeJ4cs/wqC/UE5HJ6TDDxUPzQKMXhpA6bUkb5aeYlAh9F612TW3yxnSyTgns
oGbPSIuGgx61J9SjfVCG6IrdTyVcmxAI6349x11rfFGejLOTBykGqFtBicko
k4TLvljd/xfXZ6hb4XIRo7vcOG1nkLaDLo6hOdx26HZP0u1iCEOep13az0La
T9TVWcbj56gvzE90XDgyLtFS5n2aBxS01//DzUPuK6GtNG9ozSfCw5s5m6FD
84wjeS4JZk+3SyzCkXnZeE9Ihc4jZjIm8OSRLa9eQ+cd2ykJnrwvXahuResE
HeKs13HrxP5KxCZaV3jv5hJlbl19P6TrSesTFy2bx6PPDMXntrQ+cdVLg0Jp
9j99FibmK5lMKIQD5xybVK3u4H7yPtY8luZEqhVC9djbkRtkdma/Jt+J2OxG
tYLcfDBaZP3oToEdFpI64a2yFanL1udByWnza2fCXbGN7B+OqBW/URmZA6uv
S21R/OmF59OH8NiCCj/xRQhJd/BybIofLiF1y+3VDJZbyxNonC9TUWgeiFfI
eKf9sZWZ/SwNXPft4Zy9GozHSP8z5YdAUYRvMny9/25R/IJQFK4fwmXaGHwy
1xNAbaGnVdT9MESyjljeUl/41fYRiG4VXHwoOxw3kXW3Ywf11GFDOJz8ttnk
YWIE2pK6rmA7k+GVzILL61q2eOlEYt7wd+cedsmPcW5wW/rLVMbXSGwcvi+o
myqUVDWC55cUBl2XR2FP519ceqeqESrJneHBaTsiP8e5YSwnhseOYDvDi24X
Dx3cvJW7XccOJof2E4++tufxc3kLu5OOCz12avDEJdNGCdI8YOLRVzw8TPkh
/p7mDQsjli/m5k37Y70HzTPeOH+fh+ft1eIpdF5wZF5iC9hJdB7RP+IxTx4j
ah+a0HlHqQ+TtnLn/VaZUy6tE9RKVNbl1gmbXaVN6wq7nYJjuXVVmGirSusT
8ZY1jz59x0l00PrE41411gOy//Q5p6EicllzGip8pNbso1RwO9mP5/TL/o2/
bjI+aWGH6BjdwgLCQ8Afpj/EJuK4ZuZXvXlM5JB16KiuMRd//4jHn51CPzXH
WWAemdfpt7Hk5Y89xjtdDGc/EWtcTb7bvuxkC7NLo1GNwywr77TFtcP34vbU
bxWTjUDnbmo6dcUeS8k8M7wvTsU/PwSf9VANax0d/p7X1hmIuzOFEYiT+qjj
Kied8CcZr4MGqbuvLrv+/z3R66u7nNGB1BMqBikzzUJrrBusv6JB9zPHyLi/
jKLGy2ro4USK7c1xd8F0gr+kqGyTu5dgDtnnmUdwWYrZeF7PAn4OsrXm2rig
LsGbBqmNVbnOEDmoPimU4YJI2vUcoH51PPOCzYNU5PoyZ4wn/bNyHztibnUA
JAywxmSJO+Nesq552CMwfZ1+ODR0U7EBjQ9QjqzjVLsE+rI5UZDFYWg+jr6P
hYQ38T+MzXJ3YyG9izE+S9AW3xKeNboEY3VN42FTF3vFUzErtCf1NJF2pwW4
OxEGOqms6lYzfEP2cy5q7bOfPi4ZLFsY7K0pdzGHzGeu/5AIEXmaAvq/2Xf1
PhqgNKmnvWlIAyPLNLjbTM28laeFGqSeVm3wYMnVzRngouqQlXfhAB4i8/Pf
zUm3NHcn47uquo+NlzTgGLH/vb1G9O3xBNy0w7rhmJo5/CDnDq63CTlYf3yE
E07NlhNa7gCrhu+R6KROpPdH4ZvXnhrXPzmDEuGhgyPUNWZ+xP/VdeVhNXbd
uyKzypAhUQiRKRlL6xgihGQoUyKJKJUkUU7zPM+D5umkaNag1mlONEoyxDFE
aJ7rNDy/vt/Zp/f63uv6/r2v53rOc9be695rr73WvfGM/unf6l1esJ/Mn9Ns
2kHlbdF478GZiI/5PtBJ7Ck4Qr8arBKBN8N3xPxS9puos/rApvZXf3qMSer3
WyxD/cGLzCvJMboczzFPDG4XldF+EAhHyTg2jlGfigfvYc3BlY72p4NgHRn3
xEiK8tflAx1MWPKfukruvVH+o5ScyT4TSG9h/P25PgikCZ47SoXP2GwPcisU
h25lBUITef+iMapeV8MTaPNFDllOCoQrBO8coc6+Xe0PfxMSvq8SCJjQA7wz
Qk+tPR8B/meH6kU1fcGK/K/CQeYRuRVxEIOHqk6ke8JNrr5EP/1FK/8T4F1a
bmQ95AZmxJ553SyLeX8TQbJ5UqzJdCfgxgnx7UlFCtVJMDW56er1QBso4/aJ
9zaMpSqnQME50de/lcxBiPDAry6p83zlqZCWefbIfQ0D+EZ4o95QwX2xdzrE
CWg9l5A8AM6EZw55eyqXOETCzJE7t9fY3IBA7n3ZO6RsReZHgHvekseMRjew
JnhPzx3enXMeg5Da8Pnc9vFxIbjngNKNj9J+MGv7RqWq/RFwi9ihdHDlPcu9
3tCg6c3DEIia0G/cwV41SUJlPC538dwS+DgauHX70f1TBZwKnCB+//emiLYY
eEXmT1nf1K4lPI8gZIbt66H3cfCTq+8xEDbfvfccSOmYpifVMOASwcXY+tpv
+Q0xvWpXcNFbBhwleF9fnNmJMjNcaydebfCQAfoEbx1UOqytYINvPhVbbvsZ
B88IHtq//7TEKie8Ozzt+Zy5cTB5os7w6roTPV4o4ukVKpQRDb8I/qFv/+Ip
bwNwreVOBz2tCPjC7fvrkslZnxaKi+9NtVbaEwQRxD59975Mvl8Vjn8stBYx
DvhO5HnmG8c08t6KRMvPDx4ww90hm+CbU2s8flRF4bflsmt+oDWYc8+zDI5b
TXaLQoOG4ycP8esCm+C5zpmHE0RfQsbvJd8bg1Uhhux/bz4VfL0mqgQcpDUO
Xa11hq1OHPx2NbP+4uRC2ORRtr3POwDMyf5I6zUVMqs3F5oFqeJ9T8NhP6l/
aPlFdzD9kgERJ3YU2S2LhnLSf/qig+p7eioV/uSp/7hhFgMVpC5Xq5dy2mAW
CxcX/bj11CoOTMh8PsymlMYiPKCgukC5248BpiQOeTlIDefesMcL5jFuO7IZ
8Jfg0X1UqDp/NK5omb7O/E8cVJG87rk2qqZXJAFjeXcu+ro6DlYRfmtrpvzn
RKWjd9KQ3OrWaHAmujffKyj52KwXWCO5lqnLjIDZpF/VqYbS6tAuQB/5rVZa
e4NBi9R1qCSxJmsNFuOq8z4eh8Q9oYX0LQoGdQyalJZix/HTz0qT7OCNOQfP
2RJ32HLaSzw7vcTwrsFdsNDn4NXzpUvfBtTBn03uYhdnCWIfnRP3/lSZ2a2W
XQthLX3v5765CwUlHNxoa5j377BKuKtTMO+hiTXISpDf9RFTn9lTBnEnV6jO
7XGCX+T9jGqNFO0DhTAmLzlr0W0PMCfxDI3oznX/S3fOrJNqqbVMg1tHVr8u
vOoN3PWofYS+jDoaDmcuqNTqXvEBWeLvo6PULb9YR5z3QetBu68PpBNehW76
sSPiT1E+6zJTkdcHNpH1sSaf9kQ8kIlXxq50L4/3hCukrzMrpTp5+4MSvHjw
wMb1cm7witwLk6pJv/txzWs8sBJ3F3nag4giB9cw9g/cebMGJ506xs9++ghO
dnPssz91xRax1XWYeDS9PUdYG454cnBdBfdT6aveQI5Bkuo6/VsYSXTn1LSY
l19MrYWUbdIfC8Qf4uvPHPyKAM3yxIFqcH1iEF/CtEZJ0se6S5F55JdPBYjG
HGY+1HbEVURfUfCemHfCz3K4+yhP/ayjG+qpcfCDj8XOHtlWBpSdlkPfeJwj
QfrjnHOYx+NtiyHruplGQpQ3biX3X/TVMnOT6gsg3+rj4goDX0wm+mARpZSb
iRLCy6RlkzVG/NCHxLEyLCrDvSULnOo6MzQPBuAPco52jujarfuXrt33LuoT
XS0R/ja/18kVDsLXxF8ch6mZyf4RMG2arO7c4CDUJnyVOEIJWmo4g4mb6JYP
X4LQiKyDI8OUmBmNjuak/qqLq2MzRMU8Ug7BmPVhC7IjgvAr4Z/APkrE/Xo8
FvlIbX8jHjRxP2ZzN904aV4qmp2qE754KRCFyDo10kQ/52+Uie2HGlH1fACe
IHzS1kBfm7a4ADfW+suGuvqiMMkfWhayjqeUF2FV1arPrcXe6Ef64O7E0v4o
mZZiqeLYcFyOJ1pacPAKK5Ydc205iu26m2X/2Q3LyL3hyaph3+kfXqO6yuff
LkWOeFeeg/su17imblOFB68VnV+82gZfkv7xdfr6ezYl1ODCY/X2wjxm4/E5
Z/4cOlom3vunFvutDwYsPaGHM5kc3Dan4/IxkzeoFejK7pklhnwJHFwywV53
4cUSmC+xZX7BFCP8SPYLqkVRFRdrC+FOeTLLZTyuPkfyovy1ii7GsgVwJInN
F3TWDz8Q3VRmptiBAmUmLByN+CFOC8Y6Jgff+oql/FQiF2bK91zmTQxDH6Ij
Z/ReQ3fRaBb0K/Bfu1cdgZOJzsaypjCZ728zQPTa1tYPzlEIZJ9S0cpUPZeY
ClKpu1ZIz4zBI4TPm37Rz76YmgT6q1dfMDsWi5vIOLb1U56vrkWCau6HijYR
BkYSHggienRt/9KjyxikVlwXtIctJga8G3sZyNXJ6eyn3OuiVHAlqZvi5sOL
+6lZF+8747384YHdHxgTfZoz+qmaZZeCcIr+qxFpAwb2kvnGM8CsnGoRhdvW
NKeIvIrDHeR7mjupjTy18djd8XbBwK9Y1CJxFLbpP723Kw2bVjp8cdKJRi0S
hx/72KG80DEbx4oMdrUNhGM+6edVrFBuN0zLxdbM8ysmlYWgANEHYORQ2w5+
YeK7n292O0kEoiDRg214MyymaFaAZ9Rls0Wn+SAPyds4lITxfhctwpZ16dlS
jS74mdz3lPF8k25zUDH+9hjwlXxmgX6EN/yZiybXHizBvxvLfZys1LGG3Fs0
PMgUC8n1gFdpTavX7biBLLJvihqkis5e8ILmb7d9kj3dsJTwtkAfZets7Q6v
n76Ya58YiMbEr/kH6HztNi6QpRC0LlUyFONI3GsyQD0wTXAEIYOlWZcWRGAF
WRd6BykTNZYduK+oPS3RGIkdhAc2DVEtvFNtIKWkyy35WjSKEnwVmzorv9kS
djN/S/KnxUzowiUNUDKb+E2gWXuFBn9g3ESdw7MBSrDs1HU4PKlbV8KNMdGH
rkL03/78S/9t5iIei8GYeVBVuOaUphcDPQm+v49i7TA7gy0x/e/WyzKwjvt8
P+V9fbE2KrF6hZgxccjVBx7/X5bncgywj+8uz+L6WCwneFAvNd1S2AyPnNHv
WUmPntAfOzFIl+1KsMaajTB2bGcEcu8FE+unJ+a5OiLretYctf/0nxE7j8et
sX/6nVFbIvLUA2FftODWb/cwa77dcEMz4YLS1+ruuJKM41k21RR51QN1EhrW
pQdYow/B5VTuGYoJuOG9m0+u+369hXMpDh7zbcN65tcsXBkeZ9Xm0i1/kuQV
2W1FEiKsdBQWuTT3a7IxxhNdhcg+1otoxRS08q94eWmNDXaROKq+l067X5WA
e410NRPeOuM64l+ygzT+MnUGVjYv8DITcp/oQ69gi/382hONzR6mU4y7PZB/
QneIeX2dYwQ2BFmrjkh6IVfPPH2UHu5/3Re39T3YxWZ7T9zrYTRKhen0PMJL
ItV7doz54Czyf20p6qBzpgkMPom+lbbFF0UJ7k100oz/pZO2e4yaER7gDfuU
gnNuB/ggV7+LPkL3HNMLggOjg1OKR73xOZnnIsNiktdmRUOKZKG1+gYvvM3d
v/QxHWp/PIGc5ReO3BN1x0Jih+99tFl73yVDZdinJOs9DphB+ORSu9Hgthvp
IK6cIvfInY4vyLqs96dn1rEtz2FWq+d7vXpjXETO3Z7PFAD7lVkQkVEist5N
G13JOnjot7t79eXnaOAf9/Vi8wFII/UGs7szGYdSUtHm0cOhwVpz6CY8HNqh
YTF/7Bl6/QyMdaE7gTJZ92P7wxZGrYnHuaZz6S8mecEHwsN7hllCJzZE4Xy/
DbSXBb5wg3tPzQhrfr9MOP59H3dSF/wn+qGujlImB619cGqNn+5so0B4S+xm
PUb33iVviaYZiwUNI4KAGyeMj8MB7c034e22mjr/8iCQJONSMEIP1D0zvh9e
eSXNsiUQHpDn9xIdMPt/6YA9Hdnk1GQRDtpfGbRnqX6QS75n6RDrZfGdWJjz
28dpWMEbnhK/PtpDcwy4lAi8onfcrkW6gueETnuZ7JHDKfCySyi186kVjJB5
zlqp7dQVnQ6O8fpK9HxtOEPGq3WkiHHseCT80GraYrnXFB4Tv34+kimnFh8B
0srT6YW7HMGS4AtHraNLD4fDRzG5d/MNvMCe4H1DLIEUmVD4dD5A4E2xP8gR
3Iut7H5aNhimVk+3Tgt5PKHz78NmBd/eGzC+b7+ET8zD4S7BJw3rHzxn4gvT
eWa3fbod+Z881v/jB4fDLgV7eEFwk8eKQyui4STBPQeYU89cdge16CWrO/xj
oIDwWMIg7WdviCNEb2jU+lD9z72lw0P047afrCHYJfjXpFdxUPqPTux52hYz
SC1+PUvfjgE6BH/Mpi83eGoA4X5Z70T442FNP3dcqAyHyNOAVr/3TT0YD5MJ
PnmQ+vTM4BwySf0GD8HPs6ngoa+GuFTjPV+kQPzE/b/f+6mBl9fM0dn8mOqJ
8X3iWW5f4RCz6rCxDer2ZR+lfY2DJO49X4O0gKwdTqg6b3nn7dbYCf00Y6Jv
pvAvfTOFYfeRDZ+98Mm7sRZPpWjYQOzGYivX6pX4Yn/1Km+L0Ejg6jynsZmn
t7oF4KlVHsKMtHA4TMZlO5sSUbMOxhfXUz5eWBACedz5yda/b28fipvfN5ps
PBIAAmTcy0caqOJ74bjrGPuLMp83XOCeq44oKZd+iED5p9kv35g4gRrBtUZG
hQ6FROLsEaZJyN+HoE3wDS6qkt+nRuA1nUPFhs3b4D7xFwPPgY8vksugXSzy
2RRBIwgm5+Ojz8PuL0ssBpbiDGnrOg8QJDo2p8rEBsLaC8Gectqat8YPHkQT
fqinrc2TLBj33zqJft5gcCbxJ08BtZovH2HD2el05athIED6fX68YZpU7ngB
tCuvrfpiIqCe6IpUfGXub3ySCac+izSWqEfBCpLPV26htYssS4f6FL/pQh+i
4S+Lg3d0U3rRnskg1J4h/GlhLOwg52VaA9Q8ga5IwPYp87tZcWBO4rqHAxTr
Z5I/yNyTi5fXYYAF4bdJbOqCxrAVPPfzPj39OQNEyTzxZlMmi9/cwRFSd3GK
4LZDlF7uLy9c+GpTu3gQA1aTda1gkLIydQnHhS/UGnWlGeBD+ORmN8XnMx43
HFpp/3WnSxwEkTyw62+qKAWfYaBz8GTbJ7GwlfDzsR/M2/PvP8egE9gQKh0N
84juh3gJlXLULQ/zl+5a+7Q0HPhKOHhcAzOt2TUfC6EzbJZeCCwh5xeXX4ld
ET5biIKBDZljdQFgQvqqVHNYe5OFi/FsR+j5xgJviAjk4EJxtLtfWCW4Mq9N
4d0NF/C35+C7vBWNnt0uw4cSekVuFyzAlOjqmNUxvEXmvMSMa6m6v5ZchM0k
zyC/fsnxlT/fwHHfCwEJp2jADiJ9UgbK850iayC8e97dfa7GINXCwSvOdSyz
TX4Nvm03h+vWWsMAjfiLPdPB+ftLmKJF55tRYQfPiB4XLaG66POiUqhnOXpE
CDqBAtEhVywTdFh/vAiGdVXW3u91Ab5IYs9G1k8lq3zQFpxpe/6BO/zK4eC+
72hPlt1+AUWpvLYJNR7AIjozT/op0dg9ybBsZubO0zpeIEXGS2CUEis76gNv
bypf3Ta+jnDXrwuTeC7PMLyMdaTOwZrEGx0jVOZ0nQBcIsMnrnzFG7j1vb0D
lN3QlTjk/dyyOUXSG6aQeXW3l2bxfDy+Ut8+di0i3wsGyLmYzi/mH8MvzzFq
LUwWX+sFU0meyq5BbHYRfwGmW7uPlN3yACvSv5kRGZZVGVyK9nnSrN3fnOEu
nYMfPqpxJWlrBYaK+7LS9W0hnvQN6c2l9r4ersJH/QWZGQxLSBPk4Mu0k8xT
ftbg7Hl71d7yP4Tj30leZU9U8EeZN/jV0Pt397Ah+BNdNc9r+0+yeOvQVKZ1
Bsv8MmT4cXChvWW92hvfgPdnjw8VGy7h7QwOrnhv4KQirQbGPmmfDqu3wIIB
Dn78UpiiuuRreK1w84rLV2f8dJDzPboJGuvnVJVAlI1sY+MdL6wm8/NIqZjE
JIkisK+Mn2d+ygcryLiXfKTdm2uSD7F6H9LTe3zxLBn3M3X0efV+LyBLUyrW
9JQ/Hifng2m9VNva5mS4VTBk9EwlEKOJ/W+NUNfXfgmA9ULz1i0/HoTfCa/G
jlAZp756ouHFnDm1h4JQgIyvJJvCV2FRWDzU1UH/GYjc/vTIDirnhvIzXOHe
Ko57A1GS5Dk92ygFG3o68pzcvd5ZPQB1yT56sJD5o34jE62XFc6tr/PFS4Q/
9TKZcuc7inHm1Ubzs4e8cDk5Z7xgqFFvpvgKw4ffVqrdc8aQkxzcYRpdpjeg
GpfJ9kxeqWqBElM4+PWrZcFRwrXoZ/RLwXzMCKc0cuwPRQaSs3nf4ImrKyo0
I87h+xcc/M2zh20BGiWgLD41dpP0GXxF8hLx+bfmPfQrgtO+hwUV57rgiTAO
rvZB8CHtQT78Nnp1X/VrAGaQvp4l9e7dfd45sHr3gv7ypnDUIn4X8Ze6GEVL
h0ahvlVbtaLxG+H5F10dV7vnp8BfjySZ1rIYPE/ykEv7mPKjD2Jgz660k+oN
cfiH2PMSm95cFOAJ03UmJdK7GDiXq6/bR71qmENHnTkKl08uiMd2ggsP0VQb
PcLR81XJ5foDDLQivM3uYTqs/B2LhnPu/AqwjEMp8v7KTkFLpdcpeCG1yGzV
3hhcQ+LAeJb7vgsSWbh/z4uaizMj0Yzk38yKmiPOmCJauK6VTMwPxh6i15RY
0TPr1oVC5Ovvk79H90R3oqPF2tJ/zXVKCS4x1imet8sYNcj4So9SOwfuBuKc
MWbpnuseeIvMN96RJJnH7ZEgxqYsXKrc0JTEFS873b8156RizxZB84v696Gd
rC/METpen++Pua4jNxITx+NHEg+sHaMMpGfa4919K+WSpgbBO/J+2jDzk1z7
Y6gMOpJ77r0fpJD5/55N77SFaFgV3rJNP8EbFpD4Z7CvL7jbMRKkbk19rPbX
Cg6R5526499bDoeC7KfRRfytPuBM8O+DapMqvtqAxqjJwkLeODhO/KV+aOGn
MLgDi3IGeA4bja+n3PukBsU0rsw5g3JTrv6XvoQiW0m6i88DNad36PDzxcJt
8p62AbUrT3/4YnZV+GkZqSi4Sr7TuHemhU5xMN4+JPTgUUEoKHHvzwpYqMBQ
KYOMs9+nlevRodaE8HM+69K8l0Vw2TPeve6hN6SQvOKrTxRbj5YPTak17wtk
QiCR8Mw4f+cUez6FqA9fl7wOiYVz5JzXvYd6ur4yFM5FKr4RlGIA957TgAFK
mf78KhgTnYGr5H+97aNYLqxAdP1ecSJInwECJG4J7qTzHFyUgl16gsuK1ozv
b4hfaDZS2LghCy0UXQ2n340CF9J/nZxNW264n4nK7bNp4Y/DgI/JwZsKaPdo
UkV4Ztacy6f0/GAD4U87yeUCtGl10F+45OTeVdcg35fDA6cflBUO76qBVBGh
c7GKj+DBIAdX0HE/0VT+Ci7mJbkmXLcHwaPk+zOYXrKiJWDmlpT0d7EbZJC+
PF8Wc9HDTdkwliMd9ijQC3hJvCfSSzdRYSRAyJUdH3KHvcGc+KPeGCWcVmoN
HaRvfYC7fx+h9w4UR6DXt+E1+Vo+YEjGMbGdqVoln467F3zfaXvLG1pJHiOk
kUk3acnG91d0o+5HeUEcyXN6V1QvuhZViJo6l5damnnAIgYHf+2mnDpD5SWu
Xl7BLF7kDPdukfmwXuNX8GgluiW3RU+KtYbiZRz86NHZc0Oba7F53vOU3L3G
oEzyvXLV1G56XS52uapuLBz3vxGSD5yWXsdXolkMr8wq4hLW22E40VU43Ekb
KByPR6U2bt/94mQc9pG8wVgP/fCIUDK+uV2woaw0Bo1Jve6xn8o+EprP8dlm
EZn91ZG4luQHevuYl+m7vKG8abmr9gsr3EHik+5BWiRrkifcvGRUtDXLB7nn
4N59VNfbVDMYShy5sbw4FtO5+8Eh6oKjmiGsY92fmSLNmLhvxb2fOkxdv4dB
ikqxsi9j0IT4V8kgVWb7wwKzq3+51w9F4mKuHk4/1WLpaodxwfctZxuH4jfC
Px9+Z0/OSX+OWzz6j1ooaGM+4f/N3WFDh+aloYCqR07YLTryEx5z7mTxDm5J
wk8V5qevSDsgt4+DPUw71r/7Mc4xXK5VJ+U9cX/rw1H69DsSrkjbuLTRwM8H
bcj/reun3E07jqIF6fMCYp+hEfrDZxHjcXZnxEGdTd4I5PsfD4blRd6Lg5A8
8Q1RAx7I5R/erk2iqieewa+MxgWS353xO/kez+6kXTVeqTCnwiVl604bnEF4
QKD94byBM+mYvLNt4/1UA1hA/Hdun+AXJdEUnBKR/a6x3wYOknHX7NEf8xVO
xN9d6a1TbN0hg/jFjiENuWSJWBwTHVrpNslnYj9eMkzbH2QchBkbM9/YmAYA
957ZwRFq8PtyV4wOfvR+ilQQ0AnP3xmj5uzRvIYHSH/QWmKfI2N0oSIDK5gs
06Nx+uE/fUChw6wBdcFg8EsPi9k4NQB+kPeLDgumfTeNgqFyJZEIUV84Q+bD
nX6q9sbdeDBU+bKsVMoTcgiPHe2wb/2rkgS6yyz5ltx0gIXEbnVdapj5LRXG
aFbVmR/ugycZd8moBtGPN0shunCOudk0O2iy5OC3O+l71s54AquOywasFomD
OcRu29toM/+2pOLSuT/fnnCJAQ2St99xpEgxaagWFGQcFxxZcgM+5nL81G/F
QkrTtApknYxe71R5BI8Xcp73+cssutyQAS1r133JSvecuB/zxRDV33AqBmi/
D6F5uxc8Iv4yo4a6KW2ci98eMWykND1hG9nn5ucrn5j0pggdlSxCfji7wTey
jqgQPd7Fz/5bj/fMmYTVwfdrIYd5WkBrjjHGkXrgz+sEJduqKsFr5zXBxsd2
eInoWix3DLs5y/QldEtVjxSreKCcDgfHZkqODc/B7nT3g9d3AjCX7CNSByiV
jGVxIFHPJyHeGYj8JC7qnsxzQnXgFpiTulZZMh9cGynpyw3ZWKPTlfp7pz+u
Jfz5qFpM593+QlwNC/4obfRBPnK+bBKg0TI/sAzfRrWtZC/3wBKSZ4gmuqwR
/9JlPZbW0ru/uRgeb1e7GGxDR1svDj5S6a/3iL8QkvgHcz6neaPSUw7uVcKs
25+fB2IOnm7bvUJQgeyLRb4pn/a/nQkRT3bzri6KxE2kDqqmjdp64k0C+M5Z
m36sPRZTSJzf1cNU1VUMhYrFMgaLrBk4jazLi4cp9xCGEWiSesjpxL8aB5lC
C4x8UGWnal1eBQMLyXy+0kptcKc9xem9u/WnWcRiNvH363/Cplb1p2PlvrXz
WoqjUI/Yf3Od/iP64RfIjK+Xt5wfjnpER72jYU2pcV0+Ci8N+VP32Q83ZnJw
QSZH5/PDv3Q+C7vUjn6dloaXW+k6DgPmuJLrLx2s0EpmEh7qp9Wc3G2L1SSO
nT3AyvqrF4/fB+hhp8454U4y7r3Dm15OFY1CATblV3nSDbXJeho6Rs0QfOaA
78ZYc2NPeuJuwpM/eXkMvDfJwCKKGfifOr1ybl/8GCU/7Zsj1I9pWMVoek70
Nc8ZZXYd9gmERWNio5S7B14mfBLY3zEtPice6gaYCcrlTtjHra8bUPt9YEoy
qPczY45V2KI5+f5VXXK9ezelwctWpoWaGh0LyTrY8LujvlX1OWzppiyzagwQ
iZ9W9dJfz9Z7gh9eNsp0nfaAWeT9v4c0JEeEY3Av+wzj2C9vsCL+O5NNn1Fv
HobUERvPs+l+sJTw25lJPOL7vfbi+Z9X/quubOMYFSe+3waWWqyRMm4NBDb5
XyajVHFqtQ/U5XTEx6eP8zBZj7b0U78ffI2Hig0b/TaouYMP+Z5DHdXGHTuT
gGm0eeeIph0cInyY2e14cAstFdaKhYrcKTcBATJvxQejXm828oGeLfdFdbL/
yfcm9E7VO+LgDsuPHT3z0SgGGrh1dwNxXqsCTDGwq8jlqTMD9Mh8XjlYlLRx
nR2ayW++tfdqHAxx+1hNbq9pCg7HC2Y3d/0O9YXPZD5cShNqvrk8Cg+yMqcF
zLKHYoJDG/OwkXQahLsbNskqxUATOb+430Gfub8nHhs2MQpF9sbBNMLPxo+H
Vf5El6LmaidPr/P2oEjn4Hv+R12Kgqb35B6RWpisaPdZe+sDhE8cPqTJjsfV
8pXwuElW4vZ7e8xcy3n+m4u+pv2llxCT29/wzcQDH9zk4E7FzOZB8yKwW+Pc
t2CrD+qGcfDJlbRLEbJ5YFLlk6Ik7o82pK5e/X/UUSxnU02vfaJgrHnxx1Z6
ECoQOw/O5eGROrQCMkldxEZuvMqm+8gZROFZf8bffXeCJvIDVR30JxqmaWh9
+LOytUwg1pL3HyxhsurvFuFtr8AjCpN9sIJ852K3jvP6Z16i2x/aDi1ZD+wi
/0tkt0ZojUwl7p47w2PrPntUXMfBTa82L/JYUIur1PijB6rv4wdiN++aC4qa
ygVQv6nuXTSPH8qQ/G1ymUbxxje5oPCu+iufSygacu3wjVa8ZlImSIUsuvG1
LBK1yLnhpi7mIkuZFBAWfnzVyjYGD5B4JuJ/nO/bjnv/PpNjIPGvc/zeAWrb
5pN+uLpkmdPmcAZy/SKnh9o9+2Us6mzZyey+F4dHCA84VApuTbmYizKfAzX5
1EJxOalnEK5XvB83rwBDPlK+v5i+uIfUh+x60bExiL8YqfVZqslb7XFfMAfn
G+jYY3vGBYomO9Q+/xOC2dx7qwfpIqML7KDua/mdjQ8iUZrwQEgvTSYvjA4/
pf7qee6MwSyuHuP/OHdW6aXWn916HjvaXHPXKY+vFwQPGqRe6CwwQsFLhX5C
a+OQe6/xxX4N54UPXdBBU0tfPckXNcj82ccezp62whP1bqWwlq2zxzPceHVA
rIAnlIGd8ubuQXPc0f+f+6eE7jhF4pf2LFWfdV6oxr3v5n+ch3aO0NlzWwOg
dfXyo9Uj3jiZ21f+V+p4Q1sGDCmuKlhaZYxviV8Xjmjc36gYjqKPziXHL/Of
uC97Nzmnc/rXOV3aiNxfudIICO9dqi0WZQ+2xJ5NQ9VPDWaFwbSv1DL1hX5w
muB6bI1+z7+B4OdFLVteHgpPyftH2WHMkCof2CB5eW1wXySkEPu7DNBe/Djg
DtcaHphZYwzEE3v+HGIu7dpnA1a5v25dy4mDKmJ/xhC9/NVvIxDtrWJ9/smA
nQRfN/47mY6rsYCcQ00i+L4h6pS2ijEGLbVm3mhiwDaCFwwxBWgDNpgfrSz1
MDMOuPuj2+Rc6cC/zpW62coO3yR90TZ651bLzkiIJd9/ga3hZ6YQhC2rZi6f
lBsKodx+7SF9Ra3rYWiy5Yrbmal+sJfYx3GkhLe1IwIf7D9/Yrm5Pehz63KL
Ny3sliqCrx8cBZNsfeE42deXZ9GW/Rhmwt6PP3bWLwwFe3LfZfJ7psyPqGzI
k/ju9dA9EhxqOfiXVvol0YNpsGTHZ769x2IghYx7fT/9fFpCAAQX2EWyrjAm
6sBlhina/CeHcBZyzk2454BpffTE09uDcCRx8UxKiwH83POXTko6sS4eY80C
rD7Lx8FKsi5s/ui+XWJTPho51fl1yIRCH8mrBBTQv2WrF6Ep41X5FIYv3CB6
+xfCC4qZ5qV4eYZlYuJie5hM9gVqlmHvyveUg0ibqatGnB3MJfVdakjPHt1V
DCyVLQ7iT12ghehx1ZbRtNsvIZgJzSn6FecBB0g8WS7Mc1k3cx9Wkzy//T91
FxYbDKPx7taRi+83e8M0Mo7n2iktVErHw68PNDMOeEEvyT+oimmkZxpUYYHW
1juDLZYwfREHn35iv7pnVi3aSHu6BO0wgm+kznNaMbV10KAI+Ne66i/h88Fu
wv9XKmmWZxfkAcsvUnBtoR8uJvmELDa1THtKFLZcz5kr3hU4cV+tbicVlHM0
Dcdm1bu55ATgGcLPPDcym0ObavDXXb6qw64m+Ijk+W92Vd+rV0kB2bae+cJh
MdjDvQ+3l+JTTIjFrNHqRR2ecahEeHj/KLOqf0MgLhijbiU88EATwhs/hjtC
Hm+LAl42pWii54ZnyHz+3pU0w1YjFfflvKsUTTMFJHHy0VG6ps4GX0z5w++c
XxkAHwhvyI/R96cutMP8PKH82plB8JW8fwWbWTV0PAzyZ5goPIn2Ayky/2+w
6Z4HsqLBa3qur7mbN1QSO7QbTxeVDogEw2m7VVNP2sMc8rxd91Hr3o5QeFZ5
V3v1R9+J89M/g7eyh6JsoC/2bdd77TiYSt7za0hNfumQIYgrF/et82AAncxz
z0HmyA/VM6gwRee/8pMK7JkWqas8sKK6JTzYMAYquN8zUHf22pAv9t1ZVPIu
MRKekPlzr/eT75LKYFymaJZoSwuFG8RusyJSZgXYlMJfqYrKri47yCZ1jL+L
xT7O3FwEQ7mf0vJsfGEN8feQHKbS/F9MOOVsazA6LRS+E3/P6aSfV/CPh3ne
KhooFweqxO+C++n5B+QCIcUgYO1ZTQbsIn56naJosdRBfEDyk1y/1uijr96T
EISVW+67pl9nTNy79KqVOcnoUBr+crkX6XM8BhIIb9xuoEL3lWSjwB2FBb/9
ImER4ZnzH+mh05fn44fJR9p27wqFa+QeJZ38sMjWcX/veWUxlsT0BU3i7w8U
D3duF3oD367+vLK18w5EEP06kcXKv9I+V4Hl1c+pqeWWYEN08IpNN0V3Z5eD
aapkYfYHB+g8R8Yxh7Ztv08xjD5+2PA23g22kTq6F22UgIhvOlziXRGYqOQN
c4n/irLpN/S8o+Fk045nCnt8gFv3pToe7ym8YudtFeTkJ88RfpjLprPFgqJR
WtE3TPWwDxSR5yPaaGpGAenoq9d5t0bdG6aQ9y8uYbqaf0VcIiq2MyTNE6RJ
3Is5yiKdvsVoc5h+6uQfNxAn32lpWr0v8kU5ZlV2mF+UcoR35H9lLypLVmZV
Yc/BYP5bG6zgOrGDvOLegl6hN2hlcyKvqtEIbIjdNCrpl8yl89BDI+rQDkF/
jCfxnnnma9Mla4qhmm3y6JOHPbaR8+Lsbqa72uo4WFqoXcR4GIeTCA84dtHd
2pekoM6SLREeVjH4gPCMRFPSjKbo5xjpVnnlamYkPiTn2mH9CVfktnhBpoZL
8fIGuwk9pfVDzC+frD1AccmO/To6vriKxCePBihTh/n3IMzvZ/IbiTi0JvYM
7KM2lwrpwkJfRfXPhxmYS+anVS/196n4I0ycYrN0p1zMxH3c43Ha0fmLrVHe
UF9oqmMkKhJ/f9pPS56y1B4tj9jm2a0PxVaujnrL9CXaHzIwsFTSW/jzHZxP
8khSPcye406p2HIg1NQRLXE74bFpXRquK2qeobhS6ZQvnxzQg+zj5o5S0n/T
AlD+6jnXI++8UZjwmMIY/WCmngNKvimT31/tgznk/36fyrMn20UaRCVz/z8/
SSP2WTLCPGo2zmNHAo+fidvnhUcJPzgP0B7Nf8eAl3enngwV9MALJA4U6NzE
z7sgCd5XrE7d6OqEO8j3qHcL3t72LBVMg1W8BGussZrkDeZ1Rb2cL5qG804e
b5u5whSmENyvX7DAQjYZDxctKN/rbg883Di8l9o+bVECfvXoq76o6wEPCA/Y
DoXpp+fFIK+XUoHOTh/gJ+O1eJRWEBvqi5Ni8pi5GwMn7n9sGaXfu8uyxT5m
ev3w7SCoIvbZwMsjZCSzGXUE+v4/P7mZ2KdtlJKTb7QB95aky0+1guATeb58
pMOmbHU4nA4xCCib4w8fiH0yh9wTK81iQPhs9hS1+T6wnXxPU6+GlWbDEzC4
3rZ7RN4DMrl16f0/Jn9anAwaCtUOv5eO70/J/3Xuop7uGUsFv7ve7lrC9+EE
t74uqj6MfqEUClN3XAxvtAN7Kw7e1cl8MskwHp4m84mgbBwYE751aWX5lV5K
w2L9a9FblWPAmPDkzJM/Fu5JqQWZP5XdVXQD+FtK9DlXddB1TlRBof4z9cK9
dJgqwnm+sZ1+8vz2dJA94eI0d4UXbCLrdRSberFrSjRkl3g8vDjZe6Kv6loZ
FR2ug3hFRiNGAj1gMYlzYnP1aXrKxfj3nmQRxLrCZBIXqZH85Mx/5SeDr7kK
prfXQO7ktwLzj5riym+c75SQ1ZfZJ1oJ0SaqlwbC7TFIivP8c2cmK0DpJThf
2Mp3RdcDNcl5Sk0H1dF4Iw1uDV+na9cG4GzCG/JsineudxS8uXLdMHn2P/vl
kNk8+d8XHwALkp88yL1ns5K25NC0POR7sbj1a5ofKpO4iL+Uevz5dBEK694W
EE/1RsEIDp7rQTnrL3+Jmge2rTka7Y53iZ7wM5Kf9P5XfrIgd+V5On8x1I4x
t28ztsc9ZP+YUqdxkXm4ANIa6ULLxtfza2QfvfgVc9evb7mwabC7jzcyFGUI
r+Z/E1Rv3p4JYdWzF3p/jsRCkp+07qEctwnGgcF8mZU3fOKQl8y3qwPM45vP
+8M8y7DBR0wGHiPrcsIQpV+cuw+MSX6Sq2tEG2TOubbRD2fxqEhH5zHQhjz/
pIt683FnCqqLXzdwDInBdcTOsj9YWaMtz1Glv+q4cEMkhpJ9vVdF9c+Z/rmY
JBV4WcUzFBWIPd3qaXKtKwtQ6RSoZTX54rN0Dr6A5CfD/5Wf/D+1obAf
    "]],
  Axes->True,
  AxesLabel->{
    FormBox[
     StyleBox["x", Medium, Bold, StripOnInput -> False], TraditionalForm], 
    FormBox[
     StyleBox["t", Medium, Bold, StripOnInput -> False], TraditionalForm]},
  BoxRatios->{1, 1, 0.4},
  ImageSize->350,
  Method->{"RotationControl" -> "Globe"},
  PlotLabel->FormBox[
    StyleBox[
     RowBox[{"U", "(", 
       RowBox[{"x", ",", "t"}], ")"}], Medium, Bold, StripOnInput -> False], 
    TraditionalForm],
  PlotRange->
   NCache[{{0, 1}, {0, 4 Pi}, {-1.264873464492341*^-6, 
     4.3564718166978136`*^-7}}, {{0, 1}, {
     0, 12.566370614359172`}, {-1.264873464492341*^-6, 
     4.3564718166978136`*^-7}}],
  PlotRangePadding->{
    Scaled[0.02], 
    Scaled[0.02], 
    Scaled[0.02]}]], "Text",
 CellChangeTimes->{3.492163332921875*^9, 
  3.492165196546875*^9},ImageCache->GraphicsData["CompressedBitmap", "\<\
eJzEvQd4HMeRBbxegKQoWbItnX2WZdmWLNvnc5TDnc/n84X/HGTLNkjkwJxz
lkSKYs5JDAoMYCZIEDnnRAAECeYMgDnnABAEiLj9v6rqCQsMGHT/3c/vqyWA
3enprX7vVVVPT89f+owfPGBEn/FD+vX51h/G9hk9eEi/cd/6/aix+JPP51wu
9/Mu1+civ+Win5XLZbxY/75AL/a//H/9h0H883PK4/GosrIy1a9fP+V2u9WY
MWP4d/o7/YuOjlZf+cpX1JkzZ1xuPqaTSk9PV71791azZs1SwcHB6vDhw66P
bW0P4Z991NGjR9Xzzz/P7/vo82VkZKgf/vCH6uLFi/xZ+szrr7+ubty4wb8f
OXLE+N31kUObx48fVy+88AJ9ztVZ/4366ufnp/z9/XUffVRjYyOfZ+bMmU/c
Tk1NjfrqV7+qVq5cqfvrQ22qH/3oR9Sea8UTtnPy5EnVtWtXlZeXZ7YzceJE
9dJLL6l79+49cTt79+5VnTt3Vjt37jTbmTdvHvv08uXLT9zOnj17VKdOnVRp
aen/qJ2Kigr1zDPPqOzsbLOdd955R7344ovq7t27T9wOfMCYWr58udnOX//6
Vx6vR/mZ+mu184xqbW3l495++20Trw0NDer73/++mj17tn3YB2no0iEYFtWn
Tx/VpUsXbq4Lv9dFHTt2TH3rW99SV69e5WP27dun3njjDXXr1i1HCJ0/f14N
GjSI3ILOSPsE7x49eqgZM2YwNei9lx5Bmw9s7S7U/XgUJSbbPr/gCeHvdMzj
oP6+wzGPg7XTMY+DsP2YafTiJiV85gmBaz96inm0fFQNHDiQf+vyhOi1N8Y/
+yijLbzq1vi3J8WxvcX36MWXmuhka1E+4HpSRNtH8h3z+xqntkUQ/Tdf8yT6
RJ01xB4FdftJxpl+6OxwEnebk+g4Jg535oId72PMb/Cs4zfAb26HN+bYmhhp
9u/z5k+24bc84d3EbFsTw81evNRmYKyv2PHRQ8zTfuUJj55lO3qQee6XHY52
6vlM29H9zXO/8hmO7mMe/Q2Ho30djp5hO7qX2fPXHI7u5HD0dNvREea5v/0Z
jg4zz/1dh6OdgDrNdnSweW6n0XHqz+NaDDT74/TJ1x1a7OLwuam2FrubffyR
w9HPOBw9xXa0n9mfn36Go/9invtnDkd3dTjazuk/mUf/0uFoJ55rudmtmyfR
+MIXvqB+/etfq+vXr/NnPv30U/7b3/72N3Xnzh2XJX2/+iwneZYEW33uc59T
X/7yl9Xvfvc7jrQUDelvFAVDQ0PVgwcPxppf5tcdOZIV/QPv1ltaWjiGNzU1
qUWLFqmxY8dyDKQ0iAQXkYti6WjzW/ybQ+ufd/gWk+Q8e/m/Turhw4fq5z//
OX/ke9/7Hv3uGmV2+d8/S6O+HHV+//vf80eQVIw0O/n/PGF7E707WV9fz5GF
PjJgwABq3zXU7OTvHBp93qHR9+yNPsNepByAvPrb3/6WQjqHyaqqKjrBALPT
TiL4X5/tnBs3buQCiXBCmd9PfvIT9aUvfUn5+vqqkpKSvuZ3+pND+y84tP+u
tF/O/z3LaEG2xnj85je/qXr27MmDQWj5zW9+o1555RV1+vTp3uZ3+4vDeb7g
cJ535Dz8y5tmL//2GY7+sXl0d4ejv+hw9ATb0T80ex7ocPSXHI4ebzv6++a5
gz/D0d8zzx3mcPSLDkePsx39hnnuCIejX3I4eqzt6NfNc/f6DEd/0zx3H4ej
/87h6DG2o181z62zIiOFdWrsyw6NjbY19jWzK07ZQYdfjj+mv9Ih/s+5FJJw
3NU+46Du37+v3nrrLS7V/vjHP6rJkycT2Vz/ZDY8xOG0L+qzeE+p8Jc3vHNQ
f/ARtRb/bp+uuH37Nnc2KiqKE3XS+UmTJqmUlJSfm34e7tAfIzW0u2uU9OOA
futxNZwRdykk/vjHPybHuH5iOmGkw0n/3uGkI71P+rgi0EgVSMN/8IMfcLH8
I/Objn3Ck47wPunjqkjjpLW1terVV1/lyvEfzW86/rOd9HFlqHHSnJwc9dxz
zzEe/8H8pu86nPSrDicd7n3Sx1Wvki3KnERSUhIXooQ9fHPXd8xvPNHh5C87
nHyY98kfV+0KhTurrKwsTlBofCn9oSQFHX7D/PKTP9v5H1cb++ovTx6nEPry
yy9zfgB4SMrMrU9xOPnXHE4+1H7yx5bRRoGBFI9zSrwlZQxnc9MczvmKwzlF
ebSSPLqk7qydvWLFCs4IN2/ezEajDhV5xXS2k7B+8HT9MSTWqfruovtx7do1
BoIu2JmPyJ2+avrdqZBx6sfXHT43WPpxXr9FKkY5jDIiDH/R+Q6NverQmMzb
uerMni18ugNrzTMucTjwGw4HyqyBq9o849KODuRm9Xnumn9Y4fDxV8zG2oRh
fbJb5vsfOxz9LYde9pcDr5sHrnQ48DWHA/vJgVfN/q55ugMvmWdc94QH9pUD
L5hndErKnXrxusPnJG9xnTV74YTU1U/X2GmzZ06l4yqHxr7t8Lne0liV2bNo
hwPfcDiwlxxYYfYi9ukOPGaeMd7hwO84HNhTDjxsHpj0dAceNLua6nDgdx0O
7CEH7jPPmO5w4PccDpSE27XHPGPW0x24i/5jWc/u6EBuVndwp/kHJyXO6MhN
fITTdJJUG65i83sXOjTx/Y4PLDJbL3Y48B8dDgyVA/PNM5Y6HPgDhwND5MAc
88BdT3igkKZzR7n6H6XdLPOb7H3CdiXl7fKotNv1B2k83ez0fofGf+jQuFHw
2/Pp30tjqWZPDz1lY/Y8WTeWZPbsiENjP3JozJhTsee/urEEs2fHHRr7sUNj
z+m/2fNa3Vis2bM2MenYE7Yt4+OcvupzbDc77DSn6+SRnzh8zsieOkhVNQa2
mt/ntEO7P3Vot5N+dUpBNWq3mF/gpPmTz1M1751lfsPms2HDhnFN8l//9V/q
0qVLWsVcG83vYYUStBKNId9ewaNkKo29B2922IMO086v6bdpHvG73/0uH/qH
P/yByVZdXS06LmG+bX86qxiMXiygEndCqXj0K6FKqQ669hPTdW2QZvSvg3TU
6J99SpLKU5p927Rpk+5fpMMQgUSxCFJxiHDx6GcC+pmIfiZVKpWMT6WeUirt
jNkP6qw1teWUnRjloT2Xld75qvXr1zMav/3tb6u6ujo9iqucvPaCioM+xaNn
CehZInqWhJ6loGep6FkaepaOnmWiZ1nnlMo+Lz1E737p0Kc39PlPnz6tnn32
WTb8rM//qekL2/m/pOLKcX4IcCL6kYR+JEPiUtCPVPQjDf1IRz8ycUQW+pGN
fuQg0cpDP/IvmH2RuZc2nfm27gwp4He+8x12yLp163RnPjK7UGl15u9UPKJt
AqJM4m4YInwS0oMUlHCp6FQaOpWOTmWiU1k4KhudykGn8tCpfHSqAJ0qRKd2
IB8tvsxD6NQvw0m0uoX+/p//+Z/EPQ2d5R0B87jVza+qeAThBITfRETSpDL4
DN1NQXdT0N1U+DENfszAeGYeRVdxZA7YkIvu5qG7BehuIbpbhO4Wo7sl6G4p
ult21bw+/Sh3FhUVKR8fHy6kUVDrbv9Jk6fjSTSfJ1628wvzmzolPIctB31d
xeeJgxLhjyT4Ixn+SMEQpmII04CrdOAqA/7IhD8ycWQ2hjAHQ5iLIczDEBYA
34XQ5iL4oxj4LoE/dl6EL+CPXVeUKr8mPtl7k8/jhHlJ4ruomzdvql/+8pc8
H09GdT19o+bmZj3krrf4v5eeaoKP/j1q8cWbpjtsOP6GikdqmZALp+SLg1J2
wCklcAqckw7nZMA5mXBOFgCTDXznAN+5cE4unJMP5xSgtUI4ZwecUwzAlMA5
OwGYMvRoFwBTDufsgXP2odrbf+ORwHldA4cuhJBkEg+nTJmigfNHfcTjJht9
n/BzlmhWWP54XcWlQWSQKycg50tEPpkE4KQUwCc7xD8ZAE4miJQFImWDSDnw
Sy78kge/5AM4BSBSIYhUiFZ3gEjFIFIJ/LITfimDX3bDL+Xwyx74ZR+ItB++
OQC/HLwpvjl8Wz3OPzQZFBISon7xi18QaL7j7Z/HzYv6POHn/tHJP99VcUgK
41PgH/gpEX5KhJ+S4KdkYCgFGEorBG6KxVdZ8FM2/JQDP+UBQ/kgWAEIVgg/
FcFPO+CnYrReDAyVAkM7gaEyEGw3/FQOgu2Bn/aBYPvhqwPw00Fg6BB8dVj7
6ugdpY7d7ZBwRqGLdED96le/olzc1cZZj5vP9XnCz1nTrTZnfV/FIk+NQ2Eb
nwiHJcNZSM+TkO8nZ8JZIF4qnJYGp6XDaRkAWCaIl71TnJdbLk4rgNMK4bQi
AGwHiFcC4pWCeDvhtDI4bRecthtOKwfA9sJp+wCw/XDaATjtIAB2CI47DMcd
gdOO3RLHnYDjKsRxjkj7k7eXHjcB7fOEn7Pmha35ApQRMduQjSHbjoO34uGt
BJQKiYBZEmCWDJilAGapgFkaYJYOOmaAjpnQ8SzALBt0zC0Tj+UDZoWgYxHo
uAPeKoa3SuGtnYBZGc64C3QsBx33gI574a198NZ+eOsAYHYQHjsEjx2Bt47C
W8cAs+Pw2AntsUp4q+qeUierO/baW95ee9wMus8Tfu7bTtiC15Dex6JuiIuG
12LgtTh4DZ5DeqyS4bkUeC4VnkuD59LhuQx4LhNYywLWsoG1HGAtF1jLh8gX
7BEP7gDWioG1EhC0FAQtg+d24ay7tef2Amv7gLX9IOgBeO8gvHcInjsCzx0F
1o7Be8fhvRPwXAU8V3lbvHcS3jt1T/vLiaptXPe4+X+fJ/zct0yHnbBc9wu1
fYNSMZvgPrgwDi6MhwsTAMBEADARAEwGXVNA11TQNQ10zQBdM0HXLNA1Gy7M
gQtz4cJcuDBPu7AQdC3aK24sgQtL4cKdAOAuAHA3zl4Ouu4BXffBhfvhwgMA
4EG48BBcePhSexdWAICVcGMVXHjyjrjx9D1p/1yNUufuK3W+tkPt+6O3Qx93
QcPnCT9nTR3bHPrPKhp1zPZ10rlYODZuM5waBadusxybRI4FPlOAzzTgMz2N
8hc4FvjMAj5zgM9cMDsPzM4HswvA7EIwuwgBZAfwWQxmlxyQc5Rpx5ajF3uA
z73A5z7g8wCYfZAce97bscfg2ONw7Am7Y2+JY0/fNZMSdux5OPYCWW3HTP+D
3buPvWLj+2Qf48sRPNtnTYri7NtWKhW9Gv6Fj2Pg49j18O9G8UMC+RgATgSA
k6ABydCAFPg4lXwMAKcDwBkAcBYAnA0A5wDAuQBwPgBcAAAXAsBFAPAOALgY
AC4BgEuhAWUHpf3d0IByaMBe+HgffLyffAwAHwSAD8HPhwHgI/Dx0cvtfVwF
H5+Ej09pH+sKTHxcAxDByW7ychvf/tR0gxYF+e/R16g6PcFnvmZi16lasKaF
XT9XWz9Wahuq0Gj4fjv5fg18vxZ+h+/j4fuETbqagO+T4Ptk+D4FGE8FxtMg
HunwfQZ8n2nzfS58n2fzfRF8vwO+L4bvS+D7UmB8JzBeBozvRvQqPyLn2AeM
74d4HIB4HITvDwHjh+H7I8D4UWD8GPx/HBg/gW9cAd9X2n1/m5ZxSol4rlpw
Dt/jb+fvdzwCP3dwj54TM6q3jq/POb9nXZyzVaf/oraugJ/h6+hP4GPy9Sr4
Gb6OJV8D6/EbxNeJEOqkKF2gQE9S4es0+Dodvs4A1jOhJ1nQk2zoSQ70JBd6
kgc9yYeeFEJPiqAnO6AnxdCTUujJTvi6DL7epX29B77ee0za3w+sHwTWDwHr
h+HvI8D6Ufj6GLB+HL4+AaxXkK+vefv6tCTu6ixE+hzsvPibfF1D3jR15T75
v73Xf+HgdVlhJutY2nrvlypqqVJbl8GD8GL0R5YXY+DFWHgxLlJ7EahNAGoT
N4sXU7ZJT9OA2nQoRgYUI9PuRaA2B6jNBWrzgdoCoLYQqC0CaouB2hKgthSo
3QnU7oJi7IZilIM/exDy9kIx9qOXB2S2Tx06qb0I1B4Fao/Bk8cvai8CtZXw
YhVQexJePHXLQGsndfau5UXDkz7kSZ+nQa32n7UO0Oa/f1VbFikVtQQ+/BA+
JD8uFz9uhx9jwP5Y8uNq8WM8/JgAPybCj0lAZDIQmQL2p4L95EcuDYHITCAy
C+zPBvtz4Mdc+DGP/AhEFgCRRUDkDiCyGIgsASJ3ApFlQOQuIHI3EFkORO4F
IvcBkfuByANg/8FKaf8IEHkUfjwGRB6HH08AkRVAZCV8WQVEnoQfTwGRp2/J
589AebUfyXfVRE6tAJbdp/eewqX/LS4d5g1JGbZfqc3zldqyEG4l1y7WrgVM
o+Ha7XBtDMgeq10bB9fGw7UJIHsiuXaDzbWAaSpgmgayp8fqahKuzYZrcwDT
XMA0D2TPB9kL4NrCNq4tbePacrh2TweuPQSyk2vpHB269hq71tDSs/DsOXj2
/D3W0nt4g9zrY3evEN/3aXwrq1RlLURbuMK386SPWxaIf7eSf5fY/LvC8m8c
ZCAe/k1YY/k3Cf5Nhn9TNlv+TQd8MwDfzDhpOzvJ8m8+/FsA+BYCvkWQgR2Q
gWLIQAlkoBQysBMysAsysBsyUA4Z2AMZ2AsZ2AcZ2A8ZOIjeH4IMHNb+Paon
rdv69yT8e+qa9q2vOgv02vzrJvgKen3bopdF1ZfS4Cd37kDTpbYs67dq02yl
Ns8BeOHkLQBx1ALpLDl5G5wcTU5epp0MIMd+4u3kRDg5CRqRDCenbBQnp8LJ
aVu9nZwFjchOlLbzoBH56W2cDCAXA8glAPJOALkMQN4FIO8GkMsB5D0A8j4A
eT+AfABAPohvcQhAPgwgH4HWHj1t6QOdoxJOrrKcLLoArSUvn7tN3r1ruBgJ
glvrrFFgnONYdY6cfI6dfBZ/PHNf6QDU3smyPFkWeLjbOPlf1cYZHrVpJhxt
OHsuHK2dvXWhdI6dDdXYDmfHLLc5G6iOh2okwtlJUI1km7NT4ew0qEa64Wyo
RmasODsHzs5N0hMEQHUBUF0I1SiCahTD2SVwdik5G6guA6p3AdW7gWoU5Wrv
Y5x9zHA2AlsFEE3OpvPA2WYgszlbnRNYu9jhyJfO6pTMsLNwO3lY0gb85ENu
x0+1JN3k99OwUzViHY3Bf8oYWLfIHLXG4Ddq47QWtXF6q9o0AzbTg7HwqC0Y
iyg9FlsxFtswFtsWy3fZbhuLWIA/DgoTj7FIAPgTV+uxAPhToDCpGIs0jEW6
HosMKEwmxiIL4M8G+HMSZCzyoDA0FtR+EcC/A+AvBvhLoDClhTIWuzAWuzEW
5TQWUJi9UJh9UJj9UJgDUJiD+FaHoTBHoDBHoTDHoDDHoTAnbGMB4MswPKNO
IzY6DAXHx7P3TODTCJypYYxjBM7cNzDPo1NLf6PXZ9QZFIena/V4wE7imCqy
6g4rcj0svaxw6X3Zxna54rdqw5QmtWFqE0arWW2a3oLRalGbZ7Xq0fLwaG2d
Z41WNOJBNJhDo8VFuH20PtGjBfYkrbGNFtiTtklGKwNSlYnRyrKPFtiTC/bk
IebmQ6oK0/UkEY0W2FMC9pSCPWVFjx6tg2DPIbDnMNhzBOw5CvYcA3uOn9aj
BamqvMij5dMBaRAPJLhiTDgQ6DEyzIcGRMeHMw9kaE4Rc07e5wsK+HQlrAKj
c6JanOw0RP8h42Hd4OVUKFrLgGicPmjAWDWqjTxWTRirZrWZx6pFbZndirFq
xVh52o3VdoxVDMYqZqn4NI7G6iM9Vp/axgrsSlmnxwrsSt+sxwrsyoLSZWOs
cqB0uRirPIxVPthVAHYVgl1FGdK2MVY7jbEqdh6rAzRWh53H6gTGqgJKV4mx
qrqoDHE7jYhy5rqueyhu39bj5OrMzDpzT1u10Oo01f2nabxOs6SdfiDUwljR
UKkqph2GCuKoB0sd15NeNNF/9G7HsvfvtsHTbxl3UTqt39htDePv1PpJD9X6
9x/ycG6cApvaqDZNa1SbpzdhOJvVllmw2S0qioezFcPpUdvme6zhXCzDGYvh
jFsm/Y3HcCbYh3O1Hk7QL3W9Hk7QL2OLbTi324YzwTacoF8R6LcDYlmSLe3b
h7McWcIeDOdeDOc+DOd++3Ae9R7O4+2Hk9s7hWrs9FUZz7M3jHGUXJcqiTMc
uDCaxE+My+lqHk8xHjdm3KkHpI8nMaBVtXrqHANbgQ+dqNEDWm3i5wjG8zDs
ENo/JPWzYx3sMLb0jzq43xrH/1Tr3qvjN2k8N9B4Tpbx3DS1QY9no9oyo4nH
M2o2bE6L2jq3RW2b18rjGb3AY43nEms84yGnNJ4854PxTFqpx3ONbTw32MYT
FM3apscTFM2N0+MJihYkW+NZrMezNFfPa2I8dxvjWfaI8UTgO4rxPNZ+PM35
HmM8JZmg1y7qDDh65rZVHWJMeW7uNNcxp7mEOa3Ti1PGmLpeVCfB0ypYZa1Y
BYb0hA6Lx/DZYxjWoxL61GHw9RDaPIj2D5DhfPtvdRgWf2sfWl/7W9R6uTW6
/6XWvVuLEX6g1k+sg9WrDZPq+fMbaZQ/aORR3myOcqOKmtWEUW5SW+c061Fu
UdHzW1X0wla1fZHHcZQTiLUfyzehUU4Gc1OMUV6nRxnMzdisRxnMzY62jTKY
W4BRLsQoF4G5OyDExRnWKJchxdlVKO2bowwt2od08wBG+SBG+ZAe5SM0yhXt
RlkG+Dl16pJ39niGSv+bUv7TZNTpO3Ka00zcU5TknOIRpmSF1PYkj/BJVmJj
dE/AjuO9Y/ze0RpaH3ik2pohJzuA0d1PhhPsw4n2wspx4t3oQJlEA6nAeOA0
d8Mdxt5pvVWplQb9Tq2dcF+tfee+98hPqgO365nfPPrQ7E0IwV4jP7NRbeWR
b1Lb5jZj5Jsx8i1qO498q4pZ7JGR/9A28gjBiRj5xE/EbcbIp0Kz02jk1+uR
B8czt9hGHhzPg2bn08iD44VJjx753XohwV6M/D6M/H4aeSQVB1FoHEKqdNg+
8lXe/BZmE5efNbX6tB72UzLfy/PtdF3jpMRKN12y1IPOGSoPLLTZ9feqEoNe
YRv0o7AjsMP43CHYwWpr2n4/aL0PTe5F03tg5TjVbpyyDKfeiW6UIBUoRpeK
Lks333QgdFs0WO9qaDkBosiSgP9Wa8fXMCjWaVCsZ1A8gBQIKDZOfghACDAY
FMjLvEABSdjGoGhS0QDF9vmwhS0qZhFscauKXeIBKDwqbqkNFB8JKJI+FTmg
thkUkIR0gCJjgw0UkIQcCH8ugQKSkB/35KDYgxx6r76U3Q4UR9qA4hSDQrDw
BZYCQ+8pJzulZwJP6bnpkxisKgxalb6KrcsUAgTlWzRDVcl1TcUDQcOxWkHD
4fsaCbADNZqXL6i9aGOPvm62G+3uQvtlOE8pzleC8+5AH4rQl0L0KR99y7vY
of7/xgYIr8W2dgzk2ZO1yHHVai0ZsLBuQo0NC7Vqg8bCRsZCvdoELGxCArAZ
oYHOugU5OiUAUTObBAuzDSw0MRZiFjYzFmIXw5a0qjhgIX4pbJmFhSQDCwgP
Kav1VDphYZ1gIRNYyEJ4yCYsQCRyo21YiHfGws42WKDQYAgESy6wcAhYOHyI
FnVhbJDQHUMCcBxYOHFK6QD/E1WFhO4knE2AOK0BcUoD4uQNmWYnQFRpQNCy
hkoMZmW1rpBkXoEDPCkD4eG4Ax6ABbUftk8DqRxt7IbtQntlaHenvmJdjPPt
wHmLcP4C9CUffcqFQuSgj1mo0jPR3/SzHSd+dnQ4rg/2xkmWF07G3FWRY+8B
K7Dx3nhZ3w4vde3wQgGFMTOd8NJs4WWOpR0xC5pV7CLY4mYVt6QFeGkFXlpV
wjKPhRcElWQDL9CP1DXiMxMvGzVettjwAv3Ij22PlxLgpfQxeCHtOLhPJ2Pe
eNHB44tCfhtWSDxOaayc1Fip0hfJaRFHpcZKxT2uot2UzCMFOSFTgRJANEyO
1ApMDt63YLK32shLX1K70EQZmiqFlaDZYjS/Q6+yKcCp89CFXHQlGzDJQtcy
0cV0dDXtHNwHqCQjFiae6hgy/9oxZDo7QCbNgkxntWb0HRVJBuistaDjJty4
/k2tb4ecB4ycTRo5m6c8ZORsAXK2TBf0RM0g5CAFQbmxDYlo9FwbchY2s9IQ
cuI/bNHIaVWJKzxAjkeQA7VJsSEnLVKUhtpm5GzSyIHa5G5zRk5xB8gpR6mx
py1ykIQe0pf/jxw1p13IP19XlfB/W9icvCKzy1X6Sl6VXl9RiTGtwNhW6LVm
J+7p8q9Gkg3GywN9Ivx8yIaZfYIZOe1XGDI7CS6wYjRXhGYL0HweTpWLU+bo
xbeZgEwGupWO7qVCXVIAmSR0OfEMojkgE4dUKrbKvBXBCT2/7hg9XRzQk2yG
LQjOmpG31ZpRt/mgyDHeKFoHAVo3oRoQqtEwuq82aBht9IJRPcNoC8OoQUUB
RlEIWFshQNTuttktFozmGTBCsFpkwShhaYtKXAZb0aqSGEYegRFEKJVgtFrD
CEErY72MAMNoc8cw2tEBjHY/GkZacLqoYxVmkqcqMBw2JFGKepnWfVRdkYtt
hKRKvZKhQq8kIyTRqsUTd2VG6LhG0rH7NtWpFQTRORhBsHJ8brcOUqUaQjsM
CMHy0H42zpOJ86Xj3KnoQwpglHxRIJWAPsYDRnHocwyUZztgFA0IbUNNFoXv
tAVBePOxx8FJbohrlww/44CoeEuP/huIusWIIiNdEmQJqta1RRUhSqNqYxtU
bXZA1VZGFcLZLEFW9BxUx6iSGVWolUxULbajCuK0nFDVqpI/hn3i8UbVGo0q
CFTmBvF6W1QVIA0qREpc1AGqdnWEqr063f170iV19LgFKGRAAqpzljydpCu3
tMDgqiwyqNDLkk7oRZ0nMPjHAYTjAMSxezKFcYzTYeQ5rjdMSTpwX+RojwYT
T9PoKcliDaZCtJVPYEK7OTc1mHDOVJw7Gf1IgCbFQY9i0Lft6GP0WQFXFPq9
BZq0GYDaCDBtAJjW43utw/dbi6gdiei95mCH4PoXG7j4nWcd8LTdjqfVI26q
NSNumbiKHH3bFu/ucusGrtZrXAmmDFzVMq42Ma7qbLh6aMNVo4krUivG1lzU
3fNaBFcLbLhaQrhqtXC1QnCVwrjyqFQEvjQHXGVtFLWitvOAq/wYB1ylA1eZ
gqsyZ1wJnnw53h0+rAxcibde8YIUzZIa+sRw0ivdTuh1wscx9McAgWN6SfrR
ezIjdqRGSmo7nAxd2gXbic+VGCtjEWEJRrkaRlloOx3nSMW5knHuREApDv2I
AZSi0acowGgz+rgRMNpwUiC1FroUCRitAYxWQ5dWAUYr8dU+xVf8BAXEx0gM
V+xVanl5h7D6lV2zHO7I5FrDumHRrVYPv4EadA1ha6RgK9KGrbUaW6RZjC8v
bNUQttAGkOV6U23S2NrcBltRDtiKRkJFmrUd2KJ2Y+ajfF/QyroVh1I+HuVb
wodtsIVoaGHLA2x5VDphK1Jja71gKwfYyt0q+GqHrVQLWzsNbBUAW0WMLR3x
OqkDe61kSoPLZeRRJ0D4Cr3khBGGEa26pBF2zRIsA120bv8oGdBBNz3QvPkR
IOdwtUzWGPn2fid03TVvgsrT4MrWC4TS0XwqTpMMUCfi1PHoQgwAFo3ubEW3
NgNgGxH01qOrkQDYaoBrJXTq0+MCto/Bl4/w1VZAp5YDXMvwdZcCYB8iAViy
W+DxlAgz7ka2S9gGS8I+r1YNu65Wkw2/wWbALnKUBbu1Y0zYuUnPXP8kVwUm
1JiKthGKRmq2aVJtO9RtMVCHaEnI2wrkbWPUNXmhLmaeIC92gQeoa1Vxi2yo
06qWhFSeUfexDXWrBHUZhDqoWhZQl438K2eLoC4vWhSN2i5MBOKQZRYDdSVA
XSlK3J05QF0eo8642LZvFwYflLaD7shhc6r4OAbuBAawAoNZqVXNpVeHVF7x
whswCsSBz8c03o7ckWs0hzXeqPznXL22Pd5K8ZniuwbOX2HA5aCdTGDYBJte
hRIPNYu5JGCLQn82AWwb0L+1ANvqKgHax1CyFVCxZQDahwDaYgBt8UEB32J8
zUUA20KAbUG5oaC+ajb0fRa4OLOgQ4X7547x94ID/taK6rHWrRp6De8yAIcx
APE3QBBFiglCAiDr3h3WvXVkHFPvqfXQPkaiEwrff6A2kwGFWxiF9YRCN0HQ
9V0BIVI2AmI05G87g7CFQRgz38PNxi30AIQeFb/YDkIUAMttIPzEACGGZLWA
MBPSl7XBAYQoAArjZbhMEGZ4gVAmnn4qk5c7VTsgHj4oExDUBE9Y2ZGor0BW
6iuQnKrZ0jSOqW1QSFeWDt2TqWmalGyremUWClWRXnWei+Oz0V6GRmASzhMH
9G3Hebfi/JvPmUSJBPhWAXyfAHwfobvLAL4P0f3FAN9CgG8+VG4uQDdrrwG4
z3tdGiGbDgBO26HUVCQbU5B0fIAA8T4CxaTMDgH5T3ZAOm/95iSM1n3awP2q
IdcInWr1UBZIDsuCzU5O2ARugUzXLxmb6wmbFJOhkBuATepAe2zWeWEzSsfl
rdMb2oMTeR8B1AAnKWScXuAVv9ijEpZ4AE6PBc4VBjgxQqgnOgSnriPyqY7Q
4CzSCklta3DqGPyMKjem1Q1k6ml1PZVqTEm1BSZdaqFVKRUASIVe7s2Fq64d
jGTPCMWHLVDCrQd4+YIByt02UO7A5wruGPL4eQZkmpbEhCsih1svMCDVevRj
DfqzEv36GGhcflx3t7NaCDDOB6/m4lvMxreZCa5NL9dA+KJ6D/h7BwI4vkCE
cjwwOB7hYjxwOB6sHQ/2jgcWx8NZ4xFSxqMAGwdmjxUnOq2d1Pg0tiEybl5R
tmlY+9/abjPiYunEi7FHpx3EH3uBePBVAPkqHwkwuwnJ0GQO9Gawv6kiHbRW
dPauWj9OdBZ4dhOYXT9mqRVIA8oojSng2+EcpeG8ddpDgfMMgnOjDc6itzEI
+rGAdOx8gXP8IsFFwhLkTx+2gfNHyhvOayTYGymmvSw24WwrX0rSdHDvalUu
OxzmWQTNZmZpXhjQcKYrhyf0EsXj+g4GuluEbjE7flPrsgHlO15QVgeq9SQ/
oFxeY0V4gnEhPpt322SQgWLKIklaKahvwSk3nJGATpqqUayWIJgvAITnIDzM
RPdn6LvmpiJsfLDb0NWX1AR83XH42qPx9UcCu8OhoUOB28HpgutBwOwgeGoQ
cDsIXhsEIRgMDw6GKAxBwj4UHh0a0/FEsVyN0vttPt2zRAzQL1myRL3//vt0
Z5e5VmzNmjWqf//+vFew/K3Lo9p+5AYH1t56Ttu7L7OY01mtHHzFZA8bQoFU
Z8wgYY8wKJIYpNPltU4MGt+GQT9UGzlZqWX/PQmDhD2NKvpRDFogDIrXK00T
PwR+liI8LweWVihh0MfeDMpc20Gm4l2kGdfIebLmEXNKB2SmUlD8d+a8Ek1W
6itrvErxOAh0DGg+ekFuuaLb3Y7SjcI3pCw7opfU0DKmgyDHAZBkP01f76uh
iw7EnTKpxFTRHZkqQlYsZ/2CSrHxxkhJKBlepyPAp6DyiuOUg7RC8lvAlxY1
ZXermrSzVXPla2pwtkcNzPSYOUgfcKM3uNETvOgJXvQgg296gBs9yeCrXrHC
oz74vw/815cMStQP/uwPVeoP3w6AQg2Anwdu4W/4MxNxOiIYW/i2f1iOj31z
Ck0YX/NW/Pnz5xP4jev927dv5018aCehLh02+eiHizjtrOnEmsUWa3zUykFX
NHOuUHI/5CpVmJxEXeMknxpbM/y6c/AR+rg5m/pyO/ZsQD61Qc9xGPTZNFEC
EDXrTZ+Hmj4NJn2iZzaiS9GzmvDNLPq02OiDRH+h0IcCEFOI6LPMok8qAlDa
yidL9AviNW2+L4WmbXqDmi5HRrEH9NkL+uwr807y6X3b/JnJH1qlQGvkj56V
m7+OgD+H9S3jh2hrAtrP4aYs/TuoVyvx4qJ7cmWZk/oayZ8M8uRJMu8yliJQ
Mm+Uktt07kRRZ81JD8rHVmTvLUiWmpAkNaqpuxvV+zub1LslTXL4N9XQnGY1
IKNZhWyvVSHRD1Tw1joVvAW2qV4FbZSFJAHwUAAIEQhvBcGCQYpgeC8EITwU
ngzdKEQKx/8R+L0H3uuJ93ri5174Wy94vDfCfh8yjEDftRKUfqpJYU/321PL
/gyiz2se3Lp1izd+W7WKSwCVmZnJWzidOnXKvKhgP87g2eP2RHHikNEPO4cW
mHHJDQpdBr01iWwh6BrFHiOF68wMYjYZAUhY5CYKud7U8ad9DDJYtJFY9J6N
RRSAJmkmTa5/FIuIQ2BQE7MopiMWLVI6jZMgRO0mL2/DokekcHnbjarjeVWU
bLuqYZuv2S0zEhaNrFpZw/n7stDnmLW685i+teGovhOV7vw9rLcNOKh3+Tig
t5A5cEtWXNLavH36EsWeahuF7nlRiMsPVg1bPbzlnAcJW6v6tKJZLTvapBYd
alRz9jWoabvrQZ169W7xQx10uiq/3s2wJuXXC9azEf/Xwx7gb1JB+vW9A6zS
Z19UfssbVPdVHtUdSuQP0AbAn4GfCm+C4N9g/ByCv4fi/TD4ORz/h+P3CDJ8
tsenHRbPP++YL8/r3Iq2PaOHTEyZMkW99tpr/F5Xh88bnHjc3jhOW0gbG9Db
eTLHK9YMvExkoZhDsWbwFQ44NpL8yhZqhCxGpraWjCc2b6t1Xky51yFTNtmZ
out3avOJmDLnyZiSpOMNtds2VbMzhefTo3R8ecH58p8milexUyJNa6IIR/7R
WhBn48lRfZPhEfDksN6d4KDeoeSA3kJon96GivboojWre8GTPfe8rxETRwoN
jtyycQTHx16S5GzjGY9aU9WiPjrepJYcblRz9z9U08GPETm3Ne6hsn08viBC
K+pxv94toEWzRZMeDbCHyi8C1kMkzK/XPXzuDuwWTAbfb+gF5TfiklHW+82p
U35zceg8NDO/hXHWDePRHfHfH+MRgPEIxFgEQbWCEf9D8H8Ifg9d2iFzfibM
MZbFUHVC+5/CwBl69VH//M//THtM6U+0Z4wxX5qWlsbbUC5btsy8DOnErMdt
pOTELKeHU82wmIXaZ+AlG7suG8HI4pfrdRBMMjo7xYxYxFTzotkdTTP7lIJM
kXVEs832imiyLEz3phnPKbipJIJWbNdFEbEsVrMsbn6rN8sWWywzYhE1a2R0
xlUrndG5DHo96opVu6vs1sJT4xKk15pTTTG6ceQIKHYYFDtEm1CclY1WaBOg
A3rDqX2gyF5QbA8otgcUKwd9aHEorwustkKQQS/+KsY91V3NKYP1pz1qVWWz
Wo7os/Bgg5paVoOy/6qeRAKv9AQpfgJVyFpBH6q//Xq10GtPUK0nONIDVIto
cBPPUN77hcuY+EXU4K27MLCtB9jW4zo+LjNOfoMugXWX5QQacH4zwN5ZFKD9
ZlPq5QdN7zYPtJsP2mGgApALBc6XhM5p6uxnj49OtN8dRaVPPvmE/y8uLn5k
dHrcNlsvm9wwHi5hZw4/lcBX524DL0kCJ5XQKnslJMTpKqRpQ5xIWxIn40JZ
nK9XbFo/7q6bWOMmyri+o0lz35E0WzRpjNhEDmTSTANpQJzoGU08lfBUrDHq
IFtconZtcUkvm/1i+xVPKJcpi2vHnDyva73WOgJywivmzRv2Jfx0r/Dhk7Kd
yEHUJQdo7ycEkf20VZve326v3iOx/Lq+kQLM2XVHlkkSa4rv8bwxX0qjgJRy
TZcNGLe1qHM+OdGslh5pdOl7FsEGoLWXRyMRPzFBOgPnTJAeIEgPECQCBAkn
goQ/dH1J+YVpgoTU4meQJAwkCbuNd2/io9dgmiR9QJL+V0AU/G3YDeUHIWSi
TKyTE/oov2kevEwn5PnNVAYdzEey2enxZsf0MIod2tySJgfi4uL4mPLycqbJ
gQMHHlnsPG5fNWm/M2/JvWDBAg5/9P/QoUPpQW0cFVmcjKrIzqJJVvzppD4d
cFGtHHCJ4xB9OcQiKYysNA89XTX0qp5XuOZEKDcxyk1xCH2iKEQtORGKuMRB
qPrxnCI+mfleg+bVk3DKyvcSjHzPmJozJrb12px0Wc5sLi02KyLb7Q8dJXtl
dj4hCu3Zaa5VoLmFA3puweQUItGRSolCB/VWVLTl136EjX3g1F5Eor16b81y
FDW7r8tNSbvoPpXbsoZ0p57Apkk4WmCTdo0vCMppn1VbzrYiArWq1ZXI7441
qfcKr6ogECUQhAmAdQd5uvVo7qSvV/j1kCUAfj1byUCxHibFIprEwhH0/cIa
KAaFibT5hSKVC0GhFHwfVo2fQbUQUC0UdAoDrcKuuozcxm8Qfh98Qyg2Bp8d
A3qOr++sfe432eKXU/j5acf8MrZXp/1oqbBZt26dyRN6yjBNrFVWVpoTck4c
e9wGfAaHIyMj1Ztvvsm7ddO/1NRU3maf9rx1ujvXiXLvmoR0E+Pgm08154z8
j7k36LJPm+TPxx7D+Hr9DYtsPhy6JKWwMY2JJqHrdaHZU1Bt69QGDl/U5rbp
TZpqzZpqLZpqre2p5hS6rCk8H32TBzXrdbOA0+q3R90sIEzjduw3GtGN+jyV
h6TvcIWErcM62aOwRTs/0r6Ze2hrVtrGFqFrN6i2CxTadV3fCkZ3Ad2R1f1t
aYYaSs9zPI8aqhWhq1l9fLxBzQQ/I1AMhaMwCotoUCGwYOIcLCC8UfnDuoXT
bKhfeBO9NOv0xS+ihX5tAeEimokM4Uw3ZpsPv3bVIQ18Cya+gTtBCG2B4FEQ
8r9g5H8hBAm/kKvGEgC/3oht/a4J4QbiA0NAzuE4aHS98puAE7wDbr+DpPAd
Pf3+GWn30UcfqaVLl9quE/moxMRENWrUKP5bZ4djDdo9bptG4xxEN5r3WLVq
lXnshQsX+NizZ886Us/pcbzWk5SFer5muNPUM7LIVcgiqTFrPv0ZUNCKe20r
MCPuQXm9CjBbEcbEtIow4aSv5qPJSTcREid7DCXdFPr0/S+PZeQij3fgs5JJ
YeKLXjOB1OQT55H2mzB2mPmj011/h/Q6Z8ofiYiHzsvEBuWPtN1vOYi4GzFv
l96YvQxE23lD34p3W26xMYl4sy0Rv8REjKxqUksP16pppXLFo1dEveoBY1LC
wmChRMrwBhUEC4T5w7oTMcOYmGEc5JqMlDOsWccn4WlYM5GTKRoGBoWCoqEN
9AZen9ch8SFIWC80DQJNAzVNA+7BEBoDERqDEAqDrsKuuIyq0a/XZWFqH7zf
F2ztD1oPxnHD0c4YnGdME51nDJ97bMsjc9GftCct5YpEvFcc/iaEeuy2ngbv
IiIimIswwJdeO6v/+I//4KcO0D+ao6TnBO/evds4hP70xS9+kQo+R6p+XSIi
vr+1Q6BBUO/YeMmHCdqZCarLPCHqEJDTaxayi3OlJ+zUlV4Xh5lIWT1uhU0b
RTlkPh1FX+CgSS06UpQDJui52KMXXoCiKzg3FWq+ZC3p3WC7R0ov6TUp6nRn
LlLT0hyvUk+D7U25bFzOtyJ436yv94WibSNpi046B08+6olHqu9oH3x6UMBO
MnCwlO6ZBh+Lb8k9TQ4c5Wta7NRTzWpVRYNafKBaDYh4oPrD+kXIzGHviDrV
K7xO9YT1CAdnYeHh4CssBBYMC0TeGRAGvnJcJMYSERs18ehxhn6hTQZXQ5vp
dxAYfxOqhhC3QxpAAgmmYGowmBoEhgUSU5HEBoCt/mBqd8RKf7Aw4DoMbA0A
WwMEaczS8MtcR/r1vC5TnX3B1n44bjDaGY52hzcovxHcMccJyx8LQ2XJhjyI
hjLVPn368MQlsfLlR7xnXEZ+1C6xxhOMaFKGwi5VmQYfD0GUif043pGPTs+i
H2oyk0jZ/yIXi2KXeAKGLp7Z5y5l/tJ2hUCuoXQURm35LE7Q5mKBmzgqC/2e
lax2nCzCNwrIje1nMt1EUNeXH5nYUv1oT2yZp8zRVuEozcksbNUhVNb6JS33
6BrxT3y/kHlPx/oOboHVK6DbkTTT+fZ5+ixltXt3tSEpAunBI7IdIW33ePCk
nog5Lzu/03EHrsuVAZq6pKKRdrEgghbTvex0C/Nta+UGE/S6LNiL1k+WWVvV
oD49XqcW7LujBkfch9WqQbCBsP7hsmymb/gD1QfWi80ibDgsDBYSVq+CQdQg
JutD5R/20G0xVnULbdRTbfjJl0hJJA4RjZQ36PVb/De8q61Bcxa8Cm7D2wCD
t9XC226Ist1u4mdws/s1Oc7/srm81S8E3A0FdyMQaXvdkssVfcDd/mhnENod
/LCjbPjH3oGVHoE0aNAg3hj4FYe/GU9XddpI+HkddGlSiKhIDzCif3SNIiws
jK+CP3jwoJPJum86cNLaA9JNlHQOmZd9zFrSR68MWS1rqszVIW1ncRyvbXdu
Fys1EWUy5+vCR5OLThVm23j58JFk3K5v6GMycrAkIrYiWNKqcI9w8Ct6Ibie
w9E3FdvvrXK6E5Sa5Z1tkM/u0PsXtclnBYave21ssx857QHktAdAxf1HZINg
2tKathOnvfApl6UrCPQslP36gtueW3p/ESoob0mcpJs2jXvtiIYpdOH6ktyr
wuNSUa8+OlqrhkdUq2Hh1WpoeLVbDQmvQcAYHH5fDYINhA0Il+WgfcNqVR9Y
7zAwEsaMDKtTEbAwWGiYsDIotF4FwgKIkf5gpK/qHirEov9hIGVII9GRmBnc
aKxgxI8wTcFgTcEgUCUQFAxwoiAo5Qdq+YFifpKL+3W/rLdw0glvAGgYrGlI
1y963pGrh73QTr8HHV6H+JFw8M86BNbV1fEkKmWk9Fg6eiARXetDiHMMba85
0KifpJ+S6FNoowOISh0QSopEX/ulBotdXa11VzrIubzWXjG7XNa8jZDLx36t
Du+ac6SdzYt11IyNWpKFvmQya8tTMsu4LE7Ncohb3Ooy7kuleyySjRt9Vnna
37a4qX2Ia7tDDLXbNg8tKzBy0F87bvW2X++6uxfc2nNMHomwB7noHuSie87J
ZA3NifKVOX3vF82Hlt6WGpHCm3FVLoNukMBnt1+Q+794Tu1EnVp+uFqNCr+n
RsJGwIbDhoWRMc9AM7IaNTisRg0MkwUg/cPug2T3QbL7mmi1QjRYBCyciBZa
p0JgwTAh2kNNtNAGjUF/IlkI1Yt4ZZb5CMv8ghqNrDWoASWDXxD4FdiGX/73
Nb/uCb/+hjD3V4S5v1430lIc7nfJ2CiUQp5fMM3Bgl/h4FcEXSfEsT1qOgpv
stzd9bZ+a+bMmerrX/86rXU0r0/YP/66A5V6WVlipzZZ4kVNMEoVfdukilc4
S8QhXit/ZfWvLL/y0cuvhEztrt7ZqNTJaw2WjlEut33OxZgHZUoZVOrUhkqc
LeI4EAlJZ4dUoisOfLWhBQGqRRj0VX3LnHUTMN2plLoaTIr0yH4p9mTRvteS
sQFXm63XqKdGsrgzXxk50u4SFGQ72xAJAWofiLQXRNqjn3tBD27ZRc9ZOiUP
piq7IE9844mWG3q2UxPK3FHgtlykExJ5QCJZlvvp8Xq19OBdNTYcGfmY8DsY
0lHhd9TIsLtqRBhp13C8fpk5NVTbEHBrcJhI2IDQatU/tEb1g/UNBZ9gvUOJ
T7WqZ+gD1QMWDguDhcJCTD7RYASEPtRlBH5S/iGGMbEoePEcqPDKxcQiStH/
9EZgg0ATDAvUDAuog4Fl/rWaYTXCML+7FsP+csPGsL9douD110tGvopDruBs
yDVD8NHQ23y9saPg5cUwX35Y789+9jNeKu/xeLo4HPFtB5KFWyRrW4pxDij8
Mi/h2ec17euEJV75to1XPnLXFZVksqTTygbtEauLbbm9F9WsqRNZdO9jTm9K
dm/nmnXF3OJa1/ZcmymruWJoNde8ZrrzXl/xfpk7yHfeG7s5fALCfdqqwxbI
ttYDsnmsDa0QtrIRtnIQtnIRtvIQtvITbISzZYTUNghnViS84SzCVjlSwj1I
CffuoZIb/4Nxe/STTuhJM7v0c7p2InSV0mPzTsvjBEsQvkrAphKaMrkluwUV
wvI18yy2KZNtHx+T6ZHxYfD7OHoZG0bpwpiw22o0bFQo3QE3Aq8vq+Ghd9Sw
0LtsQ0NBO9jgUCmUBxLtQqpBu2pNvRqLerAesAhYeEitCg0B7WBWKJMr6ghp
OHNACL0S7bwo52bKPSP5YZBhQj+mSWADsU5g+7wQz78N8bpV24h3y048/EyX
ov3+colO8RdJ0YiFft3BvkCwLwjsC+aLzT+x6OG9M7Vm3180++h6IT2ecdmy
ZXTtvLMD+95wYF+w2bwPEc7HnABx8/Vy4YxXaKNpEN+2N7XIJb3nzWkQuRf8
uu0WManDqDVbLWZNXvJ6fZkT8bFWdpnTlp+3VncZN+ja7ntxoJ+wr4sX+6Jn
6LWUc8C+uc06QXzZa78LajKJ9lAB61K8whyxzoMw50GY83CYy94m+0zmxsoO
o8w8JIyFCHNFCHM7kDAWS8Jo3glW1sFWz3v001rouTe7wLwyekIe4lwp4lyJ
fmDljjNo95w8pLYQBVYh7eV3Q2+6dEs2ETBZd5ETRX1JbkLoDbcaH3oTtB8X
elONDb3FNgY2GjYq5JYaGXJbjYANZwP12EC9EJlCHoT/B4bcUwNgTD1Y3xCi
nVCvV8h91RMWESK0CzOpZ2WRjLLAkHp+fWiwzsV1mkm7Brq8TnTjMq2Raacp
hxAY8NC4TdPkW/f7Ysw3BLu/3WG+8TFvXxe+/Rkxw+9tptvbF9tQDlWbP02M
MjqdrkD8QJj2V/6vE09qxMTEqLlz5/Lzw8G2dluSUxe/40A3f2+6cXzDT5pu
PnrZvnBOYpu+g0xft/Ox3VCsL6Hj3G2YJvcX+5q3xTDpdKST+2L+znkhpble
ubod3YypD2rLYX2Y0K2Tppvcpxk9qxGBrlHT7GsqblEz6rJmlUDbFtFGWDrI
UZPJqM1SEORSEeTSEOTSKciBapmbQLctoNtWjxXkDLrpIFdoC3LIKgUf31Zl
haKVXpvg07M6wLZysG032LYLWWUZYtxO/fTOErCtWD82t4ieswy2FVzQu2WC
VXnXZW+qnJve2eSGU1J6fnjwjpoYdk1NDL2u3oO9G3pd5wkTQpCFjA+5AXCP
C7kBAwthY2CjYaNCkI2MDLmFZNsi4W0mIbU7JPiOGhQMAsIGBDuQENYbRgTs
wSS8r0n4wCQhtRMcUu+jgkDATnYCqm6hRujrFsIzmzwrwuaSSChxgCMgRz5a
nxbA69P8663csTsY2V0zsluNjY23rcj3ZxRxf0KU+zOo9yfYn2liAqQ0TvFX
FHp+Vzsq6mQR82e/dVOuUUjUY6B8z4Gkfua7bm+S+pgkdVuxUOjqXepdkz0p
LH5qbtr52Yn5yXsA6GAoSKF0tKv3YmfN0zb3Fbg4I3UTRVEDWDeyed+G03YR
Z9RUawHntplNQs5XkIU2qbiFMBA0/sNm2VdsOeyjFls8FLJSPExDPEzfoEmK
eJgVBZJuA0m3eyQexnUYD13GXV72vfKpXcpEy3fLY4voqVv0HLiyQ/LATnru
aYl+MDE9wLlIP/m7APVf/nnZyzYXLM0BI7OvyeoWYmjCZY+KOtes1lZJFFm0
76Z6P5TkdFIolQsTQ6+qiSFX1XshV2XA3wm55noOdL0Gtl5nG0eGkmhs8A01
BjYaNortphoZTLNfI4JvoUYcHnxLDZOkDYS9rQYzae9o0t5V/UHcfmRM2mrV
O7hG9YL1hPUIlshpRE1qA6QFMIPx2ok4S4GT0lWDscTTEJrjDG4QjnY2LzyY
haJkqcLVF8HVOpOrwlc7T+9q/t2y8RSh8S3w8S3i6kXiKuyCMbeIJNZMRp3C
prHc5WlvGf2ScDTIocl/cGDr214hFYHUi6hcJPpoonrtY2AnKsXVodeNzFVv
nvWMdX+pYd6EpfrxNr4mNde2fDT56n2TgnCW6GpLY437TzmuTqqz7gli2urJ
T1B263RN16+r7XORws5vUrFE2UVNSGFB26Wg7bJmlbiCKNuC4hEGyqasbuW4
Sk22jatZiKvZ0aBtDGgb5zHjqv1xCDsydUz9hirNBxsRV8vaPAqImqbnDe5C
TKWnwNJjdkvA2GLE1R2Iq0X6cfQFyGLzEVfzEFdzEVdzLukdZa/q7flu0HZX
LWrL2Sa1plKWZS7Yi8g5OQSS+z69TAqB7k4MvqJnz94NvqLeCb7KNoENtcj4
YBrRccHX1Nig62pMEI3oaLx+VY0KuqFGst1UI9gkPRqG/4cEgbOwQUHOvO0b
XK36wHrBhLM1KiLYCrSMQCJtZ4SbOi/K+gtlLcZSIspXAjVhg5vMXFcTlyZ4
qDT1C6gHUesouJp31wppq22kvS2kRbprkvaPIO1bFzVxL9D/Ph0luAZTP8vN
qY9g6/cd2PpHk61MVH0EfoJd5r+15S1F2at0OX6IV4TV0ZLI68vkNbcgG3aD
+etjy4Ktrcg0aX3NTUqYvEbp+YI3Z4098fT+OxvalJ8GbxFu3URatOp9j1GD
0PVVFU137xFl58EQaWMX2SItUXY57KNmlUSU/bQFqTBRFhbZypGW51McI62H
I63XU2nkIUMug7PGA6F2ItKWIdLuKgVvy+QBgbt0lKX2KQfeiehaTHxFpC3E
zwWItPngbB4ibS4ibQ4ibTZtEg7OZiLSZlwTzsYRZ880mpyduxtMnRJCw/tB
8CU1WQxdej+YarBJ+H1S8GU1MUgiyHv4/102kDkIIz6BXsYH0bCPC7oKFl9T
YwLFRgcSm0fh9StqZKCwmdoYDjYPgw1lJt/STAYvwOaBQd5M7hN0T/UOsjP5
PjOZ2gGT3RSCEaRCg5E5M5PrbEx+aAVfDDilyt30dX0GJChtTh6ZIVhbwEPO
lzlP7lYr94p0ZRZbDL4hofetK8LgP14kFlO7f7pAavDWRSN8OzL5UTf5Pe72
2S92zOR/dGDyf5tMlssgxuQs/3ZZN6BnjlwWnenlqpvYTH+kYlZMc1ln01Yw
Jj7rgIx0ergZjGmFjb5SwitsjK0teXtLqXJ9eLtBak8uQ9Keg11srKaIbDD7
PqfRbuI1jjM2U4G5hNo+5g5b1pN7voEEWna8pDtzrX2fjY3ndUgmbq9o5pCc
BG4nrwK/V7dobsPWt6p0cDtjk/DcOySrdiG5MN28mt/26Xxl+kmJu5BEl9HD
lBGSd1ICjVBcqlesltBEEqwA4TgPlgtq5yAkZ5/Te/8jJGdckW2XaUFN3KVW
tflMk1qtqT2z9JyaFnJBTQu+oKbCpgQjIfwgCC+Tg1AqvR9E24pMCrqoJgVe
VBMDBa7vBRL53w1EdvZO4GVgfkLgZdgVNR42DjaW7SoYflWz/JpmeSewXK4J
jgDbhwWC4YE0+EMCqVi2s3wArD+Y3g/WN8jOcsmxqY2I4FozXoeB3kxxmqGy
Uzz0oawgCJGADczYGC4L8IzVPFwa02XOznIRhoK1f53BcATO+24by5nheipY
WI5Y/UfE6j9cJKYzvy+0od6bDnR81G2Ij7uV9xEs/4EDy//DFq9B605m8WsS
/Iq+dd7gtk9H3KYXqoaNQE2HG8Fac3u15rYPcRtDb98+VFPbJdzuau5gu85r
h2SvqK2z7a4Gvzlqb7SiNqzOmMnS01TfUFtn6FtEaDdb4vVc2nlbHkJCD5Vg
XiNuxyNuJ6xolgqZU20YeJ2yBtxe2yK83tDKvM5Aqp0ZJfzORtzmp8l5x20f
Ha53tH0Cqn7cbFmZPNqbHkZfijS7FGl2CUJ2SYVMWRXr5/gW0XQVuJyNcJ11
Vp7lkUEPa0DITrsq2xYbnKbFcXTMjODzbjU9+Dw8Pi34vJoWdF5N1TYl6Dy8
+EEgPjCZXt4PBNMnBVzQQj0x4KJ6T9u7ARSn3gmgtZMTAi7BLqvx2sYFUHI3
NuAKODsm4KoazXZNjQqQFSUjA66rEbDhAcTxG8RxYrgazAaOB3bE8WqT48Jv
EC48mBY0h4Hqj6A3L1vAx7rJZR9jJZ9eX9ts0LwTc7yLjuVtGY762a/GZcxI
C71vg943QW8jFdeBnCl+gQjO/3cQv/8nNxh3wGzq2w8dmP1v9Mpd72rVyJrU
qJNX8pzzo2I118w+RGc3B2k5VnYAJoVeLem3sbG5bG4u6Xcn2z7UhlGEBp9R
UBj76DOric1t8/B37nfIaH2zv47Q31RR0+vBaNTPMx+qbbOF2V5PadCPFYqj
B30sa0G0hoHRifZoDUanRILVFK03ULQGqze3MqMpWmdFC7Nz4myP/Ey2rvnY
H6ZbjHBdgnBdinC9Uz+ueyfCdeleGDLxEoTr4qOShdM8F89Eg8ZFek0rPa4n
94o8g4UeqJF2ST8dQdN6w+kGY8HKjOCzakbQWTXdtHPo0rTAcxipqYHn1BSy
APrbBwHnQG/86KveDzgHOw+KnxfRn+gP1r/nT4R/1/8C7KJ6R9sEf4rq4/0R
1cf5U1QHv8HuKybDqcPE8JEwYTfl7sMCbrj+XjP8JjOc2c0GdsPaRnBqx56n
cxQ36f2A6R3E9K4netOSpFC6y0wu6TYwt/3s/A4z+e2SRbtfkZAe3Ggjur6k
210uelC9bU5iM8lvSbb+Jz2h/ZaO438ggp9/FMn/J7dH20nO+Pqx/IRu/doM
1c8QlzszhTWhUTOv5OURYDFPdl2TmnnodeYyGAwaE5dv+HA4lsl4Csf64QSc
bdOUmH6aivdzCkwOC4W7Wo/C0I8toNYMCq8XClNwfve+kXFvNCLy+w90JAZ3
p9m5C5vTAO42MHepwZiFLdaDepbCiLsrhLuJ4G6SEZGRaaeulUw7DdxN3wT+
bgF/ibuopI2ITPyldvOSLO4WZoB7WcorLNNT4EsRlksRlksQlovB3x1It4uQ
bheBv0XgbyH4Wwj+FtAcNcJxwUV5zFa+fi4vP91E34FJG71vv9iiIqvq5LS+
albwGTUr6IyaCWMazgg8gxBNL9MC8DKVXqYEnCXunoXDQF412Z+Nqmz/c3rg
J/mfJwa7hMK+bSnsZg77EIfbhOnvMYmpCSKyQWLnMG2FaoPIA5jIVpimduyp
uEFkJxLT+gwzBdf/0wUqk8B8PxsoLDfI6Fy8SRfeoU2UazOXG6yVh5rLfHi3
Gu+Vu3/VPKaA/eermsuXhMd/YBF0vBL1P7n/+hE5+E8cIvUvTGJ/3gzIwmR9
qRhRmW0omQOjVw2n646rKMHWSfZqvRZjtcFsXy9mr6ELxZRsd9LkNh4WwQ+M
0KV0V7xWy8NuxguzmeW2AL3h3VpdUr/BDyixPxd1y9Q6JnjUjPp2BI+eD5Iv
aATBZXo0doktQK/QAfoTInirSlrVqpLXtKoUENwM0CB4OgJ0BgJ05jYJ0Nko
p3PiUFIncIA2+F2QDp4iPhchPu9oE59LEJ+LEZ937ML7SL0LEKPzwfF8pN95
SL/zUFLnVsJO6dkxmtG+bLv+pLlOmyFGX2hWayrrjP0DZgedVrMCxWbCuLIO
PA2eB5zGWEwPOA07Q1wn8yG+488gvJrif1Z9IOZmuncmuptk14SHXRDOP8+c
t0I2h23OzzXhYVfMyK0JT7V3wDW4h2rvEbDhIPtwq/72zs15ho1y87s6NxfC
01y5cY3LTviwkI4I/1ACdxcrGaf7UsN0wA5vZtb7yG1xdEfcs1oAGr3Yzgcy
42slWv/tnrmM+O2bMkn+NoL2n0H0P12WKbbfn+8oWD+K54+74VvzPNChWaOs
t/P8pybP9cbxttD9AjHcTRSnVHyoVM9Edv6NimoU0quGM9mpfl41wiQ6p+K3
qMLWa0HAdJo942nwNaPu2J6vd8dNDx2iRcdjbQ9JY6NLV+A5nEhPazTiODWn
mW484kqi92tq85Q6JvkWk+QwJvlDL5JvXwiiL24EyYXsccsokreC5K2I5LBP
NclXt3IkTwHJU41ITiRHbZ2BSJ4JkmchkmfHgujIwnMTtc9dr6gCRPFCRPEi
RPEdiOLFOooXI4rvQBQvQhQvRBTPRxTPQ4Gdi0w8B5E8GyzPQpGdhSI7E0V2
5hldUNMk2VWJ3nS7C+3VuA0MX11R59ILB+YEncLp5wSeUrPF8LdZgac0DGYG
nGKqM+HdxHcAbRpYT4yf6n+GCM//T2E7S0m6Pwd6UH+y8N0M9BbnHxXoA5Cm
g/KuH5iEp454FeOBZNc16b0JPzTQmlYfTBfIgu6Yq1GoHePimHlRm1ei1OqL
2tYqFJ5Lp7t2Qq2JNo7uYXbGa7aHtxBnw7yJ/pCJzp+lm3YCJKzw6q+/3RWi
d5EZNib6VSG6jugdzZvbt3V4yjvJv9QxyY0z2Un+Q5PkvvrKsy2EU8U95Jov
0fw5ZrdefznsOuwGGYX1G3QpG2U2BXTTNM9v+khMB9fxpVZTTB8pSxIktjPb
3TJHLlSPtFFdzKC6j0V1nktbj6RduktUt+bBX1ebJj9Um+lRm1PrTb5H2fi+
be5DzfcGk+8xS8D5D5vAd9hyWVmSYPCdAvtqW2AH31MR2NM2eVQ68V0H9kzw
PQuBPRuZe06CDuqvqvxUZQZ2nhNDYN+BwF6MwL4Dgb0Igb0Qgb0AgT0fgT0X
gT0HgT0bgT3rMCiOBD4DwT0dtE9DEp+GJD4VSXwqkviUK5Kw042mW8+3qFUV
dZqM84JOutXcoJOA35zAk3bqE/HVLFBePgjyE+9PCe8R7f3Be21T/SEHIL6b
mG8nPX2P943s3k2cd73ArAff2bwYH0B2yWsabpxmPJjvJtq7eZL9NS/GjwDT
5ULaLb6QNhRs58vitvVn1IZcSJNlLLL2TNZe9+S118YtD8YtRHKvHjNebnfn
W2dNtofzXhDhnM+Ht2jms3ViCfCVj1k3ztL1NVps6BdUJ9zvTqutea2Zy3ga
h99fQP6/IMq/bUX5Drgvkfuz35vuJQDOj4lxivZ8ddx4ftGw6524GPeO7c+Z
Ef6GwX8Xp/T6G+AnUw5ork2C/i3DWAUo7FOgXz3KSu/5nNABJIeRo+/KI5n5
scz60cymGlTzI5olxa8x1EArwff42Zb2lJ4e701KsOmDBkR/eabllukPWQmi
ZqGON5UAxkrQ4KUEsawETSr+o2YV/7GsqEy0pfjJaz2I/h4ogQfRH7YZahBl
i/6kBKjjs+ON+v1VlQcpyIcUFGRKBlCYI5KwAxlAETKAQmQABcgA8pEB5CED
yEEGkI0MIAsZQCYygAxkAOnIANJQz6cg109GFpB0Sj/A9oI8/Y82Oo+CFKw4
Uq0ZPp+kAHqAcYIgqLmBbJQV4LUTJOGkmh1wEpIg1k4W/E/5khqgxJrKmmDk
AWcgCGc4/TckYTLnBiQMvtCEc/ZcQFIBH1MYrPn5Z7zm5rUowMzrb26+zO5r
LpehpTLQBTcJg+uramjwbdgdXpY6OOSuGhQiScCAEH1bBiRB1obTHVH2uwvr
5O7CMOvG+kDIQQDvXNPIO9cIv/WOUpTsR7SILESwEuAV5I5olb/b9sOQ40Lp
ShxrAt1PTzcadq8WbfC7Y8ytiDRQXsDfnStujrNGqv+kd73rxaSv6sMe9/yd
H5knMuYT7HLwHTMv6KoZToyX6H8DUr9SeD7MO+zTN+KUn8hv5PgU9Vdzjo9X
NzGfUgEK/YbpdS9rRt/1Iea7ifaU9RukN4lPZKenbFMqcJ8fkWyF/W+jpq9j
0lNbQvpGpABN/Gz2LTMaQfoGTgG2gvTb5jWYpN++uEGTvtEkfRyTvlklfAJb
KeTnFCDSo5JB+pT1IL5Bep3yZxgpQKyR6n9T5aaAyGkgNFL+Ak34IqT8RSB8
YZGQPx/xPw/xPwfxPxvxPwvxPxPxPwPxPx3xPw3xPxXxPxnxP6lKHmyecEY/
cvi8bDm9+WyzWrxfCqoFwVVqQVAVE7+KiF9Fs7aBVd7E9yHOw8ua8fz/TDaq
DWb4C/HdID6/cB5w2swDzuhccLIm/2TKAjrK//VcvVyUg11i2lMRYCzMoGwA
RrN9gVeRBYyl5TVB12mZXLtFcsORCRiLW2lFOt0SMsS8LeSeGgjKM/X5Rsj7
fAd/X9Cd7+Dn/TTq9AY49dYGOBENvINjQIRUff4RzTRtH0FZQLeIFqG3GLGe
tk7t0Uoxn6ivswRjNpA3ugJ7mffGXhoB+gZj2v/G77bLXLT6V8kJ6LcfmhG4
7e0b9JvcEGzuR0p3N7711lucGdAeiZMnT1YlJSVG2f//x3OIvu7Q6186SMtr
prSQQIyQWUDKGJ4xJguG3TTUhiqQYTdQgQy72VWtZF3hj3C6gbRCVIZeIUai
M5aNkkTjjluKDMgLfWO9BidyDE0cktA8oyLbCM1ayi50hgGhkSmEN9SGibVq
w/u1/MDsjTqxoKZEY5qhMc1ILppU1OwmaEwja8w2aEw0acyiRrUdGhPDGtMo
GrOiiTUmXmtM4irY6haVFCkX8EhjUpBcpKLMSNuik4tt0IbtsBhzzjAnEdKR
jLIBuUUecot85BYF2ZAXlBmFKDMKUGbko8zIQ16RWyaSkwWZyYTMZEBm0pFb
pCG3SEFukYzcIgm5RSJyiwTkFvEoNeKQW8Sel3u41p9q0DniwmBIywLSF4gM
/Dwf+jLPMpQe9DInAC+zA+gDswKqTJ2BIcHwP4k/z/A/SWJDWuOgNxjWKUg5
jFSDjiftcXOi0YmnHt7XptMNuUaICMWFSMAFYy2AITswyTEk35D1PuOQZ5Dk
jA1CrkELdJ+H8tzQygPVCSYj1bHfkCY4ontAB8EGhlKdOiC0xvVF3tKgX3gt
jHbzqVO9eScfa7s8Y6u8kB6NKrinKE5gz2YVwNbiVv68B3P3nq2qm+wZS+ZD
mkMvHlpzq3MOFp0IvZFseJOIDm2TF1ynt8i7L1vk+d+lXUOsxfJXDZ46Lul5
za42XdTt27eZ5lFRUVyX0G7IkyZNUikpKebs4//xk5xecej1Pzmozaum2nD9
wZOPnJ10ISlxk6gYkx6QIfqtE712xsutTlpfLLUhRYHOaFlZPfqOL8tKJ5aV
NWPukayIvPB1ichx1bS1j01W1lqyImnLd9R6kpVJWlomP1AbP3igNk2pU5um
PlSbpzWpzdMltmyZ2YoUpgV1S7PaOq9ZbZvfpLYtbFTRWlq2Q1pilqJu0dIS
93GTlhaYKS2wta2cwlCbJC2pSGHSIC3pW6EH0Swt5vXGbJu25CKNyUMak480
pgBpTAHSmHxoSx60JRcpTA5SmGykMFmoWTL3ic6kQltSoC3J0JYkaEsitCUB
2hKPNCYOaUzMGf2we9QukVX1ctpOalGwaAVERi0MIqt0kdpUQm0CK/GBeYGV
ptrMJQugHGcOv0Ju1Gz/Kh0+ZvnT32ZBZWaKcXJDpdB0/K5Vx8Wyg7/pOQ+W
Hsp1Tus054PuZq3D2iO5Tue2NQ5d5yDRcZPquElyNHqowJkQSFczxwdecX2Z
BWdc0DU2fVOAKI51Iw/sFt99NwJqM1zfeU5tyZ3n1VCdat5EZWAY7VZEl7b6
RzxAkd43ok71gdLQBp09oTQ9euhdc6E2YVCb0F6Cp+BedKd/ED8PIbBXqwqA
+cO690Z606037Vjj16tV7wzv4YcmmLvF92jlTawpDWpGhSDb9tFF0XrZs5q2
h6d9q4NIee7QlmECKacJD601X9JvXb9+nR9bhQzHvL/u//JRVr9yEBHeL1Df
vIy0wpfrGR/OOKAJrBLP0CvkxBQM6AcZVU5GkkI/8W+++m8rRxgNUEpIr9Io
Cw6XTKv0ie6oVaiUoDrcgztInCSbGX1XS4/kNvfodSxkaKxR+0OCfEh1XP+g
1k6o8ZogsYTngQjPFAjPVAjPNNj0OrV5xkPkNMhtZkqciZrtQV7TCuFpQV7T
DOGBLW4yhScGwhPLwiM5TfynJDzNLDyJpvDANrSqlI0iQJTXpEF40qPNJYdZ
CdCRJOhJiqU5edCcfGhOPjQnD6VTLkqnnGJ8DpqTBc3JRD6TgXwmDXqTqneo
TkbZlAhLQOkUj9IpFpoTA83ZDs2JPicPgtPTpWpJSKWPWhxcCUovCq4U7Qmq
ZFtAFoi3oTxuEh4qpgIqITlsVEwF4N3ZrDOc4EB7SHUow6G/zeQMB9adtGd6
d8p6pneXjGeamFFbdT+t29B6o6+zdDGvs7RJdnSNNVErDvjyHjIcynSokXd4
VbOxsvkq3cEAY9FBnRV8HTHUuoHwJoxuu5db70eG3lEjtN4M89popkYNCq+R
XdIianmj0QE96lQ/WN8e9ao3tKYXrCf0pkfPRhXRq0mFi96gn6G9W6DdIb1b
VTAsCBYIC+jTSrVWX6qnuvVFytPHI8bPbaGaw6+3ont7e8m4siBxSiTPN+Jn
ufBjKh7y8yn8wpD6oObzCyUBop2BWYA6vNjyLW/9oa12f/CDH9i24f6/eTTY
vzjoDj/UyG1MkArhWQX03BHpgVYHkqKRNLOCVxKb26RFtw0tgsbIbyvpDeNd
yBDlMqtoWgaNGHc7jLpjs7t0Gj71ap3irOHKCa9ukhrKfSA2kBk2zn14ngaa
YxRO69+rZbFZjwxnA4RmwwciNhu9xKZebZ5Vr7bMguiggIqaI6KzdR6YusCD
TKcVYtOCTAe2tFnFLIPgQGxiP2pWcVps4pHlJJDYrCGxgdnEJgVZTiqJTZQW
mtdUZpxiscmC2GRDbHIoyUEBlYcCKh8FVB4KqFwUUDkQm2yITRYKqEwUUOm7
ITQQm1QUTykHkdwctpIb6nIcEpwY2HYUUNEooLadlUeCLZcJWfVhSCUJjloS
TFpCquOrFgV5qY6bJEeSHZRWUJp5lvmQ7EB1/PEy279SZyhadchYeJDldK9C
VILqkObYTKsO/p/anZTHFB3ID1VaLpnf8TEndq1JXR9TeCYFaOHB+JurrgNF
d97l2yvozoofsvZMgO5M0NozPviavnv5OovPmGDZcWA0hGdUKG+5w+JD7YyA
6Aw3do8L0zvHheuNU3s8gNWpgT3rVP+e9apfz4eqD6x3zwbVq1ej6gnh6dFb
Ep3wPi2wVhUGC2XzqOC+HhUEsQnsh6SnP5IeNlQo3ft5kJ91w9vd+io2v75a
d/ooUiLzeVKsPb1aRH/kOVIw6A/yLz9Ufn6hNUiCZGfyjrTnm6I9rsc/V824
JFxbW6teffVVXnZtbEP8v/lctV87yNKLZk1FSzbG3jNkgdIQN6uFKAl+Eht1
l6XKlzTlGZYaKBFUa6XkOjTLM5LV6A6rGf/klp9W8XGiS3fVqtFscpLOeL0H
WbKM+zD2HuVAdL14zThDmEiQIg1B+q5a926tWvfeA7V+UgeiBEHaRII0U4vS
bIjSnIcqam6DiprXpLbOb4UJLKIXgeVLPMiCWiFKsOUtLEqxyILiSJRWtqh4
iFICRCkRGRCJUtJ6CNNGCNMmEaVUlF9p28wZnQwIUyYJE6qvbFRf2RCmHAhT
LoQpD8KUiywoB8KUheorE9VXBqqvdGRCaciEUlF9paD6SkYmlHTYOwOKgyDF
6q3HtyELioIwbTmvjKpraWgla5Ndn9zQJ7rssDioAhpVoTWqwq0WBlaQSFUg
LwqooIyIPjU3oELN9a8kbbL0SbCAn6BNhnF21L3Kh0SKsqGTPiRISHQgSZYW
sR6Zsz86GerskAyxHhk3gpAc2e70ssnRM3Q7pylHE4JJjmQzhXGQorHBN9y0
AwpoMJp3IqJNwESJRtH+e8Z+luG0b2yNGhpxXw0h61GrBvd8AKtTg3rVqwGw
/r0eqr69GlQfWO/ejapXnyaYqFEPKE5EP0p5wvvRY+pC+3lUCCy4v0cFDvCo
gAGU8vgP9Lj+Xvnj9+5k/RWbH9kALUf0cz9lPEhSP+CgVT9Jkh64CkmCGvpB
Ff3QN78I/cguuWjuOO3zTe9UKCcnRz333HM8J2OkQv97z6H7VwelecF8V1cy
ROzOrDl23ovY3GNZ8CGB8CG1gKqMutuJFITVxli9wrpzRyRmJb23SkvTXfq8
YZ049+HGDC2j0mv0PV86I6VDyHrWiFE6NJb2viTBWTOuhgTHLjd0PMnNuokk
OXWQHJiWnA2Qm43T2kvOZpKcubB5kJ35kJ0FDWrrwibOg7YtEghs/xBJxlIk
G8s9KuajVkhOKySnRcWR5KwSyUmIbFWJpuR4VDIkJ0Ukx1iOlh4rzWVCbrK0
3GSj8MpB4ZWbrXMgSE0W8qAMyE065CYVuVAKcqFk5EJJyIUSkQslIBeKPwKZ
QS4Ue0LnQCi4oiE121Bwbb2gjOVoy0IpbyHBWRpSAcFhc0NxKjC6UBzWG7vm
LAoUzYHjITpqAYQGukOXuAz1was/qQ8bVWX+9LfZ3eX42d1Jy/DqVrO6U9o1
s3slKRBnSZYMuVmGRLGmcoZkyhDPB9FlL/s1b2MqyE13qYgAPc+3mlIDJEJa
gGDm/eQwY4OIazDe1QWNjwu5ATLQLkyyF9ptvQ2hVqDwu3pX3WqoECyiRg3r
cV8NhfoMhfoMAcOHQHkGwwZCfQb0blD9Yf2gPn2hPn36ivr0YuXp2d8DrveA
4oTDwmChUJnggciJYIGDoEKDYfjfn01Bj5AMwfwGavUZjJ8Hye9+A7T6QMVY
jZBX+SHn8oPi+fWBCqEffr2hQr2gQj1qO0yG5MkIri9opaGJ5qSkJF6mTrO+
yHzMCaH/rcf9Pa//RktpqQikBTVdHbr6GwetetaeFUVOuA8FMKyGcpEaemrK
2BoWDtPGVBsCRuoy5h5kZ/Q9LTtaiVysY6xoPvy7run0u7702tmmVmjAbOSe
ceuMJZZ0mmqWL54rEsFawxkSXkWyvqfWIkNa+55kSSxfpmzVQ7bqWbY2QLY2
atnaxJIFm+MkW41q6+JGtW0J5GsJyrgPtXwth0asgFZ8DPvEA9nyQLZaVfya
VpatBMhWImQraYPIVjJKuJQoa8OmtO2KtSsjHgbtykySdk3tyoEVSv2WZaRJ
0K1UpEopSJWSoF0J5dAspEtxSJdiD6E/SJe2I12KRrq0rQqaddpMk1TkSblU
szyMBGRZKBQJ6gWksn5BtJZog3BR4hR0wg3dOqHHa2HgCTISsIATpFsnqLTz
PwHZOsHSBXOzdvmSdqk53cW4OoCM8WslqRcrGOVPlaxclaRerGNc8/nwFBPl
UycNGXO5+dVH5MzfqPLaLOnjlIpvwIOWvc4+flENAncH9mlQA8Dj/n2bVD+t
I31RL/UB73vDeiEj6QmLgHaEw0KhGSGwYGhI0BDoyVCEmoAhdEGoO2SjG0nH
ECWBwG8oBXn6lRRFHqfmYUXh/3EWv35Qkn5Qkn7IafpCSfpCSXrXdTSbLMtf
NJE7846ItHU9kflzn/scCwLIb1RJ/5uPNTS0hCah6eJZRkaGo5b8m4OW8HmN
i3Vr332g1r7zQEW+Q5P8kRNoi9810Jc14202ju5gW00EXj2WFsiskhlgtWoM
JSb0ir+NYWVQK0fT3vfyqn83TaQFOoRfutK7bjrMrVsQLWHtotOxhqwmTXPS
kMh372sdkdSHNGSd1hBqaP2Uh9AR2LSH0JF6tXGm6MgmpD6WjoiGRC2Ejiwy
dAT2YZOKXgpDxUU6Qu3FsI7APgWfV4HXq6EnkR6VsJZ0xKMSoSNJoiMuYw6I
NCQNGpJOGpIgGpKZAr3Q+4LnGBoC/ciCfmSUSqmVCv1IodwH+pGwVzQkFjnQ
duRA0Si7tkFHtiIHikIOtAVl12bkQJvO0RyQ7OuyIqwSOlKhlodWcDpEec8y
yMhSbSQnHwafgJxAK5YEnaC0KOiEWgwRWaRNiwrSItITiIoPyYkv6Qk+PReq
Mrf7CUiIYSwlviwlnSEhFSwlnAZ1k/8hJZwJ4e3pUBRjxsgQkmkyW3SKdxgD
Qum+3PcDLtA9+Py+scPGRK633guitT3vId2hPbHeDaabeN4NoQXm74Rcp/0n
YbSTCm0D+wXafBkmFz7GItUZG3FXjYm4p0ZHVKtRParVyB41amTP+2pEz1o1
vNcDNRwCMKx3vRrW56HseIao3xPpSA9YOIQkDBYKUQkZqlTwMKWChoNNgcMo
rfDHr920cSYznJ/bPYLkCT8rv2Fah4Z68OchHlrzPxRSNBhSNBBSNABS1B9S
1B+JTT9e+e9USXnJUCeupGiG5uWXX1YDBgygmZj/k2c8vqD/VlRUxBfCqD2n
ndD/3UGDfMx8xg0K07Z/a9+tA6lhLEYPIEJ0d+yaCXTH7JrxtSxEq8fTqvzV
4+h1FVRh1dgaLWP4iZQIugQtMQy5zZhq0iKkJCs5aWEB0iLlpld6o/pZQ8J0
4iRNQnp8RPRIcf4BnUK2BcWJROaydiJsEjKY96E879ez6qz/4CGrDp1jw7QG
qE6j2jgD/89qYNXZBNXZTKqDzGWLVp0orTpbSXWgONuWQXWWw1b8v6zdd3hc
V3rneTwASKnbbtvTbbftXc/aO+4Z27PjnbWfnd151s/Ozo5n/MeOH5sUc845
J+ScgUIhFICKyIkgSIpBJBVbqSV1S+puMVOkKFIkJUZJzCTyu9/3nHMLRQls
e3at53kLAlgoVN17z+f+zrn3njssu+h07UKd/qAb+UWdPVE0aEaFFqpNjDr7
6Hjt74rPW3dwJ4A4eA4Bz2HgOeLgeZHO14uH+f5FwPmxO1sHdI6AzmEd3wGd
g+/bTtfzoLMXdHaDzi7CSx+dr17g6aYD1k2A6SLAdNIB67jg9raN87zhmAZr
j6l6a9Ds0zoGNPu01OFOrVfQYwBKVns0z5xyU91VTz+FPLaqtKadUoBOPZFq
TKUoRMmqkFu9pXikDGmH7Ix2yIxIU88g0RmrEVU01Yj0HReovd5YvndVQp4b
o/7Uu/4wyUwaoA+f8Q+eSnzlH7BJxzpnXjGTfFEq1CydYCKDjhguGZt0us3r
SX+g81NTN3VeeFvzrEzb5qtMt2XLAmRCpc2otAmVNi26LxupDYsfUA9l/ZJH
sp6Yso64smbpoKxepjUkq5bb8LRi5agsJ94sQ6tlq+W75iNOlukbRJ6jplJT
NjqdNrHVTNmsD5t0Zjwj04ax8drovq6DpzXwtAqeVg49tY/1B4kupehdsOTv
//7v9QKi+InD/6S3r0xJvH1lnChlS4/na0yaiKP/aOMPH9b505r12PVkWjIf
odEjmvijZMVI6YGkmHKUptNjxVGSqNZ2zUw8qkbe9UKRrfe0jEaalcIYFd5i
SsnZcvdZVcmzCKjCJkTxmGrNimy5O8n9btT6pgqZAHYv6X9SA+MH2WNp9+Mk
NRuSCHOQ1JIDS7laBKI8aDJBaICy16J0FA0RiIZgiSoblC6CUJdjqZsOlWEJ
knoJQuMsDTuWqOCI9IdGKXyIOJ5gaa+y1Eq1Q1OHd6LyvzImHcSkF9QkOtWH
MOkwJh05YE06gkmHMenQyzzvVZED2PTCT+zrmiD0Aa+nJv1ivDO1iyDUp0FI
PSIMdWFSB4GonUDU5sahm+Z/LE3zzkATNdcO1jTM8XA6bV16Nu6SV7hEnUIm
asYp1UnlgScDkwNKsxEqeTSRjZ7jZ+XP6VNNKJpqYxRf6V1NVZ9KIUgpskPi
tmE6irx+lklHZv9T4I0YOZ/iZw8lXDBl5jOhwcGSzllkysFkIpOZnMyDSWch
JC5lzjJTACtSsPQnZuLuNFDS2jH3JnVLdjiUts//ivpatoHSVmrLwjvUXdm8
6B51XzaB0qYlD2UjKG0ApQ3LBmQ9tQ6U1hJk1hBoVq+wB1tX0WtbSa9tBdFp
ObWU+LSEWkQtJBctIB/NR6e56DSHmr3JXWLEspiyBbW2mtI8tc2LE+bnm83P
tmjHxj4HsbZQm1BrA2qtG36qWPZEP5dkJktDQ4NUV1dLV1eXKR0hGhkZ+V0X
tP6/XjX1mwmdtZkzZ8obb7zx9KDkDfK05QxKq1b2AG16gJiUNeDuoNOc+Zgm
r/VIYlrpWno5bjRNzYriVXSHKf3Zjgf4tP0+smy77yG17Z4hK9nBpWiFbfE3
ICvVeOUGtbfEBUvVf3vG6DTZSmdfSG2yUm13ZzTTi0yAqdnCpGEv5wE9I4Wp
NY/KB6gCqhCgCgGqaNDA1OHuINhZNiKd5cPgNCRdVYMGp25w6nE49TqcdgJT
HzD1NVmcdoUAKkxFRmU3mUlx0tfbm4BTsuul7e8FHAfUwX7gSQDqMEAdAahD
APUCQB0EqAMAtR+g9tFz2/smr/0TO9JjECQ09f/S9tR2HhsPTF0A1QFQ7YSm
VoBqcUAFASo4X8MKTCWrUW6ZN8w5rUJJYLZTKtXpdMqrZCUqWX1ijQGU+Kdb
nhKIUqH0dOppPLHKpqfnTlKnvDJoJWmGOiXlU09h1Sm7jfGzEvwqsWDpkDaP
z45npwS09G8VTj3rjXDbo20piTnKzOMw/YKxyor1TFyqnBm2k5eNVNlIhVYa
qWZ9nvRvrVaz7aTlmXOuSYap65I+9wZ1U9LmadnrUnYg1Y4FaLXga+q2bEOq
rUi1Fam2LNa6L5uXPJDNSx/KpqWPZBPdq41ItYGu1nqkWodUa1daqdag1Gpq
1RrEQqeV6LScWkotQanFKLUIoRZuQixq3mbUQqLZ6DOTr9O3SnwpGqW2i5Yq
tcMolcb36VQaSm1Hqa3UZvO37cQIZtP850/adO3aNTP6o29QS4+1nz171jus
/o+9kMs7/Pb666/LnDlzxjuBZrv7q3GBJpMaRkgPw6Zac4eMRi05g8nKkY4c
ZdkrFJqz9M4JmKRtHpVUpGi6q7RHeoqPVQmRIrbUne2apMLb7YxT4W067sQj
CWnbve8ah1xCcipNdj9LQEcvy+Dx32gCe+LcQ5UnlkFmy3xg5GnO9mLRQ2lJ
kKe1gGhUSBVRxY+kvRiFShCIWNRROmz00ffQVTGKPiPoMyzd/iHprhmSHqdP
b/2w0Wen0WdkXB/k6Y+iT4xqHpU9RCPVZ2+7W77/Mg7PAYVnt4XnBeA5tM/C
cwh4XgCeg8BzAHj2Ac/zwLP3ddABnt1vAw29t773KADa5WY37gWebnprXcDT
cQp0gKeVZNRyzv57eMHHEtKy+EiQdKQpqWmuQtQ4V0d41B8zHD3bGARBp6Re
0UEetuA6klFtQqEQdRKHTurg9PSTdOamn3TdQd+0k/GqmqZPqHruZIpSlAI/
JyfbFK70pJKQTmlW8sooZPBJVntSFB4npCVnnB3v6FrCWdbe1aRJZv6opN/X
KeCUH8mdcdG8Rq6JTJckZ+Y4QNmztD43kzZnzf6CGgfI3OtkrtYNyQCfdPBJ
n28BSgOftAV6QGXHwttJfyrbF92RbYvuyjbw2brkPvVAtoDPFvDZDD6blw/I
JvDZuGJQNtCp2rDKbmzrVo/KWuBZu3ZM1lCrQWcV6KyklgPPMuBZCjpLQGcx
2CykFgDP/G0gBDSz+Tpzu13TM4BmuhbYTMug85cJOplmCMqdcDwlS6GYkq0/
B6N0INph5idwt0xOTQwo+v+uj/d9x4ie8KwnMOp33vVYdLzkL/7iL/RExfj4
UmLM+T/ixPGn2wvHqFFSgNaIoqNdsjy9HrYFdFpyhqQ5R+/X0pw96F6oOWvQ
qRPLVIlUnahWus4iH0mn8xZJMw8Pedih+ISBJ7z9gctW4Tg+kGPw+U4cH88d
jAmbhMRjqv7rJJOffkuj1BPaRNMfGG30t1ScWNZDI06z06YFbVqcNq2FvC24
IXi2gU1bCeCUUmUD0lEOPOX0xyqIPJV2jogu3xhxZxRwRgBnWHrqhqWXfliv
A2cn4PQpOESdXU+AMwY4VNuYgpPkibMPcfY7cQ4gzkEnzguIcwhxXkCcA4iz
H3H2Ic7ziLP3NbRBnH7E2YU4fYizE3F66Zd10y/rIvJ0EXe6jtttrh1xWhGn
BXFiTpzIwo8lrGXkOYM8cXU0+szVeIM70og6Tp5k2IEbzOHdm8gzU0v1qOUx
RWrhpsYW31lywMVusNXj5KSoNsmqjdvkK6bybflU/a2yqSddF+2UFShZAUqO
y5NqYs+kJ2KPPr9o6llztvVZe8r1ZDOMXfBc/JTrb05voZPX6fST34mrY2qm
lScHeXJmxeXRY2Szv+C5Kk/WHC3kQZ1M1MmcZ+XJmO/dQyd9wVdJvyNpC7+m
bksa6uxYfJe6J9tRZ/vSB7INdbYuo5Y/ki3LH8uWFQOyeeUgNSSbVg3LxtVW
ng1rRmU94qxbhz7r9UShNRsk6ddlFeKsRJwViLMcbZahzVKUWUwtQpqFOxAI
ZealuZHA2Rk6u+ssoJmRBT7g8lwO+OS4sW/Fhv+fkutS0kRD3PbiiaS/cb0r
Ped5aGgoDpH2pGbMmKGXjk5IzP8ezzHJ7NU1PrUXCfv6MVOtWNOKNa35I4QZ
qJkszbnKjKFGobHMZA8hTNag5prMQYlmDtjKGJBIhpVGMw/eKDfxCqc9MuA8
9CTZ/lBLE8x2emKhbQ+eMeR4ztx33/FoTEoyvTUTlcYvQE8xzERNqNGOHsgk
/ci+S5hpzn0kzXmPYIZSZiw10lr0OO5Mm3OmvZyqwJtKLbypIuj4RrAGZ9y5
Pz21Y1gzKj2BEWNNb+OIsWYn1vSFR401u7CmPzYmu3Fmd6uxxjLzR/J8txhq
9KX2O2oOQM1BR40yc0hDjTJD7YWaPVCzG2r6oWYX1PRBTS/U9EBNN9R0QU0n
1LQTctqOQgzctEJNszsvOnLWfo0u+jhZvQFq1SbstBkX57R6E9emcc4pxDnl
ss4pCcwyOYcCDrgxzrCSjTTTCTjTT9iadiJJwTkRB+cE2FDPnZhkN7vKqSdS
1ZoUZ4115qSWtcaEHb12dcpp19c6PW5OqjHHWmPcMdyMH36PU5Nkrmelaxaf
SYuOlpZmnTyXc/J0Omu40THtWZfNfSpyzT0qcmbrPfhy5nyhN4qyNfcapecM
Zc27QW8ka/5NyXQRJ5OIk7GQWvS1pC+6LemL70j6krvUPUlbel/Slj2QHUCz
A2i2r3gk21Y8lm0rB2TrqkHZunpItq4Zli1rLDabQGbT+jHZSG0g1qwHmfUg
sw5k1oLMGpBZDTCrAGYFtRxklgHMUqLMYmoRcWZhpl3n8xBlDjUbVWbmok4e
6uSJve/v1HxNMVMLAKjQ1pQiHfEuVjOmlIjXoZqQod9PZChFryk1l2nQ72IB
XbyoJ613dHTI0qVLXZfr2y8xPqMl/9xRTiQvYysupfjbbcXaK2zTN9RaqAeO
laYWLRODmrHpGYlhUyxnvEzQyOb/s3Q+gGiWxqIoQEUyFSaNRTymGp0wJ/2x
ijReO8zx8UkKlHLzcJKEtj+Y5CKR9cpEJReTfteDKF6RDAtRNPMhf/whb0Xr
EW/tURwiA1P+Yz4KBUQtQNQah2hA2ixEqnPFQNJvAxHhp4ryDUpnNSj5h6XL
r8GHAOTO6OmpR4SGMTAaNRDtDPEVjPocRrvAqN9iZBf3n8reLjJMDwVG+8g9
+8Bovzsh8QAYHdxP6dAOAL3wYzvurD2sPVQ/1QdGO8GoF4x6wKgbjDrBqAOM
2sGoDYxawagFjGInRKKn9Kov+/qxxWcltuisgiRRso9moAgaqUhhK1IyJJ02
+SdFIdJu12xH0ayTpuq1ZpJXNPmkSh0K1Zo6oZUCSSeS1SJDUapLtxhE5qGm
mkr1KDqhAz38rHzKSbc5lk0hFJVOOaUzdUw59YRExWbA2lKUwJClyJ7XmHAc
P8nM56EyufBTYCb8s/P3ztCr6fMdRXaifXMvDe2WzboMXXmz8Wj255I7R+sL
PLoqOXO1rknOPL0l1nydFiZ7wU3KUpQFQ1mLvpJMKMpcfJu6I5lQlLn0nmQs
uy8Zyx9I+vKHkr6CwJ228nHSv5AdqwZk++pB2b5mSLavHZbt66xEWxFoywYK
gTYj0CZqIwptRKGNCLQRedZT69BnLfKsQZ5V1Er0WUG+WYY8y3LsSl+MOovy
iUPUPMiZAzezqZlFNvtMK6alP1eiRkyFgKllprQfVq4mVTxtitzEn/3ekybp
5fL/5b/8FzfcZB//8A//0Bx9k4TDYokv8ZfjJqUSANio3fUGHfo22sv0+W28
vzaIajVEtRapbhhFcx4zQjXna6lSsTy9TFeViubYMjtihIpmD9uvWUMSMVpF
MlWrcMYgNaClHawMvTlBOH3AYuVV2mMJpdnD6aG0RzC14xHpacfDyYBl6fLm
BLYBS0Xjt7y7W3wHqB7y9yxSpoAqmmOhiuU+BiqdPh2mkv4HaS6wf6mlaMAW
ULWWDEirw6rNpKZBaU+AqsNARdVoAVbtiHSTmrqBqsedNtTbiB5NKBIai2PV
Fx2TXfTQdrWMeQfI9nSCDljtdVg932ex2gdW+0lOipW+3MEj9gDZC2/YA2T7
dez5J3YMehe1k+qmusCqE6w6wKoNrFrBqgWsmsEqBlbRkyJhklNIO2pLz0nL
krPSvNiO5cbiYAEUYukBAZOiTkuI9BTUmqsp6pQ0zdF+k9I1ydDVMPukNMw6
6RGmB/6tWzNPYJct3KILp26BF+uqZppJU09sv9XPHUcxUzp8/dzxZCA7rsPX
U4+rZl5pZw4FK6YY2qaYF9GvljYdToI6fPMqWZnTBz0bwSnnzgs447pTdpTJ
nbdtr6211/Cb+UN0EsPJdrriGVoXbM28aDMfuOnROr1d0OzLrq6g3JzPk/5a
8uZ+QV2VXK1516jrkjv/huQu0LopOQtvUfa4Wza0ZS/+WrKgLWvJHclaeley
lt2TrOX3JWvFA8lc8VAyVz6SjFWPqQFJXz0gaWsGqSFJWzcsaetHJG2DHUTY
jmvbMG0bpm3FtC0kqy24toVUtQXTtmDZZizbSG3As/V4thbP1lCrSVOrMG1V
gd3+VhRjHbUUGBYDxEJqPojNK7e+zcGROT7Mo2ZSM+hQTKemUVOpKbaDMWHW
cq49N8E/JdwY/nvkArZtXqeT11e7Opxd7RXslHkfbbwfxauV99iiZQBrKdJ+
pOLVrAVgsXytEfgakWieTskUzR12R9iiOcO2ACyilTXsAAtn6n0UwpmDDjFT
xrBkJYw3HgKyUPpjt4uFsGT169fULy9hpT0c79qpiTpIHsmi+0iMimrlPNJ3
o/cujpGmYiQpBaq5YIB3P2A+zYB3M86SQZCiQKoVpNpAqg2k2kGq3SHV4dd3
DlPsRDtrgaqOqh+W7gBYBejqNQCWQuXONNoZRpII8YdE1WegcsN1fyq7O+im
KVZ08faA1d6dFqvn+y1W+8BqP128/TqS9BJYubOMXnjPnVmkp0RTu3W8+mdu
FOlnDiqqFaxawCoGVlGwioBVGKxCYNW27Jy0ai09a8EyaH3sdftAy4H1ay5k
nf4GWgYs0+VrnK11UsFiyUCWSzkBoKq3laxa8WOTtaZ7dTzVrVc/PFUnlNXD
UOWbejxFvdI+oD5M4aHCPvCqylOqBxVMmUpRr1KUq2STx1JtHhvvFSabw3D2
94q9Uyv1gpNiHYRCKTOrmqJlZ1t2My4XztCLSgpnxO+KYp0qmPVZ0nfNbc0K
MMrUnCuST/zKn6v1heTPuyp5pq7h1/zrOniOU3kLb1K3JHeRdSp38VeSs+Rr
6rZkL70j2cvuSs7ye5Kz4r7krHwg2SsfSvaqR5K1+jE1IJkYlbFWa0gycCpj
w4hkbLSzNaSb4/hpWyTpj2UHRm3HqO0YtY3stY3ctR2ftmPTNlzagkubqU3Y
tJGstR6f1mkV2c1tHQasxYLVmLAKH1ZQy7Biic86tQg/FtGvWMSuehFb/0Jq
ATWPmkvNoTXMbny6Vb+bYJVZKePzq+mdMXnVrjqKv9BZw487qnVArIM/3s6b
aHdgtfHmWnmTrbzZllKDleYRjYjNRiuVKqbltIrmq1QjEjFaRdDqWTv2gVSR
HH6ePWK0CmtlaQ3BUabeQyIEWKEMU/wqj8Yp96msWCqKp5WOh6c/eqLbF858
FDcqkv2YP/jYkKkDYdG8x7w5U5oHCzRRxQrBiiTVXDwIwYMGqhYDlc2HreVD
0lppsWqrGgIrymIlHaQphaoTqDqBqiswIl0NpKtGrVHpaQItsOoNUe78o50x
wGoWbwyqX6EiUe12UO0Bqr1AtReongeq5/fy/0C1hy7g7oPUYTsG9fxbIOZu
87sPhPbq6UZUH9VLdVEdv7Rdv2ZFiooAVQiogkDVBFTty4kKaKX9eaxqXWK8
0nW72DtFEqtM2R6hngYJV6xOxSo075TBahyskx5W1qpnCVcnnvTKhau66ccV
KbMQNFrp+Sn+acc9rXTI6rnjbq3DlFaSAcsGLNiaclzB0koydE1SuvTq2ynH
42iVW7DArMyCFVcr8fDdN9QqGb++xMwhYOYuMZPA6kRtKtYMrU/t7V+KZl5I
+nsDVuEs23Es1Lu1zb4khWhVOEfrihSiVYHWvC+oq0at/PnXqOuSv4BaeIO6
KfmLbkn+YktW3pKvqK8ld+lt6o7kLqMgKxeyciErd9VDyV39SHLWPKYGJBuu
stcNSRZcZa2nNo5K1iZLVhZxKhOqMqAqA6rSoSqNSJUGV2nEqjTiVBpcpcNU
GkztgKht1Fa6hFugahNRahMRZWOZ3eA2ocMmaNpAxFlfA2HUahBZVWfZWkGv
YgUsrWDbX8FOemVUZDm1jG1/KbWYWhR7Ols/fHrE+tfjEetZ2hh7ZRjsArJO
/nYn76GD99LO+2qv1i6iTwfV2qrs2261kBFLyvTHzVgW41PFik0Bguk8xvjQ
UTSLFqhkoxIxncdI3ogOeOfavjhftXuYM0J7yB7BqKxhzVCZw8rYeGUY0jIG
TdoadIbpXeFRTP0yMUz7j+mmjHiPk123MJxF5zLbdvfCOQYy/i6liOV5iEUL
tFOqiMWKXBWDWYmWhaylbChZFUv6dRaAPV2prWpY2nCsDcfacawdxzpwrMM5
1mkdS5auxhF8724ifwXhjM5hT9hS1svqhDLXFfqR7GoX6Sdw9WNZP5bt7rWW
7dllLdtL4NqLZbuxrP8AoYrg1XeI16Cn2EsA68G0nZjWh2n9v3BUfsTPMavr
GKuVasOulhN2CCuiYYtqpBr0rKUVn6hn1DklLVlFY8Fo/mohe2n+0g6jZ5p6
Fllw2nCWrJKxPYTilp3USlbMeAntKDbgmJY6FvdshtZxry9Yq6RNM6UnixvS
aqYdgzRThjSd1a966jHHmn6nj6mYdgzR4qWgmQdSnKqWkqCa/U77kTaSnTQ9
SCecHh/87jfPTbBnc7pLgL1LXkp0YoJvTAs3XYfHdObbyTzae+AUz7D3uyqe
ae5bh3ezLib9nXVu9mfUJVs4VzT3CvW5FM7T+kIK51+VAlPXpGCB1nUpwLmC
RTelYPEt6kspWGKty1/6NXVb8jAubzm14p7krbwv+aseSP7qh5K/5pHkrX1M
DUjuukHJXT8kORiXQyzLwbmczWOSs8VuNDkYl41x2RiXhXGZGJeJcZkYl0ks
yySOZWJcJs08E9syaP1pKLCD2o4I2zBua4V9rW0Ytw1PtmHLVkzbQm3Cmw24
s77RWreOffs6GsS6ZqqVoiGspyGso9ZQq6lVXeb1/pf/Nur+ZJy675p218Of
6m6iPfCnu3gbnbydDujr4O21Q1+bZri2ar0Kt40Mp+y1Ovpa+EQtZLhmPl3M
uRct4elRhS9q4Is6+CIFFPCFDXxhA59BCPzCDr5RGk02QISyzMOwJrfhZC/E
ZQxJMGPINYyghrhguoegTXfaOQxlupuxT8a5AV6UyrVljM3DyEi+8gZyvDOq
yJYSFyvRGuTT0K1tLhsk6zaXo13FkKnWymE+vDJnxW6rHmH5DBvq2qGuHeo6
6kcMdZ1Eti7iWpdzrjtEhbEuQkXHpDfu3F9JX7tdoLtYrbtwrr/HWrfbWbcH
6/R67N3P8+9ktj6s24l1veS2nhdZfy+z7l5h3b3GOnudwrxOzOvCvE43aVvb
MTdUT0VOWOea1LlTPG/Veelc+Yl04p01z3gnbRrg4iHuY4veIkXPNvyoBU8i
9DS1xxkmvGmA89ALWvSkabYNcY2zTpgeJ+EJ7NwpCcS2uHTHtIx0UFXzHA+q
XKr4sazalVn/Drpx3vTEqinHUi1yFVOOpTjkHHCON9v/LLfAeZXiTr8q82gz
F9GcNtfQeHOsoJvOs1LqZqBL0Yl22Yb0Xh96i59id3svZa3E0VY8C9qKZ3kn
PhRBWxGsFc3RsrQVw1qR1nydoLto/lU6rQuuaad14XXqhhTiWuHiW/x4iTfj
WMGyrym9gqtg+Z2kH0j+irtSAGsFqx9IwZqHUrD2kRSse0wNSP76QcnfMCR5
G4Ylb+OI5G0alTxYy9tqt4k8OMuDszw4y83QDlhOpk4bmQ1p2US3HKJbDpEt
B9JyaNw5NPJsGnsWjT6Dxp9OpYFBmjt0no4Z6fiRjiXpxLQ0bNmOMVuhbEvE
0ralhf9vo+ijbIGwLWzrW9nOt7Kdb2E739z/9Aj3O0937Ufjrv2m9MJmD1Gw
h7/Zzd/v5n108X46ca6T99aBc+0Y1877bbPGSSvxrrXajJb5zGiZQ66ZDmsz
nzPGZ47x2aOl+hzDXESZixjmIjAXgbkwzIVhLmSYC+WNug5AKHfUK36co1OA
hrJHJWhK5wkNZqmBQTquwUxT/Lo+2o0n6PAzlTnknkMYzNIadKP+vGbOINSZ
MspqLAznwx/WRQocgZgXKRpUpQeT/sDjzlYZhXdqXnMFVYl7WpjX6qPUOy3/
KMvMjrC2142wLCnM68C8DszrxLxOzOvCvC7M68a87qhxz66ify872QR2wl4f
m0Ffl+OPTaGfTaGfrupuNofdkNdPvNsFezthr5euag/xrpt41wV7nbDXQcRr
/zGr8A14e5NV9Tar6R0K/prhrxn2osfcCeew10g1wF7Pmk+le/V56YY+jz+l
rwP62pW+ZRPQZ/g7IzHTf7XniFr6Tj1BX2gusQn7WPhWvxPod0L1s5lv5nHv
aCVRT+qRr276Ma0Uw98zJuKhX7xM3JuqddSEvaNuq/JNOeoVeW/KUdOHPaYG
avFdpZI4DmGF7b8mmYE4fThpjoqedOdmnIqfiaoUjl/f/CSF08YpLHXTAp8z
tzzTh/PJ6h8Psy6Yu5telJLZtgtbPPszOJxzKem/SvHcy5TyR83/nPpCihdo
XZUiUl3RQq3rUrTohhQtvkndkiJSXdFSm+yKILBw+W3qjhSuoFbelcJV96QQ
AgshsAgCiyCwaP2AFG4YlMKNQ1KwcVgKNo1I/uZRKdgyJgWOwAIILIC/AtJc
QaZIPokuD/7y4C8P/vJIdXk07jwSXT785cNAPhzkwUIuROSQibLgL6vGvl42
/GVDTDbcZENPNl2abDjKhL30FktgGtt9Grv6dHb16ezm09nW03dDKtt6Bl2Z
DHbv6QeezuBvWwanTvBP/2KcwX8mO2lbvW3uBAL+djckdvF+OnlfnZDY6Ujs
4P22K4m89zZYbIXFVlhs8ZsxOe3zNvvEu/6GDx5zHkbxMKJlTIyU6HNAUcJa
Ra4KtcYkVKAn1YXyDX151g71MVlNVABzxySYE69UtdGyyGPmiMeizQxOy2x+
nD2ccKYY3eVcRMwbtJWPhPlGwgI9TFGoUEIf73HQjVlHSvQMtyj2RcuG+Eyu
KvSYAfqxqJurhvj0GIh/LdWUHwf9I9Jag4O1OFg3ioF2SKQ9MIqBo8bADmdg
J/1bNbDLGBgfoutttetG19HOTmtgH/7tcqeO9bNN9LNN9GNfP+71H7aRr5v/
78LATgzsoIvbTuxrw8BWDGzBwBjRL/oTVgkGht8j5v1MJPgBhYVBol8jFTjh
3sYPpEcJXG0J7IonwHMmAbZDYNu3CDxjCTQMniYBegwqHiCYPK4f623OCaNf
k9XPO+gemHlcAjNsmbVQP12xMgjGI6A+pjoBj3qVogQmGwFxEPmcgiYLHlX9
jo7nQFasjuZVJJT9++6QqZ4Ngnvl5pw0e56aXgZkLgcyFwaV2Yurz7g2Vmrn
3ksanw79nL3Dk7nnoz5+B/zOm3u+ls76lLogpbO1rIIlsz9zW13JHL11YwkM
lkCgqfmf8+MFXyT9DY9XpRgBTS26Tt2QYhQsXnJLipdqfSkly+zkVcUoWIyA
RSu17koRChatuS/Fax9K8bpHUrz+sRRvGJDijYNSvGlIijYNS9HmESncMiqF
W8ekkH5t0Q67xRUhYBECFqNfEVWIgIX0awsQsJAQWEhjLiQEFtLgCwGgCP2K
0K+Q4FRA5SNgXp19rXxEyUeXfKTJR5x8BMxni89Hvjy29pxOK2EOW3sOe/tc
Ql8ue/tctvZc9vR5bOV5bOV5bOV5Lz21n/srIPyj8WMS35U+/sxOsN1JI+ul
wfXwNrpb7Vvt4q118hY7Ijq0F9JjFe2883ZcbONTtOFiKya28MlaMLGZTxkz
LsaqlbsYSyDmomIMGqMsmUi5YVEbRCkvGtasGNasGCrStxlCRDSUoBExmO9l
xGDemFcpyqE2IDBs8iobFJuyyY9NNjHmoF+OHXsL5ozGI2DeMPCZ0u8KhhTF
wiEsdlU8hH/mdJQS7VdHSvneHpbQXFuuz4/S143R142R+5q1fMNmRzBMtlb/
Wmq0MLCWwr+2eq0x/KMarIUdTWPSEaTwrxP/OiNj9nMm/aX0sOx7wK+33a4P
XS9m/QCgrqtdbBK72CR27XXBEPx2sRnson+7E+i6Aa+D8NfGz1oBsIWfN9Pv
jRIAIwAYBsDQu4BHCGx6H/QAsOHnIvW/FKmjP1wHgrs2XJS+9Rdk57oL0rvW
3gElHghVQqPhORcIz5pAaDW0ErYsPpOsFOqkiUAYW/AEhnEKdQiQDBg0ZSR0
Z2aTAtl8xik8Rhi0g3j1Ngxq13iaulg77ajUPmdKh/+eO6r94aPGP+9ohs2A
VkEF0MRBO+SXYg5npHr8mQxYoccw9Jy4SXqSrqegK4Uc/8zcEgbBM2bWLLt9
4F+KvfeM3uEu4b63M42BM3XG4wT79GezLyb9UErn2CseS+n9lsy9ZOwrxb3S
+VqfSynxr3Sh1lXqmpQs0rouJYtvUDelZAkFfiXLwG+5xa9kxW3MXHmH3kTx
qrtSsvqelGBfydoHUoJ9JdhXunFASjcNSunmISnZPCwlW0akGPuKt41J8XaR
EmdfCfaVkPxKca8U80pIfiW4V4x7xbhXTKApIf2V0LJLaOUltPoSUl8JGpQg
QzFCFJGeiuxhUynGvWJQKQaXYjb2Yjb0YswrZiMvZgMv2mn9K2IPX8RGXkzq
KybxFWNeCeaVsGGXsmGX2TMIJgqBP0iwz7SrPxiPfr8rfcSHnfyRXv5YL62q
hxbWzRvo5o10uUjYwZtrJxK200tu4w23EQlboa8V+lr5IK3Q18KHaubDNfMh
Y/AXNfRFNRJGfeImLImwRExhX5glFC5T65S+kNIXMmcbY58EtQr1O7WPx3xr
RVOeStik7jXl8htNOeZBwWgiFjbRcXalzxrxqINOXkjLdLYLddSwSG8sFsK5
ULGtcMmwOsxDpEwvdoiUD/NGbZkxLJyLVvHPMZ8ebokR8ZqJd83wpsS11Opr
t9SNsBtpoZvbSsTTaoO5tka4a7T7ig53+khHxHVx/53Zs3Rp7G6zy71H9zys
g94uu0529tp1pOuqj51f33579KKPrm3fq+5oxdv2gqMeNOtEtTZ0aybmRakw
2oX49yBRr4nnNKJdA9oFPkQ64l7tRyI1aLd702fSv/FiXLw+xNuJeL1rnHqm
C/yJy39WvI7lZxPy38fSasVLMuQlq3jgpd5F59uTdrX/G553UslT8HTHNueE
N89a06zj5D9TVr4UBY9/UOoceRoAp6GaKpdq895UWyby+ad+pDN1TfkI9ryy
8Y+vk5x+wBcfD0z5hoC29bhz6JJS3MlzUxVo455Nfd48FnqOnJnoa3zmU0/A
6XoYu3y6uz2OuQGwuQlwkrkXuD7QCS6bpbeHKyP9lZH8yuZoeemvdO4lHuZd
pies/JUt+Jz6Qsrgr2zRVeqalGotvk7dkNIl1NKb1C0phb9Sx1/ZytvUHSld
Ra2+S92T0rX3pXTdAylb/1DKNjyWMvwrw78y/CvbMixlW0ekdOuolG4fk1Ls
K7VXLUkZua8M+8rIfOXYV459ZdhXRlQpw74y7Csj95XRwstJO+XYV4595ZBQ
Dg/lUFFGSyhzraAc+8rZ/Muxr5xNv5zNvhz7ytnky9m5l+Ne5V5rYBVZz8dm
78O9anbqfjZ9P+7VsInXsnnXvmN7wn8+7luKJdBq+ISE30Dyvxv/nf9edoFs
H390J3+8lzbXwxvp5g110xa7eXNdvMlO2mgn7bXDpcM2fGzlw7TiYws+tvAB
W2juLXzYZj50Mz7GWAAxfIyyMCIslIgxMlKt0/tEfPZ1wiy0MESGHZEhFmZQ
mQwqk0FlMqgJMWhGE5tY7E0FWmOm7HbTlC+T4c88gfXTBJ7xKhi1Y4A8q3DE
jdQEi8iSRfBYPIqEpt9dokSWmsPKZcM4TcFh2HKob7pSTwKMEPmiPscjHkar
R8i8VI25LqNW02dzHTYS+0wFcLm1YZQG2gqJbU22TIxmmbWH3Sr4t9KpYRsS
u1rtbkhZ1N2S7p56ui2LZpfFqulhFXWzqrr22l6vHujoIej1QmAvHPa6aSd6
CHWdcNcGe838LAKDQf69kWqAxQA94HoCYB0BsJbn+mGx+pjIns2XZA807obG
/g3K4wUXCD81gbBnzXnHo6FRTyJcoXPLeTS2L1UeP3aB8Iy0LLJd42ZNgzYR
6q5y/ilvJhF0DM81QtrF8YztG4/bKI2kwYaZx6RhhqY/JZLOMkTGmZx2VEOh
Aln3XDwUUh+RC6d+pL3jj5IVSdM7jhOph4knRtLExIl8TB5X0kTECtNJNld0
VWg2tJOPTTvjBoXK47ftGWdR75Cu90n/hD0nMKqLsKj1KSh+anAsn6N1Ucrn
fmZTcdncS/r0eZelbL6W43Hh51IOj+XwWA6NZYu1rvP0JTeS/qOUoWPZsltS
tvxLyupYjo7lyFi++o6UoWPZmntSho7l6FiOjuUbHkn5pgGp2DwoFVuGpGLr
sFRsG5HybaNSjo7lyFieLlKRYbeyCnSsIBlWomMlTbOSJlpJnKmgR1xJY66k
UVfSwCtp8JX0hivBoAoUqgCiCiyqaAxVIFIVta/nowX42Pp9bPnVbPXVBIFq
tng/W7yfXnDNfqtjPSo2oGIjW34TXZwmdvrBt233JsSWHn7f9nIn6h5//+kw
/u44jD+UXRo6Dtox9p0g2UuL6+F9dPN+umiJnbTIDlpnB++1g9baAZLtvPc2
h2QrrbqFz9VMkIzR4GN81liTnvvSqAbGcDLKYojiZIRFEmbRhFlEIS1NkqF4
kgyxBE3BZLDcEdmkRDYpkU1KZJNeMIaQydJY4H0s/s98N1kfzb9610E0gWAT
AI6XPXQbLAHH0jE01CAaKtPDMuWqY4XGxUolLlw1gt+uqvm3qF9vSh2tsa8Q
pfMb06ID3FzP7zcHtCff0gCIjYREBKSAMah/QcO1/pZtjnZkt8NNzNPZanc6
XRrOO+yOSHdIumPqYdn37HTrgnXSSVDsYPtoZz210WNofYGit9DGHrOd7aLj
p1bDTndFetsJe9hXj4GEkK+Rf6tHylqqBhGrEdFHSNy37bI8v/WS7N2Cips/
i4dGI6MJjZ+60HjeDhqu+sR9FlXxezY0LvNC48fSZkLjGSPjkyqeIjeeMi6y
v5l30tuja+84OFtLMyIq8jNr4jEtzY14+KzxMDD9KCa6mmZjICwqismqIQ9T
P0p9ksTkhP6yuqjfTbL9ZZ8OGFaZAcOEUwCNhXbAUC3Ux5PWwudMjUuYrDNM
s625kDiuYfyuref0JvHjIvIw63zSb/H4qZTP1kqkMM6hlM+7RF2W8vlaV6R8
gTpILfpCKhZd5e8uvpb0H6R8yXXqhpQv1bop5VhYjoXlK76SipX2LgsVq29T
d6RizV2pWHtPKtbdl4r1D6Riw0Op2PhIKrGwEgsrsbBy27BUbR+Ryu2jUrlj
TCqxsBIHK90lp1WkxCocrCKF+HDQh4M+HPSREn20Wh8tuJrAU01KrCYQVdPo
qwHAj4N+bPDjYA1e1LbY16tjm6/Dlnq29Xq8CfRTbOcBtvEGtvEGtvHGI9bD
8Gu289P8tnjzo3V8ZM/kSnoKg//s6Qz+9jiDvye7XnZ9L/7UzkPucCN/voe3
0b3XNT/eWgdvsZ232kYTbeNtt9Fc2/gIbTTfVppxi/tYzWTHGCRG+biRoB4q
bjKRkKUQgcQISyQCiWGWTggSQyypoF8zoEmOQZccgyzIIAs0CIlNWizgRmWx
UVlsVBYbiwmGjUVxDFkd9rvGIvuv7loLDNUeNfI1lXo1Su+sbNT9ZrB8TEs7
0xXIFapUFas0T4YwMKxVbSviN+cv1uit5aK1oxKts2WGQev1qE4soK/ajIbN
ZMKWJn3VFkNhawgZw2MJFP5nk7PbdTyixWbvDpZjpzsrppPl28Vy7nIkdsFh
Jxx2sC7a2UzaWDetrKMW1lUz6yzGuoseZuGyLsOs08jr9pBIjCAY00PCyqHj
sYntpoGqp2op/1HL4cG0z+XAjiuyf/tlSyMs7oXFJwLj+vHAOAGNpi/dmdCX
blcWTWA8Y2mcmEWJzD/pxghD2oUGRNODTlYGrYKpPB41CjoJk5VBtxLrnvtI
K2kiCVPi4TDed7bhMNUeP/Fpl1klnGxPH0RAr5yGBkMzf5GOKRoJT3llpsnW
H+uc+9Ntmc9RMd3c4PFsijLI/82yAiYrfnw75wIPc/V68op5Fr6KeXqBLOwl
/bVULLhCfS4VwFdh4cO9q1K55JpUIF/FUq0bUrHsplQsv0V9KRXIV+nkq0S+
yjV3pHLtXeqeVCJfJfJVIl/VpkdStfmxVG0ZlKqtQ+JDPh/y+XaMii9tTHwk
QB/q+bLs5lJNAqxGvmryhh/5/PSN/ajnJwHW0DhraKy1qFdLW66lXdfRxuto
73WoVw8D9agXYDNvYPNu7HANHEqCbM4heAmxKYfZlMNsxmE24wgURdiEY6+J
O8qpzeVZc3KXzj/Tyx5cT2jV+UB3safvP/XU8cLfsgpOedpQon3pP5Jd4NpH
mNjpRqDM+WW0pu5D7uAjrayLt9jJW+2g9bXTCtsQsZWP0ULrbKGlNtNim/l4
zbTgZj5qswuKUVp5hEUQYVGECURhFkuY3nSIRRSCxFBA02C99nCDLL0gS7HJ
78qcmtPk82ZlaoREUxVKXLnRjpXQUGpKz7A12DW6OQ70q7WyVLw5Gvlf8zum
yo2s+ifKdU64pgpwrBiNl1lRlZgYrFIYffpQPZr064RYOtf0jfVruIYCw4gW
GEboG0e1AlTDqG0LsUYd1oyRDpuDtlpCdgA36T8ZBtvYPtpgsJ2F1t5mk7Ym
bk3ene5MmU4WdGefI1BXANtOKyukhRXTTIqPsaKi7DUjrLgwKzBEQgy+wkdk
pTaychtYyQ3v8P/0l5tIgI2QFzhqD46Y7ZyvVWxXhzO/MN8fTPc4vDJBUrzo
hhcvPDUp6tCied+Ow44EDtsSOGxZdFpJTFYPWbje4KJWxHSf7ZnSuCih2ceV
RgmSEZtMHTNC6oYww3ShFUntRk/XoBeYZqNi/bSPTNmdT50RUrvPTzCpZxzS
feb/dPDRsldtfbRx0TsBMQHJJO8qEpOQ7OwD+jOdE0W1TLHTTk4zpf1rczOB
yumn9UZLHpX2TpT2drhn9egMqbFSa5bWJyqncqp0VjxB53ek0qNz/iVXly2d
C69IJXRWLtJzDCsXX03694bOStg0tewGdVMqobNyxZew+ZVUrbKd6CrorILO
KuisWndPqtbfl6oND8S38aH4oNMHnb4tA1INndXbh6V6x4hUp42KP31MqgmM
fuj003H2uxkCagiMNbBZC5u1tMhaWl4dbNbDZgA2AzT4Bhp+A2w2YEIjPjRi
RSNmNNEsmmgSQZpDyDWDKGzG2PSb6RC1sNm3aGfosGtNv27yYrdOo4OWO9Fy
l05Qyla9By2fd7cVPXBW5IVPnnqE+Qk1n5wPzjPze+MZ8n80M/eYSTPIHD3u
SKWenWs2fhpjB++wg8bZsd924dp5520o2kojbqFBN5NtYjTuKJ8wSoOP0vCj
fOIoEEScohGQCLNEQiyZIIoGWUpBFA2yxIINxrCAGSQkXDaxNJsIl40s2UYz
LtlYrR+kwaXLBpZ8QyUfpKFCnpGGckJ1wMyA0OCuyrG0mvjIv6bo85TOChkX
uErLHMBRG5t8XppsqiZNVptj3H71skZhDdXS58bHUJ2tsJb2niMBvSFEpGFM
oo2uMDIWtEeIYmTG5lD8pgkxvVGUDju0tthhiLY2m7/bdWiC5dbe5YYs2Cu1
a153E5+0sdxbWf4tCiT/H2FvFmadhFg3QXa2TUDZyPpqYL0FWH/1rMc61mft
W2y5ZEj/u3z9wB5b0YFEH1VJvZx3XV7MuSaHs76QQxkOzbQr/0CGfBLMnWvP
OzQ/cWja24M4MJNVTJ2Z1HlpzTReUqfcooHJZHXSO+90jlNy9nHtVKtZTbZD
rUqaTrXmxgYXJQPT1D58nChLGiQnKZLJEyNpTsxJiUs5ySD5zLeSpAXyuAFS
J6jTw9BVZmrexLJG6mk4etMD66Qej66c7p2PUznjY0ovLayceVaDaQKUlRox
K2fr3FAVs89L5ZxPqQtSOVfrIlhe9MDkafMvJf2VVC64TKmV1CLjpVQRM6uW
aF2TKqysWqZ1Q6qW36RuSRVeVq38Unx46Vtt46Zv7R3xrbsr1XhZjZfVeFmN
l9WbH0n1lsfi3zog/m2D4sdLP17W4GVNxpjUYGUtVtZiZV2e6xhjZT1W1mMl
zVICNLsATU5br7Zobd3BgMtPQSuCyhCmZYRpFRFaRKTLitLc51rA8w4y+sXd
RIJuomU3caDnLTvnmKLZTyzQ2Zz3smXvA8sDYHkQLA+B5RGwfPFTtviLT+9x
/+bEarpd+a+Pg/nHsvOnbkZFdRo8u2lsXa/bSxk6X7HnuJm3fcg13AOOeiVf
Ew94NoNnjI8XBc8IHzXMRw6DQAgMQrq7AIcQiyPkOuYhFlGQjnlTyO1iwLOx
0eDYoNe5NOrup97tisCzQXdLZNCA3+2mLJ6pEqiSX9MVov9bIYlXDKeoqpOU
12RdWynKLmnUb7JljTvqzdcgHAbrILFOhawfSyED83/hBg2JERCMNNmKBvlx
1EuK/5sZXGhutoMNplrt4EOrDkJ0uEEJlkO7DlLoYAW7ylZNiQm7yuYj7rwl
sIu+ZlNiEz9rfNGOOQf4eT0/r2N91LKJ1LCJ+EGwmnXlY51Vse4q2VQqPhQp
J0W+VnxTXi24EcfwSPZVkyAPZXxuQQTDAx6GJkF+Np4gbYc6WTVkFSRa2IOF
3VjYtcJ5aIYZP1YOk1VDHVJwFlKuj/QbEpuv3emTEiU4aniMEB41QIbnuBAZ
D5DHVEbPRTaCGRoYtYcdZ3H6Rwk0pibSOEGEnGR0tC1CZdSzFQ2Npqet+fHo
ZEPjJHMZ8jdo1GMyz50wE3cmTbIWTovnRqmaph+wytzizt2qEwNdN7vS3Nl8
JnsKGFRagbBq9ifGQavhd78lYdU8rc+kar6Nj1ULLlGX+RsLryT9O6lCwqrF
X5jyIaFv6TXquviQ0Lf8BnVTfCtuiW8ltepLqUbCaidhNRJWI6F//T3xb7gv
/o0PxL/pofiRsAYJa7YNSM32IandMSy1aSNSmzEqdZljUkdnux4FAygYIDEG
Cl1WKRnvq2nwoDNouoZBPZ6gxxZQMKqHHlAwRhOPNduep/ZCtVeqvdPWnd5V
V79jDyoetleK9kHNLvb32vvtZzPvZxPf/Z6drkOb9H4274NIeIhO9mEkfPFj
BDwn8goSvoaEr196+unadhLzpP9svkySw4cPy+LFi6WkpMRMTK73AB6/K92v
jeP4L6WXhtXNO+jSQX09A0RnNgLJTt5hx5vuWi8aaNsr9iBAi9egXbqJkjCj
NPgoSEZo/BGgjABBGChDLI0gS6UJKJpYQk1tNl83tdis3RhzATBiM3gDSzbQ
pEgGGvVAS4D+egAoAyz5AFAGWAv1tXyI+href73fg78eMF19R+p9rvedqv/r
QapCwmS1hk89HtRgflnVNbG11hTtshYCG+vGvHjJHw7W6xtiF6jHcBrcjtBI
HmpSQcPIGQ6OmYGGiIfnJIm5z6ZbSKzFbCV6YLtNkv6DtOjWAqCtLJdWlk8r
gLb0umSu/Q2WZWy/HWWMsbyjQBl91Y4yRt50R/tZV02sp4DCyfqpYcvys2VV
s958/LyK9VjJcypYr+Ws3zISZSn72zfLv5I3Sm/JjxXSwhvySv51eSn3mrwI
pEc0WYLpC+kW0/FkeSkhWV6cMFmqpL2rvWR5ziTLzhVn6Y7bWa/ikv6mTZaL
Tse73c0LTtnBybikJ56QVAOmSmr700HthDd5iKbEEaVMT1xZDLgeuFKa7EBV
SBNQNaCmxkFNdaC6mGkug0lNOAncN/Vo3NNjT8zoYESzMwLavrh1NVWnYteb
Qnhlbh2qg55wau6CbEk1EbNqJgunSlWtmqXX/Hmq2jovVXO0PpWquVrswSA1
WT2FTxMIraiAell8i65Qn4vPcDpOavUyretSDanVkFq9goLUakj1r/5K/Gss
qX5I9UNqDaTWbLwvNZseSO3mh1K75ZHUwWnd9kGp2zEkdWnDUp8xIvVwWg+n
AeU0l0YMp416combKiZY5o6z6jFXnz0kq4dn9TBttMEcxZXmsD26a8alWr3b
0vy+dO1xA4QH7OESPXTS/7KdyHYvG/vzbOj72ND3/9TOfHSQDfyFX1pOX4TR
l07BJ4y+BqOvnxd544LIW5+JvH1Z5J3Pnx4uHad/bb48IydOnDA3Fb1x44b5
9+PHj3vfTzg78jPjwP6JdB+1k5ro5LpmXkveaysNs5X33fK2vaKshc/SQkNu
0SssaOjNOh4LtlEdm3U3swwBQhBogyTSIMsl2G/HdIOk0iBwNIFtI5A0gEpD
ux3/DYBtoMWOBwccSAGwDeg4cUhBqm9SB+t1/LjBjSXrAGldvT7UoVldrffp
6oCS0iGtGhit81tnU/X/ko3G9nk6whIwzwvo8wLqKjFXuYXTRq2AKVpwwJ2w
LU389aZGM8CQrCMNydrZ4MEDNcUO6vIZos3m9NAWSfobibnhili7GwjucAPD
rkMS63WJXXdILK/QHjv+bZbjQdsd1zHLIMs9+JY9pyf4M97Jh25Z6VFsvvez
rqpYV5Uk0wqeU846LOPnpazPEp7zbvVt+UnV1/JWheL6pcH1NYfry+D60jeS
6gturFP/xn6S6r6tCuxncWDNWGdit33NxFG103TbP3bAnvH67TaeTpaWhae0
226BVVwNsCeSVVc6AHMwDFe9SwNcPm2aeTTlv5HW+n8EramJtGpNUl2VWMPp
sVQzV4471/w5M9FzUrJ51AlXTzpNTaXEOTX3k/cMto4mjUOarH6iqU8VnfMt
RcU3TwtIfUD6l3FIfYqoB+niz6UaSKuBtHrpVcpBuvy6+IHUD6L+ldSqWyD6
pdQAaY2DtHbdHaldf1dqN96T2k33pW7zA6nb8lDqtz2W+u0DEtgxKIG0IQlk
DEtD5qg0ZI1JA73zRhBtzLNn5+nZzCF3fMGc9qynQINohLQTpZ1F9ZxpPX+6
0Z472Bpx7vyhOcOjS087dGd26Nk2ve4qV325frb9PTizF2/2Yc9+tv8DbN86
k9whLD2CVy/i1ktHraevYemPz2AoHfS36KC/TSx9h1j6HrH0p1j6/lWRD68/
3VR718Kk/+T+SWeY15uaTps2Lcm7A6He7EJvflpcXPx0V5P+te2hkZTbP2J3
8Qs3+yZNsVmPvvL2ozTXyNs2K4WhNUzz1oP6YT5qmOYefskdstARuRdcBtUT
AaChASIaWFQNeoKAnijA4gvASIBFGdATCFis9VBTB6918FMHr3XwWgdNde7E
q1p4rQ3BV60aVqua1aprtQ081JgkWQODtbZ05KveOztJj+jFi71kTa24oVE0
TjEaTzL/UJdQNhjV1/HqRGWScb3+CZOaA6a0Levf1hGIZ+xYBKlVvxp7g3ac
Ihjy9rz/1YxfhGNumIeKtNjB4UibHSg2A8bu6GJMB5K73biIxn4WW0j3TCzG
JhZnI4vVLF62vAB78noWeR17tTpWQ532/VlFdWx5dahah6Z1egmNu566mlVc
xfflKi2rt5gts4jnvB+4Jz+tvSvv+u/IO76v5W3kfbPsS3m95JaR99WC62aM
IDHaHnbR1hs01de38v6qaHveRdsn5e1y0RZ9k7wrrc3owDi5yWouSz6qcdZG
2qQEdVOMuEZec+rRf4O7KeZx0jfHCJRd3TqeOMz0ZKTVUVWD7tHJKu9T0U3V
O3t49zQzN4idflpvVa2VIr4ZeqW2gmvgnanwnhXfLB0n9ZlhAd/sc4Zd3xw9
mOSbc14Vh17fXC1Dr7J7Mem7Ur3AjgpUL7xEXZbqRVpXYBd6l3wufuj1L73K
O192LelHqIu8K25IDerWoG4N6tau+Upq135N3Za6dfY26HUb7krdpntSv/m+
1KNuYOsjCWx/LA07BqQhbVAaUbcxc0Qas0b1sje9KERPfJYg6urVc3p9caSU
DbvcbeRVopfjmYvz9EoVvWqltTE+xmjOOG6zZxr3didcdLHbXmKmJ4brNHj6
Us+z3e97xd7k7uCbdqJhvS35Ebbvl9i2X4a0V1D3teOk1pNW37dJse+QYt9F
3Z+i7vuo+8EVkZ9/IfLLayIfkUyP3Xq6vr/+pL56v4/f+73fk3A4nORNYI3E
8ud//ufm1tMTTbT/rHm0N8WI8hYjH5pTQ80poqH33DUib9vTRxvfcAeBad4N
r9ihvgY+doOeaoq6AZp/4KDlwKwtFlEti6oWdWtZbLUsvlrUrYWUWhZnLcTU
wE0N7NSwmGugqIZFXtOMav6YNxDgj9gzv/x6OrhfBfYH9WP4m9yZYY36TL9h
uMH7fIDsUDaDqsg8WWoDvECtYbTOzTRdHzBJuUF9bTS+NprRCjdi0RA0CVeH
e8fLkyGoo8ExV/qWQzrja4iezlQJ83HCfKwwHy/SYQfTw3zkMB8/tNP1oVgs
TVTjbruTCrAfr2eLqmPx1bEYaxG1hsXqZ/H6X7TXOPhY7L7X7WCAj63Lx6ry
/cJqWsHXMjdZmWp6NPpIfhl6aL7/IHBfflZ3V96rUVlvy9uVyFr+pbyBrD8u
sqOvJtfmTZxrD7pBg3FdP0vQ9YL0I+suZO3zcq0n66pzTte4rNKx1BJjc+1p
M2rQsuiUVdaMGpw0yCYrsjqaPVeZPa7IetAeS4AWYv+JoZ2UCG1CuE2AVnOu
nuxUbaeD9ObdduYetxk3xd7cxN5RyXynIwi+aeN36QZenjrDPOgFob6ZdvjA
h74+q6/am6z06q9afJVerWSVN1mqld3q+URe1KVvat29LP5FWlfEv1i9pZZ+
ITXE3Rqibg3g1qy4LrUrb1A3pRZ069Z8KXVrvwLbr6V+/W3qjm0jgBsA3MCW
B4D7UBq2PZLGHY+lEXCb0oekSSdYyBqxc9IAbghwQ/luAgeibqTETvgQq/Bu
8PivpCNkL57WS930guoedzGvdxHvbtrEHtrEHtrDXtrD84fsTW/0/RyEn0NQ
dJg28CI8vQRVr5AkXiUwvkayeJ2U8QbCvnVa5CcfW2l/eh5dL5BlPxP5xWV0
JdseRdjjCHsSYU9/ZV7bTEg7SX/jN56k9dy5c+beka+99lqc1szMTPnBD36g
t85OSp2A1u/Gx2aT/rkEsLSeBluvkegte2zYRKQf25G+Whp2DZbW8CFraPA1
fOAaBQAIalgA/n329H6zcnfbU/6r++zp/z489XXbSwJ87Kp8HeYSAd1Ht6nw
1XrJgBa2+ljgPjdo4GMF+PTqdV+Yh2rzYNJiNdnRp9XkyoyMVmva9Td5J4X6
9dtqlRN6n5GaRhuIvaMc/JqrSVJvGK1nnQdCdpyCmuQYbXT5WseNm5TRphZJ
+lt7ykabq3Z3PE6Py/EBg3zYIB+6SUdIWAiN/S7eO0XNVstCq91nF54uRD8L
tPqwvVqsigVdhaaVdB0qWPjlrIQyVkYZK6WMLapMRwI+tKMAKmkBW9ep9kdy
ovWhHI09lF+GH8jPm+zN696vJ7Oiany0QFUtvSWvu9ECzayveJk1Z+LMqqMF
JkM8oaqXWT99IrPa0YInVe1c9rHdzp4xqOpLfRPV5gUKakJ2taiOZ9djRlRv
iHzmUePqU0lNVlF/1VGtbyfWREhT3IXo8bGC6ufMg4Fzguw6zWbXFHNr3lSb
WWd4dSZZ3fR+SeV0mfUsLzkbPKvn6Gy51aBZPVfrUy3jpm7r8y+KX4vE6l/o
XWqJneS/msVXpAY5a1TOZVelVmv5NalNkLNuFbX6ltSjZ/26rySw/msJbLhN
WT0bNt+Thi33pWHrA2nc9lAatz+SJuJqMH3QzMoV0imns0cknDMmYeSM5IuZ
FCxaZOZENPMjNpd7N17+c2nz2+kVzVSLDXYeni6dpixi5+nR+Xp0eoQ+nRLQ
zYu1x015+rzOMU972E9bOHDE3sFH3+MREsWLoPQy2/4rQPUaqeLHaPo6qeJN
MutbJ5D0FFkVTd8jr/7svFX152j6SzQ9iqbHr4qcuE47uSlyBk3P3hY5d8dm
1z+1Q6dmXNE6qb/9lBT74YcfyuTJk+Xdd9+NU1tRUSHf+9739KaZ36JW/4B9
id+2W4BGIxpyFR+qioZdRQOvoqFXveIaPsJWAkElC6ESGCpZIJV0Yiv32UtL
K93wdEU/FlX0KaAVLMMK9kwVLM8K7KkA2gqWbwUeVeitaSvbeG6lGeOudOcK
VLIuTEV13VXqEE6VWlulzFZpiq0Kxo9pGdUB11WKqssG2qSfU3/mt6UxVwcf
aoIes7Uh8SpV6hyqyTosrEfa9IRhrRZbRtlWHTFgt/D/2IN3Ha667DhzI5+w
occNkLCLqUfVehZKHarWsZBqD7hcesjmUvPGWaBVukD5WsECLmerKmeBl7Hg
S1kJJchazAopZsUUsfsrZDdYwFZWwFZ2fteAnNv5WD7ufiynOx7JybaHcqz5
oXwUeSC/CN6XDxvvG2H177znvy3vVLlRgVI7KjBRdtWRAXs61ZPZ1RzwIrvq
a+3ZfFH2IOzuDYnZ9fyT2dWOCnjTO3csPSPt6Nq2+PS4sPGBgZMG1/HIelwi
c1xknX3s/6evE43ETvrGOVXfPMjlTXc07mtqwizm1dBa/Zy7GV+KuQXoJFQ9
mRBMT6mu+oQZOsN69YwzUj3TlnkBmK2epXUWYxOh/TdxaP1a8z6lLiDsBafs
RaNszUK7HmrIqFbZK1K79HOE/cIoW4eydShbt5JadcMoW++UDZBRA2TUBpRt
2HhHGjbdlUbKbN4o24SyTUbZxxJMGzBzvIYzh4yykZxRieaNSRRlowWik2yn
uu61TlLb7uaj1Om7dU5bnd9W57ntcXNM6/yQfQSSXR3j80rv3WXnxt9HEzmg
t0ZzN6A+TFM4gjkvupt5vMqm/xqb/es/I54SKt6kq/Y2uP7kuMi74PreGZGf
guv74PrhBQvsR+B6DFxPgOspcD0Drme/BNavRT4B2PMA++ld8/o/ihv7zD9s
7AcffCCTJk2Sd9555+nGmj2OzcG/Yz5BCZ+khIZdwqcqedlONlJCoy/h05bo
BCR88hJELQGJEjQtYYmUgEcJopayhErtDJ1SSmQr3akslu1UXstYimWgU8YS
LQOiMmgtYwmXAVRZGx+qXHkt9w4h2gkCYq6i5r2bR6jV/5OKSPzU08qwJddL
B0RPn/muSs8J9elDtarpNz+sicTPNUtyktbF9JiZxtJ67d3Xt/IbgTZx02s2
8C4buiyZDb2Wzfqd9mK0ul1mELhfkv5vqdGLc/faFF/N0qlmSfk0jL5og6ju
myrhstJtKzp9S6kuaX5WDKFFEFrIDroAQgvYjvIhNI9tKZdt6dL+Ybm4d0g+
7R+UT/oG5GzPYznT+YjA+lCOtzyQo9EH8svQfQLrPfkgcM8MA+jfMAOslV/J
W2X/uMCqnD5xZqobBjCcesMA3wqsn9hzB1aeS/ISauIwgHd4y5mqZ+gu1DM3
8VSa539zGOAJU1MmMrUxbuqkRFOpj8xAQAKrKYms2jP6k3QSkY8UVq2k1G8R
mxhhU8fPJojPMEylTEitd99Tc7dlc5d3njf9VIrqmqKoahCdaYdFElhNcq76
53ySrJwmq6dKPZrWaC24yFNqFup9aWoWWVFrF1+WWqdpHbm1DlHrll+V+hXX
pH7ldTbhVTeSvi+B1TclsOYWmAIqsbWB2NoIqI2b7kjT5ruU3ekGtz2Q4PaH
EtzxyN0cYMBgqvd2iuaM2E7cX5g7segdWfSmBjrTt0La4Wa27A6M3yhJb5LU
FzX3HJFd9PD62+0NR/RmI+b2bRCxn4ZyUG94CyWHYOUIjeRFGsnLNIZX37Cv
+ToN4E16aW/RM3ubpPoO/f536ff/lH7/z+j3v38WRD8R+fmnJNSLJNTLFtST
QHoaSD8G0nNA+glJ9TyYnr/tiDDTv6Xqc7/7DzN65swZefbZZ+Xll1+OM5qW
libf//739X7uE44K/IYbG9Cf6Qx1eS+62eoOu5nroCGfT54PE/n7IadgnxpZ
gKWFLJhCLC1Ek0IWVOEuuzAKd/K0ol59ms4RVdzjSueM6nLzR3WYuaSSpUQf
StuV0tI2xzHroZR4WGqOwZcqeGUx7wAVvvKgwdWqWuF66y7W6ryUlSbWRvQl
dZICX0JVR72DT6k6oCv+ZjO6a0d4a1o0xeq1vLWt8UrWY3BJ35O6dndETi/x
7bRjxTpmbBrsLjumbFTVYplU7zXjHc/r0EHVPpfoWYQVLMoKFms5i7icxV32
qp0cq5QNqRRRS9C05B23HFVWfpaPsnn8LJeNLAdlb7DxXTsyJp+/MCKXDwzL
Z88PyYXdgza89hJeu9C2ww4PHIs9kI/C9wmv9+TDhrvyPtrq8IC+/k9U2/Iv
Ca+34gOv8RMKEsLrkcTwmuad+mrDqw4P6Gt5wwP9aPvt8GrPd00YHjDitick
2FaXYvE22QwOPGtOJojNO2GGB6KK7QQhVi/EmHXMjL2amhkfg039FrsfPcnu
pF8x7PqMUjtZqf2GspO9SZyAVWd0nzzRLcTU2JRfzev/bFg1r8xXP7z6Z2ud
w1atT+D1E5NYa+ZpfYqv1AJjrNQu1PpMajG2dvElY6z5GEuvUJ8bY+udsYGV
1Krr1A2DbAPINoBswzpq/Vcg+7U0bbwtTUAbBNrgVgttaPsDvU+nvd1wut6T
eFBvnmf3mv+rNOfpLY5F78inNxe1NxrVeyJX2Ftj6W2yOv327ln6cnp3Or2F
Zh/pdRexpp9Wt5smtptGr/fN3Nttb+5r7jRO+3kBXw7RXg7Dz4u0lZfY5l+h
rbxK+vgxbeIN10beptP2Dun1vV+CLen1/RMiH5BeP/xY5Bek118C7lHAPXaJ
1HqF1PqFhfesgnsLcL804Ho3/bpAgL1IgP3snnn5P4iH2N/4h/W9ffu2/PCH
P5RAIBDX9+/+7u/MyQZ6uGsife0FBnYjzETcTGjI5CNnHVQ+sg7o87OhIxtC
sp83E9vvVVdz97p5RuEmD3ryWGx57sKIvF4+Tn6vDm4XwG8B9BZ0u0KtApZ2
QYe+VKHaW6QPUOzdlk4n+Wsx5c1OV9LsPG4xHiuVHsrJmnndR6rA04pmY3JM
nrFp1WdINWO8LbbMj6s1tfo1Sde069EpPejm5235dQ6ZbjePDG/dp4PJfKoq
LbdzqWLD8ECtcKCWs8TKqFKWXulhO/NgsRbAFhFli9hTF7LhFL7pIus7tsef
T1zN+5l93Wy+v/MT+/9fAvJNfu/6i2PyxeFRuXJwRC7tI9busbH23M6BJ0YI
jjcTayP3ibX35OeNd+WD+rvys9o78l61PUysIwTfjrU3nhprXzCx9vITsXYc
2oRYO45s/GqBbpDtUmSXf+xirUN2yWkL7aJTDtqTJtYaZeefSPbO2dKcOK6s
Dsj+UzA78aDs5G8yW5PIrBlDSLxFkN/eR+N44v3PUHY8zmr8nXZSvfVK8dUR
2uoZpxRfU35F2G9GaP3jCOvrk3D/2ABcA8A1c7W+ATAhtxaEDcCLPpM6LQCu
A+C6JRbhegCuX0Yt/0ICK64agBsAuAGAG1ZTa25K49pb0gjAjQkABx3AoS33
JLz1vrlvuzldJ+n/lFjOsBU3f0xaC80d582d59sR19yNvtLeRbWLmNtNzO2p
Q1t3SLmPmLuLmLub9rmHFrgXcZ+nwe2jse2nkR2gcR2EkUOQcphG9SIN6SUa
0cs0nlcR9zUaw+s0nDdoHG+9a1/zXcT96S+Itoj7wXFiLTH3F2dEPiLmHj0v
cvwC2iLuKcQ9g7gfX7PqfoK651H3U3t4Sy4QdS/ehlvY/Qx2L8Hu5ft2DPX3
4vZ+fwJ7fy3R3mdldHTUWPu3f/u35qQv/W9gYED+7M/+TEpLSyc60+C33K/q
z7YDyQ5XaSyDNIBJA5q0vRCXvke712ZeeyqTytJC3SxMynLqZveqjtk9Cl4O
fuW6yuvmJfK69K/rhNF5LPk8cywsX+EtiMObcM0VMiuQRZo+i80oQwkql7S4
ajZf7TsHYB0GqDAPrW7Q99d0/FeqEsqMNbS7I3Gd7uicHqUzb7qKN/33Usm2
UKkDy3ygCj5YuVa/neKwjF1NGdtHKcukdJ+L6S+4UZbDFtsiOg5FbDOF7KkL
wLOAbSefygPfPPDNZRvKBd+cd2yKVXAz2Z4G2HM/otv0gO7TXf7t9lv29W/x
uzd4vasm6Y7K5f0j8tneYfl095B80jcoZ3sG5EznY3sgrIWkG3VJt4mkGwDg
ujtmiPZd39cm6epr6slbT0u6R745TOuS7v6EpKvjCvo6ieMKIOzw/f5EB8Li
4wrxpLvIIqxjtfpadlzhRELUtQ6bI2F66cdsvTDhmC29LMEOMSQYnPQPIjzR
EEPKBEMM46O4CSDXmDMNaqba6Zq/obKJwamqspeU7Z3AlVM9SuafrucY+Kef
gl2vTvNvM/XCLxCG3jMew/wRHbqtmXMuWfVlFzHvPBGsFnhrE+CtW3QxDm+9
FvDWL7Vn2im8AYWX9Kv4Njh8G4G30cHbtI5a/6U0bfhKguAbBN/Q5jvAexd4
73k3dommP5JoxmOJZQ5ILGtQmnOGpCV3RFrzR6W1YEzaiqzBHSTfTgzuwuAu
DO5Wg0m+PSTf3noSb4M7FVYNpg+6h/a7l/a8j/a4n7Z4gHZ4kHZ3iLZ2mHZ2
hPb1EqHmZdrWq7Sp12hLr9OG3qCH+Cbt523ayDu0lfc+sK/7/kek3WPW4F+e
xl8MPvYJ/mLwqc9ETl/GXww+h8GfXMffG2KR0Y/5HbkIwZ9pwfAlGL4Mw5dh
+AoMf/7AUvyD+CDE7zydYu86hpMnT8of/dEfydWrV82///znP5cf/ehHcuvW
rQkj8PfjY7v88iaQ2UxtAZqtfN3KAtkKQNv6Faptu5S97cC0g0pzlQ5Y6e4c
pvQeXipDyc3s1j+UBXTZWl1G506Tp0Ewx1aSl3H1d3VOf4rv8tvEjKemGH7t
vxqC21TrUg2udhxYCS/v0FkIdWJYczjOvZFK1mYlb7yCD1Cx2ymq1W/HnUt2
23HoYp00mw9bxFovYs9TxB6oUIstoABhCw55h1r/L8nX4Rm2hjxkzGWLyGHP
nIOs2WwZWeiahZyZbCEZ7Kkz2EqG2SMP0xcacnNEPWav/ZC4ew917/C8r93g
lY26Il8cGpMrB0bl0vMjcoGoe34XUbeXqNvlom4rUTfmoq4ZT7gn79ffjZ9u
4B0M09f0om7iAbHxqHv1iah7cIKoa0ZwUVZfa9e6T5O8zdUbT+hB2XjUfXI8
gefiLM/1lG0h5urrxL4tbdIT1IYmptZdsOC6iP8YapNV2n/s2MITxprjZjqq
YAYYvDv/Olgtqvqz6SdUVqNrsj4mK600Jb/m25lenZGaWVofA6uWvUgOX6V2
rtYnCKt1Hl/PW2cXfCp1Cy4kS93Ci0m/Y5itX0wtscwGlmpdkcAye+2eUtvg
mG00zF6XpjU3pGntTcNsEGaD6y2zoY3Uptv2Q6NFdPt9ie6wJ63EMh5Jc+Zj
acbZFuPssLTmjUhbwai0F45Je7FzlrzbVYGvONuDs70424uzO8m7feTdXe5k
8z0RjCXvPk9e2tdmnT0IAy+os5BxhJb3Eq3uZVraKzj7Gvnlx+SWN2hVb9Ki
3qIl/USdJaO89z459+f2ddXZX5wg56qzH5Nzcfbkpzh7kZyLs2c/x9mr486e
vynxcHeRzHtxYmhZh1A70cCs8en3n46udy3ukSNHZMGCBVJUVGSuxT1z5syE
p9f+thu40J+tZUGso9bD0QZqoxbfb8TTTSyoTQTCzdQWHU/Yqg/ber20up2F
uZ0OxI4ufpymD+km4mbws4xOb44vHo2j9GNyWQt5CZXfJuMJeJIU8G1hQiWZ
OFCk5zKYYeLiDn0wfJsh5G5TPKVYwS8276uk3wZUE04P6tjyAUn6O3M7AiMr
VUgVIG3BfjegfdAOcOtAdy45NpftIAcJc5A2m+0hGxmz3fxhWWibybaRgZoZ
aJvONpKGtKP0cUbZz46wvx1hexhhuxhm+xg+YX9vgG3nEdvQfbaluzz/Nr/7
Fa9zy73uVf7u5wfH5PK+Ebmo+baffLuTfNvt8m3bIzne/HD8uFmjHjdzAwwJ
+TYub8mt+KVh8QsUJjqFNiHf7tv6rYsTLLg/NIfNdq75JA7veLz92MXbb48v
GHTd+MJT4E1wNyXR3aSUCdCd+LSEBnsmrZ3SYHxag19l77O/Mt8mmZuSJI71
xgccQNi9pMu3tqZbjB2//Dr5tgZ6KX3JWdoIx/ml5px1mzYAJ/1+nN+6+VpK
r+EXfbUuSj1RV/0NEHMDGGz8XXZFGrSWW4Otv1fx99oT/gbXUetvueMdfyUR
4m1k2z3jbgx3Y2n2VOwW3G3JGpDW7EFpzR2Strxhacsfwd1R6SDjdpJxu3C3
G3d7yLi9PrzF3b4aCnd34W5/I9k2SLYN2216Hxl3P834QId19xCMHFZ3d1t3
X6H9vUq7+zHt7Q3a2pu0hbdoEz+hbbxDG3mPtvJTksrPSCwf0D/8uZvO7Shp
5hjt68Q5zMXd07j78aUn3f3khpeYnpULzlyVU8cY1N1L4+6myBXD7mWbc8dh
Ndb+wdPZ/Tv7pKQkeyfPH9qwOH7uVBqf2xUydujJTxnuOqZMvmplaalv2epb
jj7kmsGAvHY3StBhbjGVLPldnuL5OpTbq98VGPH0+3wWbf5OUzy1z8RXlnR+
vymWRN5uzaf5LPUCd2lIAeLkax2xh/pUPdUvh8pGwmy+ZvGzLCTMZO1kImEG
EmawltLZQ6YjYTprKw0J0970lva/hzWRMfZ4Y/Q0xlgjo+wRR1lDo+dRkV7J
CHl05KR9D4O/cL3+b+TRL3n9m+40wC9eII/ud3l097Cc7xuScz2D5NEBev2P
6fU/kmOxh/T6H9Drv0+v/178+NZ7Xh51x7j09V4v/sYJWgl59NA3T4H9f2m7
7+iosi1N8FohQZr3XlW9LvPKdddU93RXTVd1zapZ3eNrpmfNmukyzwgnvPdJ
JgkkkAbS5yMtiZVDSCCDkcF7EN4JL4e8hBXy3oRRROz59t7nmghJZL2ZNX8c
gdyVFHHvL759zrnnDM+jGlx+PGxoKyc6irKIoqKI6GESdSJBXLSIOpcglkHU
4S1rBuz/PyhGr4WFt6/Z82LNqWttViJZ9Hteh3rj+OIxUuuPkcEuzqNWU8s2
Ss+rK5PCQZD4vZKYEEViLG2aUgUAp1ZbcwaRRTcDQjQPS4hykx3cAge3zOLm
dvCxOLgNDm6b/9R2cPtCtXC7cTCRGyxMWtpi8ub/RilvtVPK8g5KebuTUld0
wcNu2rGqh3bAxLQ1fbRzbT/tfHeA0pFF+Vi71vlo14d+2v1RgHZ/PESZn7CH
YcpCFs1GFs350niILLrvO/UwF1k0DzV/Hmr+AmTRA8nIoGYSzxEUkEdxTR9D
fjmBi/YkYtYpeHjmgHpYiKvz/An18DKutiu4yq7hiriOK+MmrpAi1Py3ccXc
wZVzDzX/fVPVleKqKmcPcZVVNhgPkUlqUPPXNpnK+sdU367drlaXq5Bodbma
bldoKBbi/x560seWPO5zaHzFpvHPfoDGqNT5B+bb+WNz8BDMRZuHNh9JcQHa
wixGZFEWz0NYbHaFX2raG2a3eN41nr//LXzf8kxr0v8K/t9KKeRX4RPvaMPB
VvMn1mSSC+R3s6TFckDFhzmqvm+1HJK+AoTudXhq1uGpWQdA15vF9tajXFiP
p0n+xcfW43PrcvVr1uH9dQX4YR9wX/EHB/nNIT7+B4dlGI/WnTSjXh+clg+f
UVDfPyuo4uXhLMWMp7V4dy18XQP/1uCZXw1fV+PZfweviORFG0DDU0N4qgiv
YoSnkdrQ8IoXxitfGM94GCk0hFfFkEmhQV1ElwI4W7xIoQN2Cg0jhYapAz+n
zdT+/HWaQkP0qCBI9blDVLs3ICm0ItOL2t+k0FSk0CSkUNT+OswFbzc6txtY
t8hyCuVjWkNd7ttkoyfDRs8niO5l5f+7J8IqutUjxVDPy8Wdbotr3cSVOnW4
uKaD9f+1uHJDV+xo4kZ1uY59CcBjFODvtYe1RPoC8A3fmx6B7yGutpeIu2ky
D3RtmlLJ7EJdHuhie8eKu/Lbqb0SQrfMqMNLxcx6D9Mb8xPaCni3RsCr+G4H
vNsXPBN4ty/UZSITF79geA24/0jJCKApb7YJvKmANxXw7gC8O1aireqmtHd6
KG11L+0Evunv9gPeAcp4X/HdvV7hzRR4g5SFMJr9eZhyEEZzEEb3fGXgRRjd
v9GBNx9htABh9CDgPQR4D6eRwMvHPM7wIjGdwtV9Ok/hPXdI4b2A2HPxlMJ7
tVDhvYECr+ga0S3Ae+cWd2QCXVxKD0oQQhFjyir1uBWAtwrwVuPyq0HkqUX0
qX2hn+MOgPq2SHkfmcEuxlOkBbnCrYe1xcP3COY+0gkI2mMqXa//+jczVzZG
McNbsxApZ0HA2WgR/jKSCzK5AF+IdxdxA5KGYGvO6jLhkv19y7TlXPC/nc0f
XoEHdQUS/so90jy0ao/1m7wDSVfLANNq/gT+G0tr9rGxa5FX1+7XJr233IsL
W987qHtGS04+qv9/77DuJf3uIbbyIB/8XX6XR+mO8MHXHuXhubWoJtYe17YG
r6Jr8WSuNTlyDZ7UNefkFynkXozz/LisArCr8CyvRAv5gxT2hyjsC1PYG0Yy
DevL5o8ivcVLKPHiPMi3hCc5jFfasMm3oWorB/81DaFa8d1zRrV6r4WRb8PI
t2FqKwxTy5kwNeFVodGsCvH4QIga8oJ2vq3MQr7dZfLtDuTbZOTb7SbfbnEq
/2tS+fMtXrogzAWXuU6+bbL7W6Nv8TL51po5kO+avsVVPx8quuqPyLhzJeM6
5OI0ct2AIOIqm5HkpvwG5Or6W3FRk2eL/z+rK52wsSN0BIxlcscouXCWOZ1Y
ZmnLAXYSj2dpnf+QNkmrYGV5PAvW2tJunoqQuxnQIs1Oq0ZzsN0yg1sdO0tb
Z3FrALQNBlsFd9tcbha2TwXbxIXPTTX/fyDZNlPyGy0uZNuAbDvteLsDyHZS
GpBNM8jutJBFws0wyO76wCu/TyYSbiagzfpkiLI/DVL2ZyEgG6Y9SLh7kXD3
IeHuB7K5SLh5SLj5qPgLgOwBRjZJkT0CZI+mo8o3+1ychAWncYmfAbJncVkX
4no9f0SRvYTz/vIZRfb6BYMsKv7bNxTZe6j4H6DiLwaypWVAtgLJtkqPW4Vs
U/3IRjbG2hWZe1rrGVpcn1Lxu5DleAtaVTLb2LG2sQ2m1au3Qt6/+82klYkK
Hs14syRxzoaRc9Dmos3jEh5BF6fcguyIpVVpEdxcrHNIccilPGr1xh62aRke
wDdNewttOTdounyf9M7C3lxr0tgKPMYruYHQlfv5McH/cDT5WL4MnuFjeAv3
CnjSwzt41VuNJ2Q1fF1jVv1aDTBX44mRf/GxdwDTO0fNv3h/FTd8btVJBv4U
/+yVqFJW4nlcCVtXIreuLLRW4/0/acCn59ZQIABah4TXkA/EekHsINoAmO0P
S56VB9LyFc8dtWqmJVQv9FQzbRjPe7hGvzaETBvEueHHOWKNZ/XdCNuZtv18
mFrPhmXq1ovjYXp+RNeodWfaqmw/Vez2IdN6qTRtkIpTBpBp++kujL3t6kMY
lmnNioZ8vJEzbaO96Ja5wcuco380/BZa04nAx7Ju7pJOhIUvmbo1wuIEw6CV
dbdiR+V1rM2rIZaBZV5l7WwOtzqY5QxoRbi6OfoeBZnH9aqTYV2ajudxMtnr
/nvpPPh+QolEV7tN5NcBZtX0A0wqt5qHZeXeWsRY0Gqa4rpZcWVbPUwr/iTG
dct0bro7g+KKJAtdkQ3Y1m2wddscbm5bn1i2xlj79yQtaqQkBNmkJS/kUMni
LNqyFjjbSqnDnO2knau6aOc73XC2h9LX9MLZPspAoN0Fa3d9MEi713nhrE+O
l/VxAM4OUc5nQdrzuctZBNr930Q6ewDOHoSzhxBmDxtnj7Gzu4hOmnKYnT2L
a/8cO4v4dAHOXjymzl5hZ8+pszcvOc7eLTLOIqOUFKuz5biuKuBsJa6zqjo9
ds0TsoZd65Bn63FZ1oPahjayO1YtZh/3MjPcZRAnXQYy4KXEethXDwOLz9WB
2Tp8fa3eJPaXo0v7ixGk/RN5q2tYcZ6VhgdiNmCdk23dIjA/hw2dDzMXmLZw
j/5Bi/HvYji6hAezluzj7oYliJ9L0d4wbRnam/t1UOxN+PkmHte3Dtjzg5dD
z+X40PJ8+dfDH8CbgxxBl0PVt7kd1raCG56KlZBzxUlrTGvFKXzDCukKeBuG
vn3KtNN8nDP8Fy8HqcvxtL1V6LzEPerpomd9PdTc30sdA/3U4x2gQcNsEMwG
mVnfkIdC3mDM/zJMWcJTQT1G2w7Tc8BJlqdoPENDkiWUMGHdQILCeNUNlpL0
HDhJNixJtutymDouuJNs2PTUhiXJStmzb4iqcwJOkt0JZVNNkuWeWlfvwY2N
ugSMnWQ3OLfS8rF0jlbkQtzHnHu/zEP0+3ZPbf6It9HWGmlHGMBy34kQKW2M
04kQIa10IsRGLXA41pLWbmYxbo+5tdaFbcxvru1I07WGp9jx6m6c3XHgYXY9
EmVfZXHtToNN3CaVOfImqLqxjC1+2JRKj2bYLdPgLHTFH7jFhFf+nq0z69Ak
wCKNz27wMK/cRQJct897Yl6QFFUEV8CKtriRkgFr8pImOUYKYE1BiE1BiE01
uO4ArmnA1YI1HbCmA9aMNWhrewFrH2Dtp93vDwDWQcpc76UshFg+XvYnFqwh
2osQu28DUAWsuYA1D7DmA9YCF6yHAesRwHo0CtZTCGVn9uqlUIgr/TxgvYir
+RKu5su4mq/iwr2GK/TGeYX11hWE1+sK6/3bBlZcOmWlBtZKA6sGWOuirkXG
YVjr3LC2G1i7bFjd3QINfdbYej1/oo7f1PbKijD44mq0qh6jxki2vj66rX/q
+hj3F9gj+DhvZuPxmIM217R53GDpPDxG89nS+dZq5LQQr0eL5F7aRRxUF+Xi
zWJeuWBJHkfgpXg0l8LPN+DoG3hU34CXbxy2bFzG95ct40Jf/ye3PyxDEF12
TBq+5M3j/LE3wembp6TFWDS/iVe7ZaYtOR3SQuknVNrRSdXdXXjV6UIx0E2N
ULR1oI86B/up1ztIXr+XAn59cTaKxiijf28YDQ1jlLo0rMrj5+oQ4MBKKFCo
3jCK5z1UTjQUEVjD1HfddAhEBNaQBNZnCKxPDobpUb5SGhFY071UsmOQHrwk
sOpttJ1mCW5eJZbXKmylswisEhjswPoiIrDy5yI3d4kOrM5KWvy1YNTDjsod
tFUjzHSV2a4x3DFQ4WY07QcYjaOkKRGEel5qaKy9OoHHltMq+H+oE0Biq2cE
PmPt8FoiqXWT3TixbppYGst8chfqpDLBUxBNKJf+gM1s6GZjKC8Jjqy6hdu0
6ghLZ9TQVli61e2psZT/tDnaB64XhrxJnP805v+ixAXPKGnhM/E0GWE1GWE1
BaamLFVTU2FqKsIqe7rD9hRtRQfthKnpbOrqbvF0Fzzd5fI08wPLUx9lf6Sm
7kFY3QNT934Rgqdh29N8eFoATw/A04Pw9JDL02Pw9Dg8PcGeIqOdNp6eM3Pl
LxxQTy/j0r5iPL1+Vj0tumg8vYaQelM9Lb5rPMV19LA8ytPH1kYIP6a6JoOp
6XVtsHpdrbu6OJEaReu5L6BOAisAFSVr8G8Ni1rdyymzCu9WmtDEraxz1Mzq
dlWKmT/m/+mMgLE0c7cTVWdla1ydzdX+nD2cG+dC0rl4dOaCznnc8CjNM3c7
zce/C+TG/QWM6EKu4xcW8C+9EI/hIrTF3HjUafFhrssXI/8vMV2oS/DwLhE1
l/B0KP5vLC1BLb/khDT+BFf0S07xVgSLAdDiU0HXC3csLTzeTieftlNhY7t9
g1FxRzdVdvcgwncj2XdLLG1CLG1HLO1GLO1HLPUD1CGDasgfcKLp/+yYOsCm
hoeZSm3GVasTgOPpY8dUQpESfuiKpzK9KizxtMcdT88hnp4OIZ6GzO0DIbuj
lY8j8TTTTw8zfIincDUVriYPIJ72I57C1S299gqF7pW37fVfeSIBu/qxuhoV
T61dKIdtETPi0q+1bladjtYRVyZwL1JYEbn6tkOrtR6s9AbgidRdDqy+19Gd
5d3WdN2CCGo9Elfj3HGVW6ztruel7konwetirgosXo7n424SaDeNdyOr0LKx
pawt/gg4y2/KmdwE/QM3T35oWgWgNdr+KFpb2jqdG1NruJ1ZK9Sqq9tm1eup
/g/IrY8ocd5jtCeQlttTSlrw1GUtGvKrZW3qG2jLmvXBFmvRlreJtTtd1ma8
gwZvd7G37/bS7vf6YG0/rB2gLOTXLHib/ZGPcj72w9qAHG/fF0HavyFEuV+F
Ke9rx9qDsPYQrD2cCGdh7VGXtSdh7Sm2NtuxthBFLFvLx2Rrr+K6v4bYdAPW
3ixUa29fdqx9cEutLb0/orWGgN+jGjPCVdtkRrnatPO1HkI2dKm13Lnqspap
pVq0GrRqbvh8Va/pmK3s5ZK9woVtKQ5TDA4e4LD3lIS/+M0CrXP/WKzrs8Zi
7qrNYi+NxTQbCM/GwzZHBqzmSJ6di4dwbq406zV4HgM8nwv/+Qf4S+Yjwy44
JI2NPiwyg9+FR007Rpali/HgLz4pDV+6+JRZ6GcR/utF04nQKWXtlFnVQQV4
2Tr5rAvwdtGlJr2L9H5HDz3s6kXK70X670Fp0EONgLcF8HYMDlCvb5AGge4I
+MJebsGX62sNcZkuWHkwnzudA2S6hagCqbaMZJiLp3F570BfpNre684wl6ba
kKTaxuMhc1tBSFJt/f4g1ewZkmNZqVa6YVORapM11eqtBbr6ttVBcMU11CWp
9jNNtdw5wMc6ua7JTrX8/pG1I21Z6Eq1I60Pu8heqsDD/sb8tukf+M0E3mH3
yP4wv4n/XH4jewviftjekboM4rTLQHfUHm9FavwP5rLw0Jc9nlDK+roaj31B
YcQVzrubuSVY7aELZMEYX7sFGv8YEleqxiJy1Ygib5vJrQ4W11mXyvY5DWiP
2GTOvfMec+c1TBaPFzzFx6ByzH+OMvmFmoz8u8O4nAaT02yT0VZ2wOTOCJN3
IwPvRgbOhMuZH/TD5AHKXj9IOR96YbIPJvtp72fq8v4NQZgcgslhyv820uQj
MPkoTD4Gk4/D5BMuk88AmbPG5PPG5EvmNsqrx43JKFuLYPKtC2ry3auA74aa
XHJHTS6PNFk5/l0ZD7NJbnbuOuBJB0Iy4m9Dz+gcV6FVcpNO3IpeMlvOloPn
MmNyCYB4gGPdxzHvAok7MPkWSt8ihWKkIbOX2Pz7ts26OJgOALi6FTychLkX
F48YZ2BpeOTm5xPzSwu4cdfrgoPW0NtCyb+M7yLAu+iYaXL/FOxlgaHvEm6n
rFVgXqElZ8L2a45k5jP6VK+/1mNe7sbTTlQBWdXdVIDXtVPPe+nci1661NxD
11t15aqyrn6q6ulHHdGHl71eetrXSy/6+6gNKHd5B5GIfeR9CcxhgTk4HObo
uQfW2NgL7W6QR9TV3UA4LcLl7mgcpgFEY3t8zI7GIYnGL04gGh+NjMa1pueW
j/dwl4nGpsvhXlK/LIBordoVOUbWiWjcQRcMzlY0Pm3j/EIfzp/S0bXOEJkd
jUfcSnb4rgjG5hjFeewwnHU/We5wmF2BZ3dEm6eXm/SXKrvLWhuAsc/Jrn0T
HJ51TgLvFsw2T9LGv4ltc6ydhmNtkWNfmoY9OmSme9iIw/BXLZ5QIu+VxGlP
w2ZRN1JcVZfF5e/YAnW32Oq+9oPqbptRG2PtILd9ts6vs8hNHEbuE0oWcpNB
7v8u5KYIucpuKqLwDrDL5Ka9qaVQ2vJW2gl2d4LddEThdEThDLC7a3UXyO0G
uWAXUZjJzUIUzvrAIXcPyN0Lcvd9HqD9X2hIyAO5+d+EqQDkHtjoInc7yE1S
ck+A3JMg9xTIPc3k5ii5hRa5BUruZVMbXz9pyD2n5N65pOTevw7nikYk1x6M
4TkI1QhFNc9cdx3wyga8lozpFqzv1oEvGGZxy90LVuoFtQwtPeTuBjgb8xMq
w7ulpidC4h7EvYuj3cFRb0HbIvyEGxD3On7aVQ3evym7ch+vdOr+SP/Hx4jj
Tlruo6XFwHUxZ9vFLOuSg6zkEjxmSw5rn4LVn/C6OXfewOP3xlmnLTvLj9Gy
c9zRuwzl94oLQVp9aYjeveKn9de99PHNQdpw12u7uqsazztehA487qeTjQNw
dYAuNvfTtdZ+ut2ugbiiZxAP3AAexH560tdHz+FqMwdeuNrj89KAf2Rbwz5u
kbbSy2y1RsSanG4HeegaXN0O/5zgWwhbz4SoaYTgW2eCb1WW+lqe4aNS+Fqc
qhsj8BLet7f1DQu+9qZfdtdDG4JvK4JvC536sFkfzp9J7j3KvbmSe59F5N58
135fdu4dYWta46vpeqi2fI3RXRXj7F0VNfjCWegKhtMi9v7SAl27dTX+Orxq
/NU7a8fY29VabbvsnaBTvgyw1pSv34jYsTasHifXWrratnLnLMItgLVaHNvK
vbcPzVHBqkXrVN4QYStI3TrNajarVnDlLLt9Vh03/jtm18fMs3VNnCu6UtK8
x25Z4SraomeUIrKqrqki6wuXrGhvtUBVHRNNf7sNskJXBFqRFYF212qVNfNd
tPd6IWsfZa/rp5z1A5Tz0SDt/dhL+z71QVY/ZA1Q7oYhyKqdYQXfhlXWTZGy
Hk9xZD0NWc9A1rOQ9ZyR9QLUuMiyogy+AiGuInFdN8swi6znVdZ7V1TW4pFl
la/nWQfVDS5Z9f4Fvp9LZcWVWt9lry8rUwlqe0dlVdOrMbWk174P4q659+EW
aC3CYW+A1ev4EVfB6mX8uEsA/QJ+9HkF4N+OLuzPRxD2p3awlZW9fmKEfQsB
/63TaGekmcS6/By+dHkhH3AFYtmaS0FQGaT3rw7RuutD9OGNAH1cFKBPb/np
8zt++uq+WX1tAqXXDFFmrZ/21Hvp4BMv9PTR2SYvXWzx0tVWL/4wiNKl0wOq
er14+RlE+h+gp/399AJ6tkoy9VIfkulIgoZHEJQGWdCQCmrdiRDVcRudUK0B
MXmIakgHxIZ13tKICbXZnVAPIaHyDC5JqEEk1CGqhKIPd+kgRUmalx5A0XtJ
A0io/WZ7mV668T1S+nfddNV0H7gHxc7poJh5NfpTOrFOB1COMaMmoh6yI+qT
USJq5LaJOWA02zCa5WLU7PINRKuc7RM5or4GQCtcEXVERmPU0THOPrVmr9ok
WZ9rOKXbX06px6Y07qWUjtW0upmncG2ewHNjOaOyoJtNk6+eWCKOxjGgsQwo
zuctiKdbJrubOKqmIp5ulVblYUitvTe3cTSVzgBezYwJjZN4mshtToNeM5xP
xxhD1VFjKD9Ii57F/J0YmiqGNroMbVJDkVB3vtXqOApDM8TQDhiqCXU3Emom
HM2CodmWoR/2056PBmjvJ4Mw1Ev7P/dR7q/9lLchQPlfDVHBN+rowY1hOgRD
D2+JMnRHpKHnsuEnDD0fbehhY+gJwHRar5vbbOjF4YaW4fopx3X08KGVTH8m
A2JVJp1a94DVGENr2zSdyhrdPA2r18zyivJzBDvpQa/1M36binC934TF13Gs
a22K6SUc/yKu+/P4WYX4mWdx7Z/Gzz+F3+MEfp9jWqHqouD/fE2dJRAkuZq7
GWRuFV5sVhzV+VUrjqPhAVvJY1krZWaVPTNVZ6d6aFWh3CJ2Xm+q0vJPw/z7
1wjaErQNQ9swtA1D2xD9+m6IvrwfpK8fBGnbQ3vOxu66MOU0hGj/4yE6+CxA
J14EIG+ALrQE6GqbH/L66W6nz+4p7/NRQ5+XnvQP0vOBQWoGvO0SXX2K7whd
A5H4DkFIG18P6xszzum2je4diEqwPHAmD6hrXhcn2OgZtJEJNkytwxIs34Eb
dBJsdoAqMv1Uvkt/5eIdXrqfYvzd1o8E24cE20vXN/bQNfh75ZsuJNhOJNgO
JNh2TbCf6jWIBGt33fL7R99tRIR9HhFhZeQM/kqEfeme4LVmT3A1OHMEfzPU
3xgF+FUb4DQb4IdugN0ZNln9NV24Y9hfdxeu9BJ4WN/YEeDd6obXmeY1Erxx
mmFhLsNb4mFjrRUNOLBabZJE2En863GfwBZtfMfv5IexklvNZskqrr7noW3T
qz2sLQ/ocWB1QquHsfWwtjzTYK5OQbCwTRZsn0hgTVnIgfUZoAW2S54LtjsE
WwU3zYTWnQit6cCWAysfK2NlO+0y2O4Gtplr0N7tBrY9lP1BL+Ws66M9wHbv
xwbbzxhbL7D1Ud6XfmAbALZDdOA7BffQprBiuw3IJDrYntoZhe0eQAtsLwLb
S8D2ssH2msH2JgJaEbC4bRa8Z2wfGGxL7xpsyxxoK62bbXGBVZmFX6oRemqA
YE2rLitb26nY1rlCaqVB140sA1usyNJ9G9p/QTcB7TUc4wqOdRHQXsBxC3Xx
LjqDn3UaF/lJ/Nzj+PnHAO0RQHsI0B7AxV5QTZSnwXokc19zmxtnmxujnaCv
2+zqTWS628LqY3pzAN8ksAYZfw0esjVw1rpzlVcFeO8C0fvI++suE62/qqtW
f3yD6NObRJ8h531xmwAr0Zf3rEkbcfQdXsM2om1BLkyqNND+OWXj0d2HRzcf
f92h5yFAG6IzzSE8CkG60hakmx1BZPkhKu4ZwqOpHUV1/X563O+jZwNeejHo
RcwdpE6fd1RtQ5a40JagLUVqG6Pc/t+R3LrjbktU3H1iuMXZQe4bFkpp2E1h
utShe65CODLuHgg5cXePibu7/VSWob/zg6hOg6ItiLubwO1GjbuXv+5C3O2k
C7/uQNxtp3Of6RV4mjsN1jdL3D3+vpIr3ErcfYa4+1Tjrj1ZQcndH0XuniXQ
At5C0NHE3aXieoRb3blWsRVwPawtzrUdxtvU6dr4KFafbLIVeKXLQIfNJpe6
s65w63EtyiXkTrTJjYnavibOGSyLWpN2woNXbHFjWVxm11rVENRa0E7iTuPN
CWUOuZPLY1lc/AJbpjy0ugyk2egytdOqWF5tM4zAr7gEVoUTZ9eZxMuLniXN
5T3BkiyJReHHrDC/LiH0/q8RCu8QhVXiNFG4iXZGKNxKGSv0PNi10lK4E3G3
i7KgcPb7PZQDhfesR/uwDwr3075PBmj/Z4OU+4WX8qBwPhQugMIHvgnQwe+G
6ND3QTq8SecqHrUUTnYpnAGFd7sU3ucofAUKXx1J4UKiu5rTVGHQUYprp6yY
rG3HKnB5VQK7yke64kEV0k41QKxG+qlpMWt7d5hdaXDp1ujUWJlj8LBHx7VK
TU9CMf59gHYP7S7abfPxG/jeqzjGZQB8AccrBMBncOxT+BkncMkfM2uJHwZR
B0HVAZCVj0s/FwDvB8B7AXAOLv+sstHTr1ti+dtes/HVux1+Jr/KOhQD64Ht
h64FVT/GI/QJoP0Ur1WfQpPP8Eh9flN3sN4AZb5EuPva7MX6HfTZiNC3Cb/K
5nLFNrHS2v/yNTqKP+ckJDvboq81VzvCVNQZprvdYTw8IbxWhWKs8ZtHA0P0
dCBAjYN+5Fkf8qyXuiDrSMoG0cJGWXKUZVkHgzH/0dWhENUtaykbPezl7prF
08/BNmxuDwyW6UzbgBVszXIHvKp3Z9StYcO6ZnMRbPcGqSpniCpMx0JZupE2
xelYuLUVwXYzgu33TrC9ZILt+S/arXsRzvDIF+fa9UD2gyY69t4LybV8OM61
B9+xkH1icu1jIKvdswztPhvaeoYWznJ/YvaiWnjplnY3SzvPlla6Z9O5zZau
2YpYMXbsaMZ6GFicA67+BJNpbWN5NN4A65Hxrjhb2K3SNM++bhaY3WwGsbS7
gN/GamfBRGkxAmusgZVRlQ6BSdzFwW8hKGDd4mRZxpU/NxkvF1uncK/sVtOL
oH0G/PYV6Y2N4pW2z6iBq7zND3SN+d2RfKWkOQ0sLBLuI0qep8YaXymFG5Ju
qviqxu5gY5c24phpb7yI+aXL12b4qsZmIOnuMilXniZOuWs54bKv3Ui4PeLr
3o/6aB983f8p+zoAXwcpb4MXvvqo4Gv/MF+PbFFj2dcT8PVkquPrWfY1y+Vr
bqSv11Ep3zC+3jpjfL2gXQoCoOVriUmngIuBrTDA8tKGVcg3VbgCq3ElVpvd
amTbr24H10oXriVoDOt9Aysf9w7+vdVD1tJyV3CBX8RhzgOcszjkaRz6BGw9
hh9zGBf6AVzoBbA975E6uw+27sGvlY0LPguV7G4gloGLPh2/dhoCeqpuNv1v
fijwRnYyjLHB/TNX2v38vG4UyHuybMDD9BWA/RqYfFOkm1x/B2A2IsluBDbf
42dvxu+wBTFvG3Ddzrji90vB75kOoDIbrFA/lvLxMB7E33YYf+NRfh3B33y6
RZebjflteoTk+RQJtBFJtNkboDafHwnWN8xXXts8EOkrm+oL4I9zUmyQP4Yc
+7cj+zra0Jd7akGd3nobqnQtJ2OGv5zlDXTR7o6LkTeFRc661eGv6j1BqsxG
Ys8MUDmMLd3pk84DPu5dGHt7Wz+SbB+SbC+SbA+SbLeVZM1D+CeSZHn467QO
f9lJ9uh73HGgyDpJ9ukwZPe/ibaMkW2gvUB2j4MsE0tZ3BRZ/EwQi4hrIZvh
Qnbn7ErJsmk8DgZnPcwsTqdh0E5l3oy0w5Qtjew5YG8nlbhnfo1q7ismz06w
ZnHhfza5xTK4VUJbnOZx7I0Te7eYJpIC3li796Dc7rgFurHm1N06tcLqSYC4
uu8i1JX+BP61h6H7iqCbODK6/JDMe8QzCubrxhaR6Frw2uhSGrc3XtBOQVfh
TUewzTChltHdDXQ50PLxshjdd3sE3T1Ad++HPbTvo14E2j6g20+5nw9QHtDN
B7oFX6F97aMD3/qBbgDoDtGRzUE6CnSPbdMZQja6aVHo5jjoXs6PQhf1cpGF
7jkNtfcQRx5AkuLbVg38sxHBtfZNqMKlWY1LtBpa1nT9MLaSYLsFWiqybgaD
tpfx/RdwuZ9rE3HoOI59BAodfK5F9n4k2Bwk2Exc8hn4XdKhV1qlypsK1VKg
WzKUS4J2iVBvO/Tbdkent460Ns1LyPXY5P4bO/fG/A59B0g24pH5HsZuBi5b
YOxWQLONfyL/ZFifjN8kFbbuwG+3E7/lLvy2Wfit9z4mq4OaeeU/7FiTZtrT
rfpH80sN96cUdesrEve5lMHEh/14QNFqB8y9xQhZ3XC3B83ydpDN9Q8zV8j1
SKIdr+YOuAbJ+sKRg2TR3kZP5TJ3OfBNuCFevsu1iCx31o60kKzuVGOWOzgR
pmdHw/RElvDi3oOQ6T0IItMOUfnuAJVl+KkkzUcPUtXcO4kDdAvm3tzch0wL
c7/rQabtRqbVOcfnf91BhZ+309lP2xBqW+kUzD3JvQccat/XUHt4rS6+d/Cd
Z3TgJeayt/vecMzNcZu7sJYy1Vwl93VwW236a0ckF+JW0A6jroexlXm2Sm6y
RW5sRK9BqXNLLlM71k2t3U8rv8JWmW/rXl6GuxCKX3dri6/dIh0MW6xga0lr
f2zLRFtZfm9SqcZccwCNuvzFfO8tJ90xYq6Jt9p1K5MPQC//OoB32zRp/MIw
rcp6YZhebenL8OJN4qxaXunBJW+SI68D7yNKAb4pCxRgN7w7kHiHw6v4pr+p
aZfh3WXB+04Hkm4nZa3R8yb7vR7Keb/XwNsr8O4HvLmf9VHe5/2U9+sBwDso
8B74xkcHAe+hjQE6/H0A8A7R0a1BwBui44lhgVd6rgDvmfQoePe64D0AeA+5
4D2p8N7BNXIX+eT+NXtql4H3D2RpmYcG3orHLnjNnoy8uW11p+4cPiK6+Ph9
tLvdii7bcqObrC7cwjbnjgZOe4dw6AKk2tynIpbIxYKxZKmwNgkRaysu+U3Q
buMDtffbuzTWVDscRn99STsTfgNy7Vt59da135JPbAewiRAlCcCmcHjGj9yB
H52GXyEd8mTgkcmERDl4ZPbiJWm/tRjEzxxcgdgZgyu/slzGA8V9Jhzz73On
NnAtA6wVaNUDAHaQqGFQH5FGH9DyhajdH6JOf5C6/EPU4w/EWLtb+/x+YOun
IbQQGtmdCH7H3FhjbtDVW/s3w82Nnpxgcq4czlr4gJfwqtElaq0tE/xm0eGR
tk1oK6SIxQ+e8uIHB5FzI/oSgsi5Q1S2K0Cl6X4qhrv3U9Td29sHqGir4+7V
73r00f0zurChkwq/6EDMbaczn7TRaWb3wxbE3GbpSzj63guJuYfXRLJbAHbz
wW7e208oF+zuB7v7DLt7o9jNdrO7oIZ2L7DiLtT1MLk4l7QjQdF1wBV0pUMh
FWn35fB62FzX3ITtVpvEONr38Cp0oPQVfvuqqBorlqqzLDXejrUBZTGtVWNM
JwFtnVweZ3pakVmlm0DaVITzbVMrPaLmWNNNoE0ug2g3Y5lMD3vJq2zNbaBk
btxB4OKScyp/d6oh0+IyjZuLy3Tk1PS3mikDXO5iLle2IaO2U6bF5douyuaO
1/d0JvmedX3gsg9c9hkuQeUX/ZQPLgu+HKADXw3SwW+8yKg+cOmnw5tcXG5n
LkPgMkynzJqzwuUuUJmJKtvicr/D5TXm8oiLy7O4ek3HwH2TUa2rvsysxiUd
BIDhYYOSWWH2+Ko0ZFbhcqvuMlyCw4doZWglaA84eqHd4XyKxkNc17usnzFG
NOGKmKvjA4hFec+ctbx34+el4zLdUY0UWKlV9uYy7db85r65m+pH4iFvM/Uh
D0Fd0g1SeKOUdYVmOf8zurA1f/Wfj27oP7kMNet1xfy1fOxH8rGdD7Tfgfsf
uB8iE49MDvf54pHJxW9agEfm4FPrt/9T6dc4ZbzkV4ULHerltS5J6XRHB/+o
BGaWs5kDamYdm+kleurTR77FH6b2QIg6xMwgzByiPrR+f4AG0XxoAX9AGUUm
9fvdbELNgNM/MGDyar8rr/aEI5fjGs1NnthlluaylpvlTQ8CeDj8JbqpF38d
59X+G87GXrzxQSsKoWbe2At5lZecfQI7H/FoF+ys5T6CvVYfwRCVZgSoZKef
Huzw0T3YeSdR1wd19xHw+5e+7qILX3ZKXj1n5dVPnLx6fJ3Jq8DzsMHz0GoF
9GV47lU8PSwneLLs5C6CTMvO+cPsfMUJq9F2qpl4+4r0D6Rwm1YuA17GT8DJ
hoLPWBef2118bgOfcYZPQ6fDZxzzGWfyp/HTTqMuQ+PE0DHiZ0TgnKy9rNLh
WoEv4LJ/m5M8JXfGsp9898D0aqOo1P2UKLU/p09hlJK0xain/3lUT1PhaepC
Y6rt6TPb052m7k9/qwmWwtO34emKVtptebq6A9HT8TTn/R7a84FuZLt3fT88
7Yen/cM9/Vo9PQRPD3/voyOb/HRkSwCeDsHTIJ1ICtFJ4ynHTz7eOcvTbPX0
EnuaF+XpMa37uea/Y9X8N+0AVYp0UfpQV5DlrQzKzZ2VvFVXBdirxJVWCSyq
EKqqcCVW4YqscDMKNO5x0EK71WUzSldtSl+TqvdYs0bOfBC9F0knCzluJ67W
ZFytW+1pY7H0xV07psZYvT3vXJBF/WgF/oS3YebyU+Ze3VVnZPnUU7IcIK3E
K8dKXuTqqFnwSm9r+69+OJ26P6Wy6gLhPGK2Dw9MLh6YAjwwh/BLH3liRfY/
p7PNOhLHI3KX8ABdMYreMH0ed3kqRZ8jaSVLCkXroOgjtCeQtNGvf3B7IEwd
0LQLrScQpF60fmg6iOZD86MN8aIwgQCF0cjPzW8euFlRpA45XQDDSA0PH9Ky
ulzNUsHWOlzhR2bHhBrdwSuAx8OPE8aHOOrlbtc7+vV97l0T8ALXghe3JnsX
L+0GaChAHM0LUc0+xFG7G2CISsBqcZqf7qf66G6yl24n6l4gVhzl/1/+ppsu
ftUVmUc/1Tx6kvPoepNH32+iI+8qq4fA6kHDasGqZ5QPVvPAaq7FquRRZXUP
Mqnm0fphru52XJV+gAxuc6vAKjeEObjKtx3MshJphZVIoSrkAqs8XRawJhtY
k4bBGuvqbt02yVG1xATLrZOs7tZihrVkjPahbplkw2oKezF1LHNqzWTdqh2n
MmKl41ZxVhi1ONU8qrMCtk+3Gl4/EEitdW5GA3WOAdXDlsb8nWiaMoKmnE75
QLamS59D0kY7mWZIMm1GMjWarmpDMnU0zX63i3LeczTdu75Pjrfvo0FoOmg0
HTCaDoqmh7710uHvvLamR6HpsW0BOr59CJoGoWkImobtYp41lY4maHrRrWkB
ruqDqunNE6YH1RTy9647qZSXhSlB6ChF+ChD/irjHbmQv8rNzMcKXF0VEKMS
WlR2RFGKK1LuskK73WlmtaJd7ZRsZk8R5TqXq3fuWMx9poym4edsr9D0ueGe
bCNtdebOzNfMtfSM3GoqN/4vBJMLQOR8EDkXf9YcvFjMztcCfzYvMWDubV1Y
YFZ0KdDbsfjWrEV4SBbpamQjuvqquvqLET6lrur5fBC/8WHEtWPWAmT/NZ3D
g3MeD85F/IGXWnWm2TU8SDdMLylPhLhnOC0FpeUDymkNOK1nTn0aTJnT5oA+
4B0gtQutG6T2ovWD1EE0L5ofbSjAnA6BU3DpkMoFvj6A/12UpsFITXstTdE6
wsM7VKNCqqwf2+DsQSMhtdyEVLMvwqDZSbPXFVLbrJCK17jnXOAfMQU+RK3N
DVE1RK3kAj+LC3yImh5ASPUjpProTtIg3do+oH/OH9KVb3uQT4Hpl13Ip53I
px3Ip+10GsX9qY9a6QQwPY7i/tgwTBsjMV3x1OTTJ8inj5FPHwPSRx6WNOan
lGMsFUejLN1lLFVHqyndWLpzjhVRJabyilwzKzSfvs6S2vk0eTilMoaVaDCN
M5huS3AwjTVvFdMSbrwY66SSOIPoVmf8KcYKpgko7rcaSRnScrPcp+HUqe21
rudVt6PCqYctjTWOWsFUAzo7OgaG1lqOSrdossy0SpaZVsnzGijF4lQofcx5
feGTmP9EO0wwlfLPUJr+5gs7lNqMrnQozWJK1zqUCqNc5HMo/VBfdPd/4qXc
T72U9/kgKB00lHptSo+A0qObfXRsi5+OM6WJhtIUpjQESsM2pYVml6mLexxK
rxpKb8Cfm64i/+4Vi7g/p2IQVlzsUFqK8FEGLMpAXTkuo3Kk0odmtZcKXHKV
XcpouUmk0gfKabRT9WBFeHj/UoeWuvx9J1q0sOfOT+74TKvRIv67EpkUai2x
Ej/FH/PHeOul+Kla7MVP68f/e9G68fFONN3PKX67j+IT/RSfFKD45CGKTwlS
PB4QFjAery/xO4nGo03Eg5OQQTQFD9C03UQz8CDN2DVqTjWeylLf0m36H/h/
ejX/BRXikbiAv+ISsLnSordA3MAjUoS/+naX9gTzZLISM7rEnZ9VpvOTzXzM
ZvodM9uG9NHpwr/deL8XdvajDcBOL5qaGaQgWhiN2E3/kOOmz+4Y5R5Qb8Dq
+FU8pVc0FPMfHDx7DJ6d4eFxtDkyjtobHNTr1oZDqBsCODv8OEt8eNa8vHW3
a2MZ/r5Oe1QKFgPQRrz6PYuq8mtQ5Vehyq/IDlK5VPlDVIwq//4OK44OUtG2
AXN2/g1d3dhLl6HoRSh6AYoWftFJZ6HoGSh66uM2OsmKrrcUbaYj7zXRYSh6
aC0L2kgH3jGKrrQUfRqtqMTRnKUNwmi2xeiiOsochdF0N6Ozq9yMSh5NnWEg
fQ2IRkE6tTwC0kRZcIBrfYA1uRSUStOpV2KqZzRKXYrqGNPWSaX21+nHPPbo
U5kZcjIDUGOE1zF2WrWY3SZ5dXRbNaP+PSXOqOZ8ajf+fgg7kq/Qtd4U/sN8
lahq2ZpmYqoYKzH1BWKq8XVFi8tWtNXwdU0HZVu+8kD/Bz3i674PuegfoP0f
I6Z+on3ueZ/74KsXvnpdvvqMr346tlV9PZEYQEwdolPg5PSOEJ2Br2ddvnJU
lT4nt6+HTScqzvhbhXLTq5VQH5gFYYvNtjEllcprKfOKdFKOC60cF91DXHwP
zXiRm9YHZnjplrnvioewLyurpiYeo6TWc99omLY9DNN3xWHzud+GnpBxKjco
OYUbxJzMTeGInzKABmGn9OFjPWhdaB1obfbx47+GtN/ge74NqK4bQ/hc/Hb8
keMSQeP4xOgh/n85OqzxowbVv5BDXMGDca1Z78wtwgNym5ec6dSozuNtPPbG
90/wkjU10LUOuj6Crk+g63Po+sLI2gokO4yu3fi3F60PbQC6etH80DWAFkQL
o9E/S9cxdjSVj2uxz5/rC8f8+8h4Gt2Hagp++T7ePsbE0xBvHPsDBb+1TaIk
7Itm/AnCvkB98Rzn3VMI+/hQmBoOmIIfwlai4H8IYctMwf8ABf89FPx3kr16
bv4tXd+sqyxc+a6XLn0DYL/qpvMbuugc6v0zn5mI6gL2GIA9GgXsAQMsR1S5
zABsLoDdD2D3Adi9NrCPBNjsJQ0CbNbiegNsHe0WYGsF2Ix5SokAKxlVgU0z
wO5wgDVDUPCVq/3pVky1hZVqH4Ey0QxFCa+saukYqGpBuQ1QMpu/ZfDcmqDT
UrcKlFt5XpQp66HnVh1q4oI+Ak8L0G1y0xXwjJMCXzpKrQI/RuV8bZicrKa8
IDhyciJFLv2FLWeKS05HTbTFTyltsXaV7pSuUp0BJwW+pNJm2m3kzLRS6Zp2
qAk53+1EKnXJub5X5NwPOXO5wOdU+pleAfm/DkBOHx0EBYe+8Rk5/UbOQKSc
qUOQM0hndoYgZ9iW8wIX+ZxM9+mZfPWgjtZzKpV5/xcllcrn7iNT3Ee2eMA7
buFqsLZ+LUEOKcUVU4ZsUoarqBxXVDmuroe40iq6pLA3ueEnMtR02wwz2Wwi
75w1zBbg+3O4T7QmjCQapvjpnJ7ipwX4zZA1n0jwnDIKngmDaMBzMvBMAJ4J
wDMBeCa0U/ykVrPMVJy9qIt8z7dgM34jzzwdt5Fo3Pfaxn+vJf6/Gl3OcaPK
+S/lyLdbdXEuXqSrGH9zKb+M9OhdZ7zmYh20bICWj6HlM2jZiPYCYjYDutaA
atllxLS1NLdF+aRcD0PLMLSEbgFRLxDkX25kMfGN3HiwfnCI2TcDTtYDERFJ
o3tIXQNP8rVm4j9HUt5TNmhF0moTSctNJH1gIiledftuOgNPfIxWoNl8BofC
6fYMaD45ghcOoFnvqukrUNOXo6YvRU1fjJr+PtC8m6J/UtH2QbqxZYCubVI1
L3/bi0jao5H0104kPf1JO52Emic+bKXjomYLCvtmOgw1D0HNg2teiJoFUDN/
1fNR1dwDNXMcNT1MJh5tBjNzoaK5aziaHhYTJ0maY6bW9TgNjZkmkT6MZSx5
oSdwyWFUz9XEKWUSR8ugJTcTSyWOlrKbxk6XoPgY1Ix5Xd5qJN1qPuYxjhpR
DcvyBu+OZUbHmC5SqKmHky5SFTTWSZxRbs5SN5NsO91uxrrd5JeI+Y9i/gdx
c4dJm2kmbdqVvOkUlXxvqvndK9jMVkmbWa60mWPc3POBmVoqbvYhbaqbecbN
/C+0J/DAhiE6+FUAbvrhpt+4GUBFb7k5ZNwMOm5msJvhSDf3a8coH5PT5k0n
bdodoveRFu7f110KH+CiKEaiKMZFUoKEUYoLpxSpowwXUxkurHJcZA/hYllX
VBXfpT/DmqDPA9ZnWp1J7Nmmek+Y6qWJaBOmmdmQ8dP8eB7jp/o1bWrjDw/p
a+jvRSCqgKLOnwREJyKFTgKkE1HnT0KdPwl1/iQgOrGV4ie0oOlTEz/ruSbQ
twHtqj5zR3P8Bk6iG0bb02AESsePSunvyCFK8bCUm04OnsnAK83wQl6PQOgT
EPoMhDaiNYHQFhDaCunaA8KnNZ21P1pPtCBaaEgFtTOnP+gI6rMF5bjJjyYN
BjRy8rEGglzPB3nmU59CCkD5S3vCMRMiR+5dHaPydWamKafOEFJn0KTOITyP
Abyu+h+OXNf32ndQmQkI57Sufw5Enx7Dawkqn4aDYarLD1MNEJW6HoiWoa4v
AaIPdgbo3g59sm8leunmtkG6DkSvfq+Icuy8YMdORrSTTn/aQaciEG1F7Gyh
Ixaia5tGRDQ3AtEnEYhmA9EsRE+OnZncJHbWaexEy4Ci6UbRnXN5hUFm9BVl
VGJnpcZOEz1TrOjpYUTFUHP2JUpJL4bK2+1TLEl5+AlvARvH0OF+juW3r9iR
U4R8xXSCmsrcbvq+6QQdY9x0ivXtMrpk2xkXbaeH4cRhrcjJ35+Mgt0U6x5x
878fljbTOG1GqKl9oBlmOGnXcl0C0EmbbcPS5p73Vc69kHMfy8mTnT7uh5wD
UNNL+Z+rnAVInAe+1Du7D30zBDkDkDNg5ByCnENGzqBdq5+FnOcyQlS4O0zn
LTn3mjodafMazw09aSYL/Uw2F7iHEus+Sq37OPkfVCiWxbgwSnCBlCBtlOKi
KUPILEMaKceFxdsA8EqovDYfLyJ1o0O7Oy+bO5n41z3V4gzEZzY4c0CnoM6e
jHo7YcogTZyivZvjpvpYMLxF6pziM3r65WMSR53a3dTjPxlZzwnQcwL0nAA9
J0LHiYihE9oofjz0HN9sz7ESPRdC1SX4/HLE1lWD1sIQ8R+PvOPWiIJOiOwf
NRG0uls396o3y38/6ddtxRthZhO8bIGXbfCyA851AbYeEzf7zZCP19TfDpYg
i9vIYMoMfD9zaMVOrxTqgxw6B4a435OP3B/UBjOp17jpDp1uM83iudZAEm+s
HcJpEDShcwihM8Chs9KETtQmXpw+gziNBkyl3oNKvQt1TIcxs5krdTbzBB4Q
nIGPYGb9gTDVwszq/SGq3BuSSr0UlXpxxlCMdZPz7WQfQqeXbmwdpGubB+gK
zLz8nQ7Pn/+ymwph5tkvuugMzDwFM09+3E4nPmqj4zDzWJSZB2HmAZhZADPZ
y7yVlpnPaD/M3Acz98LMPTBTvXwkpTqbqV7W025jpqbOKDPnVIuYHhbTw1zi
WUmdWSlgpsyoMHV6HCUjeyZPeyh1etK0co/IqUOUicih0qaUC54etlPIfAVk
ltlalkmmfM0eKAKU9metAl16Nz16/xK8HGM6NOUA6iM3IdLcvKRCsvw86v4j
SZhJJmG6+zSFSndVPp+XTOWRov/4g+kyI2qsiI+VKRNCrXTZIenSMRJtPZz8
sBdVuXHyU3ZyUJwsYCc3qJMHzWJ+h78LwckhOrppyOVk0DgZMk4iXSJhFu4y
TuY46VJuXtJ0qSfiH9Jd3iCgSAty3gL7Pk76+wgMDxAcHuCCKGYrESpKcLGU
ImiUInSUtRsrO9RKXmzvOny83KpLmZxr1fuQTjSbsZUf0ezJPTQLbSYq6emT
e2kaquqpaJMn91PCZB0tmwA2x03xykCRl9/4ZMjIY5LmFH4z2W/HzWggxwO8
8ajTxwPICQBwPCLmeGA4rpni43U1DAFyWiPFz8bHFuBr3sL3LMcx3vbL+fOS
VDlphE/9lbz9Azn0I7Mb7TO0RqjYBBVboGIbVOyAil1QsQcq9pnB9EETHRm7
oWEiiooeZpEB/OegyLF3IKBRsn/IsbEPrTcoNlKP8bErPGwGvXzcDLKH8bIY
cmXJIbxkBqwsiZdRH15OvVZBfk8L8l4U5N04lTphY/tF/OmF5maAU1qQP4aN
DYeI6nAW1uSFqWofXNwTorKsIJXs1rP7XlqA7qT46VaSD1nSiyw5SFc3DdDl
jX106VvLxh46t6FbbDz9mdp4wraxDQV5Kx2BjYdh46F3mx0b32mkvFWNYiO7
yMfat/ypyZKwcRnb+Jht9DCMMb8lNO5mGplFQ2MG0zgvksY0boiSO7jNqvQw
jQykJEm06dxtmCwdmYxjktWmWhsJwEU2kancPqVcQ6UGywgbkTP1PdN7qe87
X6Hl+Bj5hKFSmmaDrbyUicz9dJFpxUo+vkWmpsoxlpnuZBmj0fLvbDOtWMnf
b/Vipkbkyqfai+maomTnyggvzfjPSl3BRKcpmYrc5Mq9Vq607jn6uA+50mXm
F17kSj8qcmPm10FkSz3jj2wMw8wQzAzCzKAxM2TMDLvMRNDLcnLllUN2royx
wLyDM/yuGRGVHkxTjT9AaniAq+QBkkQxEkUxrqASpIwSXFWlbS4w26PABJQ8
8ZHvZzzWZJeYCyd30oLJXTQPbe7kbpqDNitBAZ2R0CuITk0AoGgJk7XgmgBI
x00GZ5MHmUqXoRJA7fKc37Mg/RkQBaQT8V0TGFKAOA5JcxyS5jjU6eOA6Dgk
zXgN//G/arQ7POOnANJpTYAUX7cU37cM3/8mUu5bSLVvy521LwuZCaOBanXx
NkHRFijaBkU7oGgXFO3xq6ADRlGr+DaC4kkKBYjd5Ps9TV8m0Ao5hsoNRkqo
N5JQP+fKAHcV9AccQ7mj1DIUflJ3SLKlfKMrW8r7Zpw9jJfJkCtbDuGMCJhs
6cdZ4nvoypaoxwfw0tuPerwHZ1UXDO24jD/6Ag5lDJV6HIY+OoJsiUqnFoZW
54apYl+YynNC+nj9Fd3fOUR3dwToNggtSvTRDRB6bfOgRMtL3/XRxW90jl8h
E/rrbjpjCD35iRJ6/KN2RMs2OhpF6AEQWgBC8w2huSB0v4tQjZYRhJpo2WAb
qn7WUYYayiv0zeOt8lCOy3HYUPXTMTSW+UQJPl3eIOtBTasOn/qQ1VQ7pRov
N3SWS1WOdLiNbxoaUc/J9qjPNkfJGOmutIImDrXNTO1UMMcymLHmRqPtlpjW
+M8MbtUeJpPLcReaSVY5nuB4OVfHzNlLcdP28vEIoz7RGZPrcKcHk720M+Zq
XZUke22XMRNeysiPkzFzjZl5nw3onCQx0wcvA8iYjpmHvwvDTD37jm0Jw8wQ
zAzRySQ2M0xnbDPN6A/3YPK9mnyf5hGz4tMZ/f5bvIvqVaI7SAj3zGz0YtN7
+QBXxAOkiwe4Sh7gailG8ihBAimBi6UdP+Alvu7oC7KW41yS0E6LEzpoMdy0
7JwvdnbRnIRump1g/JzcawfQKZP1ipiU0E8T0MYnQLDJA24/J6ufcYZNcW+y
ImotOy122iEUdsbDzniE0HgEzHjY+asWJ3z+wmwf9woO8QJ8cg7Fly7Cty3G
IZbqeh8j5VDdTiVm8qi9m7J2P3VAyy5o2QMt+6DlgF+nsfPnjJQeCjKStpRj
QBOk9IcdKWWnVF5zJM6M9lhU+kRK/hY+8IChWMGUofKhmF8ZLIMGy5A9KUkO
YWFphs3DeBpDjRo4gwicQ67A6Ufg9HHgLNfAOYiX2wFTjPehZukGmJ04tdpx
irUCzKZzeuxnAPPJMQROlDt1ALMmn6hyf5ge7tXfoSQzRA8ygnQPYt5JDdCt
ZD/d3O6j61u9dBViXv5+AGL20wWIef5rDZ5njZinRMxOOv5xBx37sJ2OQswj
EPMwxDz0XgsdtMRczWK+oFyIuV/E1KJ8r4j5VMTMgZjZEDMLYmYuecRi8j3y
i+pxVrGYGSwmEmc6NyTOnXNrHDFnO2KmzqrS1BlHKSjLU2ZUSvJMnlHBwZP7
EJOmVzjBc5qMZ7NUUx8qobR9qgtPpEMJo9s0PMq/2zg+SpDE/ywrnZFxDrfb
ZBGnbVMqrFGeGHsa57QK11Qj6G53YTqOzqiKFT9fifbTHTZlMmd9zP9oFec2
nnwYp0CP7sh8MSxw7jaTOTPdkzl5XvxaXWFEJnS+3+N0ZH7oBM68TxXQfAvQ
DQyoX4eBGNBvDaDfA6hNekYe34ZqeHsYgIYNoEBsp048kvnx+wBovgmcx+35
5uzmLZzkt5EO7sDOO9yZWW4MNcV5sXGzGKmjGBdUSbvLzTZ1kxdxLuT1MnCx
HdclmEyH4+/TGwlttBR4clsigHbQIoPo/AQEULS5FqBSxffSDAMo/x6T8e8k
BNCJBtBxCTy7Lz7BRShPMzIj69qkizPGY2XRBHwuwVrpSPsLBFSu6Mehov8V
hPwVQuavEEZ/1erGlOJ/aW0TPxbHYFFR8c/F18+DqAukX2GkDGownRLV0akT
kvt8hk2/DtzIrzUUiHbTw2RKeT4Cmt5haPpi+ag8xiMrOXGK7ZOpSzLGE+S1
rYTKkM7fHIlLK1s+H4VLK1uWRXLZz/U5uOy6jmyJ6qUNXLacB5dniZ6bpci5
Pq8Hl7V4Ba/Os6qd/4ZKs0NUvDtE99ODdDdtiG6Dy6IkP90Al9e2eOnKJuXy
ouGy8Cvl8gy4PP15N538rItOMJcfddBRcHnE4vL91ggu88FlnsUlqNz3tuGS
qUTLGYHL3QiYuxcxmbsW1uPlj7lMn18nXO6cVytcps3RQn2Hw6WHvcRTkDKz
SrmcyaPoyTO4aE9mNqdL42KXo2fSNGut5cRpD20yEQu3y3+3w0Areo5lOB0m
48TRWImTEfcMeUy6NHaaViEh02OGxs34uBn/sTsxIzoy46J9HI1HyZbmJsw0
dz3+kj5Md77MMkRmC5HIl+/qWiBKZK8h0hrrYSItHgeRL72oyQ2RXwd0vCeK
yGNbzDzyROS6JAKRpERyvswyN7fn6drOV4/afZc38ZpfhGKpCCf2LZzgt5EL
buOkv4Pi6i4uhLtm+cgHuFCKnzlEFrcpkbz/0k1cWFfNGvfneOULXr2tUdZO
0h/zR/R2QgstT9AQ92ZCKy2DmJaaLOYSS8wExE5bTBM7jZhW7ORjcOzkkn0i
Gpfs4yezmCjcxcJB7dlMkH5Q2BknNrrcVDbjbDalfp80aC1MYpfwHEN/CTV/
aabU/7LFqImy/efP8K/eQhY/Ee9PQhk/FVF1FuScLb/lH4+u5rRRu0L1lObA
GPCP4qbfuDlW3fQFtRtUFg/luy1ZSK/PWrl60KdtgAkd8POP7vdr3uwzjWcz
8VCT5M2gAdQg2qET4eVQUXuYhF2I2p2c1uDPw8hOTi7Q+4BoD0qYThTo7UC0
9aIW6C+A6DNddIAeAdE6vILXmIkcD/GqXpYTppKsMD3YFaJ7QPTOjiG6lRKg
m4l+ur7NR1eB6GUgemmjIno+AtEeOsWIftpFx4HoMQvRdW3Im210CIgeBKIH
gGjBGka0SRDdv7KR9rkQVUDRlj0BoE8oKwrRXYsamFAAWm8h6mFB+T5Mt6FS
pFdT6uxq29BZVcZRXrGIDX0FdlZq3jQtcVqF4ZNNBaIe9jNO/IwTP12D33Zp
bkfLcnmv/BX9rDXoY5X1JmmOsetzjzP2EyeVufxopVPVfEXVnFUbVZK7JxT9
JIJNqxtT+Bw9WfIL0dstMf9O6RwhWeZYtwq9r0sbKJ19eg+7PUw+KHQW2MnS
h2TpovO7oHRnCp2blc4T28zYdDIiXqq5+3K3rgvCa4LIgqGHbTZv4LS9idP3
JtJlEU7pWzi1b90HnTjd7yBd3sElcBfp8h4ui3tm3fMHzS42eWicq/EW3RaE
V6w/wQtf4pIqeErWuhgrE5rQmmkF2nBCW4XQN6zgCUK5eldCXcFTej57hNGZ
hk+rcuehIwmeIHQCV+zjIWicdICOm+zl8MmKMqk+E+xM5a5N9fQwnzzsPlGH
7OXLrCKec+cvOlx5E0r+HFr+E3LnPz6NsTbZi5+A3DkRlfzU9h+Qc/rL+zzj
KAjcgKU2pjLkVzT5CPicFOk+l5tecdM1o8jnhpMjJ7/p9/PwkGjpElO0jBaT
ImNnS6SY4ahhoSGXmNYUI46d/RCzF6dVN06vDojZhlfpFpxyTTj1Gs8QPUWF
/vi4/ozag/pvZS5ROV7oSyFmcWaY7meE6O7OIN2GmEXJAboBMa9BzCtGzIsQ
88K3/VT4TT+d+0qLkdNGzBNGzKMQ88j6djq8rp0OQcyDEPMAxCxYy2I2Ux7E
zLXFbKS9EHPPcu3bZDGzl7GWaEsfGy0feZhL3i/PgJnuBnMMwKwVNHc4wZOH
kGfzkErqrGoV06iZbKkZCyg5fiZOd6iMk7cIgSAOVAqXEjpFvjg3gubOnh9b
9/c4JbjJos6cdRkcN3PWXRMwTcC1b0tPcm6ndGYOuXz8T5Fdlu5hniXmFp+l
ZqhnmXsKkftWyrYII51oCR+t6tvcUsnHUyPNJEwxEj5+4XNV3374CCO/tYwM
0VEYeQxGHt+qRp5M1Ggp/TnwsTDbbB2CyvvyIWeI5zpe068jW97AWXsT2bII
2bIIZ/QtlN+3yxTIOyi47taj4Wq4h2x539z+wRO0b7frjYNXgOT5FlN2A8hD
+Lo8a7G1f0XvTGpEe0GrpDVFgMmHemtSC73JzZU537CqdLRFBsz5aPNkqKgb
YPbQnCn68jJDMqd7nB1gThnw8PwkPLs83D4eSHIbJ81nImesVY6bfs6R8iZX
9lbofN0p03/Z6eISJP78heHyGZNprUoSP75Jpn5qvh6VyxmjBk09X4EjN7xn
MxmnTPpsJnU5uTFWutQ2aC+rbIzkFUz6fSZc+rXn1OJSqBQu+Ru6QjyNv1Pv
AbKotMKlvG8W/nDPyLTuA7K4DBguOWAO4JW3DydXzy0c/AYOBy5bceI14wR8
cQ7hElw+AZePjpkT53+iKpyvFThvy/YQleAcfrA7TPeg5Z20IN1KHaKb0PI6
tLxqtLy0yUsXNg7S+W8HqPDrfjoLLc9s0FfTk0bLYx+zlp10eH0HHYKWB6Hl
gfeg5busZQvlW1quUi33Qss9Li2zXVpmQsvdSx6zlpItMxY2CJfpzCUK9J3c
5tVR2rxa8XIHNztk1kDLGjUT2MyqjmUnuUCvApNSpQNLUCmDMDxQPa2CQ1+F
nBOIiVOjXeSy/OFrkhOHpcaRUZRpQ1VW1W2q7Z/K91q5UbOjuf1xtBt4olxE
yc2TT99oxFnMxxpp2pA1DJ5p1pLLWt3p3AZpXNRbzXXVDr6ph4+lt0MO2tMs
eVinYIM/quw2Nn4PGzeFHRu3w8ZkXQeJ15Tj4503Jfelg5aLP6VrOBWvn0e7
BN8QHm/i1f0mXuWLcArfwql8G6f1bZzid3Cq332EBu/u4VK4DwPvt4uL5lh/
KWv8nDFrFfNCRnlP9ee+O+kZrZ30nNagrZbWOBzKSTpj/O1JzbQcQL5lI2lB
6XRnLnKnSoPkvCkOkjOnKJKaKnkOJ6BkJCdNGWQpvTGvQkqvkdIXOcNdc2R0
PyYHTs2V/8KeoWRnS+RK+fcX7Yrkzw2S/9ioSP7DU4BpKvN4fGyc/Kl/ODqS
M1+aKSVB4kQPi4pWEx0lNAb5MF6r+Obp6H53iIyJNbV3v7zh4ryP3/QGeJJo
dNntHuaJutknWkZrAQ/7Dslq1x2SkHEQL7X9OK167+DwkLETMrbhlGvBqdcE
GRsh49PTCJEniBqO6fGrDxBV4pQtR9ldChqLs3Da7QrT3fQQ3QaNRaDxBmi8
lhgAjX66vMVHF7/30vnvBqkQNJ4DjWe+7KPThsYToPH4p92gsYuOGBoPfgAa
31caC95tpXzQmAcac99pov2gcd/KF0rj8ueU85ahcdlTykLLdNG4y0Vj+kKO
VcARr14759cLj2nCI1IlbDR9gKkso+pIKSIkcOT8iFSZPJObJEpGElxCSg8j
ac2/BHGJMjGywiqx8V8TLiuEzWgdf8t8jCcJycdhpSNmxK2PePsHromWzm08
1gRLkdOVJF0TLPVm8YUjTBhSMRXMf2/fM86HsuajjzYOnmXC5HA0Aaasz6F3
QvKxrDshFU1rzmUAaA4ZNIN0eGNoGJrST7kDiGWg2M40O3TkkjWschVWXkO1
cw1Vz3WcuDdwAt+AlTfvwUuc3EUotG/hhL+NQvsOLoI7uCDuwsF7qLbutZkM
2WYyZJssda5PZcy/pfcnPqX3JmkTLyc+ozXS4OXE4Wbyn7kCZqqXzeLlW7DS
CpbLbC/bnWBpj6Grl3yM2bByFtoMtGlTECxh5ZQpAzR56iDOggS8fY0mTfWC
Ti/Lieaj8da89ynGzClm+pE7UWpTM2PNZKR+E9H47asIlx3q5T+1oDU5Xv4j
vPz7J3aw/KX+tSTzMkc1c1bUuI/uPhr2DTMSJnIzKdK6Y8cvTaowzo6x7uwo
Yzt+a4RHy20zwvNn9uwhllJ+zajZ6Va5LZ9rjJRSljqqjZSSZxEN4GTqw0nV
Aym7UKh04ERrxQnXDClf4MX6GYqZJ6etF97/lmp0GT+qgJRlkLIkBwES5+89
SHkHUt6ClDdTg3Q9eYiubQ/Qla1+urTZRxeMlOe+GaCzkPL0l/106tdanJ34
rIeOQcqjLOWHnXTISHkAUhZAynxImbemhXJXN9N+SLlvVZNIueftRsoRKbVo
VCXRlj5RJY2UGYu4iZKwMpZ2LqgXKdPm8/o+cBLPxI65dRIklcpaD1vpESjH
AMoaZdJQmSRDKEkGSy68kfasRGnq6+3al1jx6gg0vm5GaqZWxhoWDZCum3Qi
6usxzqi2dXPjbJ4FxSto/tawqefJ9vCNs4xG6mgy/pVrOWIts/lQI61YJLMq
ZSV3S8du6AgZZTV3J07ut1fX0PvE+Xj5n+tdO/aMdNExKCM5R0THsD2SI6M4
vKwmL1HMu3Tm6HbIFwuss/CP6Cpeu6/h7LyGs/TaFRDJPOJ1/gYqoZvMIzJA
UQWIRJl9G2X27ScgElfDXWSIu+DwFtq1Vl7fLExnm8J04kWYDjeGKP9pmPY8
Chs7Ppj42AMtn+DpFDPR3kWDlx4G08NaRhXijpVNYqXkywTLy7aIfClW2sPl
XbRgioY7zZdqpeRLWDkNVk6dOkBTpg6yl2heJtOL6mSS3GsJKpnJaQFl0kx5
ZyWnRPRaegyVCULlJDNvc3xfjDWxSGvvdheVHC+tLsv4f1AsR0qUY1XHOT9Q
dhsfJT+GNESONUtnBFxCWrc6vkRIn1Vp89fByYmaJ13zLMncrzriihtRaxrZ
KxcbKUNGSr6Xxwsp+x/gh0DKbrwMd0LK9us4DM69JrxEN+JcfHpWj9VwnKj2
CFG1kbI8F3kS5VAxSu37OJ/vokS6nR6morQQ3UiBlElDdBVSXoaUF42Uhd95
6ew3g3TmqwGR8qSR8jhL+Uk3HYGUh42UByBlAaTMf7eN8ta2Um6UlHtXOFJm
Q8qsNzVXspS7RconImXG4sciZTq3hdwaQMQCvGEnIeS8erQ6kVKcA5OxIiRK
bEvImdwZmGTeVjGPhkiptbdPrxQZx1hrXPIEcqerUW705v7GyldNUFQXZVF2
l4dSUMuibUrga86KQmZ2pHAYuaJQjK7WFhe9olBkQHQYtFYTFg7dKwqPEhJz
XCFxryskWgsN5X3qs5fMUAqH6MBXQdekyZA9MsMMHmcGU3QrN9kmEwwW7iN7
7cBTRFfNhLUb1yAfiunrEPA6BLyBM/UmBLwJAYtwFt+CgLdwZt/GWX6HBeT1
c3hVx+YwnW8M06nnyKZPQ3TwSYhyHwcpuz5oqr91Ex7hcf9gwmO2kFuMgvg7
wPCJwfDp8AA5UQMk/26M4gppToBcntDiYREB+ZtRg+HW9KFFU7poocvDuWiz
jYczpvbR9Kn9NA0eTp02SFOkeWkyN2CYAAwnTvPTeMVQ7j4PyG1AMo0d6do1
gmOa18xjH7Cio9wMJBYiOsb/vBX+NbssNKX2f3ki//JP+dnoIs4dVUQdWCJv
2EqKZn+2Ib0pJ1YtHLD7G63hmNeMfD5X80cO0fRKf2NPiGeDduva7fKzRllK
Y6QFhy0NwyY3BsxkysES/CicYz0417qgYQfOvTZo2AwNX1wkKyo+wilaBwxr
gGHVQaKH+Xr4EmD4ABjeA4a3Uf7c2gkMdyiG14DhFWB4STD00/nvfXQOGJ4B
hqeB4akN/XQCGB7/XIvsowbDQ8Dw4DrGsIPy32unPBeG+4HhvlXNtHdlE+0B
hjnAMHt5I2W5MNwtGD6lXUsZQ95EFxx62EK8JO6EhjtRaQNDSuOG7LiD2zzO
j6lz6+wSu5ZSrCYBLdnWUQaNTW6sNjfcJFoyDhtTma4D0a8aJyPi4dTKH+tI
ta637v52TYuvy+KW1vJB0qIWXkvSpMj7/fC93LJMsNnlcnhojF5wvXFUKmUj
ixW69488qK5OyOjUOJxLUGktH2xq6jykxvwvNNEc2BA0XIYi5pgfZSq3IzWm
OHu7n80WKvU8/GO6eJTo8klwd9app/mQN1Hy3LyvXN7AC/xNlEQ3cZoX1SmX
t3AZ3MYlcQeXyE0EhisIioXM5TNIDSrzHwVpb/0Q7a4d0ufzowm8vsiHE3Rm
/roJDUbQ34Ggj0TR96U9offQ3pU2sqD8/e9A0VUTX9DKiS88zCfcelvxlDYs
UU424+BGTz7Ewqk9NN/oKYkScs6EnDOm9dP0aQM0bRpX3lOncYxkQadM81EC
2sTp0HN6QP+q+Om8n864aUNoARo3NaCgyg3ozj1BkivxlwqlZjRc5hJN6HVu
+flFm8bKf4zqsfx7MPpfZBruSFW3UXTeD+VKFlR3thyUIRuOkgM6h10+P8Dz
gqDnGAZTY6Q1B0gCZJA7JeVGx7Bzk84IN4FHrCjs3qaNyXxEsm1QyKxAxDc8
evFSPAAye3GudYPMTrxMt4PMVrxsN5kViJ4WQtszRPU4T2uPITweJqo4QFSe
Z6br7kF4xGl9F0ngFswsgpk3YOZ1mHk1KUiXtw/BzABdgJmFMPMszDz99SCd
gpknYebxL/ro2OcaIo980kOHP+qGmV10YF0nFbjMzIWZ+1e30L53WmgvzNwD
M3NgZjab+Zaamfnmc2PmM3FzF7uJEJmBlo4Qmb7oMe1cxFEBcEKjtAWPDJsN
YLNBgmQqNw2SlIJ/U3j2YQrX3cmza11k2p044qZVCJuuQqEPhr5q2elU0HZX
o4tO7qbU7ClbU1bxvTj2NhXV7q0qdEHg11wLq5t90uxdKuydKmRE+zGv5Wnm
kdtwunf/WYr2Bm8PDDpj/tK1+08UnJwxTc6UiB69e4UrZ8qOQOt5VyBnQUtd
MNgXgWfBr3WhjANfhRTPb1HqbjSzfwycJ9MUzjM4w85FwnnxBNElVNuXcYJe
Bp7XrmlHZJHZx+XWQ82ZN6rwL+AswgVQhErqFi6M27hQbqBdBpznAOdJwHnY
wLmnbogyagwxH0+oYz25HwaGynHXj6+n9RMaGFC8gZ+gwRL0PWmjC+ro2Ugr
kT15wGeFNGcq0XLw+ZZ2YHrojcntMT+BoB20ZIoZgUb2XDi1mxZA0Hloc6f2
0hzoOQtyzoScM6YP0vTprOe06azn1OnQczr0hJwTZ+hL1riZiHHjZoie04cA
6hD/a0SNk1rdJagCOkZqcsFyIq951Gf2aNPaXHLoPzUbPJ/beMa8XM75dn/l
X+v/YqQa07WDzD04iqQCKQM2caLk2JGCJSupKwvFK3wj7RscVWXb/ZHWHu2P
dI8gXqotYG7UGQSU/YCyB+dWF6DsAJRtN3CYa+ZOxgswFjXPI5yPdTgva3B+
VgLKh4CyzED5AFDew2l8B1AWAcqbyATXd4TpWkqIrhgoLwLK85v8dG6jj858
q1Ce/HKQTmwYAJT9dPQzhfLwxz10CFAeXK9Q5r/fQXmAMndtG+1f00r7VrfS
XkC5x4LybYbyBWUhXGYCSxvKZc9oF7BkKDO4CZSCpUekfF0iZho3WLljgTqZ
yk2crLecjGUoedDGDIqYxjNuaqTkrnHNwgGVelNhrGPcdL5FRrWUzc50f3Td
bsJdb09jVfFW9/N5RaBUJKvdS6fjZ3DMZS1/pFpGJky3lLKfr9kjjdVEMf63
L93bx95a0miZvlz3S8uI0LJdtJRtJt/RyXa81WRWRNTsHRY1h4sJLT8P6GKW
XJl/GRQx5TTgqGm0PJ6sWp7CqXUmC1rutTol/4QuHFEuL+L0vAQuL4HLyyiJ
ruAUvopT+do9Lcv5mLfrtCy3uCzC5XHLcHnpBbh8HqYTKMkPoRzfXx+grFo/
7azy0afja+iT8fzsfjIeL5Yf85uPxteZGuHD8XUK5/j6WFo33sAZCzQfGTT5
VRlsxvyZwjlB4eTv5dj5jrRGKdodON1zMFud3Im8+Qa3KR201Ki5GGIuMmrO
Fzmh5rQ+mg01Z00foJlQc8YMnpo+HWqOgZ0+mjLDTwkzNKJNmMlYjp8ZjPkp
jZ8RpAkzwCYaJKV4bvh/PHKp0umPWi9uEHYOaM3Oa8WN73Zu7flFS2Tt/vdS
s//+6GQuHDVsjjFhMiJcxsjwtvRTarqMUzcdMzlghniLox4TLHkfSsvN6Ho8
OmA2Om6GH+mq67zaEN/g6IWbAzip+opxOLjZiaKmHSdbq1ljoPES0VO4+Rhu
1uPErMUJWg03Kw4hXMLNUrhZvF+/9i7cvA03b+Lkvo6T/FpqmK4kh+hyYpAu
bRuiC1sCVAg3z270w00fnfraSyfg5vFfD9AxuHkEbh7+VAvzg3DzANwsMG7m
ws39cHPfmjba63IzZ2UzZa9ogptNcPOFcbORdqudHoYz5reFzfQl2naCzp2L
uD2GmY9dbqLxHBpxkzv/6s1zkzK33hq2TpZIZw+gcBdi4qyaOCEz1pUqzcbl
sWbvnelVr5pOSCFS6YyRGjyO3x221/kM3euc77LZPrPWXsg3cRaSDqBkrE2g
dLY8H6tEuraSBJK8+66HfYz5G9mAl4/i5EpWstHegFd3Pnc24c1YYW3E2+Yo
uVp3mMw0G/JmmV0mOVfm2Lmy386V+1jJj73Sh5nrypX5yJUFXJR/aXLlRj2x
jxolTxglT2eZPss/ovN4rb5wHA3n4cVzCuQlAHkZ5+oVnLNXAORVnMfXcD5f
q9Q8KRnzmebJIlwT13lXmhchOv0sSEcf41doCNAe4Lir2mue7M/G4wn7dDye
OoYyDkbWsJNgslb7raGkh4nE59YBSzhJH0h75KH3+Q2YVCVfFSH5V1hj4uVq
IyR3b0JJDxMZ83s2kDaSk9voTeC4zADJh1iKonwJcGQkuTAXJKf10lwAOWd6
P80GkLNmDNLMGV6PKDmWps1QHyfP1EQ5cVaQxs+CJRPkDZz8HX6fxqHFz0ab
ZTkZME7qepvio0xoH1QfJ3Fh3sNrdFhhUGYSuWpy/ujvje7jolF9NLfe9Put
f8eY6T9Q8XW89Y7WXWnX3sppD/Gt4O5kGbV25UhChs39BkGzZoYPQg5CyH6c
Ub1Ill0QsgNCtt3Sr2u6ilAKIZ+cR6o8i1R5CqkSZ2glhHwIIcsKiEog5AOz
LvUdvOTfgpA30nGG4gS/CiEvQ8hLEPLCtiCd3zJE5zYFRMjTEPIkhDwOIY9B
yKOf99NhCHnoExXywIfdVAAh8z/opDwW8t0O2re23RZyzzutlLOqxQjZTFkQ
MnM52lsvaPdbLKT2sO9a9pwykC4zlj4Dj88MkTxYl7boiYeFxJO2g+daGyNT
jZEp8xpiTWEh4yayI4Pe0pJkKYlgF8d4WUA6xTIX44ZJZMNt2iRWVsdFUyld
ky4ltw1T8vdEye2ztGm/pe5RLmrOidinnJI4Uc6LSJQWldZG5SBz8bNYVtJ0
sjuJsslKlB6GMuZfGyqVyV2uMGkxyWEya223BEo+FAfKnA/6XFQO6NZnrkCZ
i0CZx4HSopIDpWHy8OYwmAzTMbN/+Ull0rrz5RxOukJQef4YGk7IC6DyIl7C
L4LKS6DyMk7eyyiProDKq4bKazWgsQEnprkAbuLiuIp2HhcHl92HHgUot85H
2TVe2lmpFebn46vo83F4Uj4bx8/Wp+Oq0Kq5cbwcxx3Jn4yDnaZ9NE4j/0fj
aulDaQib4yRwehjSmFgXpfySZlmKE4Urdf5eCZwThNIYHT7/ScTw+cpJ0Tf9
tNJyWCqems193pjSie9dOrULIVEDZw8thKML4Oj86X00F5bOmTFAs2HprJle
mOoFpz6aNtNPUw2kCYByEsCcMJvnMU7E298VXCfgY+PRxs0BpnNGRlUwlQDK
91QaUBP6rdDJqDr39vzTC7tQxwd+d3RQF48KqundlBFw7cHUEXGvwdQb8/9w
dt/RVWVZnufVkojIyMyqrMzqMj1VU9lVU91l1nT3ml5dM2ump2e6589eq9fC
eydAgAQC5L1D3nvvhZEQ3gUmgPA+Ah8E3jshBMh77fnuc857UkRCZM/8sR8g
IfPuPedzf/vc++7z/anI+S9+GDmnx84fo/rj6DntJpf69XojohFQHbpG5ATV
PsZej0XVx3Nt+VPG5yNQvQ+qd0H1FqjeYAxfA9Ur9EeXQfUi4/s8qJ51qH4F
ql+A6qeg+jGofljNOK+clPcrJuQ0qJ4C1ZOgegJUj4HqUYfqoYxBOZg2QOTs
l30ptmXfk9gju+NfSUfcSyLnC2l3qO4E1R0RXQ7VZ7IttFNaDapPDarNWsDa
5EX1Eag+lIYgrQdSr6/bW2fuDuGBFVLZD7XmvWruTC1U6ssa3b159NXU9jXV
M7y6VjpdNQPOMI2z0nrDtO2uqZ5hXPQ3zpZN1c8Mnm87VR255lPXPS25wZRE
W27eFrIcQcvdj9LQyTQFUvc21S55Uncsp1BapYx6KDWM6pPFUT3ZT9ysNaXL
mLVBj3x+Y0jV7+Vp0n83fna5+KlNereLn2rqi+mm+mr+5AhgaDWs9v+I1SFY
Hf4Rqy595o5D6oQh9aAj9QhjCFLtse2P5STD7T04PQWnpxiKpxmSZ5TTD6lP
GWqO0w/h9COG9Mdw+jGcfsJw/5Sh/9lD6qmuYnrueuEv7XcmpeXGmNRedZep
pM/63g9Mv1dMddl5q8HUFP8CU1811B2KVNDpinoD6QxvILWS3jH9u68ueqqk
91zz6S5Ccmue+qKAiHmP+DHh7gL3sPlP+BiOMvm3LCCVLrCKGkmdohsWvZDg
RS/VUVm/mFS6uEfWomgggq5B0FUIGkCtXDYoK1B0xbJhWUotWW6D3cIVY7IA
HeetNILyOANRJ/RvMoeaHTAhswL0czMDxn3+0Gk6ZjVdbpekjapL3BsHmRvP
DdhoOpdoOuclmnZ7r8z8r3YpTUF8naIzrKLr7fqmZ6XTG0aHPaV9+pCfUfN1
VxDNmAqivQ7NXrFp1Ffd1Dfa+D1nhCYf2du3jTN0xu5Y4YZRcxA1+1GzlyH2
6oL9eBdRtPMLEizD8CFH93s0RLdPEUNPIOa7xFDU/A41L6HmBYbxOdT8FjW/
3u6O8qj5CWp+VMswRs33UfN0+YScKh2Xk8VjcqJwVI7nj8i7uSNyNHtYDmcO
ycH0QTmAmvtRc29yn+xJsnG0AzV3oWY7arZFv5CdUd2o+dyouT28y6n5TFqR
swU5W/TtY1CzKYTyXFht1HwkDU7O+vXuMhuV05wTuaeviPbxvHuUnmj23Gii
apUHUfeGiwG3ps67aDnFtH82TbS5S7lJjMumyuRTPYGDiDOURhM2/ablTuXS
/pwyo2yZgfeGJ38qnrqcZuG8ZWvlLT8ebvuaXt3PmGkMXaWTEzlpFI2dxE9T
tOmoST10bj6yZP6D1JJA6zy1wb4OZTqbDZueTYujz71xtDn8xbQ4+srbtW+L
6fXGUf1eO5ybO3GzzcXR9mludmgc1fVN3NxXMI6bE8bNQ1WTxs2jjZ7rxP9M
ToLmew7NU6B5GjTPgOYZRuv7jNoPQPODc8DIiP7oikXzY9D8hJH/6UPbqn/A
jDjJjDjMjNjLx3cyI5puTnghzZh1BTu9Nc1Q/+mGaii1mdTfZFJ9qjaXmvVP
HjDUzxj6C+vnHK07PzzxPteGUM91nNEmhEbNe+jzLyWSEBox/7Gp8PlPqKcS
tuCphMJnKHxuWfhMNi+EUMdnyKJu2QihGxa/lGD4DKLWL+mRdUt6ZS2EBi7t
l9XwuQo+A+Bz5XIIXT4sy+Bz6QobIhdB4kJqfsCEr8wLmGQUzUPNudScVQhK
zaJmrqb0zwASHYz6/Mri6Ymoyx2gi+nvFyqiRNH57r0y5r4AUncDj//22B0Q
36hn8Gs+9Y8/yKBDWmaxc0hD59BPJk8/D6A/RvS/vjl+Pp26pds4Q2aMITPK
kBm5ZcEboJ/vY6j1uGX05/Tzz0D0CcPxEcPyPojeAdFbIHodRK+C6HcM4Usg
enEfsRNEz+4S+QZEv3KIftbEsAXRD0H0fRA9A6KnQPQ9ED1RPC7HC8fk3fxR
OQqiR0D0EIgeANH9Wwdkn0N0t0N0F4i2x1GxL6UtxiK6I1LruWwH0m36rgdh
iugzEO2UZoPoU4foE2l0kJqXPgejRn3QQ7ajNfTBVMg01zLaW4u/ZRcMpwS1
51wCrFZmmVEXNg1l3iyogJbbhxtuhdLKeQMPmU2g+HP1Uf9moqTnPyzXVdMp
IcunhNRwqThWECorAJLSOwyt0isAKlfZc+OekFk1DcrqKSgNkr5qpK/iyMPG
pz5/a3w0GyXkhz42hnqMtD42Ox9bojxG9lgjnY/b42221O81ZaTNll4j1Uda
9T3qYyHZsmQcHyecj5Pqo+fs+HHG0Ym9YpjUb/keTL4Hk6dg8rRj8gzj8n3H
5AcXGWOM3Y8IAh8xnj9mbH8Ck5880RVNkeP8/eC9Sem4PS6tN0aljmxZdrHX
TzJn6UtSM2bZW5ogJv/yWGmi5veGSu3ifU3g/Jnp41Ncea2cWge154z+yJwv
SrTni6jbesKdumPkjPde9GnV9FwBHzPvAfVQouexv6LmP/L5rUQaOJ9IxALg
BM1w0AxbqPVMQhd1yRZ7ZwvZtLibeiEhoLmR2rDklQQv7ZGgpb2yfmmfrFvW
L2upwGUDsnr5oKwCzQDQXLliRJY7NJesHJPFAeOyCCUXrNKryOfzSPZcNSlz
V0/KHGo2NWuNyZ48/soJOm4UNRSucv8OGLN0kmtnLoHPxYPu/drgc755qyGL
2G/ebOaGN5npOWc/rVH/8eqnj73jpb+9RbDnbXv6JpXPySkv9WXjQm/949Q5
CZYTDJ5xsBwDy1EG1AhYDjss+8Gy94r9ezeJswssn4LlYwblAwbnPbC8DZY3
wfIaWH4PlpfB8iID+jxYngXLbxnkX4Pllw7LT8HyI7D8ACzPgOWpCgZ92aSc
KJmQ40Xjcgwsj4LlEbA8BJYHwXI/WO7bOih7U/plT3I/WPY5LHsMlm16q1m9
5Wy0Lpxsj+ymXdgW8Rwsn4Nll7QYLJ+BZae9B4ReOaOXHro35TL30Qk2lyZ6
YoU5QbLWLQaa8yekzrdtc0vmNA6t9oY4DXQm1plwt/K2WW+sMG/+bbpmpPM3
6PmZvGka8GX6ukprpUmay274OxeNk5jo6nUu8jGvi5Wrpxc2aq2xc86FSl+F
Uu/OaZh8ZKo26PGPpPST+pBOoowSacK4ErllisimcA+TLx2TlshWR+S22D7H
ZD8xckB2KJGJdqlwikklcgwiJ2RPnodI2u8KiKym/a6b9JvG43F4PMFoOkkf
895xRou7JfUpeDzNCDzNSDwDj+/D4/sc0j9gtH5IivyQEfzRXYiExI8Z4ace
TsjRe6TW2yOy88aQNH4/IFWX++yRMGuW3jovCx4zp5Wl8jtf9VLbc70jShoh
EzM95Tdt4dPHXkjh86/dGuymJS8lZOkrqkc2LuuV4GV9EgRN65f3y7rlA7J2
xaAErhiSNSuGZfXKEQlYOSorAyxRS+FpCcQsohZC0YLVIvOpeWsgipoTCFHU
LGrmWq0JK5Vd2+FvMjPQ1epxK9QKc4XlMj0pNHPJwNRb8uq7Ss7r/j1Gbfx9
a4t9g9PWEadd8uO5e7mlyfeNNv3yBzZNYtMENo1zUBtjD45i0wg2DWPTEHt2
4IbD8X+TF+z05+dpgr8lw31FE/w5GY6BcQeabkHTdQbMVWj6DpouQdN5BtNZ
aPp2NywxwL7cKfI5NH3m3t3+w3oGEjSdrmLAQdNJaDrO+DwGTUcLxuRI3qgc
yhmRg1kjciBjWPalDcleaNqjdxyEpo4kdzsEvSOh3v061t1ORl/kobdR0HcV
0IvyDE3PoanLvILYXI4CT+aCPm3lNj5xbZS/PfHgWT1bpycm1poFtbUuAwWa
q2HW3LOdpJ83LNnuUmmaYfFYOa1W3DIJ7JbHJWeSccnfhbayZTelbLkp7XZd
5jNf5mGKb2Xrjq8LbMBE3fXQ5KsmaY5Doso19xHJlK9GOPdNqgMfuCBHIIAm
fTfJoMem060NfiK1jidf5YmHTfrep/VEuAZT9krxxtDneqo/rNvnHZyyRjU7
o1qiepxT1qhtcfpiNZTiMKFOqVGeKGf2HTFuVwZGZatRE7K3cEL2l1qjDqpR
9ZOeK3beZfgcYxgdw6njDK0TOHUSp95j2J1i+J12V4qf/pK/49QZ59T7OPWB
c+pDRvZHjPIPH3MUvD8uh+5AJEa1Xu2Xuss9UnbhpeTM0tvQZc+67Kda+bpE
p99ZqYIpH+PUO27EbLVnYUyZeZcy+7q54IctpwkumdiWNOemuVYycY4ephLn
3GbeJs69Iwmm7pqKn3fPfn3cvPv0xbHzH1APJXbBQ4lZ8Ih6LNFU1MIn1FOJ
NNUpkYue6ZLi4i5+lfDFNrqFLnkhW5a8MDcJ9/m1rF05LIEBI7Jm1aisXmVX
81Zi1XKS1lLIWwJzi9aILAyEPmoeNRd85lCzIW/WOk1uM9exJxDQA986LFw3
Ycqgt2aMmGbgC1CWZq4kohENZy4ini0kni0wVx39+s3whfxoOdBdu6MpzPuC
QpPC+sfMKRV9M7AJ12V5rNN4pheEe06cOPN8lTyf/yKTgDcBeOOANwZ4owyF
kftgx7AYArxBhkj/DTuMXjFsuhk+zxDvKeI9QrwHiHf3E4IYh8QbDLlrDL0r
iHcZ8S4g3jmG5bcMz68R78t2kS8Ysp8h3idOvA8Q7wzinUK8k4h3vHRSjiHe
u4h3pGBcDueNycGcUTmAePv1Xv160yu9yUvqoOzWGwYi3i53E5g2fRUv6ql4
eiMt83oNXas34nWbl76Zy0i08driGrFNnW4x5+f21OoGt7gVpBnlkVHPtHfa
5q01UvjZTEO40WU+4o5GHyveXaOehqU7fi43la+47YlS2npa+JbfMmc3VDcz
YwxuZctv+dvExdf4K2z6X1famOeilyavu8qcS1um1F5wU+YAucrUAy1+ST2T
rOnLnjXxJjCAq5kCjnqqxkkdLaqmMOOcr/LGw5bner+3UDuRbBJ74avE+fwJ
yL2yyDngWmM9yPWbILbdBDEL3M6kIWnTEJZml+B3Z08C3KTsLZoEuEk5UDkp
B2sm3e74CznKUHm3g2L4HGMYHUe34zSpJ95jqNCknkK30wy/01/ZoXSGYXmG
4XmGYfo+un3A0P2AYfwhQ/qMvu6FBLafBNZ2fVCav++T6kuvpOhct+TM1rev
zJl1iaeJdOqcp0w6e/sn1vqY1mm2d3U1Tb3U2XrFQYq54vGGpMzRY5q7UvyW
uVL8NuLdNupRvpIw765TVeFT85Bv/gN0iUO8OMSLVfUWPqaeSLQpvetm1KJO
euGoxc8kckmXRCyxOyp86QsJo0KXvpQty15RPbJ5ea9sXtEnm1b0S8jKAdlI
bQgYlOCAIXMPCI5Iywl1yxBuCRgtXieyiFpAzaPmrkc/ahY1M0gL8NZP2iHM
P9zbgc9cR2saOIp/+qrFNfp2CTNXQR/Rc+Zi6FtkrkLgV36je5vfuJD3jlvI
G5m6E673bRBd/9k/+aOkN2mSnp9Jeu+YpKfojYPeGOiNgt4IHegwKW+I0TJ4
x3M2+J+kx91B+TmjqpPR9QT0HjLa7jPq7oDeLdC7zki8yoj8juPuJdA7D3pn
Ga1fM2q/ZPR+AXqfMZI/2cZxFvQ+bHTH5BqO06B3opzRrTdUKZ6UIxzqD+sd
qvTGK3rXKr0Ri97FCvR2601a9IVl+gKz5AFpd+jpVcF6dbC5/s2g98peQRzh
Vty1bQI900Zt6fLxXDDVYKb6U+/qFG2YnhkOfsznFD5Po6ZkVK/Vk3S2ibO0
eJLUPU/AMkbhnytDoOoHXy6lGf1uK4i3yHYrbnlSn7Fx6rMrzQN8lgdMhboA
+43dD+HDq+/5ecl74OHOale1lhxXte6h9sv6u697ZEq/tmb9Y0efPlfQYzzU
buw07NWFPFP0qC7iXRfsaT2XBhPtGkO7ff6FNIbZS+GaNN6ZiDdNv+heJ6DV
b5vqF49+CYNOQPRLRb904h37tSN3VPYU2DG7r0zQT4x+nmx3hPFytI1SAWkZ
3j3IOEHAY4yz44y3ExxsT9BmnKTdeI98d0rz3QXk+85piIDv36YY0x8g4HsP
JuSIXnB4c1i2Xx2Qes1251+4tJA7W98cKHfWJXXQWPjWVHc6g5h32Rv3fhD5
zEqeOX3M5rZ96VUr4mwtu3qXOvua4/AXkjrHUOjqpoJI3TJZMGmu1m3qjiTN
0+4hcd5dF3oSIDF+/n1XeuIjfsFDn99K3MJH1GOJVRYXPaGeSrTW4k7qmURD
YtRSS2Lk0m6JWPZCwpe9lDBIDF1Oreih+iR0Zb9sDuiXTQEDEgKJGxFrw6ph
CV49IkGrRyUocEzWB9p36gtcOyGr17nYx+PCYFIiNZeaQ82iZm4Qt2n5mx8P
Xh2D0XH9mBafWz+qOq4boVMepEtGyCXmZkM+v3qzjlveqKN7Ofb0N/DqH3et
b//klIp+qqKfOZfxf5hzGZOgOEH7O94Fip2g+OSHKJrlOA6nPSTBlw7FZ6D4
BBQfgeJ9ULwLirdB8QYoXgPFKwzSywzWC0dJgYdEvgHFr0DxCwb0Z6D4yQ6R
jxnkHzYzSB2Kp0DxpN6KT2/JB4pHQPGw3nlKUcwbl/05Y7KPyaPvcqfvEKp3
rdIbE+jFvebqNXdXq526BqRrQRpHYnp0Od1XF43YarrKrstIdufYHdio832z
m/9qwcZOZ6IeXwlJ/J/aIGfH+kfOlIdKjZqjJ1EDH+jlz7ioXaap1fecV/ds
aJthGSPHlXtq5R197Z+NiS7n6cd8vQDqA5aWG/P4Hm/rt1P9TJlvv/q+VKzR
0l8DDJXEtQ/cr/ZQIVQN9fKKKv3NEZBSzXn8lXlGRkYNgsE2CKqItU7Eumki
1quGRsRu4yEqhr3w+VNpZGs2hb80Kur3anZNb8t0Eb0qDkxlQhreNo5q7RmI
mI2IRP09heOyt2Rc9pVP+DsID9MtHAHCI3QQRxVCxtK7Ry2Ex+g2jiuERMET
nzF2gPA9xuN7jMtTl4mG31PX7dh6n67mfcb0ifv00sTAdmJg05VeqaLBLfy2
yw2IvNmXDDh+iuBUz+sUmr5C5zXQ16ZBNfAdSZv9vb0wcfbvGGhe/JI6R69y
QkG+o8fAFGdg8lxtEZLn3mY/J88zBlJ3VUFr4Px7lMbChAUPfP5OEhY+lHj8
04pb9Jh6IrHOwBj8i1nyjOqSmKVdEr3MGYh/kctfSgQVjn/h+Be2slfCAvok
bFW/hK4akC2rBmXT6iEJWT0sG9eMyIY1o7IB/4LXWv/Wk/nWUYHUGnLgKioA
81Zi3oqNIstCXKvK4yx62Jmb7B7QP2eGKF38zQE2cyMN88Zx46SeH96gnezM
9cMEx8E3xkR/C2HoGyH0vMhFXyA47v4+OU1Bf4+C4vMfTVs8CYITLx2CpMMx
0uEo6XCEdDjkXh/df5ev4oj6EgS7QbDLnZt4xGB7wKC7C4K3QfAmCF4Hwe9B
8DsQvMhAPc+A/ZaB+/V+ANwDgCD4CYP6YxD8sJWBqferb7Df72Q1g5o08K6+
utUgKHKocNLcaEpvOKXvsrQ3e8y8zktf76WvaNBry3SBWxeR9JozH3cthS6I
69wz8zC6xy3qvUMb98KkGW3rdE6b+c1cN3Pe6ucS0lvGhpqgJ8YK4wf6IYqf
TVqV2mZqFPOzFlmXzCkCvVAGutQwLb3cJeDODPNXdyW2+4Sv/jd6XaWyfLX5
MvOtTOm3Wk2/XbHGs2JXueaBiX2Vgfrz1zrg/A1wVevdLxn0mD496AnAVuvv
70q/3Bi3odMlP9rcuk1d/Mj6zc8NcRQ/EuR8/lyBM7w1Ot6aIl5JE6GvOdLe
ElCJa9FNG8Mmju2fIk5LW16OS20co9oJ8bsI9B357LYidl/phOyrcMT9cznE
KDjcbok7wgg5ykg5Si/x7glL3LEPGBEQdxziTjDKTjLaTpL13oO4U4zEU4zI
04zMMxB3+uGknXvEua86vScGPGeW8mZf1LBnoh41w2Q9de6Sp+d1oc/uIf6m
pyZ87Flcf3MWd1ofbJMf9qFeulWPL9dH++Wq31bzcr+tuPczHm+YBJjq1EuZ
q2XkU/d8lT3Fb/5dSZpv0UsEvURCX+KC+4Y9X2WPaZ6w6BH1WOIVvsVPqKcS
q7WkU2KXPqOAz6EXvfyFRJl6KZErXknEyh6qVyJALwL0wlcPSBgBLHTNkGxZ
MyybA0dkEx1syNoxCVlnAdlIsxscPClB1DpqLditoVYD3iqQW0XTupJotpxa
Si2iFmyRGTZ+zQw17PExg94W7TFnbtblw8165eHMzYTCTeP2zWPduyC+LgE6
+MK864LT3j5B71U7oc6ZFliXA1W4vkmf/8SjeK5jMQuBk9TEKyveONFvDPFG
iX4jRL9hdyf3AcZSL+K9Yly9YHx1Mc466S0eu0tX7jEGb3O4vcmYvI54VxHv
CuJdQrwLiHcO8b5hHH/FeP4c8T7dhXaI96G+KwfinW5i3Oot8mrt9ztWae/E
rDcX1df2HyyiJyqYNO8nty93wtw8Ra/86sgYk11po2aZvM2IN2x6qx3uVJ+u
OiGe9xL2ZpKITlkzfcNf2tDyhybEWPie6/w38NWGPHNAdEoNSNQEPzVowIgx
BVssNT9HnUcqjxJkKYKkClPWLaPb6nu/UtM82JHcFLcZipsSx38tt1+mLe4a
DZAVgR7Z7AvlzLc3ytoEt878Elo+Vjc/o1s1vyilZ2UQ+5c8Wt3MkwlxquuT
9BLXLfW6AUJfSEPYC1/1zedPpHGacE0Ip5uuOdpeGdTihGt1wm2jrd3OwWYn
Aa4tA+GyEI6WtqMA4YoRrozdVjnVzh5kdx8k7R/aaXf3YYbEYTqCI4ctdUdP
wt1pCuqOMZyOcyA9/jXcnbXUnWToveeoO3WH4XPfk+QYCteHSHL9UnmxRwq+
7bbb20/yZ190BwxFz9Ssi9rkXvT3hLtL1jr/adYZ7yx3M7zceUq181Xt+BLn
nSkf7wv3cE4fdK3PQAdwlJ4DmXuLh3m3ff53Hu9Iyvw7hjn9wUkQl7TgniEu
ccEDSVyo9VASIS4R3hIWaz2ReGVuyVOqU+IgLm5ZF2WJi13eLTErXkj0ipfU
K4mCuKiAXolc1SeRq/slcs0ANSjhgUMSFjgsoRC3Ze2IbF43JpvXj8vmILsU
sWnDpGzcOCkbqCBoWw9ta8ltgfAWCF9rsGd1OHmPWkEtpRZTC6j5EXbfzo32
XIT5luWOj5sK15qUmWHINDNswgRBe85ZWfuDN4MX8cak5+dJd56ENzBp6PP5
BY9i5XM1iX4TTr5xj3zdRj43TP+tDNAg9NH09iDfC+R7znDrZNg9Yfg9vGif
3h3ku4l815HvKkfl7xiyl5DvAvKdQ75vke9r5PsC+T5jmH+sbw2s95NHvjPI
d4qpcBL5jjv5jlbaW0AdQj59nf4B5NtfILIvf1L25k7KnuwJc02XnhRsTx+j
ZxolWIzQPw3LDuTbnjhkj+6/lhains7YpqheM4Mbmc2N4a+kgfzCRDcT3kx+
o95zcOgyQNRstPIBh7aGwU99nS5GG9RRfzRrqULqXkWgKc1max646GfNu8+B
ywG32iJWblpTHs1/VuQArWKtJ7vpN3W5jmBZaXh7wk8OemJ+E71uBIurjcnU
xk4//XX1IpmNU2Sjm6/ypm+q7XCrt7iZ595o4I945fMbs1maFDY2kW6q5ug+
g5t+F8Wt1UW3HangRnRrI7q1E912Ed066E53l3AsKp+wW/wv5UALO4wde5BD
2yFC/aG9uHbQ7tgjx9ixDIqjDI53OTy+i2vHvrCuHce1EwyoEwysk9ew7SaF
a6cYfEfvjsuemyOy/eqg1F7qlZKz3ZL1ZadVpnDORbZtwZyLUoBoapzvNOny
p6Tz/6F0PtrHXvJA513Z+/F1JxnuYj2iXYZjzka7dA9zabP1UvS0Odeo61p6
Dd/cG77Gubd5vCWp824pdbbmK3Z3XVOQvOAeACYBXdJCrQeStOgh9UiSFms9
lkSQS1ii9VTigS4e6OKXUcu7KItdHNDFrnwpMaZeSXRAj0Sv6pVooIsGuqjA
QYlaOySRa4clAuTC1lHrRyU0aFxCgy10WwBuS8ikbNo0KSEAt4EKArkgkFtP
Z7kOrNbhztoo0KMCqBXUMmpJtN3Bi2JFFsaDHzWPmhtnP673vPF3wS+KeDYz
UgPZzPBxr3W/fLN1kW+0zvOugJOeMtzpg57O7Reff5JJnJtwzo0758ZwbtS9
s9Uwfe0gfW0fzvUw1F7i3HOce4ZzT3DuEcPxPsPy7nn7/2/QbVzFue9w7hLO
XeAQfY5D9bc49zXOfYlzn+m79up7rOHc+zh3Zrt9W3R9Lw19L7ZjdW46VNp7
kBzEuQM4tx/n9uHc3nyRPTi3O2dSOrImcG7cOLdz6xizcNQdSn7DzBxkhg6A
XL80M2MVuUaDXI80RChyr6Q+7KWZ+HVbtLqlFuhqga4G6BxyvmqJqkJoqgrS
emLFqVz3WF165G9kw6/Ah16/fqGPdKhrfvAJA2C5+c8VgY/0a7U0za19xLda
93iGflO33/gZ9mcFoWtV8FM//T2MZX766/EjjMabuswvbFDb3G2ehBXthXly
RvJwvTWIcvZrswGUs6ZpnOnGaTFZjZzmYvEOctrODCJzNnkplwhdMC4d5LTd
ZZ4XM/yF7GeH7ecAdYB29ADt6EHa0YPs3EPs5EPs7MPu3XKPvI9RH1GfYhoH
wmPfUOcwjdbgxBUKz07eou5qRpsko3HQujYojZd7pfxct/al/P5FcxWtIiAr
nCo/Vc2C5jcdNF2Zm3VxhpLm9/+HNLNQp/3r7Cvqmqc0y3l6VVxT1VQ4Y1ra
XHSbe0Nt03A3V6+NNHFungJ3W1Ln06+mzr/j858ldYENcimEuGQtbEvGtuRF
Wg8lGduSsS1pidYTScS2hKVanZKAbQnYluBsS1j5QuJxLS7gpcQGvJLYVT0S
u7pXYtb0Uf0Sg20x2Ba9bliicC1y/YhEYFt40JiEB1thwnAtDNfCNmPclknZ
jGkh1EZc24BrG3AtGMeCcCwoBudwbA21ilpJrXCOLUsk4CXjXQr9LH8uTLb9
6zw+PjeJ4t9zUsRzb5KZfNnMWHve4yfCXNTvA25oOnCDYoDj/0+S55xv7JDx
HvH5dzKGcaPuJtnDdLGD+NaPb72PsQ3fuhmCzxiKT/HtEb49wLe7+Hb7nP2a
a/h2Bd8u4dsFfDuHb9/i29ccur88gm0cyj9hCnyEbx/ssm/Fe2q7fcuLE032
Ju96P6WjNfb7Hapg6pQxjUqwDd/24tsefNudJ9KBb7uyJqU9c0La0se9rdH2
lFHZljwirYnD0ppgLwJriRuU5tgBaYrpl0amdENkL8b1Sj3W1eNcXRgV+tI4
V6sFFTXGuedSvdFelFa94ZlUEZmqgrWeSmWQns2oXK+X9lWue6I+eQq/1vJQ
bvKdpe2RlroX+Mh+wl1yh3Hlax9rzdCvVOz0e633lr/5EW8b74x7aqxaq78G
vw6/lhrsYY9HyNPfHfZ0zZEQ9z+Y56P0GQaVPg9/hsBXxnt13/gf5QKv0mf4
62f7wV8C/CXTppLkdqTbO1e3keTaSXK7iuCvxKW438o+duO+ZooOdT+7eD+7
+gBJ7iAd6kE61EN0qIdOICDD4zDD5Ii7sO4ow+dd2oF3OVweu8xw+J66ztDg
kHryHv+PJLf7xrC0XOmTqvMvpPDrTkn/7KEUz71IXcDAC2yAojkXNNddUPwu
KH4XpuGXP0spfC1+05pW76LdNPx8PBfqZWr3auDTl15orPPzxDnjHwrO0UyX
rnnOqqcKaqaDPR7m0bpuna+vatxKmvNol4p0iKe97cL7Pv9JUtAuBe1SVLsl
Wo+pJ5K0VOupJC7rpJ5JItolrrDaJa7slsSAF5KAdvGrXkkc2sWhXRzaxQX2
S+zaAYldNyix64ckZv2wRAeNSFTQqEQFj0nkhnGJ3GjTXATSRSBdeCjq0aJu
oTYj3Sak20SiCkG6EKTbCFEbSGrBCahHBVKrE+3ODEC5gFQETEPAdJIetTTN
irdoKwLy74UZpL1MWt0s9Mt0Yv1EmIv+fY2ruXW2eXUZj/9BuZPJATHWTWDd
uBZ5bow8N+pugT1MlhvEun6s68W6V1jXjXVdWPcU6x4zAB9g3T2su4N1N7Hu
+jf2ay9j3QUG7zkG8bcM5q+x7gus+wzrPsG6j/bh3G7zVj5yiolwEutOEgmO
MznebbB3RTrsrDuAdfuxbh/W7cG6PYU4h3UdWLcrR6Q9261M/pHsSBtnGo7J
tpQxaU0elZbEEWlJsFOyGeqaoK4xhorul4aoPqmPVOp6pS68R6lDhVA9d6vS
1Rjp9Oxjdchzd+Vl1YYu6plUBmt1Il2n0Q7W1j/VB21llalyW5ra1j3xiAaB
rt5W1t7Sv3k/Z7+GrzXfxtd9w6Cn/uYHvOWVzfwaRjjQ3fhMgVPbqjV3YnKN
sY1HBa6bEVOr4dThbcKqQc6eQK0Pf+VFrsEi56vK+SpxPu9wYAA4cGulTd2W
MiTbaVN30KbuJNu15Y1Je+G4C81/JXvqOQhxoNrLTtxHrttHrtvPDt7Pjj7A
Dj/Ajj/IADhEn3qIPvUwfeph+tQjn1NfO+UusPMZTMcYVMc4kB6nTz1+n+9B
rttBrtPLhEvJdVlf2JPJJXNxCt403Sll0CaFs035GOOABOQccRcg7gLAXbAZ
7y1ljv2aM+ui51oUe3Zipk16Sp+v99q818Q9tFP5Zl/Rh+99nXfOOiOd8Y6H
uXpDg3QiXpqn5t0Eu5te8HhYcMddVbF14V1JXXjP1qL7qh3wLX7o839LCtil
gF3KUsADu2SwSwa7pOVazyRpRZckrbTgJYFd4qqX1CtJWE2t6aX6JB7s4sEu
HuziwS4uaFjigkckNnhUYjaMSczGcYkOsdhF06ZGEeWiQC4S5CJALkwL6EIR
ZwvQbSGHbQa6zQC3iagWQlQLptZT61Lsfg0EtzWAthrQVmWDH5N2ZbYFbzl/
LuPfS3OJf0zqxQSZRUzwBfx9Hh+bm21z3i/ebF/M685S/Hv7/ilDEDdoawLu
xvstdWNQN9rjmCPWDUJdH9T1QN1LqOumbX0GdU+h7jHUPYS6e4zKO4zOW1B3
HequOuouQt05qPsW6r6Gui+g7jNG+ieM+I8Omrd2lDN6qyKoOwl1J7abuxjJ
sWbzMnI5wsw5BHUH3V2O9CKtvVC3G+o6CsVOsD+VnWy8HRmTTMIJ2ZY6Lq0Q
15I8Js1Jo9KcYK90bYobksbYQUNcA8TVR/VLXWSf1EFcbTgV1kO9khoAqNny
Uqo3vwCQTbqSXQUeVRufu+WTyg1dvqqccoZ1FYBTEdSpl5YEddKdrn/qiW/r
n5p//dx9rML+2/zL1zz6e/8fmGn5mu/kZ+0MNqU/MJgWVX/gz/jZz6xurkzE
JGoqcVCsv/Bzk+a6rdGbu63Yeu2MJlVPaYfOc1Xk7JOCOD0hA/ma5BrhXxNv
k3b58XT7INcKcttAbjsN7I6sUdlJA9tGA9te5F2H213LAYgD1B723l5S3F72
6D727D728D4C/H562P2kuAOkuIOnKHrYQ/Swhxglh+lhjzBqjjB6jjKKjroT
++/eZDRg3SGs23VrVJq+H5ByUlzulxwDSudddJcZlBDkij0FeG9mz8/LnX3m
/M3PyKdnJS4ofAY/c45Cr0i+aC9D8dhn3LMXpbwu7vl50YMsbXD1l8vAvIw5
WtdUPT+j3s+MeunzrHi2bknafK3bkrYA+NIW3PGcwwU8Sq9aWXTf579I6uIH
1ENJRT1TqJeKeinLtJ5KCuqlrHgmyaiX7NRLRr1k1EtarfVKEtf0SGJgrySu
7ZPEdQOSsH5QEoKGJCF4mBqR+A2jErdxTOJCxiV2k1UvlgY2BvViEC8G7aLR
LopeMpKKwJoIxAtHvDDEC0O8UKQLRbrNRLoQ4tvGNLtXg5mwQcS39ei2DsnW
Iloguq0psPKtQrkA5vjKYmIg8305835ZORJSi0t/r3pxb0x8/878eH2bvQn4
m4C+cegbg75RrT776w3B3wD09ULfqy6RF50iz5+IdELfE+h7BH0PoO8e9N2m
3bgJfdcZtFcZvFcYxJfcrQHPQt/XDPIvGOyf6TtHQN9H0PcB9J1hQpxiYpzU
l4C3Mcih7yj0HWXyHIG+w9B3kAm1371b+N5yz62D/pLuSQgZIjvZfDs5COxg
c27Hv21pk9K6dUJaUsalGf+a8K8pcVQa462BDbFD0hAzKPXRA1KHf7WRVESf
8a8mTKtHqkNfSbXx76VUbX4hVZtwsCqk2020Shz01ga9lLlCPawI7jIcAlsw
TWV50DOPglBGaROrPFrf9BMVQWqnU9RPZfNztG7s8ofbLnfMr9ZuGs9MGdP4
fWogzR/YXhrWai1pfhpTfX6Naj22R4+wF4iYvl1Fi7KiNSFac+IgW2mIrTUs
2xBtO6LtQLSd+ePSVuRZjvsz6eDgs5s9sbvJ7oU9xLc9xLe9xLe9HLz2sSf3
sUf3s2f3s4cPcJA7QHw7SHw7SHw7RHN6mOb0MM3pEZrTI4yWo4yad2+5K0X5
SWXzL0rZvItopvFLH19v2gzXpGp/qpL5S8EsK5nTbAozX7Vsxg8Im3nxTYT5
mqtL/K1htKiu/Ixi9lexelnBMuZqesuYq+tzGfMsYZQmunn6MsL0+Y6xBXpB
eZo3vKUR3oxji7Tuy9bFhLetS/Qa8a1LH1GPZesyGIOwVAhLhbDUFbpMkbKy
y+d/tWt7q7qpF5ICYclrXlE9kgxhSRCWtK5fktYPSBKEJUFY4oYRSdw4KgkQ
lgBhCZsnJH6LvSFTPKEtDsLi4CsOumIJbDHwFQ1f0fAVBV9RdKSR8BUBXxHQ
FQ5dYXSfoRl2JGxm3m2CrhDm4UbY2gBZwXAVVGIJWwdTa2ErELLWVBLwiDCr
mMsBzOmVdHDL7ZnH1ynmZxWL/z1rdOMoNoZio7o8NzIg9oXHMghi/QDWA2Av
AawbwLoA7CmAPX5IXuNIeh/A7gDYLYbiDYbkNYbm9wD2HYBdBLDzDrCvAexL
APtM30aW4a3vGPaB3n2XYX8awPQ2kyf0xY96kbxeIwpghwDsEIAdZNoc4Enu
qxbPKlsH22QX26iNbbUTw3ay7XZg2Ha25TYM28a2bcWwlq2T0pwyIU3J49KY
NCaNGNbgclx97LDUxwxJXTRNT9SAMawmggrvk2ocqzaG9ej1wFteaXOIY5Va
m16YMoiFYEilMa0ipFsqNmo9l3KtDc+NaWSpcvsAbOXBXR7OgrtUOA11wc/8
HWCGM9pfSjnb0DVDedSf8Nxfw6PpQe06WrXtmq1h2k7XhHoM0/MJBFA/bbh9
fuUE6zVteEOkPTfaOE2vZvRqQa/W9BHZhl7bc2gE0WtnoUev38ou9NrFWOtg
d3S0oBi7aLe7Y+KevQh2gDrMLiKU7SOU7Wc372d37yeUHfiU+oLdSAN6iGFx
iOFxmOPcYaL+ERrQo7f52htjsu3KgFSffymFX3VK2qcPpHzBRSmfrycLcE3v
bzDvgprmLQsQtvkqajanvSNFs705zVSB1qzzXuGslNOz2swLLq9dmJbVfNU5
Nz2yPU3r71r3c8ma/R11xZT17nvJnGPjWuYUdr5Gu7dUO6y7bryz5t3EuZu+
ih0PSPeOpC+0V4+n41zaIq17krb4PvVA0pZo6ZmqtKWPfP4vSVum2D2Rrcuf
2lrRKVtXPpOtAXbZOBXoUle/oF5KKtClBPZIytpeSVnXJynr+yUlaECSgwYl
OXhIkjcMSzLQJYeMSdKmcUkCuiQHXSLIJZLTEoAuAeQSQC4e5OKxJQ7k4kAu
FuRiQC4G5KJBLopJGMVkjCSfRebYwRLOZA1j0oaSybYwgTczkTcBW0iFxW4D
uAUz2IKY7+sZcOvoAtYy6AI5bK7Bg9Wt5vv8/M3YJfyeRboRsBsZ8lwk8j/J
AHGtD+leId0LpHuOdM/oUJ/QoT56TDxDuntId5ve4SbSXUe6q0h3BekuMZQv
MKTPId23SPfVp/ZZfsbQ//iUfZOvD5HufaQ7Tc/yHtKdQLpjHfblQEeYRof0
HB3P7ECjJ5b9ueyptN9nF1unja20ky22gy23Hea2sSW3wVwrW7aFLdzCoaQZ
5ppSJqUxeUIaksalIXFM6hPsxTh1MFcbQ0UPSU3UoNREDuBGRD8P4X3YFtbL
oaMqtEcqtba8otQ5e3Nh691LqTD1AuT0rijlql55SPdbQNdtePOgtsG693N9
9Ff83CFbUZyqbsXS37hJVCOOKafEQ73qd5Pe5QbWLHKbX/oY33iAtRnkyle2
vw63VRfeq69zi+j1hbc+nog25A26/hg/SGi1Z0s9uLWC2zZw2543Lju8uP2V
tHMwbWes7WKc7WJPdNBxdtBxdnA82s3e2s1e23PIhefjYPUeyJ2hiGf7iWf7
iWcHiGcHiGcHiWcHL7FX6ToPXQM5Rsz+mxOy4/shqb3QI8Vfd0n6pw+lciHE
VCxQYpxzKHdBy88Et7eklLCmwc0b4OZondcTDOd9YY6/FeoDuBnQztsVOLPy
lq/BzaS3vJkXDHE+/tOb0inh7H5zy3JvaEktcdqSZplzDlle3vT6OZDjYa6e
csgEt0yDm14kDG88zL9Jg5pBistYoHVbMqbplr5I6x7wLb7P3k0Ht/QlDyV9
6UPlTXFT6JY/8fk/JW3FU4ojA7ilgVvaKtuMbgW3rWteytbAV7J1bY9sXdcr
W9f3ydagftkaPCCpGwYldeMQNSypISOSumlMUreMS2rouKSEWdxSQC2F9JYM
bMnAlgRsScCWDGrJoJYEakmglghqCUy3BKZePKjFMxXjSG5x+XZwxDFVY5my
MaS1aECLYhpHMrgiAC28zgIXBmShDLItHEU3M/U3QUAIvcAGBlwwJATvMt/r
nTcDl/i6lbi/kYEhe+uUXjx7iWfdr0hrL2g1n5PW8Owhnt2n7bxL23nrHmkN
z64xOr/Hs8t4dhHPzl8QOYtn33Co/pJD9ud49ulH9snpe269z6H9jN619iiW
MSNO7Le3q9CXNR7Wa6Z2iKff0aVqXcbp4Pl3OM7a2DY72UY74Gwb26wVzlrZ
hi1w1sw2bYazJrZxI5w1pk5KQ/Kk1CdNSF3iuNQl2Bs71MbqPRhqYvRGfzWQ
Vg1p1ZEDWmAW0a+GEOAqtWhEKeYZKY44tUV963EJoGLzK734A+fKsY3Sf9nH
kJcqnJb5lz6WbbQg4Z02oBu7/ZQxX3XM83LZkBe2Nr3wV89UNtP4mtLfajOK
VZuoVr3F6lpjohq9ss9vSJ09dvVQS0+W0E2bVUU9gRIDanGglqCoDUH9MOSP
wL8l3oPa9sIJj2ltHEfb2PztHD/bGW67MG0Xw2wXLWcHLWcHLWcH2Xs3oW03
oW3PCecbR6697PF97Pl9jID9jIT9jIgDjIwDhLaDhLaDhLaDtyal7eqI1F/s
lZKvn0vGp48k7n29w9+PYbtgYZvnYPP/EWznNb2dN+dNz6tqWj5Tvvk736xt
57WMb+f11Q96pmGmt/zVOV+X4LzhbdqZB6Obv3lVhP902LR8vbZd+aFthrWr
CpxBzleB04cbPn8gmfNvKHCONg9vU8RlwFsG4S1jMbXkPqXXTmYsfejznyVj
2SNJX/6YeiLpK6iVT6lOSQ94JumrOEistr6lr3kh6YEvJX3tK6pH0tf3SnpQ
n6QH90v6hgFJ3zgoaSFDkrZpWNI2j0jaljFJw7a0MCpiQtIirXFbsW0rrm2N
E0nFtlQYSU3i39iWxpzbimtbmYOpuJbKnEzBtWTmaDIdaRLzNbnEDpAU5nIy
gysJ0xIxLYF5Hs+BMw7XYluscXEMtDg4iMGyaGiIYsBFciCNZNBFHvh9viW/
5lP/YB7/2vwGvUD3CuheAN3zXsIa0D0FukdA94D29B7t6R2guwl012lPr9Jf
XLlJWAO6C0B3Dui+ZTh/dVbkC4b3ZwzzTxjuHznozuj9dpgOegtFvVfYiUP2
jhVH9WLQDk9w/K3sa7UL1LuZYh0aH9giGiXanHY70W4H2m1j67WyJVvQrpkt
24R2TWzpRrRrZMs3oF092tWjXV3SpNQmTkhtwrjUxlvxauJGpDqWIsRVI15V
tL7TX1XUoKKCfJVa9K2VmukqNNNVkOloSEPtxf76Z8UWLe1ly7f0OPfKbOnH
Nr9S/DRgKYZlrvSLy0JeKng8vmU+5w2Cpl7axaIK42aFpz82oY0E+ZZrnM1C
YGiPrTC7lFajLteE9/rpsiE/QRcR62MGpD5ukAZ9kCRrmWtKG+GwMCotWWMc
KsY5bEy4s6F/LW3V1rid7IA2hl8bO6SNodeOce0MuV3ssF3suA6M68C4DrLb
brLbbrLbHrLbHvdOfnvJbvvIbvvIbvvJbvvJbgfIbgcZNO1XR6XhYp+UfvNc
Mj97JPHv26ldteiSVC3U5hTw/BQ8X7VO7/5itfO0qb7qHVsH6ax4cxSw/x7y
piKd+5emOfOgC3IzdRkvd+ZFsx6n5bAztz3Rm59MexGYfeFrtke5t4xynhSn
f2bRpGbNJcdlQdzP0O2ayXG2bhjnMnEuc4EWfWrmwts+v5TMRXZbZMJcJsRl
LtG6L5lLH0jmsofUI8lcrvVYMlc84ctWPiXJZQZ0SuaqZ5K5uouyymUEvpCM
tS8lY90rqkcygnolM7hPMjf0S+bGAckMGZTMTUOSsXlYMraMSEboqGQgXEb4
uGRGTkhmtFUuA+EyEC6DLjAD4dIRLh3hMkhvmQiXiW5ZzMFMdMtgPmagWzrz
M415moZwaWV2SGQwlzOZ05nIlsHQSmeepzG8tpLWUndY5VLRLRXVUlEtlWGW
wuE0haGWwlBLYailnjTf62dvli7lTdJ5lrm6IK4T4p7Qlz6kL73fRX6DuNsQ
d4O+9Bp96fcQ9x3EXeSofJ5RexbivoG4ry7YN5T+FOI+hrgPP7Vv2nL6ffsU
T0DccX1Z4hHzEkXXDf21uVZUry3Yw9Pt0OTQYLujNjbJTuDfAW/by+332MZm
a2XzNcNbE5u0iU3bCG8N8NYAb/VpkAZvdfBWS39aC3G1EFcDcTUJ9vLG6vhR
qY4blSqIq6JXrYzRe/9VRg/xEDUILhrsKtS28vA+TRVhdgmrgj8pPhxqPoxy
ZVu85cuDgY7AV77ZlM7NzT0uSyh+sKed6uZX/iYNuhzHJyq2aPX4aVzUy+tw
q2qqsDe0V9cDw3SN0JWe9wh394CsQbRfmuXEOj09QjdaTzfakDhEoB0m2I54
VWvOHpOW3HEODy64/a3s9GRlNnl7ow1vHtjaOKa2cTxtA7Z2onc7R6ZdRPFd
jLYOYOsAtt0fUB9Tn7ELv6TcCfS9F9mtBLh9BLj9DJV2cGu4Miyl53sk68tn
BraaJZelZvElqdZadMk+G3zTbUCWq/DWBYOdrzrn87aVDt489TvUzVDb9HyD
PsxywM2YnulszTSpbqZyp5ku15aPv3ucppzWDE+m0+tGsmdfVuCmlV43kj3n
iufKOqOcZjrr3LxrPnN5vC5Z87Vu2MK3LHJc1kKt25K1SMsil7X4rmQBXBbA
ZS2llj2gHkoWwGWt0HosWSufUE8lC+GyVlEIl7VG67lkBdp126x1L6lXkrWe
7Y5yWRv6JHtjv2RvGpDszYOSvWWIGpas0BHJChuVrPAxyYoYl6yoCcmOmZTs
WCtdNsJlI1w2cSkLSLIQLos0kc3Uy2EK5jId89Atl+mZyzTNQbdsEkk2UzeL
MZbtzgbmMsbyGGP5NAh5jLFcxlgOBOQwzrJ3W+my0S2bsZYNFTmkolxkyyUl
5THe8hhv+fYCyrffLF3qGxfl/tz8Fg96yG0gdwfkbtGs3qBZvfaY3AZyl0Hu
Is3qeZrVs4zcb0DuKw7RX4Lc5yD3Kch9DHIffmHfQuU0yL3nkDt2QjwTS699
PwDX+zvsdVN6Aq6j1U0wjNvBhNuOcdsxbhvNe6s7FLSw8ZrZiE0Y18hGbcC4
ejZwPRu6DuPqOKzU4lwtztXgXA3O1eBcDc5VJ9mz3VU0r1XxWqNSSZyrjB0m
M8RAXEX0kL61N01suRZRrjxiQMqIc+Va4fa2UPypMS2sX1vRsH6qT8pgb4Z5
VOX6PPDpcjmPFjMPiOVbet9RCv1NCHTnGZCRaKh9aihc0ijrBSpYVsU3pzRj
apg0q4TVNNa/lJrIfteDD0odpNUlDNGfD0tDygg9O5U+SrIdg7VxWHMviP9z
szW3M9y2k9W269HE3S1w186prKak7WQPtTHM2hhm7QyzdobZrtMUQ6yDIdbB
zt3NTt7Nzt7NTt/Dzt9z2R0s/0DaGRuN1yel9CJ54Uv34t+ll6VWVTN1yatb
1SLPCcxp/SquSQXprdyW5U27Vi9t5nyDhy54U9xszVa6iswjzKly1DktX7Qz
D942dqalzk8ff8o7Y93Miz/wzlxDctlxZ+7jqalOnXPnKuZ+T13V4sPz9JRD
Nsplz/fUDcleoHWTTy+85fPfJBvkskEue7GFLnuJhS4b5LJBLnu51kPJBrls
kMteSQU8oZ5KNshlr34m2SCXE/ic6pactRa67PUvqVeSHdQj2cG9krOxT3JC
+iV384DkbhmU3NAhyQ0bltzwEcmJGJWcyDHJiRqXnOgJyQW5XPeyhTwiXB7I
5WFIHsjlglwu8y6PKJfPXCxgXhYyPwsBrhDgCgGugBGXzzzOZ9TluxdmFjLP
i0CumHlfwqgrZdSVMOqKiW9FAFd00GJXRCYqIhuVAFwpjJTRKZTTKVR+LlJl
z2b+lHRbf7g65/Mn5offpD+9Rn/6PbZ9h22X6E8v0J+eu4dn2PYVtn1Jf/o5
R+dPOUp/fNG+o96HtCUffG1v3X+K4X/yI3OLHNeD/p25lP2Annc7YK8i2MOT
2k0u7Wizyz3tALeTJ76DabcN4FoBroUN08IGaga4JtfVN7IBG9iQ9WTiepCr
Y8PWsYFrQa6WjV0DcjUgVw1y1SBXBXLVWkBX5ZCrTByXSqCrALmKOF2lK4/V
N4erINRVxJjSj0XrbaMVuzItwDMVMWDTRnnEoHah4XzIU2EDUop8M1Q++As1
CIbaEKj8+erjOxoDteft8/AWpguA+tlKDYmV4XxtFYz+ShcJ1TOzalhDQKtB
s9q4IXruIfpvexlzPZo1pI3So49JU9Y4wXZcmvM8pwz+jbQyyFo5im6rttt1
m25ftvN2tvd2tvsO9ybGu9gn7eybdvZRG0mtDdbaGFxtDK52Blc7+3MX+3UX
+3cXbWgH+7uD/b6bNnQ3x7g9HOvaGRf1l4el+Cy90eedEnvmttQv+07qtNQ3
r3GXfpDeqhbZuIRwGt+0T1+gJxamEWeX5+Zp0XuWGto0vSltWvrlxTbFzT6n
vvEwjbSZ57yknZsi7S0lzXao9rPapeqVcObEqnsNa47BK4ekljNHS9OaPr7l
VSxn3lVX1yRn/jVf9ctX8VL0CGrZC29KziK9x1LOots8LL7DgVTxMt9gqQUs
B8ByACxnxUPJWfmI0jMKOQFPfP6j5Kx6SnVKDoDlAFgugOWCV+46u9abG/SS
eiW5wT2Su6FXcgEsb1O/5AFYfuig5IcNSX74sORHjEh+5KjkRY1JXvS45MVM
SH7cpOQnOHjAqxC8CqGhkHlUwHwqYG4VEiKKmG9FpLRiQkYJeJUyrkqZn6WM
qxLmagljq5ixVdJkv1cZY6ucsVVBiKkEryrGVjWHzCoOmZXvWsAqOWxWcdis
4bBZy2Gz/jN3ncfrOlFfq1b6G9fcfm1+7mXsukjjeY7G81vs+lrfBJnG83Ma
z0/pJD7RtxGh8fzgsr1v4elz9h6G7+n9bT73NJf/sxx299zfd9SeUtutyzN7
XQTgee0kEuygx96h86jJzqsWAG9mezSxXRpxqxG3Guyle1JfhFNsvzrsqmVb
1mJXLXbVsG1rsKuabV3Fk6vCrkrsqsSuyhQtPpZsk3QlflVgVwV2lWNXefyI
lBHSyuNGlLARvatbDB+CsLJorSHoGpJSR5hhqyySLFcWoe/jVhYxKKVa4YMa
HsIH/ZQxzW0Dnt4zbMD9C9F+prGO7BHW72lAyXyVpuh7KyPMWY0B4o0u9VVH
D0p1zKDUGK6G6aWHpY7wVUdPWQ9XDRl2ybARrppyPStlf2+4V/Zb2ZSt9RSh
vxWuWjkebmNIbeNwsY0htZ1dsZ0UttOd7WynsWynsWxnOLXBVRvHwjaOhW0c
C9vZte1wtYtdvYvDVQeHrQ4OXzuujEnN+X4p/PK5bP3ooUSduimNK65Iw/Lv
pF7L0HXZ0mXZ8lW39A6fRq6LP5bLuOWrbtk1NvKuJUvLx7jlZ5pNfwfWOeVK
SxfV9GHWuRnqFroBl7rlLd0+qhb/y0OXz1vT05gpq9gFd3lIrru58CW92bBK
puWnkPEDQExy5mp9b8qmTCDzVcX064hhOQu0bkjOwht8eKFe7AZlkrv4tpb+
/yV3fP4fHq1mOWiWs+y+5CJZLpLlrtR6JLkBj6knkotkuau1OiV3zTMk65K8
tc8lb1235K9/IXlBdjE3D8nykCxPJSOK5W/ul4ItA1IQNiiF4UNSGDEshZEj
Uhg1KoXRY1IQMy4FsRNSGD8phfSaRUl2WBQjWQmzqoQZVoxkxcy2YmZeCbOw
lBlZRqooZ5ZWcISsYOZWolglw66CYVfBrK6wF3FIFcOummFXw7CrZdjVMezq
kaGBYdeAYg2njGhvfFmWwyvjjXj9gfkx3wDXV8D1hb53Js3kJ3ftex59SMPw
PiP2NAfa9zjgnjxv7uTg43nTkMPgeQhED9Lm7mcW7HWvmN6lPYrOErrJHTpr
2u0s0tnUQm/TzFNs4uk2MtsaQbyBmdfApqgH9zrXVdYCfi2hq6aAsFidp+8j
Wc0WrMauKrZmFVu1kudVyVauIPBWYFdFqhZ/dy/4qMCvCuwqx66yxDEpSxiV
UrUrfkRpiRtFpFgIK40Z5oHYNQOzbLzRP8u0IjWSlUZqTCuNxLQIU/qvCAea
vwGtLNyApl88Q//hT0QDtnI1qiJcKasgwVVEDLoJVUmM+wNdv5OqmCGpih2S
6vhhqYasGsiqhaza1FGpg6x6yKonYTXQMzZ6yfqX0szGaq608jfrEUCPBE12
A7dwhGjlSNHKhm/lyNHK+Gllh2xjx2zjSLidlLX9pFtHYwe2kbLaPrVstRHh
2zgytcFWO2y1c8TaxZGr9TKt+dk+yf28S5I/eGAD9j+XxpVXrF4/Fuwngpch
bOF0wi54eku3blY+T7Eygk2tm/mqYfpwzjWYDjFTOKYnDBxk/r+Tvc5ZxUwn
eU4VM5LN0Ec/d7LAIOau/7ClF3zkzr6kD3pKNHfOZeo7V1f48FwNZLkoljvP
nizIJZDlzte6xrddQCDLXajvfJlLGMtdpOUUW6J1h08vvetu85277B5lEcsD
sTwAyw+gVj2m9FV8eauf+vwvkremU/ICn0n+2i7JX/ccwLqlIOiFFARbxAo2
9EjBxl4pCOmTAuJYAXGsMHRAikCsiPFbHElUjh6R4phRKY4dk6K4cSmKn5Di
hEkpBrASN31KmVZlTLFyplo5066M6VdGhChnVlYwOyuJGJUcN6uYvdUMwBpm
dC2A1XLcrAGwWvcmVPUI0IAEjQzARgZg01HP/ZJMR+hRyecP3wxY5k+fB/iZ
fPzAvrXH+7SKZ4hbp2gJTuqrk/V1fBfdf/srOfilvRhpH4fovXqCi0P2bgzt
oOPYdcydleRX3E5X0sqv3EKn2IzBTeDVBF6NzK0G5lg9c60es+vAq475V8cm
qGVT1DIna1zyqsb5KjZVZT4/vjJPb8ZexRasZEtWAlgFW7WC51UOYOW6pQGs
fKs+4/JUzx09ywGsLHlCypLGpTRxTCVKGIWe+FGecmncGIVosVojUhKjNYxm
5upd/lv0CA9Ral0JxywQM5DNcJyV6b8j7M333lLJaDojhnAqcohdUUGAq4y2
r86vihuWKtysTqSSR6QmZVRqto5KbdoYve+Y1GWOS332BH3xhOfMY5PDyawP
sqFa2GDNjI0mxkYTY6N5u92wuoFbdEPrBifqtrLxWznAtbIzWgFqGztnGztp
+4du57DzdpKrdjqg2ojSbQDVxr5uugjt3/RI1qedEn/mno/n1u/Nq76XpgA7
PZ1W+jKs5RpGfpC1jFY65TVs+U1JtUg7Mz2XafeKZxXMtYk+RitfF7WmccUg
/z1UmV6RvxZO5S2f3+0az/GNflcuP69fF+x1Hq5snMqbpb9tnt758gelr5xH
Mb2OVw2b+50hzEDmq4a5hOgEk7wFtJV5qlieBjEAY+ApYXmLKQjLW3JH8pZq
3ZW8ZXdt1s9bft/nP0DYA8knhxnCqAIYK1j9RArWPKU6pSCwU/JhrADGCmCs
AMYKYazQMVa4sUcKQ3qlcFOfFJLDirZYwoo5ypZwKC6JsmPdjH+dC/HjUpIw
wUSZlFI6yrJUO2R0gulE00mnE7CKDFZJR1Sl85McVq1zlqFaq3OZoVrPMG1g
mDYwTBuZ940cR5t22TtbvvUah34id2X9aKnLDoWTGHWCdHWcdHXsmidN/YMc
OAtMX4PSF3bJQ5c+tKfYSW+xg7mwnXS17aidI/p9mjmoN3Fwb2QONTCXGvhl
60GqDqTqmqzFarLaXA1SNdX2iVar2S5lVarjbIgKoCpnw5Tje4UWG6oCqcqz
rf9lbMDSDH1iHBUUn60qlmu52dBlKbrR2fhIVZI0xkE6UR8S9O0SS+J154yZ
P0vi8KskdtQtY5RwCPJUabSWflU0wawkSqGLGvV3gpkDEoqVRY5oMODxj41g
5dOLEVHBga0CDSv0JAJmVWJWVZK9CqyaRFW9leYrHbcwq5ZUVZczIXXeVPU3
0qC9c4WLpDU2pja7VKXfQ1OVOSJocWBrAq9m8Go+SB3m/71LsaNa2GGt7LhW
dmAreLVyxNkGXts4Am13Zxx3gNeOy9oQsmP4s+DbIUn9/KVEnb5nx8QfScvq
q9Ky6qo0B0wzzKSt736qX/SkLV8FzNr1Fknrwg/8sstb523YmuENW17B5ig5
JfZx9jmPYt6lrlnn/Axf/oavwplngcvU6wSboY9+bgnMEOZeBO95kYHpvtzN
j/wULh7m6HnLPJzKm+upK5I3T89Y5nmpyoMqmHJULdT3CMcqyVukdVPLV7Vi
W6pX+VhlCqvyyVv5y+195fNX3KcsWAUOq8LV1Jon1FMpDOz0lcK1z3z+tRSu
65LC9c+xqluKgl9I0QbrVXFIjxRv6pXizX1SvKVfiolcJXhVoi2DHmt1aSRG
V010BWVMyhPG6UzoTpI48KdoB2O7GXPEZdppt1PDlKzRJogpWoNVtYzOOkZn
PVO5QZsnDquN2ky12Bdov+4lTj/hU86bYpWdDf9K9l6yJ5H0ZFIHo7ad0bvz
M0YwjV8rfUMLI7yZxq+JEd/IyG9gBjQwE+r32+dRB0918FRHH1LLzKnZbqNh
Nb5WwVMVs6uy1vXAWsy6ykobKyscUeUQVcbzL8Xs0nz93QmhPm/bOMozKGVb
lWbZXrskw/TdehbKy5SRI1Vj7SRFzE0eJ+aOUeMM5cRxxlhxgh46XHEYKY7X
rFUcN+Y5kUVKnqpxnRAxfHFJzBh/ix7zV7dM4LLO8KcaxeMfssfZ0xyhdK+b
df9Euih+emUKlTomVXhUhUfVGeNSnWkv+KjJmbD3tP6t1LMR6nWHs2Hq4aie
jVVf7w5SGka32QNUa4fjiQ3fQjWRpRrZEU00e03v2h2kO6pZd5juOI4tLZDU
Akmt7NRWdm4rO3kbO3sbFDVeFvd+H+/ItsBrsm3NNWlViyjNU8ajlV6PXJ56
21hU7yyyHl3yeORjMNL3EHPdX5Xr/GxiqTDXhuGRcmSqzKSquTZVncOkc8Yk
0wD6Kkn8/+IpmKR41lll6awGqllnjUgU/59H7QfPOmY8Scvfu6plrpf1Ny8N
cBfNzrroEcm8RwIPc6xIvgqRsmQpcvU9DOmlE2DksQyS8hfo5bD5C4lP+YuI
T/mLb8JwPtEpf4mW5ahgmdZd1Fx+z+ff2t8QiQpWUgFotOqRFBqNnkgRGhUF
PpWitZ3UMymCoqL1Ws+hqFuKN7yQ4o0vpSTEXj5dsrlXSrb0SUloPxQNmAWK
ssghs7KhK7bleqDUM+4JDEaO3JUcwSuTdRFYF4Tt4rAdkHbx2CwkMxXroaie
NqeB6NTIyGyqsWK87s0LXkeS4yf3jctS/2CPj+iz/TwD8qwdoC0M1GYGbBPh
qJEB3MBArj9D0STUcbytY5DXEpBqUKiGwV/tFKpCoUoE0tW0KiZLFUGpkolT
0WJX28pRtIzkV1ZjzyuU8ZTKUKiciVfmLuQq5SmX6DkINC4uMCt5OhLztG0t
0ZU9NlFJtlvtQ6IiNl0RmhdrpU1bFWTTFqfSaKdM+EpRMooUJRmCkpAp0VWC
ljJTHD/u6R9o0m3xuVh9s+ySWD3bxt/1b1ikGQaWYChmnD1hfmk+UcYXlNHd
lyVyuGEflyePSQX4VKSOc8hhn6ePS1XGhFRlUTRx1blU3qQ9Avyd1JbarrZW
E7J2urU2Jdc12JBZh+R1iF6H7HVs23q2szb89Xttw99yxDWBx91Rgk67EYga
2W9N7L+mj+3+1P3aTGPXovuZxq4FiFrZ/9XnRiT/ix5J/eipRL53R3ZtuCnt
wTelLeiGa/B+I9vXXpftHqTWXLVQrbrqbfya3BKV/h5Toenyjxs/0/dNS0xI
RWJyQrmO77xZW5++NuVo8jU2vaU2mbTkKQeUr1enGcqR31ROmjHdJFP5pgvM
13UpD0t+P7jn7SXJn2OKD5teLt/lI/7UrzQJKR+U8ueb0o8Bk/tyhWnhdctS
gbJUAEs/53GKpYKlWoYlKVyudU8KV7h3Jy1c+YAjayE0FUJTESHJw1LxWmpd
J/WM57u+y+cvpTjouRQjUwkylSBTqZPJXHcT2m/P9KhKEXptzxDxXU+DE9s5
XFYiU1Uih0ZGbTUHbj2tXr3VnmrX0+4mYDD16glJDXp6vtg2aX/yGlZe93JI
p1De71GolhFZgzzVenkDI7WSEVtJoq8k2VdyOK1kNOsZxUpGd9Ux/kSgCgSq
QKByZkD5XieIXlLBDClFnzJmSzkClTFzSplBJRzOSzisFzO7iphlxQhUzIwr
0UKhEqdQMQoVFdnLOfSsaJFRqChPW8siNkUxChXpWVM9e5qpnyvM0OdW5HJl
UZr5/1t1Aa6IzVnIZjWVbDTShyRVpQiFiuij+VP/f4I7r2+XCeP1xuM8glbc
JA7FTcJNSTzpis+Wmg5cG0F7zUMZybacn1SeRqVPSAXUVGRScFMJN5U5k1KV
597D4++lxjXjNe4uRDWQXAM3NXBTAzc1kF3LhqvdYQNlrQZLuKmF+FrasLoD
9iRJHezUayB1r9ppgZpmdloj1cAObNRDCH12I+Q0fUtBTjPk1JwblYIvemXr
R50Sfeqe7Nl8R3aH3LZnNTbc8lV73BnfnetvyI51140+GpFap0WkFk9E+pE+
nnYNffRVmUuJE7ri5Gf7NXJRtXetyd+rjxNII9L5H6+Mqz6U31S35uQ5a/o0
T+QBH5eM3OPMqXzkBemcE8I4NMvUDHdVlvfuF7PNiydnO5DcFapzLk0rfWL5
cy/7GozAa953CpKpgvnfq0T6sOCqz8/sFy+8JgVwVLBI6wYMad2UgiX0bQVL
2OJg5POPUkhKshTdNRQVrbR3YEcjKQqgVj3EIutRMR4V41EJHpXgUcn6Z1SX
lIBRSTC1oVtKN74AI30ZhwVJLxAsD+s3F9boWZoKxUjXQGOG7YXXehF2gmI0
JjV0ELWpE+aCxto0d5EjM64+x8agv/jvBOifWYDyvatE9oLPP7XZjTarmIRe
TNApZvQWw00x3BS/Z6++KoIavRKrGG5KGO0lkFMCOcWQU7yHz7mOoJBZUgg3
hdv4GUWter1CsV7ohTiFTKpCJlcBk6yACVfAxCvUqrAXiZkv1wvGyD0FqJOP
OgUF5oIyXabMU0UKUadQLzLLNtds8OFMfZrmEg6LjiKUZv6rXt7BJiuAg4IU
5ChMmSSqJ09y2CykCS5K0pOokwYeg00CKaQoQbRL05hlzk0ku0aO71HC9yqF
lVJYKU2flLIMKtN+ra5bmTWsvMm3XBtTSStVpUtfPMMqjK3mmVfr8hhborrJ
86tWs4X+RqrZYNVsuGp4qdHzr2zQGnipOWCTpSZMTZq17IRadkatJlASTZ0m
UnezVA8vDV9TENNwXnkZl8Iv+iX94+cSe/qhbD52U/aH3ZV9W+7KXqjZs+n2
D7mxq0CWmt/lpmVa0Gn2UPM73Fw20uhNfJa4hmzxJW/U0UtaTS9mnNGLwRbo
cgzU2NQz77xd3zY9mHltounCPKVLQ2dfJ80MfdSL2c/6Wl8Ktdeyy90GGQuM
z3RhCuzdKHx83U0T3R3/vWX3UMEcfvOCuZfZpThjso8pB02BgcZgIwUL9F6I
BQs82adgCht+l8Vkn8IlN+lQCsk9hUu1bgPNbS82RSu0LDZFAffdLwA1mmzA
pnjNYykJfOKFpnQ9FfSM6pJSoCkl+ZSRfMocNOZ1Flvci87CzBUsUhk5KJVR
+qI1oNEXsMWNSA3Y1JB8akk+tSnjUpdqFwR++/8NlsLXfOrvLTY2OOdgSi7D
NhdXcnEl54S9fD2HoZ3DEM/hSJrLcM9j2OfhSj5TIJ+pkOdsyWWK5Kgrua16
j6W8FnelPLMpH1vymGG5NfrpKr3MM5eJl8cEzIOWfLe4k0+gySu2F+HnFdoL
8vMAMY9Ulq+Va69hzc9217Nqkf3yMzwTNj9d0UnjIX+rvu2A0YUmqyDFIJWi
6xgFqFE4vdwZzqJUTxz6hUYj26xpZbjlpCzb1JUSUkpzqTyEyZ90t5P6a7NE
VVHhLuOosstYFWBaoUtaejlHg20wK9kwVR5S9JKOXW71XS9SY3tW7bMXqlVp
08p2r2b7V7MfqtkfNeyXGr1YjX1V86G9YK2W9FILL3VfeS50/UMaJfT8ekzS
PhuUmA9fyuYT9+Rw9AM5FHlfDkbcg5l7si8UZqDGpBqo6Qi57RkKrqf6nVTj
6ala3tBT6UK0ocYuQk8LNf7OmYue0/2aay54gKm07ZTbiQDjP5VjZpBjzios
3iq2eWaWR5kip8xb09d77NXkPv7TlCk0ypy3yvgrK+6O+wVzPHd2gBM00QyG
KTzM02WsHyEihaaugofePhpG3PmLQlKLKVILlEiRppaipbd8/pbH21K0TOuO
FC3XspYUr9S6L8XWEykmuBSvfiglax5R1pNSPCnFkzKCSxmelAV34chzqlvK
N76wL8DHk4rNPd4XseoVcVURA1KFJ9V4oi+GrYm1ltQmjBoA/9VrQHjd64yd
H0Vv7Iz+1vzIFIZnKl1PmhbDNY1hm8bwTWMYp8FFGsM6ne4nnSGeQWUS0rMY
8pnu2t8MgnwGHVAm0yMTN7KYKlkcjbOZNtlMn2ymURZTKqvKvSKnwr46J8dl
k5xS+6qdnCJmf06hEpSDHzn4kYMduXn2RT65OUpQtj6TXCZ0bqaHjrwMPpGX
rtkkj9mfP1WGFTZNgedqVK1M01NJYZbDQ/usHANIrmaUPP0BxfzskgL7A2xP
809SWuYuW61w58uq7VJTGU+vjKdZpstPPO0ynn4Zm6GMzVHGpinXS1l32stZ
y9lsFbunlDB7/JBrNNnsldp4nrDNqF7aWoUWVWhRjRbVpMhq0mQ1TWwNYaSG
MFL+zaTkfDkmKZ8MSPT73bLp+D05nvhEjsU/lqOxj+RI9EM5FPUAOe7LgfDp
etxRPZw6f6whxfwubUGv5+O1KWU6H8s9fExviOwZeABZ5MVD7fBTO3zdKoxJ
eWal+JxdIPb0QKVTdugq2WzNIsVqyCxbLqVYO8ylj28bMdyMnnXeW+auWLOt
Gz4GDvtGRHMumhhiGLnkiRZEEVPzLvsrIr7qh8o036uHBuGFV/XhmvsiDx1F
GkU8dvgqG75qhqYMEogV454Ro2SVfZOpEhVj9SOjRmngY8R4ImXrniJGpxGj
PPiZuYFahd5vyNxOyL4aXV+8qbf4qHRqVHku89f7HkUPmV/rH18z7V93ZbRT
oviNSvyP5kdEM0xjGLJxVDyVQCWiQwIyJKBCIkM7kQNiEpXMUE/hAJnq3jYv
lWmQynRIZVqkMj22Mk3SmC5pTJt00kU6UyidqZSOEOkIkVGh8zGjXNdDMl3E
yEKILH7JzCL9XJZhIospmsVUzc5zBRPZ2r3l5HjugoUaWnptRI5+uzz+nZfr
yqYTXWXTi3voiXRPF9h1GZ0YbzsAisvtOo6u55TYK9Z1TNaKz783V67rmo/Z
nbr+o+tAPNcSnnPpdrtOVMq2MOtGbJtStlMp26uU7VbG9itjO5axbcto/irc
tUs6/ctPUvQj5QS7CvqRChrICn15DgRUEhoq6UmqvuF3+nJUsj7pk6T3n0vk
yYey8d1bcibN3hTtvZSnciIJDhIey7txcBDzUA5HecLENBK23LUS/JlmCdm1
8Za0TxPhp/qW5mlntaf3LQ1uicSs7tnF2f+3tPOAjuu40nQLgQqWrLFHHnsc
xp5xnOPxeL0er8f2jD32cdjdM7tOkiiKlCiJUaKYc845ITAn5AwiRwIgABIE
wQwi55xzRue7/62q9/qh2ZB3z/KcagKN16+r7v3+e2/VSyZZUMyZUVDIuPCU
zs+VNYX3jLjwhM68zquoctIS+GfjpOWxL0cFb7dJi5+2POLrOhvaW4QBodQ/
8b751Ve/aZ5+Ez11+2M+xi7jQ7lWVcjP8mrIqTdQXJx6o5IjQpUXhwQRDUzf
otNv1SAQ1IomNn+7jgMC4gE31BQLGsgPkxO/d7g1kd+73JoRGppFePBHaPB/
n5sMDwHqOXQBIjR0UiDCQ6AKD2eW8y1i+W6w/fI2inxr2ZWDfJdGcRez82tG
xEXcF9aNiez1fQ/a9nRplwoF/rOGgq+LLq1EBluNtgYor0Nbj7aRb38CvDcB
802Q/Wa0LUB/KySwDVLYrk6F3glp7EAI2Amp7EQI2AXp7IaEdiME7EEI2AN5
7YXM9kJue5Fp93E747phwX4UCwe4+YsQ4Q/dHvTDyyHxwhXEYX454qcFgCN8
TbAfb3yUNzkm/nCM5ysBoskFLC9eOcEL33nz5EWOLacuyVWVU1fUCguvtATx
4ksImf4LL8GIq+xOq7MjT2O8pzH207CBX5xcu+Er7sQ6DrK9H6/ppKo1ngw0
FFv+kHgApB6QJ6/AE1UFMn0gZB4ImZ+BzM9A5n4ldkh8EhIfos05PbQmq43u
nhqhOyeG6PbRQSo8PED5B/opb5+8GPTGrh7K2tFNGe5VAGSfBNlD8lLuX1BT
iOZnZB+py97zHMI1f6g2nDpc6S772RR/QVYCchYxB7OIUjGLEE0dNjaZZD3A
JzpKvbuaKAb0FQt1NYSrNniRpe9lkD5fqcrj9ZF3kpO3Nhc3OpfP75K6x8vr
2gNqIHbWOud6LgJOvSleRCUwt0pVAnxABqpHtJmnVQKnXaJH3xY0mP5W17v/
u9yayX8hN9a7pvk2CviAG2tePqItUNd7l3yYB98E/8Neefd86P3cCnU7aWie
byQoRP7D/zeRB8gVBH25Uq6GL0WmWo72YaS8U9vHEfKubavR1gD1tWjr0NYD
/Q2QwEbIeZM6p2pLEKtsaxCrZxvfKQmq2X5F3jlpB5S08xK+bxe/7ObVBChd
PQiF9b7vnGz7uZ0X/6PfKAa8RDXgTYdU2c1+fEnScYyPVx+7xGn9mHpa33Fe
r+Ar/UVfjgfzzAB6/RIdD5WX/p/AQE5gYCcwyJPQ60no9SRi18k4uYOTSMsn
odmT0OwppOVT0OypdLlGK9Zqec0Wuj3N67d5aj23UK3vQrf+xdoZF5+lR+cm
6MGZcbrnP0p3T49Q8clhKjo2RLeODFLBoQGk6T7K3SufwpKtqnaZpjsx59cr
d+0mKc9M+z9uEoV79EeNriMZn1S4z5am1XFU3of7ybMG0YoDGk/5kQriYMaz
iuV0LUJpIB9HRbL2mXE4Q5by3urVz/1UNM7afFLtH+WJtc/zq0zVSlp/kjrW
FKyePaXU+3oZi1cI2Eu8qsr8jQrVoN/Tb1aaXsFrFStZ1/Fpbm9Vi/x9eh63
WvJDYykrSXMH5/PlmH6cw6Fn/3f4ckwo2ovljAkmCzoAgg5AAg9Qgg5EAg9c
rD1zkR9Ee2ZpF1/zKx48xk+v6JWP/lnRL3v7Ew9i9XSmqhLwGQ9/EsuCn1Kx
jvW6BsivRVsfqu4P4SPkupkbClVI9nOqxt1/SdXiUOvBq7L+hequch8O8Xto
+E22a2KW70uHg0UZjr0dUfn9CL70KDR2NJIn81H8Ek2m/y1us3EUGjuGvHgM
GjuWqNYjeV0SOjueqgQMrZ2Azk4gP56Azk5AZyehs5Mog0+iDD4JrZ1EjjwF
rZ1CjjxaZKe9hdO0I3+MNuUO0ZrsXlqR2UnVIRaqCDJT2ZVpKr04RY/PT9DD
s+N0P2CMSvxGqRj5s+j4MN1yy585e3pRMveIvuj5k8tm6DF5oyzJElE2J6Bs
vr62xS2BNokEGvVRg0igvC3XzUKMHurmT0qgSpAygb7ooWTWy2apxzdL5ZFF
vr2D0iJKZ1cW9TZWzyZxmoM4A8tXnIHlQY9CgL7qVg+aAGV76mPU3mlo7zS0
d1okT0MKhe5Ov8HnNUB4eJlbxaI2qg3Nb16NUJvf23yOld/bdVo2R9XMavNf
gNk0y+2vRAINWMitGVprVnqTmgsUepOaO+PSHD8fUHvQn9jvzz1oxnd2iZ2d
TWLa9SrvQ1ofgPhFaEvQlqItw3sfon0URtrlMavDJNxrQ7VLZnxoIwSzKVRm
z82cp7YE8x/51oLb8PY2mVS9aEcw90CUzLLhvV3BUPNuftkTxH/dEyzn1nI9
bD8v5e8XS/n7QuXtvERDJw6gfwci8OcDkbwudhCJ8GCUatpqXqxc4TvEK33X
xVw7gUw/oMMQ7GEI9jAEe1jdI+cIxHoEifFIpjroAMEezVEHFfiABJLjMYj2
GJLjcYj2SJGD9hVaaGf+BG3JHaH1N/ppVWY3fZjeTq0JDmqOs1NDtDx7sibM
SlXBFiq/aqanl6foyYVJmVADOaGOiYR658Qw3UZCLURCzT84QHkqod7Y3SMS
qhDxNini1C0darnrVa0IRkZtNWRUDyJeLkUcrol4CecCSBi2M1bBni+eU0th
Sg7qaJ1++uQFTcH66QGagn1nZFSVVU1iYd1X162PB916G/KoukjFJK4Mfl7I
WK25o+zlO8h76Q9w5LIYdTA/01ZqucxbiNkH8i1nCYsmQNaU7MVC5g0gZT+X
jL2Ejl9jHZP/fJk//RfUs4ohYm6NFPAuN5eUA9/j1kKBQsZSymeEjKWUzy7p
FJL51WzZ8Tl+6zn5k1DtuVmnr58VPXoHSlkIeb0HUQgBoy3Gz0vQloZJAS+H
UD5E+4jvWKymeCvx/iq01awvJFc4ylgOI8VySQzDbgzj07U34f3NEao0xs9b
sc3WUPk/z4i34b3t3LDNDtbkjnAe0U78aSfe3om3d6mP7+Y8uiea56q8rIZf
+TfZ+OZ8kOzeOHGTPm/ad50324ep5z513qRYx4diDyDFHoBqD6RzAMgQAQDC
PQjhHoRwD0G4h3LRINxDEO5hCPdwoVbNfoWWpXXQALbpzXJSd7qTOlKc1Jbo
oJZ4OzXF2qk+Sl6T/2zmnaSHZwyZ96Qr84oqGJk315B5s5Rw07d1KcH+vaiE
k5B9E9e3qczbSvEQbpxRuEK0jSLzRmjC9ZB5jaWwUbjPXoNRbhBumUk/pVBN
W33cp63ylEJ16wN5Qo9pluPtczxckDFHXsjv96fSOUqup9WdSU5rj+dizZaJ
Z1DzS7kXC9RbJFmVot+s1BpiwdwqvLxV7cXq5Ngg0yz5i4IW8lQf0gQa8A5S
LdTJ59tDm4EztCn1eQb6PLOoTXzud7Ol0mf0eN5tpvlF8bVvo46cjzpyAbKa
rki099E+CJUPQFgcZkirSgsitYZLVWqz05XIY6siXbPUNfh/LUtqXSQrcb16
gMdG6GUjft4YKdeoNuHnzdzw/pZoeRvfrTH42FYhtW34dRuktV0dJudVbl7t
3nld/O/FP8CGOyG1XZDaLiTHXck8u03hl1R+MOoeddos3ypzb6Y8zLaXD7dB
R/ugtX2obPdBb3vyHLQz10rbcsy0+cYkbcgep7VZo7Q6c4g+zhhAguylpWnd
ZHlMNP2AaPIu0Rgq4BFodBD76L/hpJ5MJ3WlOak92WFIpjaqi5S6dCXTaT2Z
3kcyLeFkesqQTA9ryRS63NtHN5QuM3d0e6lQwBPUFFUQJ21QslSSjF/doiTZ
bMilmizrRVekJOukJD0VxM9eiK7nUoMsTe6nvpzXT31xE+ebpT4exKlmqtpp
v88rUSpBClH66KL00h9KIG+AJm9q+2dxTp/27DxDCjXJR8V7y9JY5FGZUbV6
gHXq9yY/bEATKv+o51I+zOT/dq0UKgLFfGm5gAV8vjSkykfIkEkD32Wl8p00
oFU+qfn9Fn2VRHjrPz3I1MejTC/OVuyiYBKChVi5sWjnBynhor1rFG+oTKeL
VMG7JILzIeSL/bKAl0eIpSW891EUoaZfAfV9jLZStVVQ4WpViPLq8lpktbW8
yhzjWmlej/c2cIuHzDayDjfxy+YE7SlPW5LkkaqtLMatKXxWyDakv21If9ug
x+0oWrdDj9uhxx3coMmd0OQO5MBtuVqB/gKty7XQmpwpWnVjgj7OHqMVWSP0
IfS4DHqkNtIeq0K1RM4qIns5kaWUyPyQaOoe0fgdolHUvUOQ90Cuk3qzkTYz
nNSZ6qC2JKTN63ZqVGmzNtyGtCmvOhJp85KWNifoXgDXuqN0B2nzNqfNI0OG
tNlPOZBo9u5epE31GE3UX6msz01Sn4nQZ8K6NkPKbKFY6DPGw4RVTlYlaaGa
PhcBQojT9GmVMauVND1lTGPW1Fd65bqRj2uuKpu3KnaN1wqphV+hTHHVEB8O
VvKcY7gMm1eU/LSmZqylvsbHhvxZu7Ggqnf5oeW+QpK+RkmSn2hcqvu9yWn0
9JtyIcyP5Tm30ovVCYD83qpiiZI/F7zzqoVI/bm9zQ1JdX6tqHgD5nNyZZXK
jkKpSqeNQqeiT3/0oDRvj5q8NKsmvfVS9p0Q1tM7oZx+34X+FoYZWjj/7b0I
3v79CDKEhkWRnOIWIwsuiZJtKXS3DG05N+jtQ86EH8WyIFbE6R+llSy7Vay4
1QlcByfiZW0S59pk/pb1UNp6KG19mnZO02doPdS2PlM1SGB9hoPWpdtpbbqN
1qRbaXW6hValm2ll+jR9nD5FK9In6aP0CWS9cVqePkbL0tW9PLngh/ioD60b
rROtHa2FtEKRaogcFUS2pyST5X2VLG9rydJpSJYOmSwT7dSMIrYhxi6SJc88
K4Pls9NkspzSZ54lfmNUfGqUik5wAQslaslSqfHGnj6TdmwlY3s3F7FiP6mb
OykZinQVsVKRmhpd2bJpRhHLM0/OlkKRM7OlF+vR9JKoYWfWr8a7tsjTRMXk
Tb8iZuY56WflyRjyjIwZNaw8OV2K0UfcCkGcnCHXc//8RN0YwXvGHfReUrd8
99Nkp001tYUd8XjGMm7ebnL0M8jRR8jxeSFD8bG5LMcqoUN/0fjoi/+8al58
NeoQLWA+N2hxAbd6aFCp8Y3/a91dnk13XmpF5z2I6z1Umu+JBPdeJE+T3oeY
PoiS7X2I6H2I6ANu2rMUvGhxLGZoi+NYektQTS5FW3ZdNZSRy1BGLkP2Wp4k
v8iXPkpm/X2U7KQP0T5KEc2LVqQ6WZao9lZATysA80fZ+gLv8kwrLcu0oJlp
aca07PJc6MGB7IQ27YQm0CbQxtBG0YYxtiFyqasHrUupq1WKnxrk/yLZlRFZ
nzyb7IbznSLZ9Ylk51DJzj4z2UXYqCrUijmilNjMZDfuSnbHhqnwiJTYTVWP
5uyTJzZk7eqlzJ09lA6JpSmJpWgSUwXpdUgsfk2rIeE1U/QzBelMiUl51cpi
VBWk1wwFqTHjGe6KpB8u4X24X/+h3RlJac1HXCI7M+0ptUml8ROxSp8X93nz
VslO3HsXzIj8pj+sWT0pS1Sgc1hQPiwfH5XIVAJT6qnyYtmwVjmJzRNNCKiG
j6RCPAEzhSPV+rYHGXh5FMwVtzmevCpkEVIOEg0tgiIWQRGLoIZFKOEgAy8h
A19aDAksvq5agraEuSQBNC9J5O9eAj0sRluSLEpJoYelSDJLkWSWopxbmq5E
6cM/IlegpYn/vfgN7n26U098srj7CfVNTdHQ9BSNTU/SlHmKrBYLOayyAiOL
3SAWtEmHm1jQhpxSLP1ovSoddRAXhnIfjfi5Dq1a/i7y0SNDPuLJW6GTBm8i
H+WgOsxyUFe6gzpS7IZ8JCdv1ZyPUB2WX7OIfMT7e3huEpO3CTF5k/lohG4p
weQfgmAODJi044bZu/uEYDJ2QDDbIJitUjDJmzkfdcgKcb1WIbZSLAQTI/JR
syEfNVKEmsFxhcjVoSaYYE0w7/OkBXIxvaLEUvUX79+qCUa/OY+8D7+3615i
2i0RvcVNenyNetEz1PMsmTlukuHf5rBk+IWfnfm6doMKlX+45hNTNL83yrTk
w+9pGvLVNaTpyH8uXyLPQvIxCokC5iEbB7xdI+haqJZCDKIR//C7dq3itdnS
y9dUxRTbYqXkditld1upaMBOD4Zt9HRU4tk4Yab2KQt1T5mpf3qahoHxBBA2
W6bJxhhbrEpFANn0ezeM0cYcMzEedEqM3eK+wLgJk5t6lFRcVlUqlA1xf6IY
u0JpNVyAuJ/noL4bDurORNxPs1NbMuJ+gp2a4mxUH81x36rH/bKrZsR9ifKD
s1rcH0PcH8UkZ4QKjw4j7kuUeRtRWqmJTuZOiXIaUE4Fyhz3eRsdZY77XFox
yqta9LgfBZQjNZT1uO9COfjZuA8bAmSU/xz3L3tEucINZSaIYfaR90XQ2twy
eVdib+NdiU0zb/Op3UIBVD+vqi3DPYpNxlt/avctRvNhxMWTYZ/3jPgbMi8w
52+WM9gCbmD8ZgV2ObdSu4ePq7JSTFeL71r8CTir4B806yxFrhysRlmzGhPy
NQjbaxC21yA+r0GcXs0Nc4M1mBeswQx8LWbg63LQcjFPyHPNxDegcN9YSLQZ
FcaWIidtveOkgw8ddLzUQf7ldv0k5lYHJXc4KLvHSQX9TioB3I9HHFQ5Jo8o
tU5aqRPC6UUbnDbTqHmaJiEcixCOmewWi4r/fNsQMttN/wzh2N2EgzZiEI57
DuhUwmkhkQOcyAEO5AAb5iTWp/JvYgGvRBZNI4W8QmDMAXbqSEUOQNHUfN1G
DbHIAVFWqg435gAzPb4oxSNzwDgVQzxFEM8tKR7tWYm5BwZEzZS9BykA2smA
dtK391AqtJOypQspQGoncUMHUkD7jJopBtqJRgqIEilAaodTQDi0E2bQDqcA
3ofUTY1cIVCrBFfkKoEXC4fX7hZUatLhkmk+r4Vp0jmvpFMuLtifIR3x2AKh
H1/t2VNSLNotvZ9XJdPrevyXujF56eJ4QYmDhaEEIsXhK8QhIj5LQms+Qhre
ujRk2Y+X5X9ZD8Gz6kGWRZvB/WZwvyWLaCuY3wrmt+Wh3UTNsi1frD0D+e3A
fTuC6w7UCjvByk4E212oHXaXkDhZy/RT5AE7dU/bkAesNGy20LjZTNNAmZG2
KqSdFlXWmG0MtUIabQJtXEPaYcgH9Ew+EJ/HPICaScwDnLXAGvMAW7mcB/Df
tXzApc0wuj+AEfVhqi3zAU+1OR/YZD6IsVJtJPIBSpuKYM4HFnpyyUyPzk8h
H4hb5NNdv3G6c2qMbp8Y1XC+eWiI8g4OUu7+AaQDiXWmqmzSGOut3ZQMrJM2
SawTkA6uA+v4tW0yHYjKxoV1JLCOQDoIF+mgwYB0nUgHGtbXNKwXCqy9mGvB
tBcjzY/rXaA9eqMCQFeoUhMwe+uPTZuj6hcXttqj00rFQ3C5fnldj+/q6UL+
rz99icEV3GozaFGtiIoFQVwGdhQv/m9yU4Gdk8XcCkZYYCw+uFIQ6DMDXK2K
N5lC9AJeHip9TXzXbpC5G9F4Dx+jyCfai3C1D1jug4/3A8n9wPEAQtlBlLVH
UROcAAunEeYCwMVZ1AsXUTdcQQgMalBF+ssUj9IiDZEyF4gVALUiTDtLRoge
jxJVjBPVT0qc2jFN7ZpWd1DyBc2uIO10VThmG1c4TPSUgehnAjU9E6gF0XLt
SBbrqHKc1a7FI+tj7PyB3E4Eal7KhQX6YQ1eyu3CvLsDs1sZqHl2KwN1jQjU
FipHlVN6RQbqh+em6P4ZSXWxopp/Ljw2QvlHhgXWuQcGKUdhnbVbYp0uqpwe
SmGsNxuwFpHagDVHalQ5UcA6ElhHiEjdqCJ1A4UC6xB3rN8XWHOFgzrHl64A
bY7Wl7m9U0WXxCEXptsbdFdqdPMhl7crFMbi2YCqnXuLw7cGO9c0b5bpdY63
ejWwz8dExaNSRVQO0HlXVY941Z8JLX/zkUrg3znWl2lFjmxvyLju/wZ/ub/Q
xpuQnwjl+MM6t5hsCNdhHsL1t6UcmLJX6fAtPnUFDRwcA/EnEOlOgQ0/MBJQ
SnSmDLSDmwuIiJdr+OE8RCFgKrxZWwP9a0oFc9mIqHlgsBA83hkmugfkH40B
+wngN4XgOi156zQ7qQdV+wAmoiNoExYbTWNyagH70IDa55+0Sl9FdjRkAqED
Ed0dhuiuVfv0THQXn+eJqyG6Gw9p2EpdE1feVkR3RIFBRIQ+RIdu5LBOTLDb
UxzUgolrEyau9Zi4zozuZhndL0zTA2jhXqDSwmn5cJNbx0ep4OgI3Tw8jPA+
RDnQwo19AwjvUguiatmhVS3dlAQtJG7sRHiXZ3pJHbQhvLfKqoW1sKLZEN4b
dR2ELqlXOqijIKkFLyGElyGEGlG4CCmguaQg5CCqFymFSrowv0IqwWeGEs7N
K/cSUvAVtcvZt1wPkzsjahiowpMY5uhi8FW8K/LFby/wKz+RiVdL/VX491dN
FiYa8DwxVUcwVNs0O/jhs9YpL8vegfOziOoXwPklcHAFPFxDVA8B46FgPBys
RGKGGN2iPw07A0jdAFo3EW5vAbdiYP4AmD8Zn4l5m1ni1IP/+y0OGkYbt9qB
uY3MaBbgroV7hwz5CvvveUDdGPadLty1sN/nFvbbZoZ9PmbgrJy5qDkpH4Ak
JrdDqpjpRanWhalKR5qTWpMd1JzgoMY4O9VhclsTYaNKTG5l2LfQY+D+8Pw0
3T8rcDdpRwtvnxyjQuCer3DPZdz3D1L23gHKAu6ZuyTuaapIl9VMFyUA9+vr
Je5xwD0WuMcA92hUMzLsNyPsN1E4cA8z4B4C3IMNuAd9IMO/FvprvBh1L2bd
i0H3YsL5gg3BuOCczsuCBoBjwqgT7uNON9/1TzwNWz0JW/H9gngatrf+NGw9
nLtBPkeHfI4K4jKclyus8ds2vUZRAEfMCrC8Ffs1QBsMr4bCu+FI7lGANgbQ
xgHahFYtOH+R0kFGFsjNBSn5IOa2qkkeIjiXMrmoSepAbRNobUXrsEg6+vD/
oMVJo1YHTQp67YJeq6DXYqSXtHpFfuc8Ra/DEKidngN1ryFQq+V4XpbRAjWv
MDqNR7yQmCZQko3dkZ8ZVEVLDybYnZh0tKc6qSXJSU3XHVQfa6faKDtVhduo
ArPLsmtWegJ6H1000wNFryxa5PPwbp0Yo4JjoPfICOUdGkagHkKgHqQs0Ju5
u58yQG/6jl5K3S6LFhGomd4NBnr1QG2gVwTqJkOgNtJbr+ito2suekW0vsKN
I7WI1tV06V0ZrS9yW8BrdZJmDyQDZERwnWZULW+Vg+RyLU7PFXG6zAsolxmC
NbMsiJ7jAWEfHW49PMuALejdzWA+Z6A30q3klkVVNPwZB79eh38Tm7TbSn+Z
sjENywUHBWD0Nhi9C0buc90MRp8islZOSUYbwWeLYrRbcTpoBVpWJ03YHDSF
ZganFsGpDZxaBaNcTDCnHF0lq9M2voZ4Cm9NyTOIdFS1hfARdeTIGGiNNUWb
qim0xXAEWoIUHTxr5FMlUFdMoa4YR001qp5RPYC6olfVFR2YJ7emYBeJTmqM
d1BdjINqIu1UGWaj8mAbPWVcL1vo4UWzVNX36W7AJN1RtBYqWm+C1lzQegO0
ZjOtewYoA7Sm7+yjNKYVJXayolXEWdAav07SqsdZ0Br1cYshzjapONsoaA3h
pmgNWjyT1qvv1xporTHQWv0srV4MqxeTqng4J1llVF2k8jq4ZNXVBKcGWlF/
c2nxItPqqarw8kCrt06r6/F+itbo2apkVBi829Qm1zkCN+D8PPBaCBiKAEUJ
4HgAXh8Dlqdqnlc9OZPXdrDaBdb6rHI/w0jwYzYn2HOCRI1Zu2DWrph1CmZt
GrOyKpi26tBydSDe9wStdrhTxVixneuEAo8xlisECyqEaVQIE6gQxoqxO1QI
gwWqmlEVQnsadpGMXSQ4qT7OSbXRDqqKsFNFqJ3KAG7pVSs9vixXG++dm6aS
wCkq9p+kotOK3ONjqBBGKe/wCOUcBLn7hxBjBykT5Kbv6qc0kJu6vZdSmFwU
xImK3HjE2DiQG7tWXqgiqF3ZSpEgNwLkhhvIDTWQG7ykQZFbT9cEuXUyBgBd
vhuwDm6NAdxqBldAyw9PubBAKxgqAW+lFmq5YKjgUqGcY6p4KfMRlPoYKC0D
o2UvKFDf0EFFvNVDqLcOpVjBUA+hjJkVyi+JXdwEiIVwahES/F04+R6c/RBO
fwLnlyF4ViJ41gDGOsDYOG0InArEQZua9TBLXHHqMDoAop1sAkZeLuYC1ZuX
jjUYRQS18onnDOOkVe5AlaoCNgEk+op+uEdR8XfDIUUdyHrD7EwtKZuR9KeQ
9MeR9EeR9IcxWx3Il/voRtLvQNJvS0UUTcIYrzupLtZJNVEOqgx3UDmAfBpk
18vTBxcsVHJ2mu4CyDsA8jaAvHVSztJuAshcBWQ2gMwEkBm7JZCpO/ooBUAm
b+2hJACZgKR/XQEZu7aDYtZIIKMEkC0GIJspTADZJIAM4SaBRJ+AI5KtAUgR
Sq9we6+WLr8niPRiHHmRQgKpIumFBVUikvLJoYpI6ROR9s9yJavC6FvlKpTK
cBoonpA7M4wCTvH07zK5aKHAFM1LEOqjLT1oTbyxV6dVXoZrip2NVu3JvveB
6CMgWgoUyoBEJdCoAaL1yO9NyO+tQLTDLPO6wlO57kUxEZoSEyMnCHSCRA1R
OzmAqZxB8bENX0O8tKp4yU8xBaS8mDaBnYzb5WxqTB451xE11KXife1woXuy
58U0JHt7pVwi5vMip5HsJ5Dsx5DsR5Dshwqxm5tyP11I9u0q2Tcl4uNxoDzG
SdWRToFpWYiUzOMrNnp4yUr3zzOmZioOmKIiv0m6dWoC2V5imncEmB4aQbYf
pqx9Q5SxZ5DSgWnazn4g2kfJ23qBaA9iJjDd2EXxyPZazNQx5ZiJFiEwbVGY
NlPoDEwbRdwMWtyg4iafmXv1gzp1UbMbpnSJ27t8SBGkejOgojCtkny6GGVC
vZlQMcOqkHUpQ6qH0MC5/AzBQIb1TVfTYQW6nPPB4LMgyrt4m+JmnTd9Xuyn
HD6ugr9rEZ4awF8z+GsFf53gT87Y4T9gM6rCo4s9Uuw5wZ4D7DnIrvNnU/zN
x0ZWd/5An0WGSZ0/u2FGr3gzMCh+V3Mj46lK+iEKFJx2PvIGBi3I29PI21PI
2+PI26PI28NgcAAM9oHBbvUMtTbk7Wbk7cYEpAQYqQZFTxUYrAiTOnhyzU6P
wOCDi1a6BwbvnjFTUcA03QaDhWCwQDGYCwZzwGA2GMxUDKbtGkCYlAwmbe2l
RDCYsKkbYRIMru+k2HUyTEav1hhsUwy2UjgYDDMwGLKsSTAYrDGIdk0yCALr
6YoKl2CQz5t/j+9z5mKwRsTKC9wWVKtQeX4+n9PAGJ7TMawUGHoxhTytB4uG
YOktMPQFcuXuCPIJsG+WiYDppaduF4OvSgbj3WY/8oBDA4hrRkJuQ0LuBHE9
IK4fxA0BjhG0MVUdumgjRZtT0eYAbXbQZpewzcGrVQDngs7CwHG8s/Ct1Cbw
p3GbgTcXc8yb+IjGm9uRXuN83Anm7EjNNqRmC1KzGal5Cql5AsyNgbkRMDeI
WrEftWJvHpBVzLUiNTchNTdch96QIaqjtZj+z/Q02EGPwdzDyza6D+ZKzlmo
mJnzn6Zbp6eo4OQE5R+XzOUcHqUbB0coaz+Y2zuEmDdIqTsHKAXMJW/ro0Qw
l7C5h66DufgNXRQnmOsEcx2CuSjFXcQM5looFMyFLG8WzAVzA3NBSxoVcw10
1Y25y+/XSeR8gFutQO7iu6J5MXN8xHdBNZ1fUMXNJMjzYuhUvj07r1IEP5Wk
QR0fPVDcMXICPJ6Wa+fbBaig582v3jLy4f09OnB/LYFLmLVWlJcFdgG5XiDX
D+QGgdww2phF8sF/13HD7xI3p8LNwbjx2TYSuRfVgvwzyIE4s4xzEyIXj9v4
Bh3GOGfgDnFOcfAL16FYjTtVEjrBnQO51oZca0GcMyPXTiHXTiDXjqMkHEVJ
OIyScAAlYR9Kwu5cfBwlYVu6HFIj51pwV6OucKoIR90R6qRS5u6qnR6Au3sX
rHQX3N0JNNNtcFd4aoryT0zSzWPjiHPyQFb2gRHKBHcZ4C4N3KWAu+Tt/ZTE
3G3ppevgLn5jN8WBu9j1XRQD7qLBXdTqDgN3bRQuuGs1cgcbgDrURs9y16C4
q9e4A3Z1dOm9Wg08zrUKO3C2oBrBQHA3X7Zz3GS0Y9qYQDBHZ7gp7MSrBM8F
n5hmlyv2eGlScKfFOAHY5yVyibMiJ2uEQeA2DNxGgcW4SoGyTOUFQ19gRgoz
J+a7jJlDTDLszA0fytc4mzZyZha1HD8bkCbw+7iIb/zeGD+LwhXf+P7vIM30
xZnxzXgamKrrnMipDtR1NuRUC3KqGaxNIadOIqeOI76Noq4bQV03iJzaj5za
i5zalYPwiLquVbHWkKjK3B9RZSQwA2qlIU56EuSgR0Dt/iUblQC14rMWKgJq
t/ymqQCo3QRquccmKEehlgXUMvYNU/qeIUrdBdR2DFASUEvc2kcJjNomRq0H
qHUbUOsUqEXOQK2NwoBaqECtRYS44GXNIsQFLW0SqF3jplC7skiidvl9idsl
A2oXF9ZK1Di4vVND59+pFrhJ6HxdsAngtHNJJHGKNsGalyIuEL97Ii5AUmdy
i29flLAlffLs4gWaMEtAuPuSLGQsNAfoclqcDJaDweJYZra7AFOLKmpOKzOn
2Yvh4gsuxmdLn65lFoHWgKFk63bh5UT6dCCM2ZA+rUifZqTPKaTPSaTPcaTP
UeA1gvQ5hPQ5gPTZh/TZjfTZifTZlokoqF9n8lWqQU1RFUNUDr6ehmGWH4Lp
1DUnPbgi+bp73kp3wNftADMVgq/8k1OUd3ySco5O0I3Dkq/M/SOUvneY0sBX
CvhKBl+J2/opAXxdB1/xm3spDnzFgq8Y8BW9roui1vDdXSJXd6hMEj6Dr1YK
AV/By1sEX0HcwNe1JU2Cr6uLGxVfDXTZxZcXA+YlyPIBWbV0ATlUslXjrbA6
N7/6GaxEIANH8yrF3LZSY0u0QMFY4NwKAZX3TIr+TlKUPLMs006tdrFCzAon
OvHi4GMa4sUuV4xlTpYLcBYViL5Bgr0JlUyfIcZw4GPYRYsWjPS1EFVwOZD4
bCDGisRnRuKbQjCaROIbR+IbQ+IbQeIbQuIbROLrBzG9IKYLia8Dia8VxDSn
qVF9h6pR41eixi+LQDACMI+DiR4CmPuXHVRy0UbFAKbojIVuAZiC09N0E8Dk
HpukG0cmKPvQOGUeGBXdSwMwqbuHKHnnICXpwPQDmD4DMD0AplsCs7YTuHRS
xKoOBUw7hQGY0BVtRmC8mBZ+NvOsvDTMiEcXuS3kVquYqdWYATLcAAyX/CCH
L0wAN2clN/i/0seNmkCtzVVHuXfrrPyDZCV11vQmKXBYGBZxjY2gxcwxRtAy
beeLUMUxXLUSMSnDCscfnRWLgRXBC/M06jD9D4/RRT/Mqx2BAC9OjRckLwt4
mVa8TCB5jSF5jYCXYSSvQSSvfiSvPhRK3SiUOsFLO3hpyZD7qk+S/1cBmAoA
8xTAPAlFdAkienDVSfcAzN0Ldrpzzkq3AUyhv5nyAUzeiSnKATDZACYLwGQc
kFEmdc8wpeweBjBDlLhjkBK2DdB1ABMPYOIATOzGXooBMNEAJmpdN0Wu7aII
BUy4gibs43YBTIgAplVEmKBlLXQNEebaUi6cri5pQthnYq4satSJuaSIufhe
PRPDQQYvYMWLQeEFM6ByTjROYZKVs4oVxYtkxVuwEviWtrY2g5FvSUbS/gIj
BCejiUUpZmRapCDthC6dDqtaHxC1zYSZ6dHxEIjI8uZLrvNdRpwzpm96aeOB
ELsbIZNuhAwZCOlFedOF8qYj1zVNa4QQ6hQhlSily6MQTlDfPAYhD0DIvStO
KrnkoGIQUnTWRrcCrVTgZ6abp6YpF4TcODpJWYcnKPPgOKXv1wgZoWQQkqQI
uQ5C4gUh/SCkz0BIzwxCwld1UpgiJFQnpI2CQUjQ8lZJyNJmurq0WQLyEl1Z
3CQAucxNANJgBESElAuKES6h36kVEeWcCxOGBJlHvLxdpTx7Zl6VoMQVO7xd
1weZ0v8SFwgCaOKYueDCyRdW8GUMUw7Fht2dDXht2hU+xp8JHzNPDBxWa5vu
J0UZ1pT47842CYiVAalzATLuBsgAAOkDID0ApFOta7ag/m3CSBtSMLcHINXq
GVJlAOQJAHmIAuX+NaISAFJ80UFF5+10C4AUBFgp389CeQAk5/gUZQOQTACS
oQBJ3SfzTvLuEUrcOUwJO4YAyCAAGaA4ABILQGI29lH0hl6KAiCRACRibTeF
r+4CHABkZacOSMiK9hmAXAMgV5dyAyRLmukKEg8I4XWkRY2Q6SVFyEVXGOH1
9oV8ydiFd+voPJKOaO/UejMf3swFl7tvV9MZvUqZESq+J5HI0EsP4yXOBJei
cRKZZhCmHLym49n5emwYN8SGMRUb/nNGteG+nOh+opBTud/RJjMIu9/s5v5R
N/f3wv3d6gnnrZj+NMP9DXB/Hdxfg7lgZbz8Wynq08coNx7A/ffg/ruXie7A
/bfP2anwjI3y4f680xbKOWmmG8emKevIFGUcnqT0gxOUtn8c7pcxIkm5/zrc
Hw/3x8H9sVvQNvW7ub/H4P4uClXuD/m4Q7g/GO4P+rBNub+VrkoEvOD7ZsSH
y4gPlxc1ifhw6YNG5X0ZIy4gRlxYWC/jw/l36zg+wPnn3lEN8eEst/ny2qhd
us9/IH2e5SEMfMtVeL4o3T/lVM0hT/ia1IsGPSVMi5Sg5tHS/ex2G89ux1xH
M9j9Jk9HNAxHgp3sfqQGh7oIyuj+KTf3D2N6Mgj3999VPf45tWF20oLZSSNq
zXqkv1qU1FUJqBuU95/A+4/g/fsoNkuuwvOXiIouOOkWvF8QaKOb/lbKhfdv
nDBTNryfCe+nH5qkNHg/Fd5PUd5P3D1KCTtH4P1heH+IYrcOUszmAYqB96Ph
/agNfRS5vpci4P1weD9sTTeFKu+HKAKChffbhfevLecmvX8FAQDOp8vclPsv
Kfdf5Obm/vML66X7IXmX+6WCXT7/kfR59qyh/wU1eZjF1RNm6Wlf5WmzS+hj
YkEN7v7jDHeLjxqPsbqp3anc7VDudqhrnY3unnBz94A6E7Ybc4sOzC1a4e8m
+LsB/q6Fv6vh70r4uwy1Yqm6l8lDVAL34O+78HcR/H3rvJMKzjooP9BOeX42
yjllpewTFso6ZqaMI9Pw9xSlHpyEvycoed/4DH/Hw99xBn9HbxqgqI39bv7u
0f0dshLtY+nvoBUdFGTw91X4+woUz/6+vKRF+PvSYq4dLy1q8mJX85KG7mw+
KAtXc42ISH/u3TpXNN+pe1nextR0Y1Yvz1EencW73kbv8m9CyeM8tTS4VUwF
yPQbj651smt7ZBDXXGtXrrW5uXYMrh2BawfV09x7ipG/4do2uLYFrm0ErnVI
TTUo8iqRw8uRw5+iyHuibip1H64tQZF35wrR7YtEhXBtPlx7M8BOuXDtjdPS
tZlwbTpcmwbXpsC1ycq1iXuke6/vHIVrRyh22zDFbB2i6M2DFAXXRsK1kXBt
xHq0db3CtaFwbciqbgqGa4MNrr0G1177sJ1L/+VtfNkiXHtZufaSdC0c20wX
IeeLHzTRBUj5wvuNwrPibKMduhf/XXoxZ2ZO1m5/IA/UCaeZdK/pehTzfs1r
PvJo3rhT85xwnBf7je8hpk58cPa7vOZgr3XAY6rysjVLSwuvVUuvjcJrw+rC
o757SLvwWgcmb635ECMmb/XwWi28VgWvVcBrT+G1J/DaI3jtgbqfXzFSbxFS
7y14rQBeu3nWSXmBDsrxs1P2aRtlnbBSxjELpR0xU+qhaUo+MEVJ+ycpad+E
7rV4eC1OeS0aXouC1yI3oW0coIgN/RQOr4XDa2Fre+G1Ht1rQR/La7CvCa91
0NUP2+GzdroCUUqvtbIIl7RwxbWYPSa9doG99n6jjKw79aL6l9JbebNlU3Uu
mXKZrJPHp4WbWHXjFuEwLqzG1dFXPmNqXAXQMTL47NPCZ07NZwigjm7pM7vm
s1aXz6bhs0kobaxSsfMz6ofQekogsjsQGVzWApc1wmV1qAWqUS1VoFoqQ7VU
inz5OAbuQr68p+4nVQSX3YLLCuCy/HMkXJYLl91QLss8aaV05bIUuCwJLkvc
P0UJ+yYpYc+EctkYxe4YpZhtI3DZMEVuHhIui4DLwoXL+ilsXR+FznBZt3DZ
tRVSbFeFyzrgLrhsWRtd5ra0FQ5DW9xCF7ktapZuconq19JNN2d1k49yk3AP
N3cP+Rg8pKlphnt+53KPCoQOJSk7AqG93eUec6O06USN/H8IkhqApHofQE7w
Twf80wr/NKG79YgDtfBPFfxTDv88hX8ewz8P4Z/78M9d5Z/b8E8h/JMP/+TB
P7lnnJQT6KRsfwdlnbZTxkkbpR23UuoRCyUfMlPigWlKgH+u752k68o/cco/
0fBPlPJPBPwTvnGQwjYMUBj8Ewr/hMA/IWt6KXh1DwXBP9eEf7qUfzrpivLP
5WXtwj+XIClh3+26P/679Ef+JxehvoZ5pT63NLn8YTila5yEP7zdcpNzyOAO
pRjhDijGBsVY4I5puGOyTp37iAg38BQVymO4Au7ohDva4I5mTC4a4Y46uKMa
7qhAuVGGcuMJyo1HKDfuo9woiSAqhjuK5P2AqQDuuAl35MIdOWeIsgOclOXn
oEy4I125IwXuSDpkgTvMdH3/NMXvnaK4PZMUt0u6JGbHGNwxCneMUMTmYQrf
NERhyh2h6wcoZF0/XNEHV/RS0Cp2Rw/c0U1XlTuuKHdcXt4hJeFygbw/nalg
1mpBzQKl9U3ysMMcuZAszhQxxKlx7BLWN72i13xOzfgqXAnjQw92Fa6sML4Z
KWayUVvN+SENVcDwMH4PjN8J47fD+C2Y2TXC+PUwfg0qm0rUeuUwfimM/wip
5QGMfw/Gvwvj34Hxbyvj58P4eTB+DoyfDeNnwfiZMH7GKQelnbRT6nEbJR+1
UiKMnwDjx++bpjgYPxbGj1XGj4bxo2D8SGX8MGH8IRh+EIaH8df2UzCMH7Qa
bVUvXYPxrwrjdxsumxDG/oM0duHMpK6V3cZ1V2FeeRWZVADS3S/ZuMK0TnfT
gm2HCjV2sG2DaS0w7VSLNMMouB5Wd0LphWm7YNp2mLYFk+YmmLYePapF8qqC
acth2qcw7WNk7Ycw7X2YtgSmLYZpi2DaW8q0N2HaXJj2BkybBdNmwLTpfk5K
g2lTT9gp5bidko7aKPGwla4fsFDcPjPF7p2mmD1TFL1LXoAWtX2cIreNUcTW
UQrfPALTDlPohiEKgWmDYdrgtQMUtKZfmPYaTHt1pbrH3lbdpK9Lk96eNaTP
MWRexaw0Ks9XOVzAsv/+yZZV4NpgWQuixrS6x8wYIsYwLDuoLNsNy3Y8QtDG
BKUZlm2AZWshrGpYtgKWfQrLPkE99BCWvQ/LlqAeKoZl7yCA34ZlC2HZ/Gty
XzmwbBYsmwHLpvsTpcGyqbBsygkHJR+zUyIsmwDLxh+0UCwsGwPLRu+eoihY
NnKnBDcClg3fMkphsGwoLBsCywavR1s3SEFrByScW/Ua5i1pyaK/VMNMGs7r
nhTHsCc54OI7f8bGFKZ0ejClQ5nSDlNaYUqzulXDOILvCEw5BFP2w5Q9Fepk
MJiyGaZshCnr4N9qmLISpiyDKUtRWj6CKR/AlCUwZTFMWQRT3gakhTBlPkyZ
p0yZDVNmwpTpMGUqTJly2knJMGUSTJkIUyYcsdH1wzaKO2il2P0Wit5jpqjd
0xS5a4oidkhQw7eNU9iWMQrdPEohm0YoeMOwO4jzpfnufGIuY2M5fdhi4kAL
CYM5nzUYNnQM8mOO2Gg2dRBOFAtgbxQGG25AhqpFsVAFNSuDtcJgjTBYHWrx
GhisEgYrh8FKYbDHMNgDGOweDFYMgxXBYLdQixfCYPkw2E0YLFcZLAsGy4DB
0mCwFBgsGQZLOumkRBgsAQaLP2KnuEM2ij1gpRgYLGqvmSJ3mykCBgtXBgvb
Ok6hW8aEjbboNloobVTsFv+0Y5a87CBWnPH6YzaSMJHTg4kc3MCVHc2qjmxP
IfhNgKlRmGgIJhqAiXphom6YqKMcCbxUnQgBE9WgC1UwUTlM9BQmegITPYSJ
7sNEd2GiOzDRLZioACa6ielKHiaZuTDRDZgoWz3qJh0mSoWJkmGixNNECTDR
9eMOij/moDiYKBYmijlgo+h9Vorca6EImCh85zSF7ZiSI96s22WRtEvJrNJ7
3rUUO6UarOOU1uGz37kGdaDm+R45YCI7zGNVh+amQM84TDMK0wzBNAMwTS9M
0wXTdMA0rTBNkzJNLWZyVTBNBUxTBtM8gWkeYSZ3H6YpgWnuwDS3YZoCmOYm
TJML0+TANNlBiFZXITNlmjSYJgWmSYJpEmCa6zBNPEwTd9RBMTBNNEwTBdNE
wjQReyzSHJt0cyyT5rg3qzlcK9NOAYwT0H1fmMPBDcA4AIwdzQZorOrs1UmA
Mg5rjCD4DMEa/bBGL6zRBWu0wxqtsEYTrFEPa9Q+kp8phzVKUYQ/yYclMEl6
AGvcgzWKYY0iWKMQ1siHNXJhjRuwRnYIrABrZMAa6bBG6gW5nyRYIxHWiIc1
4mCN2ONOioE1og/bKeqg3WABMd4V0gL3Z7WAnKg4YQEHtyl2/yTfZt8OA9hh
ABuaZUwNHCiMIfKOIPIOYvD9GHwPBt+Fwbdj8C0YfBMGX4/B12LwVWop5imC
2WMM/gEGfx+DL8HgizH4Igz+Fgafj8HnYfA5GHwWgkgGBp+OwaddgfsvQRlq
8AmBQACDj8PgY0+ozm/U3b1KDvaBHhVmHMM2iyHCyfYpHrwd3NsmDAERqI8h
uwxjfIMYXz/G14Pypwvja8f4WjC+JoyvHuOrwfiqMMMqx/ieqguMH2B8Jagq
i1HS30FJfxszrEKMrwDju4nx5WB82RhfBsaXhvGlIgKkYHxJGF/iebmP+EB5
/bVrSPJuB6ZHHvz3TT0Z4Ec7RmeDA61TaroOr00A2TGMahijGsSo+jCqHtTL
nRhVO0bVgqKuCaOqx6hqMKoqzBvLMapSjOpxidxPCUZ1B6O6jVEVYlQFGNVN
zBtzMW/MwbwxG/PGTJQd6RhVCuJaMkaViFElXFR236APRV6/bno8K4r/IL7R
qi4on4J/JjCKUYxiCKMYwCh6MYouhKAOjKIVo2jCKBrgmzqMogajqMR0qxyj
KMUoHgODBxhFibp89jZGUYDofBPFUy7K0hxU/NkYRSZGkYFRpGEUKRhFUrD0
wXq949tkx5/M2vG/kwDx+X/o9DA6PYBO96LT3eh0ByJFKzrdjE43oNO1mLZX
NyE2okwpQ5lSiqz7BBXfI1jmATpdgk7fUZ0uQKfz0OkciCUbnc5EpzMwR0xD
LZ0SLTu6Tu/oLtnRUjf+5W36B9C1PnStG13rQNfa0LVmdK0BXauDjqvb0SUQ
UYYK6gls+QhEPADn97C7u+CvGDGkCBXULdR1BerY2A10LRNdywDnaUmG7ggr
7ZPdKZuNXZN4YhV18lnifLY4OtWITtWhU9UQXwU6VQYHP4GDH8HB92tgGzi4
GDssgjNuAdMCiO8mImse8kwO8ky2drOxtbpRDspelM/aC3mqVyN6UIfwVo3Y
XgmhlKEHT+CtR/DWfXirpB5egbduw1sF8NZNeCsP3sqBt7LhrcxCOfw1+hcf
lV9c8cnSfZlKMd7HcMIDjPcexlsMJxTBCbfARwGccBNdz4ETsjHezHvyW1br
33JSfkulm8/lZfPFQO42/FqIXeZjl3nYZQ4GkY1OZT5VCl2l70s+LtRUPaup
ZOGeg71lYW8Z2Ft6jXEv4jPyWUumGg97+YbhPRV35Wx9pd6HC/LTtR4+/XUP
763QP3hFfrDOw0b/4OG9ZfoH5U2+TPW6BT1tvkjfXN5rw9ToYaOvenhvof5B
ed2tqcnDRn/n4b0FukHj5QebPWz0ZQ/vzdO/UZ61bGrRR+Zp8zf0zeVZYKY2
Dxv9rYf3/qh/MFN+sN3DRl/w8N7/0j+YIz/Y4WGjz3t473/qJsmXH+zUR+Zp
89/q33NLbt7tYaPXPLz3K/2DxfKDPR42+msP7/1c/6AsuEy9Hjb6rIf3fqp/
UKZHU58+Mk+b/zd9cxlcTQMeNnrVw3s/1C1YJT846GGjT3t47/v6N0plmoY8
bPSKh/e+q39QKsY0rI/M0+bf1jdvlZuPetjoJQ/vfV3/YKf84JiHjV708N7X
dJNIZ5nGPWzk6XHrX9a/UVrfNOFhI0/Pbf2C/sER+cFJ3SSeNn9N31x+gWna
w0Y+Ht77K/2DZvlBs4eNvD2897L+Qbv8oMXDRl6z2df1lrrhgFUfnqfP+Opf
RvIn8Rm725b4X3bVtaX0icnB/7nu4viyfJf0f69+0hv/VX1NQ0MDOZ1O8Vut
4e9aYOa/xcbGUmlpqekz6r2UlBRavXo1jY+P6+9NTU3R3r17aWRkRC3gyP18
RfzsI278tWrVKtq3bx85HA5N248ePaI//vGPND09re+qoqKCfvKTn1BdXZ1a
SpO7+rLald1uF4P+t3/7N96tFo747X/913+lmJgYPdLEx8fTV77yFWptbVXr
myaDrV6gyclJ0evvfve7NGfOHPrUpz5F//Iv/0KBgYG8aw3+a9eu0fPPP0+3
b99Wz1p8kTIyMujVV1+ln/70p9TTI+IknT9/Xrz3+9//ngYHBxWbvjxg2rhx
I/n4yEnnn//8ZyUs+bcVK1aIr//Vr35F7e3t6jt8hFG/+c1v0o9+9CO20C3D
CORlsC+JTX7xi1+I3X7pS1+i1NRU6urqEoZdtGgRvfHGG2Q2m+eoPQ4PD9OX
v/xl+sIXvsCu8lV7CQgIoOeee44+97nP0W9+8xvq7e0Vm/B76CzNmzePJiYm
vFWf2Wxf+9rX9Bnkxx9/rMYzh/tJ3/rWt8T7v/vd72ju3Lmub/KmlStXkre3
8Izp2fH40L1794SZ+JvhSU2kbCV8C125csWkjSUzM5O8vLzohz/8IdlsNm0s
zEF5ebm4g9GJEydo3bp1wrif/vSnhWU6OjoYLW0sDPjmzZvFl/7jP/4jtbW1
6WPhv/32t7/VfIZ5YwuFhob6GjrA/fzxj3/MHSj0MJzc3FyxCTdsrgUrBoZZ
hfdmPLyTv+jXv/61Cte+wpg8PH7/29/+tpCJFin5b5pyX1RfFxQUJL7q61//
OjtJs9TDhw/F+F577TUmwFNHWXSMOH/T8uXLtY7yF8yfP5+ePHmid/Q//uM/
xGZ/+MMf9C82Wgrvv6be5ujy0ksviYaftf48ffpUuOTll19m3p/tj68A9W/+
5m/EDr/zne+IkWudysvLo02bNqmdyfd+/vOfu3XKV2jjG9/4hnh/yZIl3ElV
vLikxdaCvLWelZWV6T0DCZ56xnxx6OG9crxobm7We9HX10c/+9nPWHH6ewsX
LhTbQtyqZy8IDl955RXxVdzz7Oxs/gzV1tZyLz+jesMC5o/+8pe/ZAVo3D3A
ZJnd+dnPfpaGhoaMnXxZbXL27FnxSR5eRESE1hfuOweZpqYm1T8fSkhIEDLi
uAeKX1BdDAkJEW9zGGDuv//979NnPvMZ8cWIg1oXCwoKhJ7ZV/CZ1sWsrCzx
3T/4wQ9YiM920ZdqamrohRfkgTuOOewdrZ8cj4KDg9Vvcpf9/f30+c9/nr74
xS/S2NjYHCV3lvn+/fvFLr761a/Su+++K2hkmbObOCgCPVESQDvsIQ6nPDRu
LHkOURi5XhEwW/w3cDEjRmk9RyTUw58KpHrPq6qqhBDgLv09f39/oS3ENr7c
TIyGPc3bsZF27dqlOYMh4C790z/9E3+N8dtfUZtwROdv9vX1ZWFrX4JkLD6F
0KK7lm3z+uuvC9tggH9v+JK33npL87g2bA5nbODq6uoZyVL74rCwMD3iI2Np
X8yZ/Xvf+x4nvxmJ65133qFz586xM/5ebQpDibA3MDCgV1HQv3AIhjIj239K
/Z0jP+MA/tTx7ZeEMd977z3hY/7HfLJZmE2W5JEjR/hrjdRzan78+LGazst6
ZcOGDcJcxnpF/PvEyun/8w3Tc/8HHl+c/A==\
\>"]]
}, Open  ]],

Cell["\<\
Therefore, we exploit some of the Options available for  NDSolve.\
\>", "Text",
 CellChangeTimes->{{3.4495644573028126`*^9, 3.4495644649037423`*^9}, {
  3.449564509838355*^9, 3.4495645266124754`*^9}, {3.49216623725*^9, 
  3.492166252921875*^9}, {3.492252610125*^9, 3.492252687359375*^9}},
 FontSize->14,
 Background->GrayLevel[0.85]],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"kmet", "=", "1"}], ";"}], "      ", 
  RowBox[{"(*", " ", 
   RowBox[{
    RowBox[{
     RowBox[{"if", 
      StyleBox[" ",
       FontColor->GrayLevel[0]], 
      StyleBox["kmet",
       FontColor->GrayLevel[0]]}], 
     StyleBox["=",
      FontColor->GrayLevel[0]], 
     StyleBox[
      RowBox[{"1", "  ", "\"\<StiffnessSwitching\>\""}],
      FontColor->GrayLevel[0]]}], 
    StyleBox[",",
     FontColor->GrayLevel[0]], 
    StyleBox[" ",
     FontColor->GrayLevel[0]], 
    StyleBox["\[IndentingNewLine]",
     FontColor->GrayLevel[0]], 
    StyleBox["               ",
     FontColor->GrayLevel[0]], 
    StyleBox[
     RowBox[{"otherwise", " ", "\"\<SpatialDiscretization\>\""}],
     FontColor->GrayLevel[0]]}], " ", "*)"}]}]], "Input",
 CellChangeTimes->{{3.451043483765625*^9, 3.451043484625*^9}, {
  3.454675073453125*^9, 3.454675074546875*^9}, {3.45467528146875*^9, 
  3.454675282578125*^9}, {3.492251873859375*^9, 3.492251907609375*^9}},
 FontSize->14],

Cell[BoxData[
 RowBox[{
  RowBox[{"Dord", "=", "4"}], ";"}]], "Input",
 CellChangeTimes->{{3.451043130125*^9, 3.451043130703125*^9}, {
  3.4510432583125*^9, 3.451043258984375*^9}, {3.4510435393125*^9, 
  3.451043540328125*^9}, {3.45109636984375*^9, 3.451096370359375*^9}, {
  3.45109646459375*^9, 3.451096465125*^9}, {3.451097622375*^9, 
  3.4510976235*^9}, {3.45109849078125*^9, 3.451098491921875*^9}, {
  3.454675986890625*^9, 3.45467598790625*^9}, {3.492165985890625*^9, 
  3.492165987328125*^9}, {3.492166042640625*^9, 3.49216604353125*^9}},
 FontSize->14],

Cell[BoxData[
 RowBox[{
  RowBox[{"MinP", "=", 
   RowBox[{"{", 
    RowBox[{"4", "*", "512", "*", "1"}], "}"}]}], ";", 
  RowBox[{"MaxP", "=", 
   RowBox[{"{", 
    RowBox[{"8", "*", "512", "*", "32"}], "}"}]}], ";"}]], "Input",
 CellChangeTimes->{{3.4332130346875*^9, 3.433213042921875*^9}, {
  3.451043031984375*^9, 3.451043070015625*^9}, {3.45104330221875*^9, 
  3.45104331246875*^9}, {3.451043546234375*^9, 3.451043559953125*^9}, {
  3.45109622240625*^9, 3.4510962229375*^9}, {3.4510969145625*^9, 
  3.451096915140625*^9}, {3.45109766346875*^9, 3.45109766459375*^9}, {
  3.451097729046875*^9, 3.451097730015625*^9}, {3.451097778*^9, 
  3.451097778578125*^9}, {3.451098610421875*^9, 3.451098612203125*^9}, {
  3.451099083734375*^9, 3.451099084328125*^9}, {3.45439134721875*^9, 
  3.454391362546875*^9}, {3.454675247265625*^9, 3.454675248234375*^9}, {
  3.454676034984375*^9, 3.454676046890625*^9}, {3.454932542234375*^9, 
  3.454932542640625*^9}, {3.492165940359375*^9, 3.492165944859375*^9}, {
  3.4921660309375*^9, 3.49216603696875*^9}},
 FontSize->14],

Cell[BoxData[
 RowBox[{
  RowBox[{"AG1", "=", "6"}], ";", 
  RowBox[{"PG1", "=", " ", "6"}], ";"}]], "Input",
 CellChangeTimes->{{3.433211943296875*^9, 3.433211943890625*^9}, {
   3.45104325296875*^9, 3.451043253796875*^9}, {3.451043718171875*^9, 
   3.45104371878125*^9}, {3.451043791859375*^9, 3.45104379534375*^9}, {
   3.451095764203125*^9, 3.45109576740625*^9}, 3.451095898140625*^9, {
   3.45109625296875*^9, 3.451096253828125*^9}, {3.451096305734375*^9, 
   3.451096331765625*^9}, {3.451096895*^9, 3.4510968954375*^9}, {
   3.4510973661875*^9, 3.451097367171875*^9}, {3.451097438609375*^9, 
   3.451097442359375*^9}, {3.451097531765625*^9, 3.4510975359375*^9}, {
   3.45109855765625*^9, 3.451098561453125*^9}, {3.451098736046875*^9, 
   3.45109874146875*^9}, {3.451098877421875*^9, 3.451098887859375*^9}, {
   3.45109900221875*^9, 3.451099005015625*^9}, {3.45109912959375*^9, 
   3.451099134*^9}, {3.4510992395*^9, 3.451099244390625*^9}, {
   3.451099344046875*^9, 3.45109934840625*^9}, {3.451099397078125*^9, 
   3.451099401328125*^9}, {3.451099787390625*^9, 3.451099790703125*^9}, {
   3.454675458640625*^9, 3.454675464375*^9}, {3.454675965453125*^9, 
   3.454675969625*^9}, {3.4549325531875*^9, 3.454932556484375*^9}, 
   3.45493384471875*^9},
 FontSize->14],

Cell[BoxData[
 RowBox[{" ", 
  RowBox[{
   RowBox[{"AG2", "=", "0"}], ";", 
   RowBox[{"PG2", "=", "AG2"}], ";"}]}]], "Input",
 CellChangeTimes->{{3.433211943296875*^9, 3.433211943890625*^9}, {
   3.45104325296875*^9, 3.451043253796875*^9}, {3.451043718171875*^9, 
   3.45104371878125*^9}, {3.451043791859375*^9, 3.45104379534375*^9}, {
   3.451095764203125*^9, 3.45109576740625*^9}, 3.451095898140625*^9, {
   3.451096428890625*^9, 3.451096429625*^9}, {3.451096889859375*^9, 
   3.451096890359375*^9}, {3.451098677453125*^9, 3.451098680125*^9}, {
   3.451098891296875*^9, 3.451098891875*^9}, {3.454675130015625*^9, 
   3.454675130609375*^9}, {3.45467597446875*^9, 3.4546759755*^9}},
 FontSize->14],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"Unum", "[", 
    RowBox[{"x_", ",", "t_"}], "]"}], "=", 
   RowBox[{
    RowBox[{"u", "[", 
     RowBox[{"x", ",", "t"}], "]"}], "/.", 
    RowBox[{"First", "[", 
     RowBox[{"NDSolve", "[", 
      RowBox[{"FS", ",", "u", ",", 
       RowBox[{"{", 
        RowBox[{"x", ",", "0", ",", "pvalue"}], "}"}], ",", 
       "\[IndentingNewLine]", 
       RowBox[{"{", 
        RowBox[{"t", ",", "0", ",", 
         RowBox[{"5", 
          RowBox[{"T", "[", "fvalue", "]"}]}]}], "}"}], ",", 
       "\[IndentingNewLine]", " ", 
       RowBox[{"AccuracyGoal", "\[Rule]", "AG1"}], ",", " ", 
       RowBox[{"PrecisionGoal", "\[Rule]", "PG1"}], ",", 
       RowBox[{"MaxSteps", "\[Rule]", "Infinity"}], ",", "   ", 
       RowBox[{"Method", "\[Rule]", 
        RowBox[{"{", 
         RowBox[{"\"\<MethodOfLines\>\"", ",", 
          RowBox[{"If", "[", 
           RowBox[{
            RowBox[{"kmet", "\[Equal]", "1"}], ",", " ", 
            RowBox[{"Method", "\[Rule]", "StiffnessSwitching"}], ",", 
            RowBox[{"{", "}"}]}], "]"}], ",", 
          RowBox[{"\"\<SpatialDiscretization\>\"", "\[Rule]", 
           RowBox[{"{", 
            RowBox[{"\"\<TensorProductGrid\>\"", ",", " ", 
             RowBox[{"DifferenceOrder", "\[Rule]", "Dord"}], ",", " ", 
             RowBox[{"AccuracyGoal", "\[Rule]", "AG2"}], ",", " ", 
             RowBox[{"PrecisionGoal", "\[Rule]", "PG2"}], ",", " ", 
             RowBox[{"\"\<MaxPoints\>\"", "\[Rule]", 
              RowBox[{"MaxP", "[", 
               RowBox[{"[", "1", "]"}], "]"}]}], ",", " ", 
             RowBox[{"\"\<MinPoints\>\"", "\[Rule]", 
              RowBox[{"MinP", "[", 
               RowBox[{"[", "1", "]"}], "]"}]}]}], "\[IndentingNewLine]", 
            "}"}]}]}], "\[IndentingNewLine]", "                ", "}"}]}]}], 
      "                                               ", "]"}], 
     "\[IndentingNewLine]", 
     "                                                        ", "]"}]}]}], 
  ";"}]], "Input",
 CellChangeTimes->{
  3.4493312556044445`*^9, {3.449331382466864*^9, 3.4493313825569935`*^9}, 
   3.449331508668333*^9, {3.449464532328125*^9, 3.4494645799375*^9}, {
   3.449564121529995*^9, 3.4495641484787455`*^9}, {3.449564402003296*^9, 
   3.44956440626943*^9}, 3.449564530387904*^9, {3.4495747333390274`*^9, 
   3.449574745696797*^9}, {3.4495755028054657`*^9, 3.449575532027485*^9}, 
   3.449595281921875*^9, {3.44963477540625*^9, 3.44963477646875*^9}, {
   3.450543214671875*^9, 3.4505432194375*^9}, 3.4921653463125*^9, {
   3.492165620703125*^9, 3.492165733671875*^9}, 3.49223766559375*^9, 
   3.492251856328125*^9, 3.492252028234375*^9, {3.49225208428125*^9, 
   3.492252126515625*^9}},
 FontSize->14],

Cell[BoxData[
 RowBox[{"Plot3D", "[", 
  RowBox[{
   RowBox[{"Unum", "[", 
    RowBox[{"x", ",", "t"}], "]"}], ",", 
   RowBox[{"{", 
    RowBox[{"x", ",", "0", ",", "pvalue"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"t", ",", "0", ",", 
     RowBox[{"2", 
      RowBox[{"T", "[", "fvalue", "]"}]}]}], "}"}]}], "]"}]], "Input",
 CellChangeTimes->{
  3.4493312556044445`*^9, {3.449331382466864*^9, 3.4493313825569935`*^9}, 
   3.449331508668333*^9, {3.449464532328125*^9, 3.4494645799375*^9}, {
   3.449564121529995*^9, 3.4495641484787455`*^9}, {3.449564402003296*^9, 
   3.44956440626943*^9}, 3.449564530387904*^9, {3.4495747333390274`*^9, 
   3.449574745696797*^9}, {3.4495755028054657`*^9, 3.449575532027485*^9}, 
   3.449595281921875*^9, {3.44963477540625*^9, 3.44963477646875*^9}, {
   3.450543214671875*^9, 3.4505432194375*^9}, 3.4921653463125*^9, 
   3.492237666671875*^9},
 FontSize->14]
}, Open  ]],

Cell[CellGroupData[{

Cell["Part  III.3  Comparison Symbolic-Numerical ", "Text",
 CellChangeTimes->{{3.449411809610634*^9, 3.4494118132658896`*^9}, {
   3.4495478930846367`*^9, 3.4495478951275744`*^9}, 3.4495798226571074`*^9, {
   3.4496405459375*^9, 3.449640559890625*^9}, {3.4922359399375*^9, 
   3.492235965828125*^9}, 3.4922360090625*^9, {3.49225592715625*^9, 
   3.492255936390625*^9}, {3.4922562916875*^9, 3.49225631484375*^9}, {
   3.492256350875*^9, 3.492256359140625*^9}, {3.492256676375*^9, 
   3.492256693859375*^9}},
 FontSize->14,
 Background->GrayLevel[0.85]],

Cell[BoxData[
 RowBox[{
  RowBox[{"{", 
   RowBox[{
    RowBox[{"Plot3D", "[", 
     RowBox[{
      RowBox[{"Unum", "[", 
       RowBox[{"x", ",", "t"}], "]"}], ",", 
      RowBox[{"{", 
       RowBox[{"x", ",", "0", ",", "pvalue"}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{"t", ",", "0", ",", 
        RowBox[{"2", 
         RowBox[{"T", "[", "fvalue", "]"}]}]}], "}"}], ",", 
      RowBox[{"PlotLabel", "\[Rule]", 
       RowBox[{"Style", "[", 
        RowBox[{"\"\<NDSolve\>\"", ",", "Italic", ",", "Bold"}], "]"}]}], ",", 
      RowBox[{"ImageSize", "\[Rule]", "300"}]}], "]"}], ",", 
    "\[IndentingNewLine]", 
    RowBox[{"Plot3D", "[", 
     RowBox[{
      RowBox[{"Utenterms", "[", 
       RowBox[{"x", ",", "t"}], "]"}], ",", 
      RowBox[{"{", 
       RowBox[{"x", ",", "0", ",", "pvalue"}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{"t", ",", "0", ",", 
        RowBox[{"2", 
         RowBox[{"T", "[", "fvalue", "]"}]}]}], "}"}], ",", 
      RowBox[{"PlotLabel", "\[Rule]", 
       RowBox[{"Style", "[", 
        RowBox[{"\"\<SepVar\>\"", ",", "Italic", ",", "Bold"}], "]"}]}], ",", 
      RowBox[{"ImageSize", "\[Rule]", "300"}]}], "]"}]}], 
   "\[IndentingNewLine]", "}"}], "//", 
  RowBox[{
   RowBox[{"TableForm", "[", 
    RowBox[{"#", ",", 
     RowBox[{"TableDirections", "\[Rule]", "Row"}], ",", 
     RowBox[{"TableSpacing", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{"1", ",", "1"}], "}"}]}]}], "]"}], "&"}]}]], "Input",
 CellChangeTimes->{{3.449565905665456*^9, 3.4495659133264723`*^9}, 
   3.4495660250671473`*^9, {3.4495661422456417`*^9, 3.4495661599711294`*^9}, {
   3.449566250210888*^9, 3.4495664839169407`*^9}, {3.4495665346599054`*^9, 
   3.449566549641448*^9}, {3.449566712275304*^9, 3.449566798849792*^9}, {
   3.4495757996523104`*^9, 3.4495758001029587`*^9}, 3.4495759270154495`*^9, {
   3.449595296015625*^9, 3.44959531628125*^9}, {3.44964302003125*^9, 
   3.449643024265625*^9}, {3.449643325671875*^9, 3.449643329546875*^9}, 
   3.450543459421875*^9, 3.45054688721875*^9, {3.49223767140625*^9, 
   3.492237671984375*^9}, 3.492249095703125*^9, {3.492252943359375*^9, 
   3.492252946515625*^9}, {3.492253079953125*^9, 3.49225312546875*^9}},
 FontSize->14],

Cell["\<\
When we examine the difference between the Symbolic and the numerical \
solution, we observe 
that the difference is getting worse when time increases. \
\>", "Text",
 CellChangeTimes->{{3.45054327203125*^9, 3.4505432835625*^9}, {
  3.45054344403125*^9, 3.45054344584375*^9}, {3.49216627228125*^9, 
  3.49216627584375*^9}, {3.492253289625*^9, 3.49225337009375*^9}, {
  3.492253494984375*^9, 3.492253512546875*^9}, {3.492253584109375*^9, 
  3.4922536243125*^9}},
 FontSize->14,
 Background->GrayLevel[0.85]],

Cell[BoxData[
 RowBox[{"Plot3D", "[", 
  RowBox[{
   RowBox[{
    RowBox[{"(", 
     RowBox[{
      RowBox[{"Uoneterm", "[", 
       RowBox[{"x", ",", "t"}], "]"}], "-", 
      RowBox[{"Unum", "[", 
       RowBox[{"x", ",", "t"}], "]"}]}], ")"}], "/", "AmpU"}], ",", 
   RowBox[{"{", 
    RowBox[{"x", ",", "0", ",", "pvalue"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"t", ",", "0", ",", 
     RowBox[{"2", 
      RowBox[{"T", "[", "fvalue", "]"}]}]}], "}"}], ",", 
   RowBox[{"PlotLabel", "\[Rule]", 
    RowBox[{"Style", "[", 
     RowBox[{
     "\"\<Relative difference Usymb-\!\(\*SubscriptBox[\(U\), \(1\)]\)\>\"", 
      ",", "Italic", ",", "Bold"}], "]"}]}]}], "]"}]], "Input",
 CellChangeTimes->{{3.450543298*^9, 3.4505433661875*^9}, {3.45054341503125*^9,
    3.4505434303125*^9}, {3.450543545609375*^9, 3.450543549453125*^9}, {
   3.450543581015625*^9, 3.450543636703125*^9}, {3.450543945484375*^9, 
   3.450543952*^9}, {3.450546831640625*^9, 3.45054687146875*^9}, {
   3.450583999796875*^9, 3.450584142609375*^9}, {3.49223767396875*^9, 
   3.49223767446875*^9}, 3.492249097140625*^9, 3.49225093334375*^9, {
   3.492253677828125*^9, 3.492253714671875*^9}},
 FontSize->14],

Cell[BoxData[
 RowBox[{"Plot3D", "[", 
  RowBox[{
   RowBox[{
    RowBox[{"(", 
     RowBox[{
      RowBox[{"Utenterms", "[", 
       RowBox[{"x", ",", "t"}], "]"}], "-", 
      RowBox[{"Unum", "[", 
       RowBox[{"x", ",", "t"}], "]"}]}], ")"}], "/", "AmpU"}], ",", 
   RowBox[{"{", 
    RowBox[{"x", ",", "0", ",", "pvalue"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"t", ",", "0", ",", 
     RowBox[{"2", 
      RowBox[{"T", "[", "fvalue", "]"}]}]}], "}"}], ",", 
   RowBox[{"PlotLabel", "\[Rule]", 
    RowBox[{"Style", "[", 
     RowBox[{
     "\"\<Relative difference Usymb-\!\(\*SubscriptBox[\(U\), \(10\)]\)\>\"", 
      ",", "Italic", ",", "Bold"}], "]"}]}]}], "]"}]], "Input",
 CellChangeTimes->{{3.450543298*^9, 3.4505433661875*^9}, {3.45054341503125*^9,
    3.4505434303125*^9}, {3.450543545609375*^9, 3.450543549453125*^9}, {
   3.450543581015625*^9, 3.450543636703125*^9}, {3.450543945484375*^9, 
   3.450543952*^9}, {3.450546831640625*^9, 3.45054687146875*^9}, {
   3.450583999796875*^9, 3.450584142609375*^9}, {3.49223767396875*^9, 
   3.49223767446875*^9}, 3.492249097140625*^9, 3.49225093334375*^9, {
   3.49225343853125*^9, 3.492253443484375*^9}, {3.492253726828125*^9, 
   3.492253730125*^9}},
 FontSize->14]
}, Open  ]]
}, Open  ]],

Cell[BoxData[
 RowBox[{"Date", "[", "]"}]], "Input",
 CellChangeTimes->{{3.5516943875801687`*^9, 3.55169438958517*^9}}]
},
AutoGeneratedPackage->None,
CellGrouping->Manual,
WindowSize->{1904, 946},
WindowMargins->{{0, Automatic}, {Automatic, 0}},
ShowSelection->True,
Magnification->1.5,
FrontEndVersion->"8.0 for Microsoft Windows (64-bit) (February 23, 2011)",
StyleDefinitions->"Zosi-direi-buono.nb"
]
(* End of Notebook Content *)

(* Internal cache information *)
(*CellTagsOutline
CellTagsIndex->{}
*)
(*CellTagsIndex
CellTagsIndex->{}
*)
(*NotebookFileOutline
Notebook[{
Cell[545, 20, 315, 9, 112, "Text"],
Cell[863, 31, 3770, 96, 769, "Text"],
Cell[4636, 129, 144, 4, 49, "Input"],
Cell[4783, 135, 120, 2, 43, "Input"],
Cell[4906, 139, 211, 3, 43, "Input"],
Cell[5120, 144, 115, 2, 45, "Input"],
Cell[5238, 148, 1252, 26, 69, "Input"],
Cell[CellGroupData[{
Cell[6515, 178, 632, 11, 86, "Text"],
Cell[7150, 191, 619, 10, 145, "Text"],
Cell[7772, 203, 494, 10, 202, "Text"],
Cell[8269, 215, 585, 15, 72, "EquationNumbered"],
Cell[8857, 232, 215, 5, 145, "Text"],
Cell[9075, 239, 414, 11, 72, "Equation"],
Cell[9492, 252, 266, 6, 145, "Text"],
Cell[9761, 260, 951, 23, 126, "Equation"],
Cell[10715, 285, 471, 8, 145, "Text"],
Cell[11189, 295, 1015, 23, 136, "Equation"],
Cell[12207, 320, 255, 6, 145, "Text"],
Cell[12465, 328, 486, 11, 123, "EquationNumbered"],
Cell[12954, 341, 313, 6, 145, "Text"],
Cell[13270, 349, 1055, 28, 130, "Equation"],
Cell[14328, 379, 788, 20, 207, "Text"],
Cell[15119, 401, 663, 15, 72, "EquationNumbered"],
Cell[15785, 418, 536, 15, 90, "Equation"],
Cell[16324, 435, 262, 7, 117, "Equation"],
Cell[16589, 444, 205, 5, 145, "Text"],
Cell[16797, 451, 851, 26, 90, "Equation"],
Cell[17651, 479, 1758, 54, 411, "Text"],
Cell[19412, 535, 281, 6, 145, "Text"],
Cell[19696, 543, 557, 16, 123, "Equation"],
Cell[20256, 561, 406, 7, 145, "Text"],
Cell[20665, 570, 613, 18, 148, "EquationNumbered"],
Cell[21281, 590, 598, 10, 145, "Text"],
Cell[21882, 602, 1707, 47, 294, "Equation"],
Cell[23592, 651, 498, 13, 145, "Text"],
Cell[24093, 666, 927, 26, 148, "Equation"],
Cell[25023, 694, 465, 12, 145, "Text"],
Cell[25491, 708, 853, 21, 78, "EquationNumbered"],
Cell[26347, 731, 454, 13, 150, "Text"],
Cell[26804, 746, 756, 21, 135, "EquationNumbered"],
Cell[27563, 769, 305, 6, 145, "Text"],
Cell[27871, 777, 1001, 29, 121, "Equation"],
Cell[28875, 808, 454, 11, 145, "Text"],
Cell[29332, 821, 899, 27, 148, "Equation"],
Cell[30234, 850, 265, 6, 145, "Text"],
Cell[30502, 858, 658, 18, 117, "Equation"],
Cell[31163, 878, 703, 20, 135, "Equation"],
Cell[31869, 900, 1192, 30, 121, "EquationNumbered"],
Cell[33064, 932, 453, 14, 148, "Equation"]
}, Closed]],
Cell[CellGroupData[{
Cell[33554, 951, 654, 11, 79, "Text"],
Cell[34211, 964, 318, 6, 145, "Text"],
Cell[CellGroupData[{
Cell[34554, 974, 1095, 31, 342, "Input",
 InitializationCell->True],
Cell[35652, 1007, 268, 5, 96, "Input",
 InitializationCell->True],
Cell[35923, 1014, 395, 10, 216, "Input",
 InitializationCell->True]
}, Open  ]],
Cell[36333, 1027, 261, 6, 145, "Text"],
Cell[36597, 1035, 418, 10, 154, "Input",
 InitializationCell->True],
Cell[37018, 1047, 453, 11, 96, "Input",
 InitializationCell->True],
Cell[37474, 1060, 279, 6, 145, "Text"],
Cell[37756, 1068, 677, 21, 159, "Input",
 InitializationCell->True],
Cell[38436, 1091, 640, 14, 256, "Text"],
Cell[39079, 1107, 1927, 54, 189, "Input",
 InitializationCell->True],
Cell[41009, 1163, 224, 5, 145, "Text"],
Cell[41236, 1170, 540, 12, 96, "Input"],
Cell[41779, 1184, 322, 6, 145, "Text"],
Cell[42104, 1192, 566, 15, 96, "Input"]
}, Closed]],
Cell[CellGroupData[{
Cell[42707, 1212, 841, 14, 79, "Text"],
Cell[CellGroupData[{
Cell[43573, 1230, 448, 7, 68, "Text"],
Cell[44024, 1239, 292, 5, 97, "Text"],
Cell[44319, 1246, 974, 20, 64, "Input"],
Cell[45296, 1268, 254, 5, 97, "Text"],
Cell[45553, 1275, 412, 9, 64, "Input"],
Cell[45968, 1286, 304, 5, 97, "Text"],
Cell[46275, 1293, 1902, 34, 106, "Input"],
Cell[48180, 1329, 343, 8, 135, "Text"],
Cell[48526, 1339, 638, 12, 64, "Input"],
Cell[49167, 1353, 603, 12, 64, "Input"],
Cell[49773, 1367, 725, 21, 97, "Text"],
Cell[50501, 1390, 1772, 35, 115, "Input"],
Cell[52276, 1427, 464, 8, 97, "Text"],
Cell[52743, 1437, 957, 26, 85, "Input"],
Cell[53703, 1465, 233, 5, 97, "Text"],
Cell[53939, 1472, 1007, 19, 64, "Input"],
Cell[54949, 1493, 779, 13, 64, "Input"],
Cell[55731, 1508, 740, 24, 97, "Text"],
Cell[56474, 1534, 454, 15, 67, "Input"],
Cell[56931, 1551, 580, 14, 64, "Input"],
Cell[57514, 1567, 609, 17, 97, "Text"],
Cell[58126, 1586, 1081, 21, 64, "Input"],
Cell[59210, 1609, 401, 14, 97, "Text"],
Cell[59614, 1625, 916, 22, 64, "Input"],
Cell[60533, 1649, 313, 10, 97, "Text"],
Cell[60849, 1661, 238, 5, 97, "Text"],
Cell[61090, 1668, 655, 20, 90, "EquationNumbered"],
Cell[61748, 1690, 2036, 60, 201, "EquationNumbered"],
Cell[63787, 1752, 2311, 69, 201, "EquationNumbered"],
Cell[66101, 1823, 466, 10, 97, "Text"],
Cell[66570, 1835, 813, 21, 67, "Input"],
Cell[67386, 1858, 1657, 37, 112, "Input"],
Cell[69046, 1897, 822, 23, 127, "Text"],
Cell[69871, 1922, 610, 10, 67, "Input"],
Cell[70484, 1934, 211, 4, 102, "Text"],
Cell[70698, 1940, 2129, 44, 112, "Input"],
Cell[72830, 1986, 308, 10, 102, "Text"],
Cell[73141, 1998, 1200, 27, 112, "Input"],
Cell[74344, 2027, 349, 11, 102, "Text"],
Cell[74696, 2040, 1297, 28, 112, "Input"],
Cell[75996, 2070, 365, 6, 102, "Text"],
Cell[76364, 2078, 695, 18, 73, "Input"],
Cell[77062, 2098, 653, 19, 102, "Text"],
Cell[77718, 2119, 800, 20, 67, "Input"],
Cell[78521, 2141, 640, 15, 102, "Text"],
Cell[79164, 2158, 833, 18, 67, "Input"],
Cell[80000, 2178, 368, 11, 102, "Text"],
Cell[80371, 2191, 2311, 42, 112, "Input"]
}, Closed]],
Cell[CellGroupData[{
Cell[82719, 2238, 494, 8, 61, "Text"],
Cell[83216, 2248, 275, 5, 68, "Text"],
Cell[83494, 2255, 1955, 35, 45, "Input"],
Cell[85452, 2292, 585, 13, 123, "Text"],
Cell[86040, 2307, 891, 16, 96, "Text"],
Cell[CellGroupData[{
Cell[86956, 2327, 1026, 19, 68, "Text"],
Cell[87985, 2348, 315686, 5154, 433, 162355, 2639, "CachedBoxData", \
"BoxData", "Text"]
}, Open  ]],
Cell[403686, 7505, 343, 7, 102, "Text"],
Cell[404032, 7514, 1013, 31, 112, "Input"],
Cell[405048, 7547, 560, 10, 67, "Input"],
Cell[405611, 7559, 1058, 20, 67, "Input"],
Cell[406672, 7581, 1268, 21, 67, "Input"],
Cell[407943, 7604, 698, 13, 67, "Input"],
Cell[408644, 7619, 2734, 58, 417, "Input"],
Cell[411381, 7679, 897, 20, 67, "Input"]
}, Open  ]],
Cell[CellGroupData[{
Cell[412315, 7704, 552, 9, 102, "Text"],
Cell[412870, 7715, 2208, 51, 156, "Input"],
Cell[415081, 7768, 516, 11, 144, "Text"],
Cell[415600, 7781, 1183, 28, 112, "Input"],
Cell[416786, 7811, 1231, 29, 112, "Input"]
}, Open  ]]
}, Open  ]],
Cell[418044, 7844, 119, 2, 64, "Input"]
}
]
*)

(* End of internal cache information *)
