(* Content-type: application/vnd.wolfram.mathematica *)

(*** Wolfram Notebook File ***)
(* http://www.wolfram.com/nb *)

(* CreatedBy='Mathematica 8.0' *)

(*CacheID: 234*)
(* Internal cache information:
NotebookFileLineBreakTest
NotebookFileLineBreakTest
NotebookDataPosition[       157,          7]
NotebookDataLength[    100490,       2627]
NotebookOptionsPosition[     96491,       2490]
NotebookOutlinePosition[     97432,       2528]
CellTagsIndexPosition[     97310,       2521]
WindowFrame->Normal*)

(* Beginning of Notebook Content *)
Notebook[{
Cell["\<\
Evaluation time:
\[CapitalDelta]t < 5 s\
\>", "Text",
 CellChangeTimes->{{3.5726815466762786`*^9, 3.572681568044501*^9}},
 FontSize->24,
 FontColor->RGBColor[0, 0, 1],
 Background->RGBColor[1, 0.9, 0.8]],

Cell[TextData[{
 StyleBox["NATURAL CUBIC SPLINES (DIRECT METHOD) - ", "Title",
  FontFamily->"Times New Roman",
  FontSize->16,
  FontWeight->"Plain"],
 StyleBox["INTRODUCTION", "Section",
  FontFamily->"Times New Roman",
  FontSize->16,
  FontWeight->"Plain"],
 StyleBox["\n", "Title"],
 "\nIn this .nb  we describe how to calculate, step  by step, the (twenty) \
coefficients  of the five \nthird-degree  polynomials constituing the cubic \
spline interpolating  the  simple  set of points \n\n",
 Cell[BoxData[
  FormBox[
   RowBox[{
    RowBox[{"{", 
     RowBox[{"(", 
      RowBox[{
       SubscriptBox["x", "i"], ",", 
       SubscriptBox["f", "i"]}], ")"}], "}"}], "=", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{"0", ",", "0"}], "}"}], ",", "  ", 
      RowBox[{"{", 
       RowBox[{"2", ",", "2"}], "}"}], ",", "  ", 
      RowBox[{"{", 
       RowBox[{"5", ",", "3"}], "}"}], ",", "  ", 
      RowBox[{"{", 
       RowBox[{"9", ",", "5"}], "}"}], ",", "  ", 
      RowBox[{"{", 
       RowBox[{"11", ",", "2"}], "}"}], ",", " ", 
      RowBox[{"{", 
       RowBox[{"14", ",", "1"}], "}"}]}], "}"}]}], TraditionalForm]]],
 "\n\nIn part  ",
 ButtonBox["I",
  BaseStyle->"Hyperlink",
  ButtonData->"Part A"],
 ", instead of using the method described in Section \\ref{211}, which \
requires some manipulations to obtain the coefficients\n\n",
 Cell[BoxData[
  FormBox[
   RowBox[{
    SubscriptBox["s", 
     RowBox[{"k", ",", "0"}]], " ", ",", "  ", 
    SubscriptBox["s", 
     RowBox[{"k", ",", "1"}]], " ", ",", " ", 
    SubscriptBox["s", 
     RowBox[{"k", ",", "2"}]], ",", " ", 
    SubscriptBox["s", 
     RowBox[{"k", ",", "3"}]]}], TraditionalForm]]],
 "\n\nin terms of\n\n",
 Cell[BoxData[
  FormBox[
   RowBox[{
    RowBox[{
     SubscriptBox["S", "k"], "(", 
     SubscriptBox["x", "k"], ")"}], ",", 
    RowBox[{
     SubscriptBox["S", "k"], "(", 
     SubscriptBox["x", 
      RowBox[{"k", "+", "1"}]], ")"}], ",", " ", 
    RowBox[{
     SubsuperscriptBox["S", "k", "''"], "(", 
     SubscriptBox["x", "k"], ")"}], ",", " ", 
    RowBox[{
     SubsuperscriptBox["S", "k", "''"], "(", 
     SubscriptBox["x", 
      RowBox[{"k", "+", "1"}]], ")"}]}], TraditionalForm]]],
 "\n\nand ",
 Cell[BoxData[
  FormBox[
   SubscriptBox["h", "k"], TraditionalForm]]],
 ", we impose from the beginning the conditions (I) to (IV) required in \
Section \\ref{sub211}.\n\nThe second derivative at the end points is set \
equal to zero, condition (VI) of Section \\ref{sub211}, and all the \
conditions are thus assembled to form the final system.\n\nIn part ",
 ButtonBox["II",
  BaseStyle->"Hyperlink",
  ButtonData->"Part B"],
 ", the coordinates of points are introduced and the solutions \nof the \
system give the twenty coefficients of the piecewise  polynomials.\n\nIn part \
",
 ButtonBox["III",
  BaseStyle->"Hyperlink",
  ButtonData->"Part C"],
 ", the explicit  representation of the polynomial on each  subdomain\nis \
given.\n\nNote: An alternative method to obtain the coefficients can be found \
in\n\n",
 ButtonBox["http://math.fullerton.edu/mathews/n2003/CubicSplinesMod.html",
  BaseStyle->"Hyperlink",
  ButtonData->{
    URL["http://math.fullerton.edu/mathews/n2003/CubicSplinesMod.html"], None},
  ButtonNote->"http://math.fullerton.edu/mathews/n2003/CubicSplinesMod.html"],
 "\n               "
}], "Text",
 CellChangeTimes->{{3.560421038626769*^9, 3.560421039056433*^9}, {
  3.560421081586558*^9, 3.560421082082908*^9}, {3.560421207926751*^9, 
  3.560421248249384*^9}, {3.560421289124728*^9, 3.560421453919998*^9}, {
  3.560421497058775*^9, 3.560421824390606*^9}, {3.5604398390729*^9, 
  3.560439841552505*^9}, {3.56043995967916*^9, 3.560439990829438*^9}, {
  3.560453568663887*^9, 3.560453638264796*^9}, {3.560582320757521*^9, 
  3.560582324705972*^9}, {3.560584317822356*^9, 3.560584320520732*^9}, {
  3.572681465023608*^9, 3.572681524765025*^9}, {3.572681592543902*^9, 
  3.5726816102869167`*^9}, {3.5774553842444706`*^9, 3.5774553989864964`*^9}},
 FontColor->RGBColor[0, 0, 1],
 Background->RGBColor[1, 1, 0.85]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"Remove", "[", "\"\<Global`*\>\"", "]"}], ";", 
  RowBox[{"$Line", "=", "0"}], ";"}]], "Input",
 CellChangeTimes->{{3.481022187171875*^9, 3.481022222703125*^9}, 
   3.48102225303125*^9, {3.48125798384375*^9, 3.481257989375*^9}, {
   3.481258048796875*^9, 3.481258049421875*^9}, 3.481258330015625*^9, {
   3.481258527140625*^9, 3.481258577125*^9}, 3.486126360451357*^9, {
   3.507637155479566*^9, 3.507637157897114*^9}}],

Cell[BoxData[
 RowBox[{
  StyleBox[
   RowBox[{"Remove", "::", "rmnsm"}], "MessageName"], 
  RowBox[{
  ":", " "}], "\<\"There are no symbols matching \
\\\"\[NoBreak]\\!\\(\\\"Global`*\\\"\\)\[NoBreak]\\\". \
\\!\\(\\*ButtonBox[\\\"\[RightSkeleton]\\\", ButtonStyle->\\\"Link\\\", \
ButtonFrame->None, ButtonData:>\\\"paclet:ref/message/Remove/rmnsm\\\", \
ButtonNote -> \\\"Remove::rmnsm\\\"]\\)\"\>"}]], "Message", "MSG",
 CellChangeTimes->{3.5777002017377253`*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData["$Version"], "Input",
 CellChangeTimes->{{3.507637164278963*^9, 3.507637166287161*^9}}],

Cell[BoxData["\<\"9.0 for Linux x86 (64-bit) (January 24, 2013)\"\>"], \
"Output",
 CellChangeTimes->{3.577700201993484*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Date", "[", "]"}]], "Input",
 CellChangeTimes->{{3.507637351112958*^9, 3.507637352507922*^9}}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
  "2013", ",", "5", ",", "16", ",", "15", ",", "36", ",", 
   "42.041554`8.376253738370512"}], "}"}]], "Output",
 CellChangeTimes->{3.5777002020491858`*^9}]
}, Open  ]],

Cell[BoxData[
 RowBox[{
  RowBox[{"points", "=", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"0", ",", "0"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"2", ",", "2"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"5", ",", "3"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"9", ",", "5"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"11", ",", "2"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"14", ",", "1"}], "}"}]}], "}"}]}], ";"}]], "Input",
 CellChangeTimes->{{3.481022187171875*^9, 3.481022222703125*^9}, 
   3.48102225303125*^9, {3.48125798384375*^9, 3.481257989375*^9}, {
   3.481258048796875*^9, 3.481258049421875*^9}, 3.481258330015625*^9, {
   3.481258527140625*^9, 3.4812585526875*^9}, {3.481259178296875*^9, 
   3.4812591903125*^9}, 3.485579354890625*^9, {3.485599206703125*^9, 
   3.4855992109375*^9}, {3.485599283671875*^9, 3.485599286609375*^9}, 
   3.485609879578125*^9, {3.4861263948289337`*^9, 3.486126410650749*^9}, {
   3.560440083991767*^9, 3.560440087546916*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"numpoints", "=", 
  RowBox[{"Length", "[", "points", "]"}]}]], "Input",
 CellChangeTimes->{{3.481022187171875*^9, 3.481022222703125*^9}, 
   3.48102225303125*^9, {3.48125798384375*^9, 3.481257989375*^9}, {
   3.481258048796875*^9, 3.481258049421875*^9}, 3.481258330015625*^9, {
   3.481258527140625*^9, 3.481258581203125*^9}, 3.485579355390625*^9, 
   3.485583282640625*^9, 3.485599650328125*^9, 3.486126556101701*^9}],

Cell[BoxData["6"], "Output",
 CellChangeTimes->{3.577700202108042*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"grapoints", "=", 
  RowBox[{"ListPlot", "[", 
   RowBox[{"points", ",", 
    RowBox[{"PlotStyle", "\[Rule]", 
     RowBox[{"PointSize", "[", "Medium", "]"}]}]}], "]"}]}]], "Input",
 CellChangeTimes->{
  3.478176561*^9, {3.47886444053125*^9, 3.478864453640625*^9}, {
   3.481370595125*^9, 3.481370597578125*^9}, {3.4813708623125*^9, 
   3.481370865234375*^9}, {3.485579366921875*^9, 3.48557936759375*^9}, 
   3.4866469631954308`*^9, {3.560440105879177*^9, 3.560440139271071*^9}}],

Cell[BoxData[
 GraphicsBox[{{}, 
   {RGBColor[0.24720000000000014`, 0.24, 0.6], PointSize[Medium], 
    PointBox[{{0., 0.}, {2., 2.}, {5., 3.}, {9., 5.}, {11., 2.}, {14., 
     1.}}]}, {}},
  AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
  Axes->True,
  AxesLabel->{None, None},
  AxesOrigin->{0, 0},
  Method->{},
  PlotRange->{{0, 14.}, {0, 5.}},
  PlotRangeClipping->True,
  PlotRangePadding->{{0.28, 0.28}, {0.1, 0.1}}]], "Output",
 CellChangeTimes->{
  3.577700202198763*^9},ImageCache->GraphicsData["CompressedBitmap", "\<\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\
\>"]]
}, Open  ]],

Cell["We extract the coordinates from the list of points.", "Text",
 Background->GrayLevel[0.85]],

Cell[BoxData[
 RowBox[{
  RowBox[{"xpoints", "=", 
   RowBox[{"points", "[", 
    RowBox[{"[", 
     RowBox[{"All", ",", "1"}], "]"}], "]"}]}], ";", 
  RowBox[{"ypoints", "=", 
   RowBox[{"points", "[", 
    RowBox[{"[", 
     RowBox[{"All", ",", "2"}], "]"}], "]"}]}], ";"}]], "Input",
 CellChangeTimes->{{3.481168711203125*^9, 3.48116873875*^9}, {
   3.481168784109375*^9, 3.48116878440625*^9}, {3.481257990609375*^9, 
   3.481257994953125*^9}, 3.481258050171875*^9, 3.481258115453125*^9, {
   3.48125833725*^9, 3.481258343921875*^9}, {3.4855793566875*^9, 
   3.48557935909375*^9}, 3.485599654328125*^9, {3.560440272860049*^9, 
   3.560440297408477*^9}}],

Cell["\<\
We define the i-th third-degree polynomial with its first and second \
derivatives\
\>", "Text",
 CellChangeTimes->{{3.481258169046875*^9, 3.481258191015625*^9}, {
   3.4812589095625*^9, 3.48125891409375*^9}, {3.485583333921875*^9, 
   3.4855834316875*^9}, {3.48619287126575*^9, 3.486192877139627*^9}, 
   3.560440558979886*^9, 3.560442903483376*^9},
 Background->GrayLevel[0.85]],

Cell[BoxData[
 RowBox[{
  RowBox[{"Splinek", "[", 
   RowBox[{"k_Integer", ",", "x_"}], "]"}], ":=", "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{"s0", "[", "k", "]"}], " ", "+", " ", 
   RowBox[{
    RowBox[{"s1", "[", "k", "]"}], " ", 
    RowBox[{"(", 
     RowBox[{"x", "-", 
      RowBox[{"xpoints", "[", 
       RowBox[{"[", "k", "]"}], "]"}]}], ")"}]}], " ", "+", 
   RowBox[{
    RowBox[{"s2", "[", "k", "]"}], " ", 
    SuperscriptBox[
     RowBox[{"(", 
      RowBox[{"x", "-", 
       RowBox[{"xpoints", "[", 
        RowBox[{"[", "k", "]"}], "]"}]}], ")"}], "2"]}], "+", 
   RowBox[{
    RowBox[{"s3", "[", "k", "]"}], " ", 
    SuperscriptBox[
     RowBox[{"(", 
      RowBox[{"x", "-", 
       RowBox[{"xpoints", "[", 
        RowBox[{"[", "k", "]"}], "]"}]}], ")"}], "3"]}]}]}]], "Input",
 CellChangeTimes->{{3.4810257514375*^9, 3.481025780328125*^9}, 
   3.48102585075*^9, 3.481028596953125*^9, 3.481258263109375*^9, {
   3.485581277453125*^9, 3.48558130740625*^9}, {3.486192831087728*^9, 
   3.4861928332235394`*^9}, {3.4867365116133423`*^9, 
   3.4867365694025383`*^9}, {3.486736599654405*^9, 3.486736621229403*^9}, {
   3.486736860025666*^9, 3.48673693376058*^9}, {3.486736983053804*^9, 
   3.486736990316464*^9}, {3.560442913972138*^9, 3.560442916474089*^9}, {
   3.560452677998627*^9, 3.560452717502199*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"SplinekD1", "[", 
   RowBox[{"k_Integer", ",", "x_"}], "]"}], ":=", 
  RowBox[{
   RowBox[{"s1", "[", "k", "]"}], " ", "+", " ", 
   RowBox[{"2", 
    RowBox[{"s2", "[", "k", "]"}], " ", 
    RowBox[{"(", 
     RowBox[{"x", "-", 
      RowBox[{"xpoints", "[", 
       RowBox[{"[", "k", "]"}], "]"}]}], ")"}]}], "+", " ", 
   RowBox[{"3", 
    RowBox[{"s3", "[", "k", "]"}], " ", 
    SuperscriptBox[
     RowBox[{"(", 
      RowBox[{"x", "-", 
       RowBox[{"xpoints", "[", 
        RowBox[{"[", "k", "]"}], "]"}]}], ")"}], "2"]}]}]}]], "Input",
 CellChangeTimes->{
  3.4810257514375*^9, {3.481258305578125*^9, 3.481258306015625*^9}, {
   3.485581285953125*^9, 3.485581299390625*^9}, {3.486192844303831*^9, 
   3.486192845727736*^9}, {3.486736546657803*^9, 3.486736583214348*^9}, {
   3.486736626867426*^9, 3.486736681239847*^9}, {3.486736946950328*^9, 
   3.486736955115497*^9}, {3.4867369948881063`*^9, 3.4867370000440903`*^9}, {
   3.560442924142695*^9, 3.5604429343918*^9}, {3.56045259467756*^9, 
   3.560452616498255*^9}, {3.560452709691867*^9, 3.560452712883379*^9}, 
   3.56045277729163*^9, {3.560452824864834*^9, 3.560452831124082*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"SplinekD2", "[", 
   RowBox[{"k_Integer", ",", "x_"}], "]"}], ":=", 
  RowBox[{
   RowBox[{"2", " ", 
    RowBox[{"s2", "[", "k", "]"}]}], " ", "+", " ", 
   RowBox[{"6", " ", 
    RowBox[{"s3", "[", "k", "]"}], 
    RowBox[{"(", 
     RowBox[{"x", "-", 
      RowBox[{"xpoints", "[", 
       RowBox[{"[", "k", "]"}], "]"}]}], ")"}]}]}]}]], "Input",
 CellChangeTimes->{{3.560452833421798*^9, 3.56045283667159*^9}}],

Cell[CellGroupData[{

Cell["Part I", "Section",
 CellChangeTimes->{{3.481257998609375*^9, 3.481257999875*^9}, {
  3.48125838840625*^9, 3.48125841678125*^9}, {3.48133765459375*^9, 
  3.481337701859375*^9}, {3.4855832109375*^9, 3.48558321753125*^9}, {
  3.5726816507562313`*^9, 3.5726816509732437`*^9}},
 FontSize->36,
 FontColor->RGBColor[0, 0, 1],
 Background->RGBColor[1, 0.9, 0.8],
 CellTags->"Part A"],

Cell[TextData[{
 "We impose the conditions\n\n",
 Cell[BoxData[
  FormBox[
   SubscriptBox["S", "k"], TraditionalForm]]],
 "(",
 Cell[BoxData[
  FormBox[
   SubscriptBox["x", "k"], TraditionalForm]]],
 ") = ",
 Cell[BoxData[
  FormBox[
   SubscriptBox["y", "k"], TraditionalForm]]],
 "    with k = 1,2,3,4,5 \n\nand\n\n",
 Cell[BoxData[
  FormBox[
   SubscriptBox["S", "k"], TraditionalForm]]],
 "(",
 Cell[BoxData[
  FormBox[
   SubscriptBox["x", 
    RowBox[{"k", "+", "1"}]], TraditionalForm]]],
 ") = ",
 Cell[BoxData[
  FormBox[
   SubscriptBox["y", 
    RowBox[{"k", "+", "1", "   "}]], TraditionalForm]]],
 "with k = 1,2,3,4,5"
}], "Text",
 CellChangeTimes->{{3.481257998609375*^9, 3.481257999875*^9}, {
   3.48125838840625*^9, 3.48125841678125*^9}, 3.485579361109375*^9, {
   3.485583558609375*^9, 3.485583561671875*^9}, {3.485583665390625*^9, 
   3.48558382215625*^9}, {3.48559560103125*^9, 3.485595619140625*^9}, {
   3.4867018311803102`*^9, 3.4867018641753407`*^9}, {3.48670189515548*^9, 
   3.486701895330472*^9}, {3.560440901823851*^9, 3.560440913538362*^9}},
 Background->GrayLevel[0.85]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"tab1", "=", 
   RowBox[{"Table", "[", 
    RowBox[{
     RowBox[{
      RowBox[{"Splinek", "[", 
       RowBox[{"i", ",", 
        RowBox[{"x", "[", "i", "]"}]}], "]"}], "\[Equal]", 
      RowBox[{"y", "[", "i", "]"}]}], ",", 
     RowBox[{"{", 
      RowBox[{"i", ",", 
       RowBox[{"numpoints", "-", "1"}]}], "}"}]}], "]"}]}], ";", 
  RowBox[{"tab1", "//", "Column"}]}]], "Input",
 CellChangeTimes->{{3.48102580940625*^9, 3.4810258294375*^9}, 
   3.481258266078125*^9, {3.485581328765625*^9, 3.485581331640625*^9}, {
   3.4856099461875*^9, 3.485609946625*^9}, 3.486217333671915*^9, {
   3.486217685794669*^9, 3.486217691740452*^9}, {3.560441677612932*^9, 
   3.560441709397636*^9}, {3.560452725503032*^9, 3.560452727818899*^9}}],

Cell[BoxData[
 TagBox[GridBox[{
    {
     RowBox[{
      RowBox[{
       RowBox[{"s0", "[", "1", "]"}], "+", 
       RowBox[{
        RowBox[{"s1", "[", "1", "]"}], " ", 
        RowBox[{"x", "[", "1", "]"}]}], "+", 
       RowBox[{
        RowBox[{"s2", "[", "1", "]"}], " ", 
        SuperscriptBox[
         RowBox[{"x", "[", "1", "]"}], "2"]}], "+", 
       RowBox[{
        RowBox[{"s3", "[", "1", "]"}], " ", 
        SuperscriptBox[
         RowBox[{"x", "[", "1", "]"}], "3"]}]}], "\[Equal]", 
      RowBox[{"y", "[", "1", "]"}]}]},
    {
     RowBox[{
      RowBox[{
       RowBox[{"s0", "[", "2", "]"}], "+", 
       RowBox[{
        RowBox[{"s1", "[", "2", "]"}], " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"-", "2"}], "+", 
          RowBox[{"x", "[", "2", "]"}]}], ")"}]}], "+", 
       RowBox[{
        RowBox[{"s2", "[", "2", "]"}], " ", 
        SuperscriptBox[
         RowBox[{"(", 
          RowBox[{
           RowBox[{"-", "2"}], "+", 
           RowBox[{"x", "[", "2", "]"}]}], ")"}], "2"]}], "+", 
       RowBox[{
        RowBox[{"s3", "[", "2", "]"}], " ", 
        SuperscriptBox[
         RowBox[{"(", 
          RowBox[{
           RowBox[{"-", "2"}], "+", 
           RowBox[{"x", "[", "2", "]"}]}], ")"}], "3"]}]}], "\[Equal]", 
      RowBox[{"y", "[", "2", "]"}]}]},
    {
     RowBox[{
      RowBox[{
       RowBox[{"s0", "[", "3", "]"}], "+", 
       RowBox[{
        RowBox[{"s1", "[", "3", "]"}], " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"-", "5"}], "+", 
          RowBox[{"x", "[", "3", "]"}]}], ")"}]}], "+", 
       RowBox[{
        RowBox[{"s2", "[", "3", "]"}], " ", 
        SuperscriptBox[
         RowBox[{"(", 
          RowBox[{
           RowBox[{"-", "5"}], "+", 
           RowBox[{"x", "[", "3", "]"}]}], ")"}], "2"]}], "+", 
       RowBox[{
        RowBox[{"s3", "[", "3", "]"}], " ", 
        SuperscriptBox[
         RowBox[{"(", 
          RowBox[{
           RowBox[{"-", "5"}], "+", 
           RowBox[{"x", "[", "3", "]"}]}], ")"}], "3"]}]}], "\[Equal]", 
      RowBox[{"y", "[", "3", "]"}]}]},
    {
     RowBox[{
      RowBox[{
       RowBox[{"s0", "[", "4", "]"}], "+", 
       RowBox[{
        RowBox[{"s1", "[", "4", "]"}], " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"-", "9"}], "+", 
          RowBox[{"x", "[", "4", "]"}]}], ")"}]}], "+", 
       RowBox[{
        RowBox[{"s2", "[", "4", "]"}], " ", 
        SuperscriptBox[
         RowBox[{"(", 
          RowBox[{
           RowBox[{"-", "9"}], "+", 
           RowBox[{"x", "[", "4", "]"}]}], ")"}], "2"]}], "+", 
       RowBox[{
        RowBox[{"s3", "[", "4", "]"}], " ", 
        SuperscriptBox[
         RowBox[{"(", 
          RowBox[{
           RowBox[{"-", "9"}], "+", 
           RowBox[{"x", "[", "4", "]"}]}], ")"}], "3"]}]}], "\[Equal]", 
      RowBox[{"y", "[", "4", "]"}]}]},
    {
     RowBox[{
      RowBox[{
       RowBox[{"s0", "[", "5", "]"}], "+", 
       RowBox[{
        RowBox[{"s1", "[", "5", "]"}], " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"-", "11"}], "+", 
          RowBox[{"x", "[", "5", "]"}]}], ")"}]}], "+", 
       RowBox[{
        RowBox[{"s2", "[", "5", "]"}], " ", 
        SuperscriptBox[
         RowBox[{"(", 
          RowBox[{
           RowBox[{"-", "11"}], "+", 
           RowBox[{"x", "[", "5", "]"}]}], ")"}], "2"]}], "+", 
       RowBox[{
        RowBox[{"s3", "[", "5", "]"}], " ", 
        SuperscriptBox[
         RowBox[{"(", 
          RowBox[{
           RowBox[{"-", "11"}], "+", 
           RowBox[{"x", "[", "5", "]"}]}], ")"}], "3"]}]}], "\[Equal]", 
      RowBox[{"y", "[", "5", "]"}]}]}
   },
   DefaultBaseStyle->"Column",
   GridBoxAlignment->{"Columns" -> {{Left}}},
   GridBoxItemSize->{"Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}],
  "Column"]], "Output",
 CellChangeTimes->{3.577700202436532*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"tab2", "=", 
   RowBox[{"Table", "[", 
    RowBox[{
     RowBox[{
      RowBox[{"Splinek", "[", 
       RowBox[{"i", ",", 
        RowBox[{"x", "[", 
         RowBox[{"i", "+", "1"}], "]"}]}], "]"}], "\[Equal]", 
      RowBox[{"y", "[", 
       RowBox[{"i", "+", "1"}], "]"}]}], ",", 
     RowBox[{"{", 
      RowBox[{"i", ",", 
       RowBox[{"numpoints", "-", "1"}]}], "}"}]}], "]"}]}], ";", " ", 
  RowBox[{"tab2", "//", "Column"}]}]], "Input",
 CellChangeTimes->{{3.481028654125*^9, 3.481028657921875*^9}, 
   3.481258266609375*^9, {3.48558133534375*^9, 3.485581339140625*^9}, {
   3.485609949359375*^9, 3.48560994978125*^9}, 3.486217375733328*^9, {
   3.486217697711337*^9, 3.48621769957086*^9}, {3.560441712583369*^9, 
   3.560441717153493*^9}, {3.560452732367831*^9, 3.560452733519765*^9}}],

Cell[BoxData[
 TagBox[GridBox[{
    {
     RowBox[{
      RowBox[{
       RowBox[{"s0", "[", "1", "]"}], "+", 
       RowBox[{
        RowBox[{"s1", "[", "1", "]"}], " ", 
        RowBox[{"x", "[", "2", "]"}]}], "+", 
       RowBox[{
        RowBox[{"s2", "[", "1", "]"}], " ", 
        SuperscriptBox[
         RowBox[{"x", "[", "2", "]"}], "2"]}], "+", 
       RowBox[{
        RowBox[{"s3", "[", "1", "]"}], " ", 
        SuperscriptBox[
         RowBox[{"x", "[", "2", "]"}], "3"]}]}], "\[Equal]", 
      RowBox[{"y", "[", "2", "]"}]}]},
    {
     RowBox[{
      RowBox[{
       RowBox[{"s0", "[", "2", "]"}], "+", 
       RowBox[{
        RowBox[{"s1", "[", "2", "]"}], " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"-", "2"}], "+", 
          RowBox[{"x", "[", "3", "]"}]}], ")"}]}], "+", 
       RowBox[{
        RowBox[{"s2", "[", "2", "]"}], " ", 
        SuperscriptBox[
         RowBox[{"(", 
          RowBox[{
           RowBox[{"-", "2"}], "+", 
           RowBox[{"x", "[", "3", "]"}]}], ")"}], "2"]}], "+", 
       RowBox[{
        RowBox[{"s3", "[", "2", "]"}], " ", 
        SuperscriptBox[
         RowBox[{"(", 
          RowBox[{
           RowBox[{"-", "2"}], "+", 
           RowBox[{"x", "[", "3", "]"}]}], ")"}], "3"]}]}], "\[Equal]", 
      RowBox[{"y", "[", "3", "]"}]}]},
    {
     RowBox[{
      RowBox[{
       RowBox[{"s0", "[", "3", "]"}], "+", 
       RowBox[{
        RowBox[{"s1", "[", "3", "]"}], " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"-", "5"}], "+", 
          RowBox[{"x", "[", "4", "]"}]}], ")"}]}], "+", 
       RowBox[{
        RowBox[{"s2", "[", "3", "]"}], " ", 
        SuperscriptBox[
         RowBox[{"(", 
          RowBox[{
           RowBox[{"-", "5"}], "+", 
           RowBox[{"x", "[", "4", "]"}]}], ")"}], "2"]}], "+", 
       RowBox[{
        RowBox[{"s3", "[", "3", "]"}], " ", 
        SuperscriptBox[
         RowBox[{"(", 
          RowBox[{
           RowBox[{"-", "5"}], "+", 
           RowBox[{"x", "[", "4", "]"}]}], ")"}], "3"]}]}], "\[Equal]", 
      RowBox[{"y", "[", "4", "]"}]}]},
    {
     RowBox[{
      RowBox[{
       RowBox[{"s0", "[", "4", "]"}], "+", 
       RowBox[{
        RowBox[{"s1", "[", "4", "]"}], " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"-", "9"}], "+", 
          RowBox[{"x", "[", "5", "]"}]}], ")"}]}], "+", 
       RowBox[{
        RowBox[{"s2", "[", "4", "]"}], " ", 
        SuperscriptBox[
         RowBox[{"(", 
          RowBox[{
           RowBox[{"-", "9"}], "+", 
           RowBox[{"x", "[", "5", "]"}]}], ")"}], "2"]}], "+", 
       RowBox[{
        RowBox[{"s3", "[", "4", "]"}], " ", 
        SuperscriptBox[
         RowBox[{"(", 
          RowBox[{
           RowBox[{"-", "9"}], "+", 
           RowBox[{"x", "[", "5", "]"}]}], ")"}], "3"]}]}], "\[Equal]", 
      RowBox[{"y", "[", "5", "]"}]}]},
    {
     RowBox[{
      RowBox[{
       RowBox[{"s0", "[", "5", "]"}], "+", 
       RowBox[{
        RowBox[{"s1", "[", "5", "]"}], " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"-", "11"}], "+", 
          RowBox[{"x", "[", "6", "]"}]}], ")"}]}], "+", 
       RowBox[{
        RowBox[{"s2", "[", "5", "]"}], " ", 
        SuperscriptBox[
         RowBox[{"(", 
          RowBox[{
           RowBox[{"-", "11"}], "+", 
           RowBox[{"x", "[", "6", "]"}]}], ")"}], "2"]}], "+", 
       RowBox[{
        RowBox[{"s3", "[", "5", "]"}], " ", 
        SuperscriptBox[
         RowBox[{"(", 
          RowBox[{
           RowBox[{"-", "11"}], "+", 
           RowBox[{"x", "[", "6", "]"}]}], ")"}], "3"]}]}], "\[Equal]", 
      RowBox[{"y", "[", "6", "]"}]}]}
   },
   DefaultBaseStyle->"Column",
   GridBoxAlignment->{"Columns" -> {{Left}}},
   GridBoxItemSize->{"Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}],
  "Column"]], "Output",
 CellChangeTimes->{3.5777002025564737`*^9}]
}, Open  ]],

Cell["We put together the previous equations", "Text",
 CellChangeTimes->{{3.481168880640625*^9, 3.4811688860625*^9}, 
   3.481258479625*^9, {3.48558390334375*^9, 3.485583920515625*^9}, {
   3.486128414643187*^9, 3.486128417771188*^9}},
 Background->GrayLevel[0.85]],

Cell[BoxData[
 RowBox[{
  RowBox[{"equaz", "=", 
   RowBox[{"Join", "[", 
    RowBox[{"tab1", ",", "tab2"}], "]"}]}], ";"}]], "Input",
 CellChangeTimes->{{3.486217719512596*^9, 3.486217783090219*^9}, {
  3.560440977335521*^9, 3.560441027604613*^9}}],

Cell["\<\
We impose the continuity conditions for the first and second derivative at \
the internal points\
\>", "Text",
 CellChangeTimes->{{3.481258428046875*^9, 3.481258430125*^9}, {
   3.481258611578125*^9, 3.481258646203125*^9}, {3.48125898009375*^9, 
   3.481258986796875*^9}, {3.48558393840625*^9, 3.485583991015625*^9}, 
   3.4861285859639673`*^9, {3.560441030362773*^9, 3.560441030802447*^9}},
 Background->GrayLevel[0.85]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"tab3", "=", 
   RowBox[{"Table", "[", 
    RowBox[{
     RowBox[{
      RowBox[{"SplinekD1", "[", 
       RowBox[{"i", ",", 
        RowBox[{"x", "[", "i", "]"}]}], "]"}], "\[Equal]", 
      RowBox[{"SplinekD1", "[", 
       RowBox[{
        RowBox[{"i", "-", "1"}], ",", 
        RowBox[{"x", "[", "i", "]"}]}], "]"}]}], ",", 
     RowBox[{"{", 
      RowBox[{"i", ",", "2", ",", 
       RowBox[{"numpoints", "-", "1"}]}], "}"}]}], "]"}]}], ";", 
  RowBox[{"tab3", "//", "Column"}]}]], "Input",
 CellChangeTimes->{{3.48102580940625*^9, 3.4810258294375*^9}, 
   3.481258266078125*^9, {3.485581328765625*^9, 3.485581331640625*^9}, {
   3.4856099461875*^9, 3.485609946625*^9}, 3.486217333671915*^9, {
   3.486217685794669*^9, 3.486217691740452*^9}, {3.4863646530022173`*^9, 
   3.4863646916061697`*^9}, {3.56044177967339*^9, 3.560441783359059*^9}, {
   3.560452740673521*^9, 3.560452745944285*^9}, {3.560582782462014*^9, 
   3.560582785126947*^9}}],

Cell[BoxData[
 TagBox[GridBox[{
    {
     RowBox[{
      RowBox[{
       RowBox[{"s1", "[", "2", "]"}], "+", 
       RowBox[{"2", " ", 
        RowBox[{"s2", "[", "2", "]"}], " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"-", "2"}], "+", 
          RowBox[{"x", "[", "2", "]"}]}], ")"}]}], "+", 
       RowBox[{"3", " ", 
        RowBox[{"s3", "[", "2", "]"}], " ", 
        SuperscriptBox[
         RowBox[{"(", 
          RowBox[{
           RowBox[{"-", "2"}], "+", 
           RowBox[{"x", "[", "2", "]"}]}], ")"}], "2"]}]}], "\[Equal]", 
      RowBox[{
       RowBox[{"s1", "[", "1", "]"}], "+", 
       RowBox[{"2", " ", 
        RowBox[{"s2", "[", "1", "]"}], " ", 
        RowBox[{"x", "[", "2", "]"}]}], "+", 
       RowBox[{"3", " ", 
        RowBox[{"s3", "[", "1", "]"}], " ", 
        SuperscriptBox[
         RowBox[{"x", "[", "2", "]"}], "2"]}]}]}]},
    {
     RowBox[{
      RowBox[{
       RowBox[{"s1", "[", "3", "]"}], "+", 
       RowBox[{"2", " ", 
        RowBox[{"s2", "[", "3", "]"}], " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"-", "5"}], "+", 
          RowBox[{"x", "[", "3", "]"}]}], ")"}]}], "+", 
       RowBox[{"3", " ", 
        RowBox[{"s3", "[", "3", "]"}], " ", 
        SuperscriptBox[
         RowBox[{"(", 
          RowBox[{
           RowBox[{"-", "5"}], "+", 
           RowBox[{"x", "[", "3", "]"}]}], ")"}], "2"]}]}], "\[Equal]", 
      RowBox[{
       RowBox[{"s1", "[", "2", "]"}], "+", 
       RowBox[{"2", " ", 
        RowBox[{"s2", "[", "2", "]"}], " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"-", "2"}], "+", 
          RowBox[{"x", "[", "3", "]"}]}], ")"}]}], "+", 
       RowBox[{"3", " ", 
        RowBox[{"s3", "[", "2", "]"}], " ", 
        SuperscriptBox[
         RowBox[{"(", 
          RowBox[{
           RowBox[{"-", "2"}], "+", 
           RowBox[{"x", "[", "3", "]"}]}], ")"}], "2"]}]}]}]},
    {
     RowBox[{
      RowBox[{
       RowBox[{"s1", "[", "4", "]"}], "+", 
       RowBox[{"2", " ", 
        RowBox[{"s2", "[", "4", "]"}], " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"-", "9"}], "+", 
          RowBox[{"x", "[", "4", "]"}]}], ")"}]}], "+", 
       RowBox[{"3", " ", 
        RowBox[{"s3", "[", "4", "]"}], " ", 
        SuperscriptBox[
         RowBox[{"(", 
          RowBox[{
           RowBox[{"-", "9"}], "+", 
           RowBox[{"x", "[", "4", "]"}]}], ")"}], "2"]}]}], "\[Equal]", 
      RowBox[{
       RowBox[{"s1", "[", "3", "]"}], "+", 
       RowBox[{"2", " ", 
        RowBox[{"s2", "[", "3", "]"}], " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"-", "5"}], "+", 
          RowBox[{"x", "[", "4", "]"}]}], ")"}]}], "+", 
       RowBox[{"3", " ", 
        RowBox[{"s3", "[", "3", "]"}], " ", 
        SuperscriptBox[
         RowBox[{"(", 
          RowBox[{
           RowBox[{"-", "5"}], "+", 
           RowBox[{"x", "[", "4", "]"}]}], ")"}], "2"]}]}]}]},
    {
     RowBox[{
      RowBox[{
       RowBox[{"s1", "[", "5", "]"}], "+", 
       RowBox[{"2", " ", 
        RowBox[{"s2", "[", "5", "]"}], " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"-", "11"}], "+", 
          RowBox[{"x", "[", "5", "]"}]}], ")"}]}], "+", 
       RowBox[{"3", " ", 
        RowBox[{"s3", "[", "5", "]"}], " ", 
        SuperscriptBox[
         RowBox[{"(", 
          RowBox[{
           RowBox[{"-", "11"}], "+", 
           RowBox[{"x", "[", "5", "]"}]}], ")"}], "2"]}]}], "\[Equal]", 
      RowBox[{
       RowBox[{"s1", "[", "4", "]"}], "+", 
       RowBox[{"2", " ", 
        RowBox[{"s2", "[", "4", "]"}], " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"-", "9"}], "+", 
          RowBox[{"x", "[", "5", "]"}]}], ")"}]}], "+", 
       RowBox[{"3", " ", 
        RowBox[{"s3", "[", "4", "]"}], " ", 
        SuperscriptBox[
         RowBox[{"(", 
          RowBox[{
           RowBox[{"-", "9"}], "+", 
           RowBox[{"x", "[", "5", "]"}]}], ")"}], "2"]}]}]}]}
   },
   DefaultBaseStyle->"Column",
   GridBoxAlignment->{"Columns" -> {{Left}}},
   GridBoxItemSize->{"Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}],
  "Column"]], "Output",
 CellChangeTimes->{3.5777002026252613`*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"tab4", "=", 
   RowBox[{"Table", "[", 
    RowBox[{
     RowBox[{
      RowBox[{"SplinekD2", "[", 
       RowBox[{"i", ",", 
        RowBox[{"x", "[", "i", "]"}]}], "]"}], "\[Equal]", 
      RowBox[{"SplinekD2", "[", 
       RowBox[{
        RowBox[{"i", "-", "1"}], ",", 
        RowBox[{"x", "[", "i", "]"}]}], "]"}]}], ",", 
     RowBox[{"{", 
      RowBox[{"i", ",", "2", ",", 
       RowBox[{"numpoints", "-", "1"}]}], "}"}]}], "]"}]}], ";", 
  RowBox[{"tab4", "//", "Column"}]}]], "Input",
 CellChangeTimes->{{3.48102580940625*^9, 3.4810258294375*^9}, 
   3.481258266078125*^9, {3.485581328765625*^9, 3.485581331640625*^9}, {
   3.4856099461875*^9, 3.485609946625*^9}, 3.486217333671915*^9, {
   3.486217685794669*^9, 3.486217691740452*^9}, {3.4863646530022173`*^9, 
   3.4863646916061697`*^9}, {3.486364753311594*^9, 3.486364760682445*^9}, {
   3.56044178713431*^9, 3.560441791079743*^9}, {3.560452850550837*^9, 
   3.560452856128634*^9}}],

Cell[BoxData[
 TagBox[GridBox[{
    {
     RowBox[{
      RowBox[{
       RowBox[{"2", " ", 
        RowBox[{"s2", "[", "2", "]"}]}], "+", 
       RowBox[{"6", " ", 
        RowBox[{"s3", "[", "2", "]"}], " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"-", "2"}], "+", 
          RowBox[{"x", "[", "2", "]"}]}], ")"}]}]}], "\[Equal]", 
      RowBox[{
       RowBox[{"2", " ", 
        RowBox[{"s2", "[", "1", "]"}]}], "+", 
       RowBox[{"6", " ", 
        RowBox[{"s3", "[", "1", "]"}], " ", 
        RowBox[{"x", "[", "2", "]"}]}]}]}]},
    {
     RowBox[{
      RowBox[{
       RowBox[{"2", " ", 
        RowBox[{"s2", "[", "3", "]"}]}], "+", 
       RowBox[{"6", " ", 
        RowBox[{"s3", "[", "3", "]"}], " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"-", "5"}], "+", 
          RowBox[{"x", "[", "3", "]"}]}], ")"}]}]}], "\[Equal]", 
      RowBox[{
       RowBox[{"2", " ", 
        RowBox[{"s2", "[", "2", "]"}]}], "+", 
       RowBox[{"6", " ", 
        RowBox[{"s3", "[", "2", "]"}], " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"-", "2"}], "+", 
          RowBox[{"x", "[", "3", "]"}]}], ")"}]}]}]}]},
    {
     RowBox[{
      RowBox[{
       RowBox[{"2", " ", 
        RowBox[{"s2", "[", "4", "]"}]}], "+", 
       RowBox[{"6", " ", 
        RowBox[{"s3", "[", "4", "]"}], " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"-", "9"}], "+", 
          RowBox[{"x", "[", "4", "]"}]}], ")"}]}]}], "\[Equal]", 
      RowBox[{
       RowBox[{"2", " ", 
        RowBox[{"s2", "[", "3", "]"}]}], "+", 
       RowBox[{"6", " ", 
        RowBox[{"s3", "[", "3", "]"}], " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"-", "5"}], "+", 
          RowBox[{"x", "[", "4", "]"}]}], ")"}]}]}]}]},
    {
     RowBox[{
      RowBox[{
       RowBox[{"2", " ", 
        RowBox[{"s2", "[", "5", "]"}]}], "+", 
       RowBox[{"6", " ", 
        RowBox[{"s3", "[", "5", "]"}], " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"-", "11"}], "+", 
          RowBox[{"x", "[", "5", "]"}]}], ")"}]}]}], "\[Equal]", 
      RowBox[{
       RowBox[{"2", " ", 
        RowBox[{"s2", "[", "4", "]"}]}], "+", 
       RowBox[{"6", " ", 
        RowBox[{"s3", "[", "4", "]"}], " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"-", "9"}], "+", 
          RowBox[{"x", "[", "5", "]"}]}], ")"}]}]}]}]}
   },
   DefaultBaseStyle->"Column",
   GridBoxAlignment->{"Columns" -> {{Left}}},
   GridBoxItemSize->{"Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}],
  "Column"]], "Output",
 CellChangeTimes->{3.577700202672447*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"equaz", "=", 
   RowBox[{"Join", "[", 
    RowBox[{"equaz", ",", "tab3", ",", "tab4"}], "]"}]}], ";", 
  RowBox[{"Length", "[", "equaz", "]"}]}]], "Input",
 CellChangeTimes->{{3.486217719512596*^9, 3.486217783090219*^9}, {
   3.486365123188199*^9, 3.486365136305236*^9}, 3.4864739699444857`*^9, {
   3.486474033447693*^9, 3.4864741117598877`*^9}, {3.4864745588401337`*^9, 
   3.486474563521443*^9}, {3.486474614500966*^9, 3.486474622242896*^9}, {
   3.4864747023164062`*^9, 3.486474706059621*^9}, {3.560441801794491*^9, 
   3.560441821700316*^9}, {3.560441886652292*^9, 3.560441887964549*^9}, {
   3.560452862740119*^9, 3.560452865679714*^9}}],

Cell[BoxData["18"], "Output",
 CellChangeTimes->{3.577700202711649*^9}]
}, Open  ]],

Cell["\<\
We add the conditions to obtain the natural spline (that is, the second \
derivatives are set to zero at the end points)\
\>", "Text",
 CellChangeTimes->{{3.481258428046875*^9, 3.481258430125*^9}, {
  3.481258611578125*^9, 3.48125869225*^9}, {3.4855839986875*^9, 
  3.485584087015625*^9}, {3.48558491565625*^9, 3.48558492275*^9}, {
  3.560441827116551*^9, 3.560441827714529*^9}},
 Background->GrayLevel[0.85]],

Cell[BoxData[
 RowBox[{
  RowBox[{"equaz", "=", 
   RowBox[{"Join", "[", 
    RowBox[{"equaz", ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        RowBox[{"SplinekD2", "[", 
         RowBox[{"1", ",", 
          RowBox[{"x", "[", "1", "]"}]}], "]"}], " ", "\[Equal]", " ", "0"}], 
       ",", 
       RowBox[{
        RowBox[{"SplinekD2", "[", 
         RowBox[{
          RowBox[{"numpoints", "-", "1"}], ",", 
          RowBox[{"x", "[", "numpoints", "]"}]}], "]"}], " ", "\[Equal]", " ",
         "0"}]}], "}"}]}], "]"}]}], ";"}]], "Input",
 CellChangeTimes->{
  3.481025800453125*^9, 3.48102862415625*^9, {3.48125805175*^9, 
   3.481258052265625*^9}, {3.48125830865625*^9, 3.481258309171875*^9}, 
   3.4812584808125*^9, {3.485581381390625*^9, 3.48558139834375*^9}, {
   3.485599657015625*^9, 3.485599657578125*^9}, {3.560441912955468*^9, 
   3.560441948085501*^9}, {3.560452911733042*^9, 3.560452918326156*^9}}],

Cell["We have assembled all the conditions", "Text",
 CellChangeTimes->{{3.481258428046875*^9, 3.481258430125*^9}, {
   3.481258611578125*^9, 3.48125869225*^9}, {3.4855839986875*^9, 
   3.485584087015625*^9}, {3.48558412878125*^9, 3.485584136015625*^9}, 
   3.486220289556675*^9, {3.48636342111878*^9, 3.486363432393417*^9}, {
   3.4869026539047823`*^9, 3.486902655419804*^9}},
 Background->GrayLevel[0.85]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"equaz", "//", "Column"}]], "Input",
 CellChangeTimes->{
  3.481025800453125*^9, 3.48102862415625*^9, {3.481253057953125*^9, 
   3.481253067421875*^9}, {3.48125848153125*^9, 3.481258482109375*^9}, {
   3.560441973627579*^9, 3.560441975347063*^9}}],

Cell[BoxData[
 TagBox[GridBox[{
    {
     RowBox[{
      RowBox[{
       RowBox[{"s0", "[", "1", "]"}], "+", 
       RowBox[{
        RowBox[{"s1", "[", "1", "]"}], " ", 
        RowBox[{"x", "[", "1", "]"}]}], "+", 
       RowBox[{
        RowBox[{"s2", "[", "1", "]"}], " ", 
        SuperscriptBox[
         RowBox[{"x", "[", "1", "]"}], "2"]}], "+", 
       RowBox[{
        RowBox[{"s3", "[", "1", "]"}], " ", 
        SuperscriptBox[
         RowBox[{"x", "[", "1", "]"}], "3"]}]}], "\[Equal]", 
      RowBox[{"y", "[", "1", "]"}]}]},
    {
     RowBox[{
      RowBox[{
       RowBox[{"s0", "[", "2", "]"}], "+", 
       RowBox[{
        RowBox[{"s1", "[", "2", "]"}], " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"-", "2"}], "+", 
          RowBox[{"x", "[", "2", "]"}]}], ")"}]}], "+", 
       RowBox[{
        RowBox[{"s2", "[", "2", "]"}], " ", 
        SuperscriptBox[
         RowBox[{"(", 
          RowBox[{
           RowBox[{"-", "2"}], "+", 
           RowBox[{"x", "[", "2", "]"}]}], ")"}], "2"]}], "+", 
       RowBox[{
        RowBox[{"s3", "[", "2", "]"}], " ", 
        SuperscriptBox[
         RowBox[{"(", 
          RowBox[{
           RowBox[{"-", "2"}], "+", 
           RowBox[{"x", "[", "2", "]"}]}], ")"}], "3"]}]}], "\[Equal]", 
      RowBox[{"y", "[", "2", "]"}]}]},
    {
     RowBox[{
      RowBox[{
       RowBox[{"s0", "[", "3", "]"}], "+", 
       RowBox[{
        RowBox[{"s1", "[", "3", "]"}], " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"-", "5"}], "+", 
          RowBox[{"x", "[", "3", "]"}]}], ")"}]}], "+", 
       RowBox[{
        RowBox[{"s2", "[", "3", "]"}], " ", 
        SuperscriptBox[
         RowBox[{"(", 
          RowBox[{
           RowBox[{"-", "5"}], "+", 
           RowBox[{"x", "[", "3", "]"}]}], ")"}], "2"]}], "+", 
       RowBox[{
        RowBox[{"s3", "[", "3", "]"}], " ", 
        SuperscriptBox[
         RowBox[{"(", 
          RowBox[{
           RowBox[{"-", "5"}], "+", 
           RowBox[{"x", "[", "3", "]"}]}], ")"}], "3"]}]}], "\[Equal]", 
      RowBox[{"y", "[", "3", "]"}]}]},
    {
     RowBox[{
      RowBox[{
       RowBox[{"s0", "[", "4", "]"}], "+", 
       RowBox[{
        RowBox[{"s1", "[", "4", "]"}], " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"-", "9"}], "+", 
          RowBox[{"x", "[", "4", "]"}]}], ")"}]}], "+", 
       RowBox[{
        RowBox[{"s2", "[", "4", "]"}], " ", 
        SuperscriptBox[
         RowBox[{"(", 
          RowBox[{
           RowBox[{"-", "9"}], "+", 
           RowBox[{"x", "[", "4", "]"}]}], ")"}], "2"]}], "+", 
       RowBox[{
        RowBox[{"s3", "[", "4", "]"}], " ", 
        SuperscriptBox[
         RowBox[{"(", 
          RowBox[{
           RowBox[{"-", "9"}], "+", 
           RowBox[{"x", "[", "4", "]"}]}], ")"}], "3"]}]}], "\[Equal]", 
      RowBox[{"y", "[", "4", "]"}]}]},
    {
     RowBox[{
      RowBox[{
       RowBox[{"s0", "[", "5", "]"}], "+", 
       RowBox[{
        RowBox[{"s1", "[", "5", "]"}], " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"-", "11"}], "+", 
          RowBox[{"x", "[", "5", "]"}]}], ")"}]}], "+", 
       RowBox[{
        RowBox[{"s2", "[", "5", "]"}], " ", 
        SuperscriptBox[
         RowBox[{"(", 
          RowBox[{
           RowBox[{"-", "11"}], "+", 
           RowBox[{"x", "[", "5", "]"}]}], ")"}], "2"]}], "+", 
       RowBox[{
        RowBox[{"s3", "[", "5", "]"}], " ", 
        SuperscriptBox[
         RowBox[{"(", 
          RowBox[{
           RowBox[{"-", "11"}], "+", 
           RowBox[{"x", "[", "5", "]"}]}], ")"}], "3"]}]}], "\[Equal]", 
      RowBox[{"y", "[", "5", "]"}]}]},
    {
     RowBox[{
      RowBox[{
       RowBox[{"s0", "[", "1", "]"}], "+", 
       RowBox[{
        RowBox[{"s1", "[", "1", "]"}], " ", 
        RowBox[{"x", "[", "2", "]"}]}], "+", 
       RowBox[{
        RowBox[{"s2", "[", "1", "]"}], " ", 
        SuperscriptBox[
         RowBox[{"x", "[", "2", "]"}], "2"]}], "+", 
       RowBox[{
        RowBox[{"s3", "[", "1", "]"}], " ", 
        SuperscriptBox[
         RowBox[{"x", "[", "2", "]"}], "3"]}]}], "\[Equal]", 
      RowBox[{"y", "[", "2", "]"}]}]},
    {
     RowBox[{
      RowBox[{
       RowBox[{"s0", "[", "2", "]"}], "+", 
       RowBox[{
        RowBox[{"s1", "[", "2", "]"}], " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"-", "2"}], "+", 
          RowBox[{"x", "[", "3", "]"}]}], ")"}]}], "+", 
       RowBox[{
        RowBox[{"s2", "[", "2", "]"}], " ", 
        SuperscriptBox[
         RowBox[{"(", 
          RowBox[{
           RowBox[{"-", "2"}], "+", 
           RowBox[{"x", "[", "3", "]"}]}], ")"}], "2"]}], "+", 
       RowBox[{
        RowBox[{"s3", "[", "2", "]"}], " ", 
        SuperscriptBox[
         RowBox[{"(", 
          RowBox[{
           RowBox[{"-", "2"}], "+", 
           RowBox[{"x", "[", "3", "]"}]}], ")"}], "3"]}]}], "\[Equal]", 
      RowBox[{"y", "[", "3", "]"}]}]},
    {
     RowBox[{
      RowBox[{
       RowBox[{"s0", "[", "3", "]"}], "+", 
       RowBox[{
        RowBox[{"s1", "[", "3", "]"}], " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"-", "5"}], "+", 
          RowBox[{"x", "[", "4", "]"}]}], ")"}]}], "+", 
       RowBox[{
        RowBox[{"s2", "[", "3", "]"}], " ", 
        SuperscriptBox[
         RowBox[{"(", 
          RowBox[{
           RowBox[{"-", "5"}], "+", 
           RowBox[{"x", "[", "4", "]"}]}], ")"}], "2"]}], "+", 
       RowBox[{
        RowBox[{"s3", "[", "3", "]"}], " ", 
        SuperscriptBox[
         RowBox[{"(", 
          RowBox[{
           RowBox[{"-", "5"}], "+", 
           RowBox[{"x", "[", "4", "]"}]}], ")"}], "3"]}]}], "\[Equal]", 
      RowBox[{"y", "[", "4", "]"}]}]},
    {
     RowBox[{
      RowBox[{
       RowBox[{"s0", "[", "4", "]"}], "+", 
       RowBox[{
        RowBox[{"s1", "[", "4", "]"}], " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"-", "9"}], "+", 
          RowBox[{"x", "[", "5", "]"}]}], ")"}]}], "+", 
       RowBox[{
        RowBox[{"s2", "[", "4", "]"}], " ", 
        SuperscriptBox[
         RowBox[{"(", 
          RowBox[{
           RowBox[{"-", "9"}], "+", 
           RowBox[{"x", "[", "5", "]"}]}], ")"}], "2"]}], "+", 
       RowBox[{
        RowBox[{"s3", "[", "4", "]"}], " ", 
        SuperscriptBox[
         RowBox[{"(", 
          RowBox[{
           RowBox[{"-", "9"}], "+", 
           RowBox[{"x", "[", "5", "]"}]}], ")"}], "3"]}]}], "\[Equal]", 
      RowBox[{"y", "[", "5", "]"}]}]},
    {
     RowBox[{
      RowBox[{
       RowBox[{"s0", "[", "5", "]"}], "+", 
       RowBox[{
        RowBox[{"s1", "[", "5", "]"}], " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"-", "11"}], "+", 
          RowBox[{"x", "[", "6", "]"}]}], ")"}]}], "+", 
       RowBox[{
        RowBox[{"s2", "[", "5", "]"}], " ", 
        SuperscriptBox[
         RowBox[{"(", 
          RowBox[{
           RowBox[{"-", "11"}], "+", 
           RowBox[{"x", "[", "6", "]"}]}], ")"}], "2"]}], "+", 
       RowBox[{
        RowBox[{"s3", "[", "5", "]"}], " ", 
        SuperscriptBox[
         RowBox[{"(", 
          RowBox[{
           RowBox[{"-", "11"}], "+", 
           RowBox[{"x", "[", "6", "]"}]}], ")"}], "3"]}]}], "\[Equal]", 
      RowBox[{"y", "[", "6", "]"}]}]},
    {
     RowBox[{
      RowBox[{
       RowBox[{"s1", "[", "2", "]"}], "+", 
       RowBox[{"2", " ", 
        RowBox[{"s2", "[", "2", "]"}], " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"-", "2"}], "+", 
          RowBox[{"x", "[", "2", "]"}]}], ")"}]}], "+", 
       RowBox[{"3", " ", 
        RowBox[{"s3", "[", "2", "]"}], " ", 
        SuperscriptBox[
         RowBox[{"(", 
          RowBox[{
           RowBox[{"-", "2"}], "+", 
           RowBox[{"x", "[", "2", "]"}]}], ")"}], "2"]}]}], "\[Equal]", 
      RowBox[{
       RowBox[{"s1", "[", "1", "]"}], "+", 
       RowBox[{"2", " ", 
        RowBox[{"s2", "[", "1", "]"}], " ", 
        RowBox[{"x", "[", "2", "]"}]}], "+", 
       RowBox[{"3", " ", 
        RowBox[{"s3", "[", "1", "]"}], " ", 
        SuperscriptBox[
         RowBox[{"x", "[", "2", "]"}], "2"]}]}]}]},
    {
     RowBox[{
      RowBox[{
       RowBox[{"s1", "[", "3", "]"}], "+", 
       RowBox[{"2", " ", 
        RowBox[{"s2", "[", "3", "]"}], " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"-", "5"}], "+", 
          RowBox[{"x", "[", "3", "]"}]}], ")"}]}], "+", 
       RowBox[{"3", " ", 
        RowBox[{"s3", "[", "3", "]"}], " ", 
        SuperscriptBox[
         RowBox[{"(", 
          RowBox[{
           RowBox[{"-", "5"}], "+", 
           RowBox[{"x", "[", "3", "]"}]}], ")"}], "2"]}]}], "\[Equal]", 
      RowBox[{
       RowBox[{"s1", "[", "2", "]"}], "+", 
       RowBox[{"2", " ", 
        RowBox[{"s2", "[", "2", "]"}], " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"-", "2"}], "+", 
          RowBox[{"x", "[", "3", "]"}]}], ")"}]}], "+", 
       RowBox[{"3", " ", 
        RowBox[{"s3", "[", "2", "]"}], " ", 
        SuperscriptBox[
         RowBox[{"(", 
          RowBox[{
           RowBox[{"-", "2"}], "+", 
           RowBox[{"x", "[", "3", "]"}]}], ")"}], "2"]}]}]}]},
    {
     RowBox[{
      RowBox[{
       RowBox[{"s1", "[", "4", "]"}], "+", 
       RowBox[{"2", " ", 
        RowBox[{"s2", "[", "4", "]"}], " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"-", "9"}], "+", 
          RowBox[{"x", "[", "4", "]"}]}], ")"}]}], "+", 
       RowBox[{"3", " ", 
        RowBox[{"s3", "[", "4", "]"}], " ", 
        SuperscriptBox[
         RowBox[{"(", 
          RowBox[{
           RowBox[{"-", "9"}], "+", 
           RowBox[{"x", "[", "4", "]"}]}], ")"}], "2"]}]}], "\[Equal]", 
      RowBox[{
       RowBox[{"s1", "[", "3", "]"}], "+", 
       RowBox[{"2", " ", 
        RowBox[{"s2", "[", "3", "]"}], " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"-", "5"}], "+", 
          RowBox[{"x", "[", "4", "]"}]}], ")"}]}], "+", 
       RowBox[{"3", " ", 
        RowBox[{"s3", "[", "3", "]"}], " ", 
        SuperscriptBox[
         RowBox[{"(", 
          RowBox[{
           RowBox[{"-", "5"}], "+", 
           RowBox[{"x", "[", "4", "]"}]}], ")"}], "2"]}]}]}]},
    {
     RowBox[{
      RowBox[{
       RowBox[{"s1", "[", "5", "]"}], "+", 
       RowBox[{"2", " ", 
        RowBox[{"s2", "[", "5", "]"}], " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"-", "11"}], "+", 
          RowBox[{"x", "[", "5", "]"}]}], ")"}]}], "+", 
       RowBox[{"3", " ", 
        RowBox[{"s3", "[", "5", "]"}], " ", 
        SuperscriptBox[
         RowBox[{"(", 
          RowBox[{
           RowBox[{"-", "11"}], "+", 
           RowBox[{"x", "[", "5", "]"}]}], ")"}], "2"]}]}], "\[Equal]", 
      RowBox[{
       RowBox[{"s1", "[", "4", "]"}], "+", 
       RowBox[{"2", " ", 
        RowBox[{"s2", "[", "4", "]"}], " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"-", "9"}], "+", 
          RowBox[{"x", "[", "5", "]"}]}], ")"}]}], "+", 
       RowBox[{"3", " ", 
        RowBox[{"s3", "[", "4", "]"}], " ", 
        SuperscriptBox[
         RowBox[{"(", 
          RowBox[{
           RowBox[{"-", "9"}], "+", 
           RowBox[{"x", "[", "5", "]"}]}], ")"}], "2"]}]}]}]},
    {
     RowBox[{
      RowBox[{
       RowBox[{"2", " ", 
        RowBox[{"s2", "[", "2", "]"}]}], "+", 
       RowBox[{"6", " ", 
        RowBox[{"s3", "[", "2", "]"}], " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"-", "2"}], "+", 
          RowBox[{"x", "[", "2", "]"}]}], ")"}]}]}], "\[Equal]", 
      RowBox[{
       RowBox[{"2", " ", 
        RowBox[{"s2", "[", "1", "]"}]}], "+", 
       RowBox[{"6", " ", 
        RowBox[{"s3", "[", "1", "]"}], " ", 
        RowBox[{"x", "[", "2", "]"}]}]}]}]},
    {
     RowBox[{
      RowBox[{
       RowBox[{"2", " ", 
        RowBox[{"s2", "[", "3", "]"}]}], "+", 
       RowBox[{"6", " ", 
        RowBox[{"s3", "[", "3", "]"}], " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"-", "5"}], "+", 
          RowBox[{"x", "[", "3", "]"}]}], ")"}]}]}], "\[Equal]", 
      RowBox[{
       RowBox[{"2", " ", 
        RowBox[{"s2", "[", "2", "]"}]}], "+", 
       RowBox[{"6", " ", 
        RowBox[{"s3", "[", "2", "]"}], " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"-", "2"}], "+", 
          RowBox[{"x", "[", "3", "]"}]}], ")"}]}]}]}]},
    {
     RowBox[{
      RowBox[{
       RowBox[{"2", " ", 
        RowBox[{"s2", "[", "4", "]"}]}], "+", 
       RowBox[{"6", " ", 
        RowBox[{"s3", "[", "4", "]"}], " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"-", "9"}], "+", 
          RowBox[{"x", "[", "4", "]"}]}], ")"}]}]}], "\[Equal]", 
      RowBox[{
       RowBox[{"2", " ", 
        RowBox[{"s2", "[", "3", "]"}]}], "+", 
       RowBox[{"6", " ", 
        RowBox[{"s3", "[", "3", "]"}], " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"-", "5"}], "+", 
          RowBox[{"x", "[", "4", "]"}]}], ")"}]}]}]}]},
    {
     RowBox[{
      RowBox[{
       RowBox[{"2", " ", 
        RowBox[{"s2", "[", "5", "]"}]}], "+", 
       RowBox[{"6", " ", 
        RowBox[{"s3", "[", "5", "]"}], " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"-", "11"}], "+", 
          RowBox[{"x", "[", "5", "]"}]}], ")"}]}]}], "\[Equal]", 
      RowBox[{
       RowBox[{"2", " ", 
        RowBox[{"s2", "[", "4", "]"}]}], "+", 
       RowBox[{"6", " ", 
        RowBox[{"s3", "[", "4", "]"}], " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"-", "9"}], "+", 
          RowBox[{"x", "[", "5", "]"}]}], ")"}]}]}]}]},
    {
     RowBox[{
      RowBox[{
       RowBox[{"2", " ", 
        RowBox[{"s2", "[", "1", "]"}]}], "+", 
       RowBox[{"6", " ", 
        RowBox[{"s3", "[", "1", "]"}], " ", 
        RowBox[{"x", "[", "1", "]"}]}]}], "\[Equal]", "0"}]},
    {
     RowBox[{
      RowBox[{
       RowBox[{"2", " ", 
        RowBox[{"s2", "[", "5", "]"}]}], "+", 
       RowBox[{"6", " ", 
        RowBox[{"s3", "[", "5", "]"}], " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"-", "11"}], "+", 
          RowBox[{"x", "[", "6", "]"}]}], ")"}]}]}], "\[Equal]", "0"}]}
   },
   DefaultBaseStyle->"Column",
   GridBoxAlignment->{"Columns" -> {{Left}}},
   GridBoxItemSize->{"Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}],
  "Column"]], "Output",
 CellChangeTimes->{3.577700202764336*^9}]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Part II", "Section",
 CellChangeTimes->{{3.481257998609375*^9, 3.481257999875*^9}, {
   3.48125838840625*^9, 3.48125841678125*^9}, {3.48133765459375*^9, 
   3.481337701859375*^9}, {3.4855832109375*^9, 3.48558321753125*^9}, {
   3.485584935421875*^9, 3.48558493609375*^9}, 3.4866520700107718`*^9, 
   3.486652121680141*^9, {3.5726816864042706`*^9, 3.572681686708288*^9}},
 FontSize->36,
 FontColor->RGBColor[0, 0, 1],
 Background->RGBColor[1, 0.9, 0.8],
 CellTags->"Part B"],

Cell["\<\
We solve the system using the numerical values fot the points\
\>", "Text",
 CellChangeTimes->{{3.481258428046875*^9, 3.481258430125*^9}, {
   3.481258611578125*^9, 3.48125869225*^9}, {3.4855839986875*^9, 
   3.485584087015625*^9}, {3.48558412878125*^9, 3.485584136015625*^9}, 
   3.486220289556675*^9, {3.48636342111878*^9, 3.486363432393417*^9}, {
   3.4869026539047823`*^9, 3.486902655419804*^9}, {3.560442024823437*^9, 
   3.560442045649098*^9}, {3.560442292215493*^9, 3.560442294476576*^9}},
 Background->GrayLevel[0.85]],

Cell[BoxData[
 RowBox[{
  RowBox[{"pointrule", "=", 
   RowBox[{"Flatten", "[", 
    RowBox[{"Table", "[", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{
        RowBox[{
         RowBox[{"x", "[", "i", "]"}], "\[Rule]", 
         RowBox[{"xpoints", "[", 
          RowBox[{"[", "i", "]"}], "]"}]}], ",", 
        RowBox[{
         RowBox[{"y", "[", "i", "]"}], "\[Rule]", 
         RowBox[{"ypoints", "[", 
          RowBox[{"[", "i", "]"}], "]"}]}]}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{"i", ",", "numpoints"}], "}"}]}], "]"}], "]"}]}], 
  ";"}]], "Input",
 CellChangeTimes->{
  3.481025800453125*^9, 3.48102862415625*^9, {3.481253057953125*^9, 
   3.481253067421875*^9}, {3.48125848153125*^9, 3.481258482109375*^9}, {
   3.486475254829937*^9, 3.486475367140348*^9}, {3.486475602303331*^9, 
   3.486475606790205*^9}, {3.486475731145455*^9, 3.486475764426319*^9}, {
   3.4864758123348618`*^9, 3.486475816267816*^9}, {3.486476352228588*^9, 
   3.486476369016283*^9}, {3.486476415942169*^9, 3.4864764199709377`*^9}, {
   3.486476584765547*^9, 3.4864766053888493`*^9}, {3.486476652953957*^9, 
   3.4864766639058943`*^9}, {3.486476700748397*^9, 3.4864767185256233`*^9}, 
   3.486476908096891*^9, {3.560442332362879*^9, 3.56044234040553*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"solution", "=", 
   RowBox[{"Solve", "[", 
    RowBox[{"equaz", "/.", "pointrule"}], "]"}]}], ";", 
  RowBox[{
   RowBox[{"solution", "[", 
    RowBox[{"[", "1", "]"}], "]"}], "//", "Column"}]}]], "Input",
 CellChangeTimes->{{3.48137244821875*^9, 3.481372501875*^9}, 
   3.485610128140625*^9, {3.4856101671875*^9, 3.48561020996875*^9}, {
   3.48613080131485*^9, 3.486130849820629*^9}, {3.4864758547805147`*^9, 
   3.4864758690279303`*^9}, {3.486476948475902*^9, 3.48647695904475*^9}, {
   3.486476999921118*^9, 3.486477014309394*^9}, {3.4867379814588823`*^9, 
   3.486737986668706*^9}, {3.560442343781273*^9, 3.56044234796222*^9}, {
   3.560442405716942*^9, 3.560442438534679*^9}}],

Cell[BoxData[
 TagBox[GridBox[{
    {
     RowBox[{
      RowBox[{"s0", "[", "1", "]"}], "\[Rule]", "0"}]},
    {
     RowBox[{
      RowBox[{"s0", "[", "2", "]"}], "\[Rule]", "2"}]},
    {
     RowBox[{
      RowBox[{"s0", "[", "3", "]"}], "\[Rule]", "3"}]},
    {
     RowBox[{
      RowBox[{"s0", "[", "4", "]"}], "\[Rule]", "5"}]},
    {
     RowBox[{
      RowBox[{"s0", "[", "5", "]"}], "\[Rule]", "2"}]},
    {
     RowBox[{
      RowBox[{"s2", "[", "1", "]"}], "\[Rule]", "0"}]},
    {
     RowBox[{
      RowBox[{"s1", "[", "1", "]"}], "\[Rule]", 
      FractionBox["1350", "1133"]}]},
    {
     RowBox[{
      RowBox[{"s1", "[", "2", "]"}], "\[Rule]", 
      FractionBox["699", "1133"]}]},
    {
     RowBox[{
      RowBox[{"s3", "[", "1", "]"}], "\[Rule]", 
      RowBox[{"-", 
       FractionBox["217", "4532"]}]}]},
    {
     RowBox[{
      RowBox[{"s2", "[", "2", "]"}], "\[Rule]", 
      RowBox[{"-", 
       FractionBox["651", "2266"]}]}]},
    {
     RowBox[{
      RowBox[{"s1", "[", "3", "]"}], "\[Rule]", 
      FractionBox["1423", "2266"]}]},
    {
     RowBox[{
      RowBox[{"s3", "[", "2", "]"}], "\[Rule]", 
      FractionBox["3931", "61182"]}]},
    {
     RowBox[{
      RowBox[{"s2", "[", "3", "]"}], "\[Rule]", 
      FractionBox["989", "3399"]}]},
    {
     RowBox[{
      RowBox[{"s1", "[", "4", "]"}], "\[Rule]", 
      RowBox[{"-", 
       FractionBox["6253", "6798"]}]}]},
    {
     RowBox[{
      RowBox[{"s3", "[", "3", "]"}], "\[Rule]", 
      RowBox[{"-", 
       FractionBox["4391", "54384"]}]}]},
    {
     RowBox[{
      RowBox[{"s2", "[", "4", "]"}], "\[Rule]", 
      RowBox[{"-", 
       FractionBox["9217", "13596"]}]}]},
    {
     RowBox[{
      RowBox[{"s1", "[", "5", "]"}], "\[Rule]", 
      RowBox[{"-", 
       FractionBox["1478", "1133"]}]}]},
    {
     RowBox[{
      RowBox[{"s3", "[", "4", "]"}], "\[Rule]", 
      FractionBox["5273", "27192"]}]},
    {
     RowBox[{
      RowBox[{"s2", "[", "5", "]"}], "\[Rule]", 
      FractionBox["3301", "6798"]}]},
    {
     RowBox[{
      RowBox[{"s3", "[", "5", "]"}], "\[Rule]", 
      RowBox[{"-", 
       FractionBox["3301", "61182"]}]}]}
   },
   DefaultBaseStyle->"Column",
   GridBoxAlignment->{"Columns" -> {{Left}}},
   GridBoxItemSize->{"Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}],
  "Column"]], "Output",
 CellChangeTimes->{3.5777002029759073`*^9}]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Part III", "Section",
 CellChangeTimes->{{3.481257998609375*^9, 3.481257999875*^9}, {
  3.48125838840625*^9, 3.48125841678125*^9}, {3.48133765459375*^9, 
  3.481337701859375*^9}, {3.4855832109375*^9, 3.48558321753125*^9}, {
  3.485584935421875*^9, 3.48558493609375*^9}, {3.48558568240625*^9, 
  3.485585683046875*^9}, {3.572681687564337*^9, 3.572681688596396*^9}},
 FontSize->36,
 FontColor->RGBColor[0, 0, 1],
 Background->RGBColor[1, 0.9, 0.8],
 CellTags->"Part C"],

Cell["We construct the polynomial representation on each domain", "Text",
 CellChangeTimes->{{3.56045298682974*^9, 3.560452998170805*^9}},
 Background->GrayLevel[0.85]],

Cell[BoxData[
 RowBox[{
  RowBox[{"Spline", "[", 
   RowBox[{"i_", ",", "x_"}], "]"}], ":=", 
  RowBox[{
   RowBox[{"Splinek", "[", 
    RowBox[{"i", ",", "x"}], "]"}], "/.", 
   RowBox[{"Flatten", "[", "solution", "]"}]}]}]], "Input",
 CellChangeTimes->{{3.478864388375*^9, 3.4788644106875*^9}, {
   3.48136997090625*^9, 3.481370036875*^9}, {3.481370352015625*^9, 
   3.48137039659375*^9}, {3.481370456953125*^9, 3.48137048196875*^9}, {
   3.481370537609375*^9, 3.481370538359375*^9}, {3.485581646671875*^9, 
   3.485581659984375*^9}, 3.48558238965625*^9, 3.485599660765625*^9, {
   3.4866502735700808`*^9, 3.486650281382329*^9}, {3.48665034982545*^9, 
   3.486650383486067*^9}, {3.4866504400677223`*^9, 3.486650476918561*^9}, 
   3.486650525287737*^9, 3.486650586764394*^9, {3.560453060160716*^9, 
   3.560453064682354*^9}, {3.560453114045724*^9, 3.560453141884013*^9}, {
   3.560453335521559*^9, 3.560453338881849*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"Table", "[", 
   RowBox[{
    RowBox[{"Spline", "[", 
     RowBox[{"i", ",", "x"}], "]"}], ",", 
    RowBox[{"{", 
     RowBox[{"i", ",", 
      RowBox[{"numpoints", "-", "2"}]}], "}"}]}], "]"}], "//", 
  "Column"}]], "Input",
 CellChangeTimes->{{3.486648764645464*^9, 3.486648800347858*^9}, {
  3.486650607179964*^9, 3.486650612811702*^9}, {3.486651254235032*^9, 
  3.486651257778431*^9}, {3.560453118730633*^9, 3.560453122298453*^9}, {
  3.560453161486095*^9, 3.560453210341862*^9}}],

Cell[BoxData[
 TagBox[GridBox[{
    {
     RowBox[{
      FractionBox[
       RowBox[{"1350", " ", "x"}], "1133"], "-", 
      FractionBox[
       RowBox[{"217", " ", 
        SuperscriptBox["x", "3"]}], "4532"]}]},
    {
     RowBox[{"2", "+", 
      FractionBox[
       RowBox[{"699", " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"-", "2"}], "+", "x"}], ")"}]}], "1133"], "-", 
      FractionBox[
       RowBox[{"651", " ", 
        SuperscriptBox[
         RowBox[{"(", 
          RowBox[{
           RowBox[{"-", "2"}], "+", "x"}], ")"}], "2"]}], "2266"], "+", 
      FractionBox[
       RowBox[{"3931", " ", 
        SuperscriptBox[
         RowBox[{"(", 
          RowBox[{
           RowBox[{"-", "2"}], "+", "x"}], ")"}], "3"]}], "61182"]}]},
    {
     RowBox[{"3", "+", 
      FractionBox[
       RowBox[{"1423", " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"-", "5"}], "+", "x"}], ")"}]}], "2266"], "+", 
      FractionBox[
       RowBox[{"989", " ", 
        SuperscriptBox[
         RowBox[{"(", 
          RowBox[{
           RowBox[{"-", "5"}], "+", "x"}], ")"}], "2"]}], "3399"], "-", 
      FractionBox[
       RowBox[{"4391", " ", 
        SuperscriptBox[
         RowBox[{"(", 
          RowBox[{
           RowBox[{"-", "5"}], "+", "x"}], ")"}], "3"]}], "54384"]}]},
    {
     RowBox[{"5", "-", 
      FractionBox[
       RowBox[{"6253", " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"-", "9"}], "+", "x"}], ")"}]}], "6798"], "-", 
      FractionBox[
       RowBox[{"9217", " ", 
        SuperscriptBox[
         RowBox[{"(", 
          RowBox[{
           RowBox[{"-", "9"}], "+", "x"}], ")"}], "2"]}], "13596"], "+", 
      FractionBox[
       RowBox[{"5273", " ", 
        SuperscriptBox[
         RowBox[{"(", 
          RowBox[{
           RowBox[{"-", "9"}], "+", "x"}], ")"}], "3"]}], "27192"]}]}
   },
   DefaultBaseStyle->"Column",
   GridBoxAlignment->{"Columns" -> {{Left}}},
   GridBoxItemSize->{"Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}],
  "Column"]], "Output",
 CellChangeTimes->{3.577700203246364*^9}]
}, Open  ]],

Cell["We check the interpolation conditions", "Text",
 CellChangeTimes->{{3.560453260280023*^9, 3.560453270012649*^9}, 
   3.560453678545815*^9},
 Background->GrayLevel[0.85]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Table", "[", 
  RowBox[{
   RowBox[{
    RowBox[{"Spline", "[", 
     RowBox[{"i", ",", 
      RowBox[{"xpoints", "[", 
       RowBox[{"[", "i", "]"}], "]"}]}], "]"}], "\[Equal]", 
    RowBox[{"ypoints", "[", 
     RowBox[{"[", "i", "]"}], "]"}]}], ",", 
   RowBox[{"{", 
    RowBox[{"i", ",", 
     RowBox[{"numpoints", "-", "1"}]}], "}"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.486648764645464*^9, 3.486648800347858*^9}, {
  3.486650607179964*^9, 3.486650612811702*^9}, {3.48665065459324*^9, 
  3.4866507073940077`*^9}, {3.560453239308821*^9, 3.560453255780783*^9}}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"True", ",", "True", ",", "True", ",", "True", ",", "True"}], 
  "}"}]], "Output",
 CellChangeTimes->{3.577700203305666*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Table", "[", 
  RowBox[{
   RowBox[{
    RowBox[{"Spline", "[", 
     RowBox[{"i", ",", 
      RowBox[{"xpoints", "[", 
       RowBox[{"[", 
        RowBox[{"i", "+", "1"}], "]"}], "]"}]}], "]"}], "\[Equal]", 
    RowBox[{"ypoints", "[", 
     RowBox[{"[", 
      RowBox[{"i", "+", "1"}], "]"}], "]"}]}], ",", 
   RowBox[{"{", 
    RowBox[{"i", ",", 
     RowBox[{"numpoints", "-", "1"}]}], "}"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.486648764645464*^9, 3.486648800347858*^9}, {
  3.486650607179964*^9, 3.486650612811702*^9}, {3.48665065459324*^9, 
  3.4866507073940077`*^9}, {3.486650746338719*^9, 3.48665074699219*^9}, {
  3.560453282016647*^9, 3.560453294966141*^9}}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"True", ",", "True", ",", "True", ",", "True", ",", "True"}], 
  "}"}]], "Output",
 CellChangeTimes->{3.577700203332713*^9}]
}, Open  ]],

Cell["We reconstruct the interpolating spline", "Text",
 CellChangeTimes->{{3.481258169046875*^9, 3.481258191015625*^9}, {
  3.4812589095625*^9, 3.48125891409375*^9}, {3.485583333921875*^9, 
  3.4855834316875*^9}, {3.48619287126575*^9, 3.486192877139627*^9}, {
  3.4867394848399982`*^9, 3.486739500179656*^9}, {3.560453299399889*^9, 
  3.560453332550001*^9}},
 Background->GrayLevel[0.85]],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"S", "[", "x_", "]"}], "=", 
   RowBox[{"Sum", "[", 
    RowBox[{
     RowBox[{
      RowBox[{"Spline", "[", 
       RowBox[{"i", ",", "x"}], "]"}], "*", 
      RowBox[{"(", 
       RowBox[{"If", "[", 
        RowBox[{
         RowBox[{
          RowBox[{"xpoints", "[", 
           RowBox[{"[", "i", "]"}], "]"}], "\[LessEqual]", " ", "x", " ", 
          "\[LessEqual]", " ", 
          RowBox[{"xpoints", "[", 
           RowBox[{"[", 
            RowBox[{"i", "+", "1"}], "]"}], "]"}]}], ",", "1", ",", "0"}], 
        "]"}], ")"}]}], ",", 
     RowBox[{"{", 
      RowBox[{"i", ",", "1", ",", 
       RowBox[{"numpoints", "-", "1"}]}], "}"}]}], "]"}]}], ";"}]], "Input",
 CellChangeTimes->{{3.478864388375*^9, 3.4788644106875*^9}, {
   3.48137068846875*^9, 3.481370755921875*^9}, {3.48557936578125*^9, 
   3.48557936625*^9}, {3.48558166575*^9, 3.485581668421875*^9}, 
   3.485599661890625*^9, {3.486739292292282*^9, 3.486739295276779*^9}, {
   3.4867395395208597`*^9, 3.48673954364093*^9}, {3.486739770190029*^9, 
   3.486739772614367*^9}, {3.560453348357019*^9, 3.560453353061451*^9}}],

Cell["And plot the result", "Text",
 CellChangeTimes->{{3.481258169046875*^9, 3.481258191015625*^9}, {
  3.4812589095625*^9, 3.48125891409375*^9}, {3.485583333921875*^9, 
  3.4855834316875*^9}, {3.48619287126575*^9, 3.486192877139627*^9}, {
  3.4867394848399982`*^9, 3.486739500179656*^9}, {3.560453299399889*^9, 
  3.560453332550001*^9}, {3.56045337054767*^9, 3.560453374716021*^9}},
 Background->GrayLevel[0.85]],

Cell[BoxData[
 RowBox[{
  RowBox[{"graspline", "=", 
   RowBox[{"Plot", "[", 
    RowBox[{
     RowBox[{"S", "[", "x", "]"}], ",", 
     RowBox[{"{", 
      RowBox[{"x", ",", 
       RowBox[{"xpoints", "[", 
        RowBox[{"[", "1", "]"}], "]"}], ",", 
       RowBox[{"xpoints", "[", 
        RowBox[{"[", "numpoints", "]"}], "]"}]}], "}"}]}], "]"}]}], 
  ";"}]], "Input",
 CellChangeTimes->{
  3.478176561*^9, {3.47886444053125*^9, 3.4788644661875*^9}, {
   3.48137080265625*^9, 3.48137082796875*^9}, {3.4813708694375*^9, 
   3.481370875625*^9}, {3.48557936825*^9, 3.48557936871875*^9}, {
   3.485586639046875*^9, 3.485586652265625*^9}, 3.48559966340625*^9, {
   3.560453382768798*^9, 3.560453517499179*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Show", "[", 
  RowBox[{"graspline", ",", "grapoints"}], "]"}]], "Input",
 CellChangeTimes->{{3.560453469645726*^9, 3.56045351043243*^9}}],

Cell[BoxData[
 GraphicsBox[{{{}, {}, 
    {Hue[0.67, 0.6, 0.6], LineBox[CompressedData["
1:eJwVl3k8VO8Xx80wtsg2kyXLNbZZypa1xXMq2ZLsIVokkiWkFCppobJviULK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      "]]}}, {{}, 
    {RGBColor[0.24720000000000014`, 0.24, 0.6], PointSize[Medium], 
     PointBox[{{0., 0.}, {2., 2.}, {5., 3.}, {9., 5.}, {11., 2.}, {14., 
      1.}}]}, {}}},
  AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
  Axes->True,
  AxesLabel->{None, None},
  AxesOrigin->{0, 0},
  Method->{},
  PlotRange->{{0, 14}, {0., 5.343383491656324}},
  PlotRangeClipping->True,
  PlotRangePadding->{
    Scaled[0.02], 
    Scaled[0.02]}]], "Output",
 CellChangeTimes->{
  3.5777002034287367`*^9},ImageCache->GraphicsData["CompressedBitmap", "\<\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\
\>"]]
}, Open  ]]
}, Open  ]]
},
AutoGeneratedPackage->None,
WindowSize->{1438, 813},
WindowMargins->{{0, Automatic}, {Automatic, 0}},
PrintingCopies->1,
PrintingPageRange->{1, Automatic},
PrintingOptions->{"PrintCellBrackets"->True,
"PrintMultipleHorizontalPages"->False,
"PrintRegistrationMarks"->True,
"PrintingMargins"->{{54, 54}, {54, 54}}},
ShowSelection->True,
Magnification->1.5,
FrontEndVersion->"9.0 for Linux x86 (64-bit) (January 25, 2013)",
StyleDefinitions->"Default.nb"
]
(* End of Notebook Content *)

(* Internal cache information *)
(*CellTagsOutline
CellTagsIndex->{
 "Part A"->{
  Cell[17948, 449, 382, 8, 141, "Section",
   CellTags->"Part A"]},
 "Part B"->{
  Cell[55956, 1626, 479, 9, 141, "Section",
   CellTags->"Part B"]},
 "Part C"->{
  Cell[61398, 1790, 473, 9, 141, "Section",
   CellTags->"Part C"]}
 }
*)
(*CellTagsIndex
CellTagsIndex->{
 {"Part A", 97055, 2509},
 {"Part B", 97136, 2512},
 {"Part C", 97218, 2515}
 }
*)
(*NotebookFileOutline
Notebook[{
Cell[557, 20, 213, 7, 132, "Text"],
Cell[773, 29, 4073, 107, 930, "Text"],
Cell[CellGroupData[{
Cell[4871, 140, 453, 8, 45, "Input"],
Cell[5327, 150, 468, 10, 33, "Message"]
}, Open  ]],
Cell[CellGroupData[{
Cell[5832, 165, 100, 1, 45, "Input"],
Cell[5935, 168, 124, 2, 45, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[6096, 175, 118, 2, 45, "Input"],
Cell[6217, 179, 196, 5, 45, "Output"]
}, Open  ]],
Cell[6428, 187, 1022, 24, 45, "Input"],
Cell[CellGroupData[{
Cell[7475, 215, 442, 7, 45, "Input"],
Cell[7920, 224, 70, 1, 45, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[8027, 230, 502, 10, 45, "Input"],
Cell[8532, 242, 5259, 93, 375, 448, 12, "CachedBoxData", "BoxData", "Output"]
}, Open  ]],
Cell[13806, 338, 97, 1, 70, "Text"],
Cell[13906, 341, 656, 15, 45, "Input"],
Cell[14565, 358, 390, 8, 70, "Text"],
Cell[14958, 368, 1330, 33, 76, "Input"],
Cell[16291, 403, 1180, 27, 47, "Input"],
Cell[17474, 432, 449, 13, 45, "Input"],
Cell[CellGroupData[{
Cell[17948, 449, 382, 8, 141, "Section",
 CellTags->"Part A"],
Cell[18333, 459, 1102, 35, 251, "Text"],
Cell[CellGroupData[{
Cell[19460, 498, 767, 18, 45, "Input"],
Cell[20230, 518, 3876, 123, 166, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[24143, 646, 832, 20, 45, "Input"],
Cell[24978, 668, 3878, 123, 166, "Output"]
}, Open  ]],
Cell[28871, 794, 266, 4, 70, "Text"],
Cell[29140, 800, 249, 6, 45, "Input"],
Cell[29392, 808, 431, 8, 70, "Text"],
Cell[CellGroupData[{
Cell[29848, 820, 981, 23, 75, "Input"],
Cell[30832, 845, 4202, 129, 136, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[35071, 979, 981, 23, 75, "Input"],
Cell[36055, 1004, 2617, 84, 120, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[38709, 1093, 678, 12, 45, "Input"],
Cell[39390, 1107, 71, 1, 45, "Output"]
}, Open  ]],
Cell[39476, 1111, 419, 8, 70, "Text"],
Cell[39898, 1121, 927, 23, 45, "Input"],
Cell[40828, 1146, 407, 6, 70, "Text"],
Cell[CellGroupData[{
Cell[41260, 1156, 270, 5, 45, "Input"],
Cell[41533, 1163, 14374, 457, 591, "Output"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[55956, 1626, 479, 9, 141, "Section",
 CellTags->"Part B"],
Cell[56438, 1637, 536, 9, 70, "Text"],
Cell[56977, 1648, 1255, 28, 45, "Input"],
Cell[CellGroupData[{
Cell[58257, 1680, 716, 14, 45, "Input"],
Cell[58976, 1696, 2373, 88, 712, "Output"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[61398, 1790, 473, 9, 141, "Section",
 CellTags->"Part C"],
Cell[61874, 1801, 168, 2, 70, "Text"],
Cell[62045, 1805, 922, 17, 45, "Input"],
Cell[CellGroupData[{
Cell[62992, 1826, 520, 13, 45, "Input"],
Cell[63515, 1841, 2105, 71, 196, "Output"]
}, Open  ]],
Cell[65635, 1915, 175, 3, 70, "Text"],
Cell[CellGroupData[{
Cell[65835, 1922, 595, 15, 45, "Input"],
Cell[66433, 1939, 163, 4, 45, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[66633, 1948, 699, 18, 45, "Input"],
Cell[67335, 1968, 163, 4, 45, "Output"]
}, Open  ]],
Cell[67513, 1975, 389, 6, 70, "Text"],
Cell[67905, 1983, 1137, 28, 45, "Input"],
Cell[69045, 2013, 414, 6, 70, "Text"],
Cell[69462, 2021, 710, 18, 45, "Input"],
Cell[CellGroupData[{
Cell[70197, 2043, 161, 3, 45, "Input"],
Cell[70361, 2048, 26102, 438, 405, 11415, 195, "CachedBoxData", "BoxData", \
"Output"]
}, Open  ]]
}, Open  ]]
}
]
*)

(* End of internal cache information *)
