(* Content-type: application/mathematica *)

(*** Wolfram Notebook File ***)
(* http://www.wolfram.com/nb *)

(* CreatedBy='Mathematica 7.0' *)

(*CacheID: 234*)
(* Internal cache information:
NotebookFileLineBreakTest
NotebookFileLineBreakTest
NotebookDataPosition[       145,          7]
NotebookDataLength[     86737,       1595]
NotebookOptionsPosition[     85304,       1544]
NotebookOutlinePosition[     85670,       1560]
CellTagsIndexPosition[     85627,       1557]
WindowFrame->Normal*)

(* Beginning of Notebook Content *)
Notebook[{
Cell["\<\
This nb examines how  the ouput  of a second order linear system
depends on the natural frequency \[Omega]n, the damping factor  \[Zeta] and 
the Initial Conditions.\
\>", "Text",
 CellChangeTimes->{{3.489579710921875*^9, 3.489579718984375*^9}, {
  3.489579754421875*^9, 3.4895798570625*^9}, {3.489579910328125*^9, 
  3.48957998371875*^9}},
 FontSize->24,
 Background->RGBColor[0.9, 1, 1]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"Remove", "[", "\"\<Global`*\>\"", "]"}], ";", 
  RowBox[{"$Line", "=", "0"}]}]], "Input",
 CellChangeTimes->{{3.489406524234375*^9, 3.48940656078125*^9}, 
   3.48940662253125*^9},
 FontSize->24],

Cell[BoxData[
 RowBox[{
  StyleBox[
   RowBox[{"Remove", "::", "rmnsm"}], "MessageName"], 
  RowBox[{
  ":", " "}], "\<\"There are no symbols matching \
\\\"\[NoBreak]\\!\\(\\\"Global`*\\\"\\)\[NoBreak]\\\". \
\\!\\(\\*ButtonBox[\\\"\[RightSkeleton]\\\", ButtonStyle->\\\"Link\\\", \
ButtonFrame->None, ButtonData:>\\\"paclet:ref/message/Remove/rmnsm\\\", \
ButtonNote -> \\\"Remove::rmnsm\\\"]\\)\"\>"}]], "Message", "MSG",
 CellChangeTimes->{3.571984202329719*^9}],

Cell[BoxData["0"], "Output",
 CellChangeTimes->{
  3.489645870859375*^9, 3.489646028171875*^9, 3.5719143032263393`*^9, 
   3.571918630244955*^9, 3.5719227411721897`*^9, 3.571922907540358*^9, 
   3.5719808430973167`*^9, {3.571980956704764*^9, 3.5719809728560457`*^9}, 
   3.5719828318658533`*^9, 3.571984202537649*^9}]
}, Open  ]],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"SetOptions", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"Plot", ",", "ListPlot"}], "}"}], ",", 
     RowBox[{"ImageSize", "\[Rule]", "600"}], ",", "\[IndentingNewLine]", 
     "                      ", 
     RowBox[{"LabelStyle", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"FontFamily", "\[Rule]", "\"\<Helvetica\>\""}], ",", "Red", 
        ",", 
        RowBox[{"FontSize", "\[Rule]", "32"}]}], "}"}]}], ",", 
     "\[IndentingNewLine]", "                     ", 
     RowBox[{"AxesStyle", "\[Rule]", 
      RowBox[{"Directive", "[", 
       RowBox[{"24", ",", 
        RowBox[{"Thickness", "[", "0.005", "]"}], ",", "Blue"}], "]"}]}]}], 
    "]"}], ";"}], "\[IndentingNewLine]"}]], "Input",
 CellChangeTimes->{{3.571893688446418*^9, 3.571893720823801*^9}, {
  3.571893769281314*^9, 3.571893778333867*^9}, {3.571897057593268*^9, 
  3.571897058441244*^9}, {3.571897120614431*^9, 3.571897124212874*^9}, {
  3.571897252876203*^9, 3.5718972925170116`*^9}, {3.571897380576166*^9, 
  3.571897381622324*^9}, {3.571897598970675*^9, 3.57189760324011*^9}, {
  3.571897659591607*^9, 3.571897660968927*^9}, {3.571912117646233*^9, 
  3.571912118586385*^9}, {3.5719155776674633`*^9, 3.571915578126437*^9}, {
  3.571982853999198*^9, 3.571982861140841*^9}},
 FontSize->18,
 Background->RGBColor[1, 1, 0.85]],

Cell[CellGroupData[{

Cell["\<\
Subcase 2 :  \[Zeta]  < 1    (eq. 5.3.26)\
\>", "Text",
 CellChangeTimes->{{3.489572376234375*^9, 3.4895724029375*^9}, {
  3.489572459359375*^9, 3.489572464203125*^9}, {3.4895725311875*^9, 
  3.4895725530625*^9}},
 FontSize->24,
 Background->RGBColor[0.87, 0.94, 1]],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{
   SubscriptBox["x", "0"], "=", " ", ".1"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   SubscriptBox[
    OverscriptBox["x", "."], "0"], "=", " ", "1.2"}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"f", "=", " ", "2"}], ";"}]}], "Input",
 CellChangeTimes->{{3.489406629609375*^9, 3.489406707953125*^9}, 
   3.489407198859375*^9, {3.489407245078125*^9, 3.48940730809375*^9}, {
   3.4894075081875*^9, 3.489407547046875*^9}, {3.48940764034375*^9, 
   3.4894076799375*^9}, {3.489407850390625*^9, 3.48940792928125*^9}, {
   3.489408413328125*^9, 3.48940854975*^9}, {3.489410501703125*^9, 
   3.489410595671875*^9}, {3.48941080159375*^9, 3.48941083984375*^9}, {
   3.48941086996875*^9, 3.4894111024375*^9}, {3.4894111731875*^9, 
   3.489411200296875*^9}, {3.489411234859375*^9, 3.489411291078125*^9}, {
   3.489411338328125*^9, 3.489411343484375*^9}, {3.489573098734375*^9, 
   3.489573109421875*^9}, {3.48957314178125*^9, 3.489573161421875*^9}, 
   3.4895732151875*^9, {3.4895735858125*^9, 3.489573589609375*^9}, {
   3.489574040453125*^9, 3.489574218890625*^9}, {3.489574292*^9, 
   3.48957431290625*^9}, {3.4895750045625*^9, 3.489575071890625*^9}, {
   3.4895751250625*^9, 3.489575159515625*^9}, {3.4895752841875*^9, 
   3.489575311734375*^9}, {3.489575369359375*^9, 3.489575450546875*^9}, {
   3.489575554578125*^9, 3.489575597171875*^9}, {3.4895784145*^9, 
   3.48957842446875*^9}, {3.4896458286875*^9, 3.48964583646875*^9}, {
   3.48964591390625*^9, 3.48964591453125*^9}, {3.571914047443334*^9, 
   3.571914166441094*^9}, 3.57191423163223*^9, {3.571915812613641*^9, 
   3.571915813836206*^9}},
 FontSize->24],

Cell[BoxData[
 RowBox[{
  RowBox[{"\[Zeta]", " ", "=", "0.3"}], ";"}]], "Input",
 CellChangeTimes->{{3.489406629609375*^9, 3.489406707953125*^9}, 
   3.489407198859375*^9, {3.489407245078125*^9, 3.48940730809375*^9}, {
   3.4894075081875*^9, 3.489407547046875*^9}, {3.48940764034375*^9, 
   3.4894076799375*^9}, {3.489407850390625*^9, 3.48940792928125*^9}, {
   3.489408413328125*^9, 3.48940854975*^9}, {3.489410501703125*^9, 
   3.489410595671875*^9}, {3.48941080159375*^9, 3.48941083984375*^9}, {
   3.48941086996875*^9, 3.4894111024375*^9}, {3.4894111731875*^9, 
   3.489411200296875*^9}, {3.489411234859375*^9, 3.489411291078125*^9}, {
   3.489411338328125*^9, 3.489411343484375*^9}, {3.489573098734375*^9, 
   3.489573109421875*^9}, {3.48957314178125*^9, 3.489573161421875*^9}, 
   3.4895732151875*^9, {3.4895735858125*^9, 3.489573589609375*^9}, {
   3.489574040453125*^9, 3.489574218890625*^9}, {3.489574292*^9, 
   3.48957431290625*^9}, {3.4895750045625*^9, 3.489575071890625*^9}, {
   3.4895751250625*^9, 3.489575159515625*^9}, {3.4895752841875*^9, 
   3.489575311734375*^9}, {3.489575369359375*^9, 3.489575450546875*^9}, {
   3.489575554578125*^9, 3.489575597171875*^9}, {3.4895784145*^9, 
   3.48957842446875*^9}, {3.4896458286875*^9, 3.48964583646875*^9}, {
   3.48964591390625*^9, 3.48964591453125*^9}, {3.571914047443334*^9, 
   3.571914166441094*^9}, {3.57191423163223*^9, 3.5719142349877872`*^9}},
 FontSize->24],

Cell[BoxData[
 RowBox[{
  RowBox[{
   SubscriptBox["\[Omega]", "n"], " ", "=", " ", 
   RowBox[{"2", " ", "\[Pi]", " ", "f"}]}], ";"}]], "Input",
 CellChangeTimes->{{3.489406629609375*^9, 3.489406707953125*^9}, 
   3.489407198859375*^9, {3.489407245078125*^9, 3.48940730809375*^9}, {
   3.4894075081875*^9, 3.489407547046875*^9}, {3.48940764034375*^9, 
   3.4894076799375*^9}, {3.489407850390625*^9, 3.48940792928125*^9}, {
   3.489408413328125*^9, 3.48940854975*^9}, {3.489410501703125*^9, 
   3.489410595671875*^9}, {3.48941080159375*^9, 3.48941083984375*^9}, {
   3.48941086996875*^9, 3.4894111024375*^9}, {3.4894111731875*^9, 
   3.489411200296875*^9}, {3.489411234859375*^9, 3.489411291078125*^9}, {
   3.489411338328125*^9, 3.489411343484375*^9}, {3.489573098734375*^9, 
   3.489573109421875*^9}, {3.48957314178125*^9, 3.489573161421875*^9}, 
   3.4895732151875*^9, {3.4895735858125*^9, 3.489573589609375*^9}, {
   3.489574040453125*^9, 3.489574218890625*^9}, {3.489574292*^9, 
   3.48957431290625*^9}, {3.4895750045625*^9, 3.489575071890625*^9}, {
   3.4895751250625*^9, 3.489575159515625*^9}, {3.4895752841875*^9, 
   3.489575311734375*^9}, {3.489575369359375*^9, 3.489575450546875*^9}, {
   3.489575554578125*^9, 3.489575597171875*^9}, {3.4895784145*^9, 
   3.48957842446875*^9}, {3.4896458286875*^9, 3.48964583646875*^9}, {
   3.48964591390625*^9, 3.48964591453125*^9}, {3.571914047443334*^9, 
   3.571914166441094*^9}, {3.57191423163223*^9, 3.5719142349877872`*^9}},
 FontSize->24],

Cell[BoxData[
 RowBox[{
  RowBox[{"K1", "=", 
   SubscriptBox["x", "0"]}], ";"}]], "Input",
 CellChangeTimes->{{3.489406629609375*^9, 3.489406707953125*^9}, 
   3.489407198859375*^9, {3.489407245078125*^9, 3.48940730809375*^9}, {
   3.4894075081875*^9, 3.489407547046875*^9}, {3.48940764034375*^9, 
   3.4894076799375*^9}, {3.489407850390625*^9, 3.48940792928125*^9}, {
   3.489408413328125*^9, 3.48940854975*^9}, {3.489410501703125*^9, 
   3.489410595671875*^9}, {3.48941080159375*^9, 3.48941083984375*^9}, {
   3.48941086996875*^9, 3.4894111024375*^9}, {3.4894111731875*^9, 
   3.489411200296875*^9}, {3.489411234859375*^9, 3.489411291078125*^9}, {
   3.489411338328125*^9, 3.489411343484375*^9}, {3.489573098734375*^9, 
   3.489573109421875*^9}, {3.48957314178125*^9, 3.489573161421875*^9}, 
   3.4895732151875*^9, {3.4895735858125*^9, 3.489573589609375*^9}, {
   3.489574040453125*^9, 3.489574218890625*^9}, {3.489574292*^9, 
   3.48957431290625*^9}, {3.4895750045625*^9, 3.489575071890625*^9}, {
   3.4895751250625*^9, 3.489575159515625*^9}, {3.4895752841875*^9, 
   3.489575311734375*^9}, {3.489575369359375*^9, 3.489575450546875*^9}, {
   3.489575554578125*^9, 3.489575597171875*^9}, {3.4895784145*^9, 
   3.48957842446875*^9}, {3.4896458286875*^9, 3.48964583646875*^9}, {
   3.48964591390625*^9, 3.48964591453125*^9}, {3.571914047443334*^9, 
   3.571914166441094*^9}, {3.57191423163223*^9, 3.5719142412575502`*^9}, 
   3.5719143157863073`*^9},
 FontSize->24],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"K2", "=", 
  FractionBox[
   RowBox[{
    SubscriptBox[
     OverscriptBox["x", "."], "0"], "+", 
    RowBox[{"\[Zeta]", " ", 
     SubscriptBox["\[Omega]", "n"], 
     SubscriptBox["x", "0"], " "}]}], 
   RowBox[{
    SubscriptBox["\[Omega]", "n"], 
    SqrtBox[
     RowBox[{"1", "-", 
      SuperscriptBox["\[Zeta]", "2"]}]]}]]}]], "Input",
 CellChangeTimes->{{3.489406629609375*^9, 3.489406707953125*^9}, 
   3.489407198859375*^9, {3.489407245078125*^9, 3.48940730809375*^9}, {
   3.4894075081875*^9, 3.489407547046875*^9}, {3.48940764034375*^9, 
   3.4894076799375*^9}, {3.489407850390625*^9, 3.48940792928125*^9}, {
   3.489408413328125*^9, 3.48940854975*^9}, {3.489410501703125*^9, 
   3.489410595671875*^9}, {3.48941080159375*^9, 3.48941083984375*^9}, {
   3.48941086996875*^9, 3.4894111024375*^9}, {3.4894111731875*^9, 
   3.489411200296875*^9}, {3.489411234859375*^9, 3.489411291078125*^9}, {
   3.489411338328125*^9, 3.489411343484375*^9}, {3.489573098734375*^9, 
   3.489573109421875*^9}, {3.48957314178125*^9, 3.489573161421875*^9}, 
   3.4895732151875*^9, {3.4895735858125*^9, 3.489573589609375*^9}, {
   3.489574040453125*^9, 3.489574218890625*^9}, {3.489574292*^9, 
   3.48957431290625*^9}, {3.4895750045625*^9, 3.489575071890625*^9}, {
   3.4895751250625*^9, 3.489575159515625*^9}, {3.4895752841875*^9, 
   3.489575311734375*^9}, {3.489575369359375*^9, 3.489575450546875*^9}, {
   3.489575554578125*^9, 3.489575597171875*^9}, {3.4895784145*^9, 
   3.48957842446875*^9}, {3.4896458286875*^9, 3.48964583646875*^9}, {
   3.48964591390625*^9, 3.48964591453125*^9}, {3.571914047443334*^9, 
   3.571914166441094*^9}, {3.57191423163223*^9, 3.5719142412575502`*^9}},
 FontSize->24],

Cell[BoxData["0.13155237322120175`"], "Output",
 CellChangeTimes->{{3.57191432129309*^9, 3.571914333165689*^9}, 
   3.5719155871978493`*^9, 3.571915822001211*^9, 3.5719186307319527`*^9, 
   3.571922741454097*^9, 3.5719229077568197`*^9, 3.5719808432586803`*^9, {
   3.57198095683379*^9, 3.571980972993147*^9}, 3.5719828320439987`*^9, 
   3.57198420274457*^9}]
}, Open  ]],

Cell[BoxData[
 RowBox[{
  RowBox[{"X", "=", " ", 
   SqrtBox[
    RowBox[{
     SuperscriptBox["K1", "2"], " ", "+", " ", 
     SuperscriptBox["K2", "2"]}]]}], ";"}]], "Input",
 CellChangeTimes->{{3.489406629609375*^9, 3.489406707953125*^9}, 
   3.489407198859375*^9, {3.489407245078125*^9, 3.48940730809375*^9}, {
   3.4894075081875*^9, 3.489407547046875*^9}, {3.48940764034375*^9, 
   3.4894076799375*^9}, {3.489407850390625*^9, 3.48940792928125*^9}, {
   3.489408413328125*^9, 3.48940854975*^9}, {3.489410501703125*^9, 
   3.489410595671875*^9}, {3.48941080159375*^9, 3.48941083984375*^9}, {
   3.48941086996875*^9, 3.4894111024375*^9}, {3.4894111731875*^9, 
   3.489411200296875*^9}, {3.489411234859375*^9, 3.489411291078125*^9}, {
   3.489411338328125*^9, 3.489411343484375*^9}, {3.489573098734375*^9, 
   3.489573109421875*^9}, {3.48957314178125*^9, 3.489573161421875*^9}, 
   3.4895732151875*^9, {3.4895735858125*^9, 3.489573589609375*^9}, {
   3.489574040453125*^9, 3.489574218890625*^9}, {3.489574292*^9, 
   3.48957431290625*^9}, {3.4895750045625*^9, 3.489575071890625*^9}, {
   3.4895751250625*^9, 3.489575159515625*^9}, {3.4895752841875*^9, 
   3.489575311734375*^9}, {3.489575369359375*^9, 3.489575450546875*^9}, {
   3.489575554578125*^9, 3.489575597171875*^9}, {3.4895784145*^9, 
   3.48957842446875*^9}, {3.4896458286875*^9, 3.48964583646875*^9}, {
   3.48964591390625*^9, 3.48964591453125*^9}, {3.571914047443334*^9, 
   3.571914166441094*^9}, {3.57191423163223*^9, 3.571914250879212*^9}},
 FontSize->24],

Cell[BoxData[
 RowBox[{
  RowBox[{"\[Phi]", " ", "=", " ", 
   RowBox[{"ArcTan", "[", 
    FractionBox["K2", "K1"], "]"}]}], ";"}]], "Input",
 CellChangeTimes->{{3.489406629609375*^9, 3.489406707953125*^9}, 
   3.489407198859375*^9, {3.489407245078125*^9, 3.48940730809375*^9}, {
   3.4894075081875*^9, 3.489407547046875*^9}, {3.48940764034375*^9, 
   3.4894076799375*^9}, {3.489407850390625*^9, 3.48940792928125*^9}, {
   3.489408413328125*^9, 3.48940854975*^9}, {3.489410501703125*^9, 
   3.489410595671875*^9}, {3.48941080159375*^9, 3.48941083984375*^9}, {
   3.48941086996875*^9, 3.4894111024375*^9}, {3.4894111731875*^9, 
   3.489411200296875*^9}, {3.489411234859375*^9, 3.489411291078125*^9}, {
   3.489411338328125*^9, 3.489411343484375*^9}, {3.489573098734375*^9, 
   3.489573109421875*^9}, {3.48957314178125*^9, 3.489573161421875*^9}, 
   3.4895732151875*^9, {3.4895735858125*^9, 3.489573589609375*^9}, {
   3.489574040453125*^9, 3.489574218890625*^9}, {3.489574292*^9, 
   3.48957431290625*^9}, {3.4895750045625*^9, 3.489575071890625*^9}, {
   3.4895751250625*^9, 3.489575159515625*^9}, {3.4895752841875*^9, 
   3.489575311734375*^9}, {3.489575369359375*^9, 3.489575450546875*^9}, {
   3.489575554578125*^9, 3.489575597171875*^9}, {3.4895784145*^9, 
   3.48957842446875*^9}, {3.4896458286875*^9, 3.48964583646875*^9}, {
   3.48964591390625*^9, 3.48964591453125*^9}, {3.571914047443334*^9, 
   3.571914166441094*^9}, {3.57191423163223*^9, 3.571914268782106*^9}},
 FontSize->24],

Cell[BoxData[""], "Input",
 CellChangeTimes->{{3.489406629609375*^9, 3.489406707953125*^9}, 
   3.489407198859375*^9, {3.489407245078125*^9, 3.48940730809375*^9}, {
   3.4894075081875*^9, 3.489407547046875*^9}, {3.48940764034375*^9, 
   3.4894076799375*^9}, {3.489407850390625*^9, 3.48940792928125*^9}, {
   3.489408413328125*^9, 3.48940854975*^9}, {3.489410501703125*^9, 
   3.489410595671875*^9}, {3.48941080159375*^9, 3.48941083984375*^9}, {
   3.48941086996875*^9, 3.4894111024375*^9}, {3.4894111731875*^9, 
   3.489411200296875*^9}, {3.489411234859375*^9, 3.489411291078125*^9}, {
   3.489411338328125*^9, 3.489411343484375*^9}, {3.489573098734375*^9, 
   3.489573109421875*^9}, {3.48957314178125*^9, 3.489573161421875*^9}, 
   3.4895732151875*^9, {3.4895735858125*^9, 3.489573589609375*^9}, {
   3.489574040453125*^9, 3.489574218890625*^9}, {3.489574292*^9, 
   3.48957431290625*^9}, {3.4895750045625*^9, 3.489575071890625*^9}, {
   3.4895751250625*^9, 3.489575159515625*^9}, {3.4895752841875*^9, 
   3.489575311734375*^9}, {3.489575369359375*^9, 3.489575450546875*^9}, {
   3.489575554578125*^9, 3.489575597171875*^9}, {3.4895784145*^9, 
   3.48957842446875*^9}, {3.4896458286875*^9, 3.48964583646875*^9}, {
   3.48964591390625*^9, 3.48964591453125*^9}, {3.571914047443334*^9, 
   3.571914166441094*^9}, {3.57191423163223*^9, 3.571914268782106*^9}, 
   3.571922729750557*^9},
 FontSize->24],

Cell[BoxData[
 RowBox[{
  RowBox[{"g2", "[", "t_", "]"}], ":=", " ", 
  RowBox[{"X", " ", 
   RowBox[{"Exp", "[", 
    RowBox[{
     RowBox[{"-", " ", "\[Zeta]"}], " ", 
     SubscriptBox["\[Omega]", "n"], " ", "t"}], "]"}], 
   RowBox[{"Cos", "[", 
    RowBox[{
     RowBox[{
      SqrtBox[
       RowBox[{"1", "-", 
        SuperscriptBox["\[Zeta]", "2"]}]], " ", 
      SubscriptBox["\[Omega]", "n"], " ", "t"}], "  ", "-", " ", "\[Phi]"}], 
    " ", "]"}]}]}]], "Input",
 CellChangeTimes->{{3.489406629609375*^9, 3.489406707953125*^9}, 
   3.489407198859375*^9, {3.489407245078125*^9, 3.48940730809375*^9}, {
   3.4894075081875*^9, 3.489407547046875*^9}, {3.48940764034375*^9, 
   3.4894076799375*^9}, {3.489407850390625*^9, 3.48940792928125*^9}, {
   3.489408413328125*^9, 3.48940854975*^9}, {3.489410501703125*^9, 
   3.489410595671875*^9}, {3.48941080159375*^9, 3.48941083984375*^9}, {
   3.48941086996875*^9, 3.4894111024375*^9}, {3.4894111731875*^9, 
   3.489411200296875*^9}, {3.489411234859375*^9, 3.489411291078125*^9}, {
   3.489411338328125*^9, 3.489411343484375*^9}, {3.489573098734375*^9, 
   3.489573109421875*^9}, {3.48957314178125*^9, 3.489573161421875*^9}, 
   3.4895732151875*^9, {3.4895735858125*^9, 3.489573589609375*^9}, {
   3.489574040453125*^9, 3.489574218890625*^9}, {3.489574292*^9, 
   3.48957431290625*^9}, {3.4895750045625*^9, 3.489575071890625*^9}, {
   3.4895751250625*^9, 3.489575159515625*^9}, {3.4895752841875*^9, 
   3.489575311734375*^9}, {3.489575369359375*^9, 3.489575450546875*^9}, {
   3.489575554578125*^9, 3.489575597171875*^9}, {3.4895784145*^9, 
   3.48957842446875*^9}, {3.4896458286875*^9, 3.48964583646875*^9}, {
   3.48964591390625*^9, 3.48964591453125*^9}, {3.571914047443334*^9, 
   3.571914166441094*^9}, {3.57191423163223*^9, 3.571914268782106*^9}, 
   3.571922729750557*^9},
 FontSize->24],

Cell[BoxData[""], "Input",
 CellChangeTimes->{{3.489406629609375*^9, 3.489406707953125*^9}, 
   3.489407198859375*^9, {3.489407245078125*^9, 3.48940730809375*^9}, {
   3.4894075081875*^9, 3.489407547046875*^9}, {3.48940764034375*^9, 
   3.4894076799375*^9}, {3.489407850390625*^9, 3.48940792928125*^9}, {
   3.489408413328125*^9, 3.48940854975*^9}, {3.489410501703125*^9, 
   3.489410595671875*^9}, {3.48941080159375*^9, 3.48941083984375*^9}, {
   3.48941086996875*^9, 3.4894111024375*^9}, {3.4894111731875*^9, 
   3.489411200296875*^9}, {3.489411234859375*^9, 3.489411291078125*^9}, {
   3.489411338328125*^9, 3.489411343484375*^9}, {3.489573098734375*^9, 
   3.489573109421875*^9}, {3.48957314178125*^9, 3.489573161421875*^9}, 
   3.4895732151875*^9, {3.4895735858125*^9, 3.489573589609375*^9}, {
   3.489574040453125*^9, 3.489574218890625*^9}, {3.489574292*^9, 
   3.48957431290625*^9}, {3.4895750045625*^9, 3.489575071890625*^9}, {
   3.4895751250625*^9, 3.489575159515625*^9}, {3.4895752841875*^9, 
   3.489575311734375*^9}, {3.489575369359375*^9, 3.489575450546875*^9}, {
   3.489575554578125*^9, 3.489575597171875*^9}, {3.4895784145*^9, 
   3.48957842446875*^9}, {3.4896458286875*^9, 3.48964583646875*^9}, {
   3.48964591390625*^9, 3.48964591453125*^9}, {3.571914047443334*^9, 
   3.571914166441094*^9}, {3.57191423163223*^9, 3.571914268782106*^9}, 
   3.571922729750557*^9},
 FontSize->24],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"gra2", " ", "=", 
  RowBox[{"Plot", "[", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{
      RowBox[{"g2", "[", "t", "]"}], ",", " ", 
      RowBox[{"X", " ", 
       RowBox[{"Exp", "[", 
        RowBox[{
         RowBox[{"-", " ", "\[Zeta]"}], " ", 
         SubscriptBox["\[Omega]", "n"], "t"}], "]"}]}], ",", " ", 
      RowBox[{
       RowBox[{"-", "X"}], " ", 
       RowBox[{"Exp", "[", 
        RowBox[{
         RowBox[{"-", " ", "\[Zeta]"}], " ", 
         SubscriptBox["\[Omega]", "n"], " ", "t"}], "]"}]}]}], "}"}], ",", 
    "\[IndentingNewLine]", "                          ", 
    RowBox[{"{", 
     RowBox[{"t", ",", 
      RowBox[{"-", "0"}], ",", "1.05"}], "}"}], ",", 
    RowBox[{"ImageSize", "\[Rule]", 
     RowBox[{"{", 
      RowBox[{"800", ",", "800"}], "}"}]}], ",", "\[IndentingNewLine]", 
    "                      ", 
    RowBox[{"AxesLabel", "\[Rule]", 
     RowBox[{"{", " ", 
      RowBox[{"\"\<t [s]\>\"", ",", " ", "\"\<amp [m]\>\""}], "  ", "}"}]}], 
    ",", 
    RowBox[{"PlotRange", "\[Rule]", "All"}], ",", "\[IndentingNewLine]", 
    RowBox[{"Epilog", "\[Rule]", " ", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"Text", "[", 
        RowBox[{
         RowBox[{"Style", "[", 
          RowBox[{
          "\"\<X Exp[- \[Zeta] \!\(\*SubscriptBox[\(\[Omega]\), \(n\)]\) t]\>\
\"", ",", "30", ",", "Red"}], "]"}], ",", 
         RowBox[{"{", 
          RowBox[{"0.3", ",", "0.08"}], "}"}], ",", 
         RowBox[{"{", 
          RowBox[{
           RowBox[{"-", "1"}], ",", "0"}], "}"}]}], "]"}], ",", 
       "\[IndentingNewLine]", 
       RowBox[{"Text", "[", 
        RowBox[{
         RowBox[{"Style", "[", 
          RowBox[{
          "\"\<X Exp[- \[Zeta] \!\(\*SubscriptBox[\(\[Omega]\), \(n\)]\) t]\>\
\"", ",", "30", ",", "Red"}], "]"}], ",", 
         RowBox[{"{", 
          RowBox[{"0.3", ",", 
           RowBox[{"-", "0.08"}]}], "}"}], ",", 
         RowBox[{"{", 
          RowBox[{
           RowBox[{"-", "1"}], ",", "0"}], "}"}]}], "]"}]}], "}"}]}], ",", 
    "\[IndentingNewLine]", " ", 
    RowBox[{"PlotStyle", " ", "\[Rule]", " ", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"Thickness", "[", "0.004", "]"}], ",", "\[IndentingNewLine]", 
       RowBox[{"{", 
        RowBox[{"Red", ",", 
         RowBox[{"Thickness", "[", "0.004", "]"}], ",", 
         RowBox[{"Dashing", "[", "Large", "]"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"Red", ",", 
         RowBox[{"Thickness", "[", "0.004", "]"}], ",", 
         RowBox[{"Dashing", "[", "Large", "]"}]}], "}"}]}], "}"}]}], ",", 
    "\[IndentingNewLine]", 
    RowBox[{"PlotLabel", "\[Rule]", 
     RowBox[{"Style", "[", 
      RowBox[{
      "\"\<  X Exp[- \[Zeta] \!\(\*SubscriptBox[\(\[Omega]\), \(n\)]\) t]Cos[\
\!\(\*SqrtBox[\(1 - \*SuperscriptBox[\(\[Zeta]\), \(2\)]\)]\) \
\!\(\*SubscriptBox[\(\[Omega]\), \(n\)]\) t  - \[Phi] ]  \>\"", ",", "Blue", 
       ",", "32"}], "]"}]}]}], "]"}]}]], "Input",
 CellChangeTimes->{{3.489406629609375*^9, 3.489406707953125*^9}, 
   3.489407198859375*^9, {3.489407245078125*^9, 3.48940730809375*^9}, {
   3.4894075081875*^9, 3.489407547046875*^9}, {3.48940764034375*^9, 
   3.4894076799375*^9}, {3.489407850390625*^9, 3.48940792928125*^9}, {
   3.489408413328125*^9, 3.48940854975*^9}, {3.489410501703125*^9, 
   3.489410595671875*^9}, {3.48941080159375*^9, 3.48941083984375*^9}, {
   3.48941086996875*^9, 3.4894111024375*^9}, {3.4894111731875*^9, 
   3.489411200296875*^9}, {3.489411234859375*^9, 3.489411291078125*^9}, {
   3.489411338328125*^9, 3.489411343484375*^9}, {3.489573098734375*^9, 
   3.489573109421875*^9}, {3.48957314178125*^9, 3.489573161421875*^9}, 
   3.4895732151875*^9, {3.4895735858125*^9, 3.489573589609375*^9}, {
   3.489574040453125*^9, 3.489574218890625*^9}, {3.489574292*^9, 
   3.48957431290625*^9}, {3.4895750045625*^9, 3.489575071890625*^9}, {
   3.4895751250625*^9, 3.489575159515625*^9}, {3.4895752841875*^9, 
   3.489575311734375*^9}, {3.489575369359375*^9, 3.489575450546875*^9}, {
   3.489575554578125*^9, 3.489575597171875*^9}, {3.4895784145*^9, 
   3.48957842446875*^9}, {3.4896458286875*^9, 3.48964583646875*^9}, {
   3.48964591390625*^9, 3.48964591453125*^9}, {3.571914047443334*^9, 
   3.571914166441094*^9}, {3.57191423163223*^9, 3.5719142870147247`*^9}, {
   3.57191436974296*^9, 3.57191437944411*^9}, {3.571914435760189*^9, 
   3.57191446645907*^9}, {3.571914507609153*^9, 3.57191457601192*^9}, {
   3.571914722030469*^9, 3.571914726262465*^9}, {3.5719155266328373`*^9, 
   3.5719155633320637`*^9}, {3.571918265334527*^9, 3.5719183234512873`*^9}, {
   3.571918379584146*^9, 3.5719184271995296`*^9}, {3.5719227902206163`*^9, 
   3.5719227918891363`*^9}, {3.571980756515984*^9, 3.571980769236607*^9}, {
   3.5719809496749353`*^9, 3.571980969957985*^9}, {3.571982819816807*^9, 
   3.571982821526575*^9}, {3.571984183536949*^9, 3.571984193325449*^9}},
 FontSize->18],

Cell[BoxData[
 GraphicsBox[{{}, {}, 
   {Hue[0.67, 0.6, 0.6], Thickness[0.004], LineBox[CompressedData["
1:eJwVl3c8le8bxyUUSUqJSGkgqxKF4lJGVkgokhXKyN7HigiZJ7PsdY6Znaz7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     "]]}, 
   {RGBColor[1, 0, 0], Thickness[0.004], Dashing[Large], 
    LineBox[CompressedData["
1:eJwVkHk4lAkAhx21K0mrVZlpXYnGsaIlHczPlkpFYuUorSNm85mNUY5MGixP
SlpXKGVEiFQ2Z4nGDKFypeTK0ZgsjfElZAu79o/3ef98n+fV9PJ38JGRkpKy
XeR/T8uaFFjIONOXFW7y4uvUQy953XW9daZIXMi5YKRRD75lVtocdTdCC9lV
WZR6XE7zuiKiHkanyYsd5xXqMcXfpdxD9UGFLW4wJ+uQ71L6yytqEKZFbKf0
mjpE5DBPtVNjkL5qxsrfpQ7jjdaybdQrkHu9tHE2UQDCbEvMsoVclB/hJWG+
FpTuY28POBVjkMkKGcvigSHXMMJLKkOnxoyZ7LMapIk2reywrALHjN0XZ/8Y
rgeaGsb38GCpHx+10fgRusLCUi11BBBZUlzoSpWwES646c3W44n8rXljnXKU
mUod+vNqIzzaC2zPcUrxnXtkO//Uc1xK+LJQ2PUAHoEcDku1Bbo/fzWpYf4F
B/fbSb1ubXjI1lqes74Y42RbkU9DO4xkvxGtLr6LqM9mx+5SOmC06x/Jp+A7
SBjtd3SLfYU3J347o0QvgEqof6MT+RpxfwioXub5yGDTXypavoHWnuk8w6hc
pBG2WoZFXQjnZH/Oa8jB5ZZr8sulehByJ8Kwdn825lVp2+wCenHWOzPapiUL
75dxhf3dfWjn8R+Wj2fiGeG4wUC/HwJz/yZW5nVsrNhXNJg+gClGboOe3TXg
Md1HN2QQAdG9h6wc0kHzs90cqzYEnYxfuaXRqWhZOZdNfTWEH3ObA9LKU/BR
0tQfF/4OE0qnV3TQktEuMKsxMhUi96p4p3NGIiSMa0fZo0IYtg2Lg00SEGv1
Q92txGHs3RHeqvRvPPrX0tukrUW4mb9vrzglDg+0OfkWkyIUF6mKBiMuQCBd
Zq5+9T22DbAe0TPPI6HjYpDJwRF4qzoRbY9i0DvAOUP7PIIT2z963qdG492Q
suahe3/D96IksjAsCgy1pmQn11ForGCfuKEcCZpuYJ2M9Bgi+tQHWrgc5OlW
pb8rH4P897uDn60Ox01vra03PT7A03tFz4H3YXC9os9OVhGjwGVo5khFKA6m
0M7qN4txpohiyq8JBq/Zyjo7aBx7Xh7N91EIwsScVKWNgQQhgRqBU66nkMHo
m3zdKUHe2NpWuWEWojOLPiw5N4G9O39fOpgQAGWGYl0JhcRsLekdEXYS2tTO
EMeTJAiKW1uHMRMPJle5tviT0B85vulbGhP053bbrVkkVD7Yz1ioMeFytmlu
x2kStl0bKsrkmbjU/zhSK4xElXqGsFnoh6nsnLjJGBKxNQ2D3FQ/1OmzuAk3
SCiqeezjLxCwX3IvQp5LwquH9PSYJtDfN+YZnUWiVmxXLS0mMBvvvSE0h0S1
kDQ72E3AgHQucC8gIdNBVVUsJZBSSi8xLCNBYVvcoREENOPZKbfLSRQ1xft+
8SBwz6cyaH0lCW3lhy6tzgQa12zeuqaKBMPduD5qN4G5UO3qeR4Jv/slFSs1
CVyw98oM4S/+kBt++2UtgTV6XM5HAQnuENVgVJGAUa/KTtHTxT8q28xb53xR
XXJYy72RBEcy8fXpJ1/sv5S0pLuJhONPNgO1Y77o9G4VOTwnYZa6RfRkyBfH
LRQaXrxY7G1MV6jt8sV/bfhiqQ==
     "]]}, 
   {RGBColor[1, 0, 0], Thickness[0.004], Dashing[Large], 
    LineBox[CompressedData["
1:eJwVkHk4lAkcgB21K0mrVZlpiUTjWNGSDuZnS6UisXKU1tGYzWc2RjkyabA8
KWldoZQRIVLZnCV+jBEqjJRcORqTpTG+hGxh1/7xPu+f7/O8Wt7+jj5yMjIy
dov872l50wJLORf6ssLN3nzdBtRPXndDf50ZJC7kXDTWbEC+VVbaHHUPhBZy
qrIoDXglzfuqmHoEOk1f7Lyg1IBT/N2qPVQfqLCDm6xJAea7lv7yihoE02KO
c3qNACNyWKfbqTGQvmrG2t9VgONNNvJC6lVQeL20aTaxHgnzrTHLFnKh/Ght
EszXIaX7+NuDzsUwyGKHjGXVIlOhcaQ2qQw6NWfM5Z/VYJp488oOqyrgmnP6
4hyeoNvB5sbxvbVgZRAftcnkMXaFhaVa6daD2IriSlepRFvRgrv+bAOg4u15
E91yLDOTOfzntSbwbC+wO88txe88Itv5p5/D5YQvC4VdD9EzkMtlq7eC3s9f
TWtYf6Gjx52kXnchPOJoL8/ZUIzjpLDIp7EdjOW/Ea8uvodRn82P36N0gPHu
f6Sfgu9iwmi/k3vsK3hz8rezKvQCVAv1b3ImX0PcH/VUb4t8zODQXypbvQHt
vdN5RlG5mEbYaRsVdUE4N/tzXmMOXmm9rrhcpgdC7kYY1R3Ixnl12nb7gF44
x8iMtm3NwvfLeKL+7j5or+U/Kh/PxGeE00ZDg36ot/BvZmfewE0V+4sG0wdg
ipnbqG9/HeEJ3UcvZBAConsPWzumI83PbkusxhDoZvzKK41OxdaVc9nUV0Pw
Y25LQFp5Cn6UNvfHhb+DCZUzKzpoydheb15jbCaC3GuSXS4ZiShlXj/GGRWB
kXBYEmyagLHWPwhuJw7Dvp3hbSr/xmP/WrpQ1kYMt/L375OkxOFDHW6+5aQY
iovUxYMRF7Fetsxi/bX3sH2A/ZieeQETOi4FmR4aAYa6MyF8HIO9A9yztM8j
cHLHR68H1Gh8N6Sqdfj+3+B7SRpZGBaFTI3mZGe3UdBcwTl5UzUSaXqBAjnZ
MYjoWz/QyuNinl5V+rvyMVD8fk/ws9XheIuhve2W5wfwYqzoOfg+DN2uGnCS
1SRQ4Do0c7QiFA+l0M4ZtEjgbBHFjF8TjLUt1jbZQeOw9+WxfB+lIJyYk6m0
NZRCSKBm4JTbacxg9k2+7pRC3tjaNoVhNkZnFn1Ycn4C9u36felgQgCqMpUF
JRQSZutIRkTYKdShdoY4nSKBoLgLO0xY+HBylVurPwkGIyc2f0tjIf25/Q4b
NglqHxxmLDVY6HqueW7nGRLsujZWlCmy8HL/k0jtMBKq1meIWkR+OJWdEzcZ
Q0JsTeMgL9UPBQZsXsJNEpQ1PPfzFwh0WHI/QpFHgncP6eU5TWB/35hXdBYJ
dRL7alkJgbPxjI2hOSRUi0jzQ90EGpIuBR4FJMh1UNWVSwlMKaWXGJWRQOFY
3qURBGrFc1LulJNQ1Bzv+8WTwPs+lUEbKknQUX3k2uZCYNOaLdvWVJHA9DBp
iNpD4FyoTvV8LQl+D0oqVmoReNHBOzOEv/hDYfjtl7UErtHncT/Wk8AbohqO
KhNo3Ku2S/x08Y/adou2OV+sLjmi7dFEAlc68fXpJ188cDlpSXczCU4/2Q7U
jfliJ6NN7PicBPPUrWIc8sUTlkqNL14s9jalK9V1+eJ/CdyJKQ==
     "]]}},
  AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
  Axes->True,
  AxesLabel->{
    FormBox["\"t [s]\"", TraditionalForm], 
    FormBox["\"amp [m]\"", TraditionalForm]},
  AxesOrigin->{0, 0},
  AxesStyle->Directive[24, 
    Thickness[0.005], 
    RGBColor[0, 0, 1]],
  Epilog->{
    InsetBox[
     FormBox[
      StyleBox[
      "\"X Exp[- \[Zeta] \\!\\(\\*SubscriptBox[\\(\[Omega]\\), \\(n\\)]\\) t]\
\"", 30, 
       RGBColor[1, 0, 0], StripOnInput -> False], TraditionalForm], {0.3, 
     0.08}, {-1, 0}], 
    InsetBox[
     FormBox[
      StyleBox[
      "\"X Exp[- \[Zeta] \\!\\(\\*SubscriptBox[\\(\[Omega]\\), \\(n\\)]\\) t]\
\"", 30, 
       RGBColor[1, 0, 0], StripOnInput -> False], TraditionalForm], {
     0.3, -0.08}, {-1, 0}]},
  ImageSize->{800, 800},
  LabelStyle->{FontFamily -> "Helvetica", 
    RGBColor[1, 0, 0], FontSize -> 32},
  Method->{},
  PlotLabel->FormBox[
    StyleBox[
    "\"  X Exp[- \[Zeta] \\!\\(\\*SubscriptBox[\\(\[Omega]\\), \\(n\\)]\\) \
t]Cos[\\!\\(\\*SqrtBox[\\(1 - \\*SuperscriptBox[\\(\[Zeta]\\), \
\\(2\\)]\\)]\\) \\!\\(\\*SubscriptBox[\\(\[Omega]\\), \\(n\\)]\\) t  - \[Phi] \
]  \"", 
     RGBColor[0, 0, 1], 32, StripOnInput -> False], TraditionalForm],
  PlotRange->{All, All},
  PlotRangeClipping->True,
  PlotRangePadding->{Automatic, Automatic}]], "Output",
 CellChangeTimes->{{3.57191455109726*^9, 3.571914580471896*^9}, 
   3.5719147296588287`*^9, 3.571915587318924*^9, 3.571915822070376*^9, {
   3.571918270475109*^9, 3.571918280553138*^9}, {3.5719183116900043`*^9, 
   3.5719183262990417`*^9}, {3.57191838365383*^9, 3.5719184307798567`*^9}, 
   3.571918630848193*^9, {3.5719227736368723`*^9, 3.571922796446392*^9}, 
   3.5719229078672533`*^9, 3.57198084340878*^9, {3.571980956977105*^9, 
   3.5719809731017447`*^9}, 3.5719828321790247`*^9, 
   3.571984202902965*^9},ImageCache->GraphicsData["CompressedBitmap", "\<\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\
\>"]]
}, Open  ]]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Export", "[", 
  RowBox[{
  "\"\</home/zosi/Book-Mathematica/nb-chap5-Fig/Chap5-Fig-5-9-zetaless1.jpg\>\
\"", ",", " ", "gra2", " ", ",", "\"\<JPG\>\""}], "]"}]], "Input",
 CellChangeTimes->{{3.489572376234375*^9, 3.4895724029375*^9}, {
   3.489572482796875*^9, 3.4895724946875*^9}, 3.4895793945*^9, 
   3.489579443234375*^9, {3.48957950396875*^9, 3.4895795488125*^9}, {
   3.489645409875*^9, 3.4896454715*^9}, {3.571911566667901*^9, 
   3.571911580869019*^9}, {3.5719118673190403`*^9, 3.571911868519342*^9}, {
   3.571912314398628*^9, 3.571912326395692*^9}, {3.5719129307876368`*^9, 
   3.5719129403749743`*^9}, {3.571914699439974*^9, 3.57191470466334*^9}, {
   3.571914736879774*^9, 3.571914737242505*^9}, {3.571918888180777*^9, 
   3.571918889505721*^9}, {3.571980807255822*^9, 3.571980812579556*^9}},
 FontSize->24,
 Background->RGBColor[0.87, 0.94, 1]],

Cell[BoxData["\<\"/home/zosi/Book-Mathematica/nb-chap5-Fig/Chap5-Fig-5-9-\
zetaless1.jpg\"\>"], "Output",
 CellChangeTimes->{
  3.571914745987719*^9, 3.571915596158267*^9, 3.571915831944578*^9, 
   3.571918440656767*^9, 3.571918640920352*^9, 3.57191889745944*^9, 
   3.5719808459393063`*^9, {3.571980957264493*^9, 3.571980973405293*^9}, 
   3.571982834206633*^9, 3.571984205177746*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Export", "[", 
  RowBox[{
  "\"\</home/zosi/Book-Mathematica/nb-chap5-Fig/Chap5-Fig-5-9-zetaless1.pdf\>\
\"", ",", " ", "gra2", " ", ",", "\"\<PDF\>\""}], "]"}]], "Input",
 CellChangeTimes->{{3.489572376234375*^9, 3.4895724029375*^9}, {
   3.489572482796875*^9, 3.4895724946875*^9}, 3.4895793945*^9, 
   3.489579443234375*^9, {3.48957950396875*^9, 3.4895795488125*^9}, {
   3.489645409875*^9, 3.4896454715*^9}, {3.571911566667901*^9, 
   3.571911580869019*^9}, {3.5719118673190403`*^9, 3.571911868519342*^9}, {
   3.571912314398628*^9, 3.571912326395692*^9}, {3.571914710456629*^9, 
   3.5719147402064667`*^9}, {3.5719188924197702`*^9, 3.571918893050078*^9}, {
   3.5719808196151876`*^9, 3.571980828991737*^9}},
 FontSize->24,
 Background->RGBColor[0.87, 0.94, 1]],

Cell[BoxData["\<\"/home/zosi/Book-Mathematica/nb-chap5-Fig/Chap5-Fig-5-9-\
zetaless1.pdf\"\>"], "Output",
 CellChangeTimes->{
  3.5719147480147142`*^9, 3.571915598188301*^9, 3.571915832142638*^9, 
   3.571918442028081*^9, 3.571918647798232*^9, 3.5719188976594467`*^9, 
   3.5719808481372766`*^9, {3.571980957412808*^9, 3.571980973565111*^9}, 
   3.5719828360936832`*^9, 3.5719842071714487`*^9}]
}, Open  ]]
},
CellGrouping->Manual,
WindowSize->{1438, 813},
WindowMargins->{{0, Automatic}, {Automatic, 0}},
FrontEndVersion->"9.0 for Linux x86 (64-bit) (January 25, 2013)",
StyleDefinitions->"Zosi-direi-buono.nb"
]
(* End of Notebook Content *)

(* Internal cache information *)
(*CellTagsOutline
CellTagsIndex->{}
*)
(*CellTagsIndex
CellTagsIndex->{}
*)
(*NotebookFileOutline
Notebook[{
Cell[545, 20, 399, 9, 93, "Text"],
Cell[CellGroupData[{
Cell[969, 33, 229, 6, 33, "Input"],
Cell[1201, 41, 466, 10, 18, "Message"],
Cell[1670, 53, 317, 5, 24, "Output"]
}, Open  ]],
Cell[2002, 61, 1370, 30, 107, "Input"],
Cell[CellGroupData[{
Cell[3397, 95, 276, 7, 44, "Text"],
Cell[CellGroupData[{
Cell[3698, 106, 1668, 31, 90, "Input"],
Cell[5369, 139, 1427, 22, 33, "Input"],
Cell[6799, 163, 1492, 24, 33, "Input"],
Cell[8294, 189, 1466, 24, 33, "Input"],
Cell[CellGroupData[{
Cell[9785, 217, 1714, 33, 91, "Input"],
Cell[11502, 252, 358, 5, 24, "Output"]
}, Open  ]],
Cell[11875, 260, 1521, 26, 50, "Input"],
Cell[13399, 288, 1486, 24, 66, "Input"],
Cell[14888, 314, 1397, 21, 33, "Input"],
Cell[16288, 337, 1845, 36, 58, "Input"],
Cell[18136, 375, 1397, 21, 33, "Input"],
Cell[CellGroupData[{
Cell[19558, 400, 4903, 106, 214, "Input"],
Cell[24464, 508, 58272, 976, 611, 19468, 340, "CachedBoxData", "BoxData", \
"Output"]
}, Open  ]]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[82797, 1491, 881, 15, 45, "Input"],
Cell[83681, 1508, 385, 6, 24, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[84103, 1519, 788, 14, 45, "Input"],
Cell[84894, 1535, 394, 6, 81, "Output"]
}, Open  ]]
}
]
*)

(* End of internal cache information *)
